/**
 * Application Dependency Management API
 * Use the Application Dependency Management API to create knowledge bases and vulnerability audits.  For more information, see [ADM](/Content/application-dependency-management/home.htm).
 * OpenAPI spec version: 20220421
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import common = require("oci-common");
import * as requests from "./request";
import * as responses from "./response";
import { ApplicationDependencyManagementWaiter } from "./applicationdependencymanagement-waiter";
declare const Breaker: any;
export declare enum ApplicationDependencyManagementApiKeys {
}
/**
 * This service client uses {@link common.CircuitBreaker.DefaultConfiguration} for all the operations by default if no circuit breaker configuration is defined by the user.
 */
export declare class ApplicationDependencyManagementClient {
    protected static serviceEndpointTemplate: string;
    protected static endpointServiceName: string;
    protected "_realmSpecificEndpointTemplateEnabled": boolean | undefined;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_waiters": ApplicationDependencyManagementWaiter;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: typeof Breaker | null;
    protected _httpOptions: any;
    protected _bodyDuplexMode: any;
    targetService: string;
    protected _regionId: string;
    protected "_region": common.Region;
    protected _lastSetRegionOrRegionId: string;
    protected _httpClient: common.HttpClient;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    get endpoint(): string;
    /**
     * Sets the endpoint to call (ex, https://www.example.com).
     * @param endpoint The endpoint of the service.
     */
    set endpoint(endpoint: string);
    get logger(): import("oci-common/lib/log").Logger;
    /**
     * Determines whether realm specific endpoint should be used or not.
     * Set realmSpecificEndpointTemplateEnabled to "true" if the user wants to enable use of realm specific endpoint template, otherwise set it to "false"
     * @param realmSpecificEndpointTemplateEnabled flag to enable the use of realm specific endpoint template
     */
    set useRealmSpecificEndpointTemplate(realmSpecificEndpointTemplateEnabled: boolean);
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    set region(region: common.Region);
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    set regionId(regionId: string);
    /**
     * Creates a new ApplicationDependencyManagementWaiter for resources for this service.
     *
     * @param config The waiter configuration for termination and delay strategy
     * @return The service waiters.
     */
    createWaiters(config?: common.WaiterConfiguration): ApplicationDependencyManagementWaiter;
    /**
     * Gets the waiters available for resources for this service.
     *
     * @return The service waiters.
     */
    getWaiters(): ApplicationDependencyManagementWaiter;
    /**
     * Shutdown the circuit breaker used by the client when it is no longer needed
     */
    shutdownCircuitBreaker(): void;
    /**
     * Close the client once it is no longer needed
     */
    close(): void;
    /**
     * Activates the specified Remediation Recipe.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ActivateRemediationRecipeRequest
     * @return ActivateRemediationRecipeResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/adm/ActivateRemediationRecipe.ts.html |here} to see how to use ActivateRemediationRecipe API.
     */
    activateRemediationRecipe(activateRemediationRecipeRequest: requests.ActivateRemediationRecipeRequest): Promise<responses.ActivateRemediationRecipeResponse>;
    /**
     * Cancels the specified remediation run.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CancelRemediationRunRequest
     * @return CancelRemediationRunResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/adm/CancelRemediationRun.ts.html |here} to see how to use CancelRemediationRun API.
     */
    cancelRemediationRun(cancelRemediationRunRequest: requests.CancelRemediationRunRequest): Promise<responses.CancelRemediationRunResponse>;
    /**
     * Cancel work request with the given ID.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CancelWorkRequestRequest
     * @return CancelWorkRequestResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/adm/CancelWorkRequest.ts.html |here} to see how to use CancelWorkRequest API.
     */
    cancelWorkRequest(cancelWorkRequestRequest: requests.CancelWorkRequestRequest): Promise<responses.CancelWorkRequestResponse>;
    /**
     * Moves a Knowledge Base from one compartment to another.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ChangeKnowledgeBaseCompartmentRequest
     * @return ChangeKnowledgeBaseCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/adm/ChangeKnowledgeBaseCompartment.ts.html |here} to see how to use ChangeKnowledgeBaseCompartment API.
     */
    changeKnowledgeBaseCompartment(changeKnowledgeBaseCompartmentRequest: requests.ChangeKnowledgeBaseCompartmentRequest): Promise<responses.ChangeKnowledgeBaseCompartmentResponse>;
    /**
     * Moves a Remediation Recipe from one compartment to another.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ChangeRemediationRecipeCompartmentRequest
     * @return ChangeRemediationRecipeCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/adm/ChangeRemediationRecipeCompartment.ts.html |here} to see how to use ChangeRemediationRecipeCompartment API.
     */
    changeRemediationRecipeCompartment(changeRemediationRecipeCompartmentRequest: requests.ChangeRemediationRecipeCompartmentRequest): Promise<responses.ChangeRemediationRecipeCompartmentResponse>;
    /**
     * Moves a remediation run from one compartment to another.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ChangeRemediationRunCompartmentRequest
     * @return ChangeRemediationRunCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/adm/ChangeRemediationRunCompartment.ts.html |here} to see how to use ChangeRemediationRunCompartment API.
     */
    changeRemediationRunCompartment(changeRemediationRunCompartmentRequest: requests.ChangeRemediationRunCompartmentRequest): Promise<responses.ChangeRemediationRunCompartmentResponse>;
    /**
     * Moves a Vulnerability Audit from one compartment to another.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ChangeVulnerabilityAuditCompartmentRequest
     * @return ChangeVulnerabilityAuditCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/adm/ChangeVulnerabilityAuditCompartment.ts.html |here} to see how to use ChangeVulnerabilityAuditCompartment API.
     */
    changeVulnerabilityAuditCompartment(changeVulnerabilityAuditCompartmentRequest: requests.ChangeVulnerabilityAuditCompartmentRequest): Promise<responses.ChangeVulnerabilityAuditCompartmentResponse>;
    /**
     * Creates a new Knowledge Base.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateKnowledgeBaseRequest
     * @return CreateKnowledgeBaseResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/adm/CreateKnowledgeBase.ts.html |here} to see how to use CreateKnowledgeBase API.
     */
    createKnowledgeBase(createKnowledgeBaseRequest: requests.CreateKnowledgeBaseRequest): Promise<responses.CreateKnowledgeBaseResponse>;
    /**
     * Creates a new Remediation Recipe.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateRemediationRecipeRequest
     * @return CreateRemediationRecipeResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/adm/CreateRemediationRecipe.ts.html |here} to see how to use CreateRemediationRecipe API.
     */
    createRemediationRecipe(createRemediationRecipeRequest: requests.CreateRemediationRecipeRequest): Promise<responses.CreateRemediationRecipeResponse>;
    /**
     * Creates a new remediation run.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateRemediationRunRequest
     * @return CreateRemediationRunResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/adm/CreateRemediationRun.ts.html |here} to see how to use CreateRemediationRun API.
     */
    createRemediationRun(createRemediationRunRequest: requests.CreateRemediationRunRequest): Promise<responses.CreateRemediationRunResponse>;
    /**
     * Creates a new Vulnerability Audit by providing a tree of Application Dependencies.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateVulnerabilityAuditRequest
     * @return CreateVulnerabilityAuditResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/adm/CreateVulnerabilityAudit.ts.html |here} to see how to use CreateVulnerabilityAudit API.
     */
    createVulnerabilityAudit(createVulnerabilityAuditRequest: requests.CreateVulnerabilityAuditRequest): Promise<responses.CreateVulnerabilityAuditResponse>;
    /**
     * Deactivates the specified Remediation Recipe.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeactivateRemediationRecipeRequest
     * @return DeactivateRemediationRecipeResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/adm/DeactivateRemediationRecipe.ts.html |here} to see how to use DeactivateRemediationRecipe API.
     */
    deactivateRemediationRecipe(deactivateRemediationRecipeRequest: requests.DeactivateRemediationRecipeRequest): Promise<responses.DeactivateRemediationRecipeResponse>;
    /**
     * Deletes the specified Knowledge Base.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteKnowledgeBaseRequest
     * @return DeleteKnowledgeBaseResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/adm/DeleteKnowledgeBase.ts.html |here} to see how to use DeleteKnowledgeBase API.
     */
    deleteKnowledgeBase(deleteKnowledgeBaseRequest: requests.DeleteKnowledgeBaseRequest): Promise<responses.DeleteKnowledgeBaseResponse>;
    /**
     * Deletes the specified Remediation Recipe.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteRemediationRecipeRequest
     * @return DeleteRemediationRecipeResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/adm/DeleteRemediationRecipe.ts.html |here} to see how to use DeleteRemediationRecipe API.
     */
    deleteRemediationRecipe(deleteRemediationRecipeRequest: requests.DeleteRemediationRecipeRequest): Promise<responses.DeleteRemediationRecipeResponse>;
    /**
     * Deletes the specified remediation run.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteRemediationRunRequest
     * @return DeleteRemediationRunResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/adm/DeleteRemediationRun.ts.html |here} to see how to use DeleteRemediationRun API.
     */
    deleteRemediationRun(deleteRemediationRunRequest: requests.DeleteRemediationRunRequest): Promise<responses.DeleteRemediationRunResponse>;
    /**
     * Deletes the specified Vulnerability Audit.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteVulnerabilityAuditRequest
     * @return DeleteVulnerabilityAuditResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/adm/DeleteVulnerabilityAudit.ts.html |here} to see how to use DeleteVulnerabilityAudit API.
     */
    deleteVulnerabilityAudit(deleteVulnerabilityAuditRequest: requests.DeleteVulnerabilityAuditRequest): Promise<responses.DeleteVulnerabilityAuditResponse>;
    /**
     * Returns the details of the specified Knowledge Base.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetKnowledgeBaseRequest
     * @return GetKnowledgeBaseResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/adm/GetKnowledgeBase.ts.html |here} to see how to use GetKnowledgeBase API.
     */
    getKnowledgeBase(getKnowledgeBaseRequest: requests.GetKnowledgeBaseRequest): Promise<responses.GetKnowledgeBaseResponse>;
    /**
     * Returns the details of the specified RemediationRecipe.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetRemediationRecipeRequest
     * @return GetRemediationRecipeResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/adm/GetRemediationRecipe.ts.html |here} to see how to use GetRemediationRecipe API.
     */
    getRemediationRecipe(getRemediationRecipeRequest: requests.GetRemediationRecipeRequest): Promise<responses.GetRemediationRecipeResponse>;
    /**
     * Returns the details of the specified remediation run.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetRemediationRunRequest
     * @return GetRemediationRunResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/adm/GetRemediationRun.ts.html |here} to see how to use GetRemediationRun API.
     */
    getRemediationRun(getRemediationRunRequest: requests.GetRemediationRunRequest): Promise<responses.GetRemediationRunResponse>;
    /**
     * Returns the details of the specified Remediation Run Stage.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetStageRequest
     * @return GetStageResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/adm/GetStage.ts.html |here} to see how to use GetStage API.
     */
    getStage(getStageRequest: requests.GetStageRequest): Promise<responses.GetStageResponse>;
    /**
     * Returns the details of the specified Vulnerability Audit.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetVulnerabilityAuditRequest
     * @return GetVulnerabilityAuditResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/adm/GetVulnerabilityAudit.ts.html |here} to see how to use GetVulnerabilityAudit API.
     */
    getVulnerabilityAudit(getVulnerabilityAuditRequest: requests.GetVulnerabilityAuditRequest): Promise<responses.GetVulnerabilityAuditResponse>;
    /**
     * Gets the status of the work request with the given ID.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetWorkRequestRequest
     * @return GetWorkRequestResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/adm/GetWorkRequest.ts.html |here} to see how to use GetWorkRequest API.
     */
    getWorkRequest(getWorkRequestRequest: requests.GetWorkRequestRequest): Promise<responses.GetWorkRequestResponse>;
    /**
     * Returns a list of application dependency with their associated recommendations.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListApplicationDependencyRecommendationsRequest
     * @return ListApplicationDependencyRecommendationsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/adm/ListApplicationDependencyRecommendations.ts.html |here} to see how to use ListApplicationDependencyRecommendations API.
     */
    listApplicationDependencyRecommendations(listApplicationDependencyRecommendationsRequest: requests.ListApplicationDependencyRecommendationsRequest): Promise<responses.ListApplicationDependencyRecommendationsResponse>;
    /**
     * Returns a list of Application Dependencies with their associated vulnerabilities.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListApplicationDependencyVulnerabilitiesRequest
     * @return ListApplicationDependencyVulnerabilitiesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/adm/ListApplicationDependencyVulnerabilities.ts.html |here} to see how to use ListApplicationDependencyVulnerabilities API.
     */
    listApplicationDependencyVulnerabilities(listApplicationDependencyVulnerabilitiesRequest: requests.ListApplicationDependencyVulnerabilitiesRequest): Promise<responses.ListApplicationDependencyVulnerabilitiesResponse>;
    /**
     * Returns a list of KnowledgeBases based on the specified query parameters.
     * At least id or compartmentId query parameter must be provided.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListKnowledgeBasesRequest
     * @return ListKnowledgeBasesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/adm/ListKnowledgeBases.ts.html |here} to see how to use ListKnowledgeBases API.
     */
    listKnowledgeBases(listKnowledgeBasesRequest: requests.ListKnowledgeBasesRequest): Promise<responses.ListKnowledgeBasesResponse>;
    /**
     * Returns a list of Remediation Recipes based on the specified query parameters.
     * The query parameters `compartmentId` or `id` must be provided.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListRemediationRecipesRequest
     * @return ListRemediationRecipesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/adm/ListRemediationRecipes.ts.html |here} to see how to use ListRemediationRecipes API.
     */
    listRemediationRecipes(listRemediationRecipesRequest: requests.ListRemediationRecipesRequest): Promise<responses.ListRemediationRecipesResponse>;
    /**
     * Returns a list of remediation runs contained by a compartment.
     * The query parameter `compartmentId` is required unless the query parameter `id` is specified.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListRemediationRunsRequest
     * @return ListRemediationRunsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/adm/ListRemediationRuns.ts.html |here} to see how to use ListRemediationRuns API.
     */
    listRemediationRuns(listRemediationRunsRequest: requests.ListRemediationRunsRequest): Promise<responses.ListRemediationRunsResponse>;
    /**
     * Returns a list of Remediation Run Stages based on the specified query parameters and Remediation Run identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListStagesRequest
     * @return ListStagesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/adm/ListStages.ts.html |here} to see how to use ListStages API.
     */
    listStages(listStagesRequest: requests.ListStagesRequest): Promise<responses.ListStagesResponse>;
    /**
     * Returns a list of Vulnerability Audits based on the specified query parameters.
     * At least one of id, compartmentId query parameter must be provided.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListVulnerabilityAuditsRequest
     * @return ListVulnerabilityAuditsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/adm/ListVulnerabilityAudits.ts.html |here} to see how to use ListVulnerabilityAudits API.
     */
    listVulnerabilityAudits(listVulnerabilityAuditsRequest: requests.ListVulnerabilityAuditsRequest): Promise<responses.ListVulnerabilityAuditsResponse>;
    /**
     * Return a (paginated) list of errors for a given work request.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListWorkRequestErrorsRequest
     * @return ListWorkRequestErrorsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/adm/ListWorkRequestErrors.ts.html |here} to see how to use ListWorkRequestErrors API.
     */
    listWorkRequestErrors(listWorkRequestErrorsRequest: requests.ListWorkRequestErrorsRequest): Promise<responses.ListWorkRequestErrorsResponse>;
    /**
     * Return a (paginated) list of logs for a given work request.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListWorkRequestLogsRequest
     * @return ListWorkRequestLogsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/adm/ListWorkRequestLogs.ts.html |here} to see how to use ListWorkRequestLogs API.
     */
    listWorkRequestLogs(listWorkRequestLogsRequest: requests.ListWorkRequestLogsRequest): Promise<responses.ListWorkRequestLogsResponse>;
    /**
     * Lists the work requests in a compartment.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListWorkRequestsRequest
     * @return ListWorkRequestsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/adm/ListWorkRequests.ts.html |here} to see how to use ListWorkRequests API.
     */
    listWorkRequests(listWorkRequestsRequest: requests.ListWorkRequestsRequest): Promise<responses.ListWorkRequestsResponse>;
    /**
     * Updates one or more attributes of the specified Knowledge Base.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateKnowledgeBaseRequest
     * @return UpdateKnowledgeBaseResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/adm/UpdateKnowledgeBase.ts.html |here} to see how to use UpdateKnowledgeBase API.
     */
    updateKnowledgeBase(updateKnowledgeBaseRequest: requests.UpdateKnowledgeBaseRequest): Promise<responses.UpdateKnowledgeBaseResponse>;
    /**
     * Updates one or more attributes of the specified Remediation Recipe.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateRemediationRecipeRequest
     * @return UpdateRemediationRecipeResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/adm/UpdateRemediationRecipe.ts.html |here} to see how to use UpdateRemediationRecipe API.
     */
    updateRemediationRecipe(updateRemediationRecipeRequest: requests.UpdateRemediationRecipeRequest): Promise<responses.UpdateRemediationRecipeResponse>;
    /**
     * Updates by identifier one or more attributes of the specified remediation run.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateRemediationRunRequest
     * @return UpdateRemediationRunResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/adm/UpdateRemediationRun.ts.html |here} to see how to use UpdateRemediationRun API.
     */
    updateRemediationRun(updateRemediationRunRequest: requests.UpdateRemediationRunRequest): Promise<responses.UpdateRemediationRunResponse>;
    /**
     * Updates one or more attributes of the specified Vulnerability Audit.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateVulnerabilityAuditRequest
     * @return UpdateVulnerabilityAuditResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/adm/UpdateVulnerabilityAudit.ts.html |here} to see how to use UpdateVulnerabilityAudit API.
     */
    updateVulnerabilityAudit(updateVulnerabilityAuditRequest: requests.UpdateVulnerabilityAuditRequest): Promise<responses.UpdateVulnerabilityAuditResponse>;
}
export {};
