/**
 * Anomaly Detection API
 * OCI AI Service solutions can help Enterprise customers integrate AI into their products immediately by using our proven,
pre-trained/custom models or containers, and without a need to set up in house team of AI and ML experts.
This allows enterprises to focus on business drivers and development work rather than AI/ML operations, shortening the time to market.

 * OpenAPI spec version: 20210101
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * Anomaly Job contains information for asynchronous detection of anomalies.
 */
export interface DetectAnomalyJob {
    /**
     * Id of the job.
     */
    "id": string;
    /**
     * The OCID of the compartment that starts the job.
     */
    "compartmentId": string;
    /**
     * Detect anomaly job display name.
     */
    "displayName"?: string;
    /**
     * Detect anomaly job description.
     */
    "description"?: string;
    /**
     * The OCID of the trained model.
     */
    "modelId": string;
    /**
     * The OCID of the project.
     */
    "projectId"?: string;
    /**
     * The value that customer can adjust to control the sensitivity of anomaly detection Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "sensitivity"?: number;
    /**
     * Flag to enable the service to return estimates for all data points rather than just the anomalous data points
     */
    "areAllEstimatesRequired"?: boolean;
    "inputDetails": model.InlineInputJobDetails | model.ObjectListInputJobDetails;
    "outputDetails": model.ObjectStorageLocation;
    /**
     * Job accepted time
     */
    "timeAccepted": Date;
    /**
     * Job started time
     */
    "timeStarted"?: Date;
    /**
     * Job finished time
     */
    "timeFinished"?: Date;
    /**
     * The current state of the batch document job.
     */
    "lifecycleState": DetectAnomalyJob.LifecycleState;
    /**
     * The current state details of the batch document job.
     */
    "lifecycleStateDetails"?: string;
    /**
     * Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
     * Example: {@code {\"bar-key\": \"value\"}}
     *
     */
    "freeformTags"?: {
        [key: string]: string;
    };
    /**
     * Defined tags for this resource. Each key is predefined and scoped to a namespace.
     * Example: {@code {\"foo-namespace\": {\"bar-key\": \"value\"}}}
     *
     */
    "definedTags"?: {
        [key: string]: {
            [key: string]: any;
        };
    };
    /**
     * Usage of system tag keys. These predefined keys are scoped to namespaces.
     * Example: {@code { \"orcl-cloud\": { \"free-tier-retained\": \"true\" } }}
     *
     */
    "systemTags"?: {
        [key: string]: any;
    };
}
export declare namespace DetectAnomalyJob {
    enum LifecycleState {
        Succeeded = "SUCCEEDED",
        PartiallySucceeded = "PARTIALLY_SUCCEEDED",
        Failed = "FAILED",
        Accepted = "ACCEPTED",
        Canceled = "CANCELED",
        InProgress = "IN_PROGRESS",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    function getJsonObj(obj: DetectAnomalyJob): object;
    function getDeserializedJsonObj(obj: DetectAnomalyJob): object;
}
