/**
 * Document Understanding API
 * Document AI helps customers perform various analysis on their documents. If a customer has lots of documents, they can process them in batch using asynchronous API endpoints.
 * OpenAPI spec version: 20221109
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * The information needed to create a new model.
 */
export interface CreateModelDetails {
    /**
     * A human-friendly name for the model, which can be changed.
     */
    "displayName"?: string;
    /**
     * An optional description of the model.
     */
    "description"?: string;
    /**
     * The model version
     */
    "modelVersion"?: string;
    /**
     * The type of the Document model.
     */
    "modelType": string;
    /**
     * The compartment identifier.
     */
    "compartmentId": string;
    /**
     * Set to true when experimenting with a new model type or dataset, so the model training is quick, with a predefined low number of passes through the training data.
     */
    "isQuickMode"?: boolean;
    /**
     * The maximum model training time in hours, expressed as a decimal fraction. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "maxTrainingTimeInHours"?: number;
    "trainingDataset"?: model.DataScienceLabelingDataset | model.ObjectStorageDataset;
    "testingDataset"?: model.DataScienceLabelingDataset | model.ObjectStorageDataset;
    "validationDataset"?: model.DataScienceLabelingDataset | model.ObjectStorageDataset;
    /**
     * The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) list of active custom Key Value models that need to be composed.
     */
    "componentModels"?: Array<model.ComponentModel>;
    /**
     * the alias name of the model.
     */
    "aliasName"?: string;
    /**
     * The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the project that contains the model.
     */
    "projectId": string;
    /**
     * A simple key-value pair that is applied without any predefined name, type, or scope. It exists for cross-compatibility only.
     * For example: {@code {\"bar-key\": \"value\"}}
     *
     */
    "freeformTags"?: {
        [key: string]: string;
    };
    /**
     * Defined tags for this resource. Each key is predefined and scoped to a namespace.
     * For example: {@code {\"foo-namespace\": {\"bar-key\": \"value\"}}}
     *
     */
    "definedTags"?: {
        [key: string]: {
            [key: string]: any;
        };
    };
}
export declare namespace CreateModelDetails {
    function getJsonObj(obj: CreateModelDetails): object;
    function getDeserializedJsonObj(obj: CreateModelDetails): object;
}
