/**
 * Language API
 * OCI Language Service solutions can help enterprise customers integrate AI into their products immediately using our proven,
pre-trained and custom models or containers, without a need to set up an house team of AI and ML experts.
This allows enterprises to focus on business drivers and development work rather than AI and ML operations, which shortens the time to market.

 * OpenAPI spec version: 20221001
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * Job details which contain input document details on which prediction need to run, features (which and all language services ) need to run and where to store results
 */
export interface Job {
    /**
     * The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the job.
     */
    "id": string;
    /**
     * A user-friendly display name for the job.
     */
    "displayName"?: string;
    /**
     * A short description of the job.
     */
    "description"?: string;
    "inputLocation": model.ObjectStoragePrefixLocation | model.ObjectStorageFileNameLocation;
    "inputConfiguration"?: model.InputConfiguration;
    /**
     * training model details
     * For this release only one model is allowed to be input here.
     * One of the three modelType, ModelId, endpointId should be given other wise error will be thrown from API
     *
     */
    "modelMetadataDetails": Array<model.ModelMetadataDetails>;
    /**
     * The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment where you want to create the job.
     */
    "compartmentId": string;
    /**
     * The current state of the Job.
     */
    "lifecycleState"?: Job.LifecycleState;
    /**
     * A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.
     */
    "lifecycleDetails"?: string;
    /**
     * How much progress the operation has made, vs the total amount of work that must be performed. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "percentComplete"?: number;
    /**
     * Total number of documents given as input for prediction. For CSV this signifies number of rows and for TXT this signifies number of files. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "totalDocuments"?: number;
    /**
     * Number of documents still to process. For CSV this signifies number of rows and for TXT this signifies number of files. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "pendingDocuments"?: number;
    /**
     * Number of documents processed for prediction. For CSV this signifies number of rows and for TXT this signifies number of files. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "completedDocuments"?: number;
    /**
     * Number of documents failed for prediction. For CSV this signifies number of rows and for TXT this signifies number of files. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "failedDocuments"?: number;
    /**
     * warnings count Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "warningsCount"?: number;
    "outputLocation": model.ObjectPrefixOutputLocation;
    /**
     * Time to live duration in days for Job. Job will be available till max 90 days. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "ttlInDays"?: number;
    /**
     * The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the user who created the job.
     */
    "createdBy"?: string;
    /**
     * Job accepted time.
     */
    "timeAccepted"?: Date;
    /**
     * Job started time.
     */
    "timeStarted"?: Date;
    /**
     * Job finished time.
     */
    "timeCompleted"?: Date;
}
export declare namespace Job {
    enum LifecycleState {
        Accepted = "ACCEPTED",
        InProgress = "IN_PROGRESS",
        Succeeded = "SUCCEEDED",
        Failed = "FAILED",
        Canceling = "CANCELING",
        Canceled = "CANCELED",
        Deleting = "DELETING",
        Deleted = "DELETED",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    function getJsonObj(obj: Job): object;
    function getDeserializedJsonObj(obj: Job): object;
}
