/**
 * Speech API
 * The OCI Speech Service harnesses the power of spoken language by allowing developers to easily convert file-based data containing human speech into highly accurate text transcriptions.
 * OpenAPI spec version: 20220101
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import common = require("oci-common");
import * as requests from "./request";
import * as responses from "./response";
import { AIServiceSpeechWaiter } from "./aiservicespeech-waiter";
declare const Breaker: any;
export declare enum AIServiceSpeechApiKeys {
}
/**
 * This service client uses {@link common.CircuitBreaker.DefaultConfiguration} for all the operations by default if no circuit breaker configuration is defined by the user.
 */
export declare class AIServiceSpeechClient {
    protected static serviceEndpointTemplate: string;
    protected static endpointServiceName: string;
    protected "_realmSpecificEndpointTemplateEnabled": boolean | undefined;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_waiters": AIServiceSpeechWaiter;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: typeof Breaker | null;
    protected _httpOptions: any;
    protected _bodyDuplexMode: any;
    targetService: string;
    protected _regionId: string;
    protected "_region": common.Region;
    protected _lastSetRegionOrRegionId: string;
    protected _httpClient: common.HttpClient;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    get endpoint(): string;
    /**
     * Sets the endpoint to call (ex, https://www.example.com).
     * @param endpoint The endpoint of the service.
     */
    set endpoint(endpoint: string);
    get logger(): import("oci-common/lib/log").Logger;
    /**
     * Determines whether realm specific endpoint should be used or not.
     * Set realmSpecificEndpointTemplateEnabled to "true" if the user wants to enable use of realm specific endpoint template, otherwise set it to "false"
     * @param realmSpecificEndpointTemplateEnabled flag to enable the use of realm specific endpoint template
     */
    set useRealmSpecificEndpointTemplate(realmSpecificEndpointTemplateEnabled: boolean);
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    set region(region: common.Region);
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    set regionId(regionId: string);
    /**
     * Creates a new AIServiceSpeechWaiter for resources for this service.
     *
     * @param config The waiter configuration for termination and delay strategy
     * @return The service waiters.
     */
    createWaiters(config?: common.WaiterConfiguration): AIServiceSpeechWaiter;
    /**
     * Gets the waiters available for resources for this service.
     *
     * @return The service waiters.
     */
    getWaiters(): AIServiceSpeechWaiter;
    /**
     * Shutdown the circuit breaker used by the client when it is no longer needed
     */
    shutdownCircuitBreaker(): void;
    /**
     * Close the client once it is no longer needed
     */
    close(): void;
    /**
     * Canceling the job cancels all the tasks under it.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CancelTranscriptionJobRequest
     * @return CancelTranscriptionJobResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/aispeech/CancelTranscriptionJob.ts.html |here} to see how to use CancelTranscriptionJob API.
     */
    cancelTranscriptionJob(cancelTranscriptionJobRequest: requests.CancelTranscriptionJobRequest): Promise<responses.CancelTranscriptionJobResponse>;
    /**
     * Cancel Transcription Task
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CancelTranscriptionTaskRequest
     * @return CancelTranscriptionTaskResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/aispeech/CancelTranscriptionTask.ts.html |here} to see how to use CancelTranscriptionTask API.
     */
    cancelTranscriptionTask(cancelTranscriptionTaskRequest: requests.CancelTranscriptionTaskRequest): Promise<responses.CancelTranscriptionTaskResponse>;
    /**
     * Moves a transcription Job resource into a different compartment.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangeTranscriptionJobCompartmentRequest
     * @return ChangeTranscriptionJobCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/aispeech/ChangeTranscriptionJobCompartment.ts.html |here} to see how to use ChangeTranscriptionJobCompartment API.
     */
    changeTranscriptionJobCompartment(changeTranscriptionJobCompartmentRequest: requests.ChangeTranscriptionJobCompartmentRequest): Promise<responses.ChangeTranscriptionJobCompartmentResponse>;
    /**
     * Creates a new Transcription Job.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateTranscriptionJobRequest
     * @return CreateTranscriptionJobResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/aispeech/CreateTranscriptionJob.ts.html |here} to see how to use CreateTranscriptionJob API.
     */
    createTranscriptionJob(createTranscriptionJobRequest: requests.CreateTranscriptionJobRequest): Promise<responses.CreateTranscriptionJobResponse>;
    /**
     * Delete API cleans job, tasks and the related metadata. However the generated transcriptions in customer tenancy will not be deleted.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteTranscriptionJobRequest
     * @return DeleteTranscriptionJobResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/aispeech/DeleteTranscriptionJob.ts.html |here} to see how to use DeleteTranscriptionJob API.
     */
    deleteTranscriptionJob(deleteTranscriptionJobRequest: requests.DeleteTranscriptionJobRequest): Promise<responses.DeleteTranscriptionJobResponse>;
    /**
     * Gets a Transcription Job by identifier
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetTranscriptionJobRequest
     * @return GetTranscriptionJobResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/aispeech/GetTranscriptionJob.ts.html |here} to see how to use GetTranscriptionJob API.
     */
    getTranscriptionJob(getTranscriptionJobRequest: requests.GetTranscriptionJobRequest): Promise<responses.GetTranscriptionJobResponse>;
    /**
     * Gets a Transcription Task by identifier
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetTranscriptionTaskRequest
     * @return GetTranscriptionTaskResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/aispeech/GetTranscriptionTask.ts.html |here} to see how to use GetTranscriptionTask API.
     */
    getTranscriptionTask(getTranscriptionTaskRequest: requests.GetTranscriptionTaskRequest): Promise<responses.GetTranscriptionTaskResponse>;
    /**
     * Returns a list of Transcription Jobs.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListTranscriptionJobsRequest
     * @return ListTranscriptionJobsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/aispeech/ListTranscriptionJobs.ts.html |here} to see how to use ListTranscriptionJobs API.
     */
    listTranscriptionJobs(listTranscriptionJobsRequest: requests.ListTranscriptionJobsRequest): Promise<responses.ListTranscriptionJobsResponse>;
    /**
     * Returns a list of Transcription Tasks.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListTranscriptionTasksRequest
     * @return ListTranscriptionTasksResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/aispeech/ListTranscriptionTasks.ts.html |here} to see how to use ListTranscriptionTasks API.
     */
    listTranscriptionTasks(listTranscriptionTasksRequest: requests.ListTranscriptionTasksRequest): Promise<responses.ListTranscriptionTasksResponse>;
    /**
     * Updates the Transcription Job
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateTranscriptionJobRequest
     * @return UpdateTranscriptionJobResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/aispeech/UpdateTranscriptionJob.ts.html |here} to see how to use UpdateTranscriptionJob API.
     */
    updateTranscriptionJob(updateTranscriptionJobRequest: requests.UpdateTranscriptionJobRequest): Promise<responses.UpdateTranscriptionJobResponse>;
}
export {};
