/**
 * Speech API
 * The OCI Speech Service harnesses the power of spoken language by allowing developers to easily convert file-based data containing human speech into highly accurate text transcriptions.
 * OpenAPI spec version: 20220101
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * Description of Transcription Task.
 */
export interface TranscriptionTask {
    /**
     * The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the task.
     */
    "id": string;
    /**
     * A user-friendly display name for the task.
     */
    "displayName"?: string;
    /**
     * Task started time.
     */
    "timeStarted"?: Date;
    /**
     * Task finished time.
     */
    "timeFinished"?: Date;
    /**
     * How much progress the operation has made, vs the total amount of work that must be performed. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "percentComplete"?: number;
    /**
     * Time to live duration in days for tasks. Task will be available till max 90 days. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "ttlInDays"?: number;
    "modelDetails"?: model.TranscriptionModelDetails;
    "audioFormatDetails"?: model.AudioFormatDetails;
    /**
     * Size of input file in Bytes. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "fileSizeInBytes"?: number;
    /**
     * Duration of input file in Seconds. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "fileDurationInSeconds"?: number;
    /**
     * Task proccessing duration, which excludes waiting time in the system. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "processingDurationInSeconds"?: number;
    "inputLocation"?: model.ObjectLocation;
    "outputLocation"?: model.ObjectLocation;
    /**
     * The current state of the Task.
     */
    "lifecycleState"?: TranscriptionTask.LifecycleState;
    /**
     * A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.
     */
    "lifecycleDetails"?: string;
}
export declare namespace TranscriptionTask {
    enum LifecycleState {
        Accepted = "ACCEPTED",
        InProgress = "IN_PROGRESS",
        Succeeded = "SUCCEEDED",
        Failed = "FAILED",
        Canceled = "CANCELED",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    function getJsonObj(obj: TranscriptionTask): object;
    function getDeserializedJsonObj(obj: TranscriptionTask): object;
}
