/**
 * API Gateway API
 * API for the API Gateway service. Use this API to manage gateways, deployments, and related items.
For more information, see
[Overview of API Gateway](/iaas/Content/APIGateway/Concepts/apigatewayoverview.htm).

 * OpenAPI spec version: 20190501
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * A subscriber, which encapsulates a number of clients and usage plans that they are subscribed to.
 *
 */
export interface Subscriber {
    /**
     * The [OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the resource.
     *
     */
    "id": string;
    /**
     * The [OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment in which the
     * resource is created.
     *
     */
    "compartmentId": string;
    /**
      * A user-friendly name. Does not have to be unique, and it's changeable.
  * Avoid entering confidential information.
  * <p>
  Example: {@code My new resource}
  *
      */
    "displayName"?: string;
    /**
     * The clients belonging to this subscriber.
     */
    "clients": Array<model.Client>;
    /**
     * An array of [OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm)s of usage
     * plan resources.
     *
     */
    "usagePlans": Array<string>;
    /**
     * The time this resource was created. An RFC3339 formatted datetime string.
     */
    "timeCreated": Date;
    /**
     * The time this resource was last updated. An RFC3339 formatted datetime string.
     */
    "timeUpdated": Date;
    /**
     * The current state of the subscriber.
     */
    "lifecycleState": Subscriber.LifecycleState;
    /**
     * A message describing the current state in more detail.
     * For example, can be used to provide actionable information for a
     * resource in a Failed state.
     *
     */
    "lifecycleDetails"?: string;
    /**
      * Free-form tags for this resource. Each tag is a simple key-value pair
  * with no predefined name, type, or namespace. For more information, see
  * [Resource Tags](https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
  * <p>
  Example: {@code {\"Department\": \"Finance\"}}
  *
      */
    "freeformTags"?: {
        [key: string]: string;
    };
    /**
      * Defined tags for this resource. Each key is predefined and scoped to a
  * namespace. For more information, see
  * [Resource Tags](https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
  * <p>
  Example: {@code {\"Operations\": {\"CostCenter\": \"42\"}}}
  *
      */
    "definedTags"?: {
        [key: string]: {
            [key: string]: any;
        };
    };
}
export declare namespace Subscriber {
    enum LifecycleState {
        Creating = "CREATING",
        Active = "ACTIVE",
        Updating = "UPDATING",
        Deleting = "DELETING",
        Deleted = "DELETED",
        Failed = "FAILED",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    function getJsonObj(obj: Subscriber): object;
    function getDeserializedJsonObj(obj: Subscriber): object;
}
