/**
 * API Gateway API
 * API for the API Gateway service. Use this API to manage gateways, deployments, and related items.
For more information, see
[Overview of API Gateway](/iaas/Content/APIGateway/Concepts/apigatewayoverview.htm).

 * OpenAPI spec version: 20190501
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * A description of the work request status.
 */
export interface WorkRequest {
    /**
     * The [OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the resource.
     *
     */
    "id": string;
    /**
     * The type of the work request.
     */
    "operationType": WorkRequest.OperationType;
    /**
     * The status of the work request.
     */
    "status": WorkRequest.Status;
    /**
     * The [OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment in which the
     * resource is created.
     *
     */
    "compartmentId": string;
    /**
     * The resources affected by this work request.
     */
    "resources": Array<model.WorkRequestResource>;
    /**
     * Percentage of the request completed. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "percentComplete": number;
    /**
     * The date and time the request was created, as described in
     * [RFC 3339](https://tools.ietf.org/rfc/rfc3339), section 14.29.
     *
     */
    "timeAccepted": Date;
    /**
     * The date and time the request was started, as described in [RFC 3339](https://tools.ietf.org/rfc/rfc3339),
     * section 14.29.
     *
     */
    "timeStarted"?: Date;
    /**
     * The date and time the request was finished, as described in [RFC 3339](https://tools.ietf.org/rfc/rfc3339).
     *
     */
    "timeFinished"?: Date;
}
export declare namespace WorkRequest {
    enum OperationType {
        CreateGateway = "CREATE_GATEWAY",
        UpdateGateway = "UPDATE_GATEWAY",
        DeleteGateway = "DELETE_GATEWAY",
        CreateDeployment = "CREATE_DEPLOYMENT",
        UpdateDeployment = "UPDATE_DEPLOYMENT",
        DeleteDeployment = "DELETE_DEPLOYMENT",
        CreateCertificate = "CREATE_CERTIFICATE",
        UpdateCertificate = "UPDATE_CERTIFICATE",
        DeleteCertificate = "DELETE_CERTIFICATE",
        CreateApi = "CREATE_API",
        UpdateApi = "UPDATE_API",
        DeleteApi = "DELETE_API",
        ValidateApi = "VALIDATE_API",
        CreateSdk = "CREATE_SDK",
        DeleteSdk = "DELETE_SDK",
        CreateUsagePlan = "CREATE_USAGE_PLAN",
        UpdateUsagePlan = "UPDATE_USAGE_PLAN",
        DeleteUsagePlan = "DELETE_USAGE_PLAN",
        CreateSubscriber = "CREATE_SUBSCRIBER",
        UpdateSubscriber = "UPDATE_SUBSCRIBER",
        DeleteSubscriber = "DELETE_SUBSCRIBER",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    enum Status {
        Accepted = "ACCEPTED",
        InProgress = "IN_PROGRESS",
        Failed = "FAILED",
        Succeeded = "SUCCEEDED",
        Canceling = "CANCELING",
        Canceled = "CANCELED",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    function getJsonObj(obj: WorkRequest): object;
    function getDeserializedJsonObj(obj: WorkRequest): object;
}
