/**
 * Application Performance Monitoring Synthetic Monitoring API
 * Use the Application Performance Monitoring Synthetic Monitoring API to query synthetic scripts and monitors. For more information, see [Application Performance Monitoring](https://docs.oracle.com/iaas/application-performance-monitoring/index.html).
 * OpenAPI spec version: 20200630
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * The information about a monitor.
 */
export interface Monitor {
    /**
     * The [OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the monitor.
     */
    "id": string;
    /**
     * Unique name that can be edited. The name should not contain any confidential information.
     */
    "displayName": string;
    /**
     * Type of monitor.
     */
    "monitorType": model.MonitorTypes;
    /**
     * List of public and dedicated vantage points where the monitor is running.
     */
    "vantagePoints": Array<model.VantagePointInfo>;
    /**
     * Number of vantage points where monitor is running. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "vantagePointCount": number;
    /**
     * The [OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the script.
     * scriptId is mandatory for creation of SCRIPTED_BROWSER and SCRIPTED_REST monitor types. For other monitor types, it should be set to null.
     *
     */
    "scriptId": string;
    /**
     * Name of the script.
     */
    "scriptName": string;
    /**
     * Enables or disables the monitor.
     */
    "status": model.MonitorStatus;
    /**
     * Interval in seconds after the start time when the job should be repeated.
     * Minimum repeatIntervalInSeconds should be 300 seconds for Scripted REST, Scripted Browser and Browser monitors, and 60 seconds for REST monitor.
     *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "repeatIntervalInSeconds": number;
    /**
     * If runOnce is enabled, then the monitor will run once.
     */
    "isRunOnce": boolean;
    /**
     * Timeout in seconds. If isFailureRetried is true, then timeout cannot be more than 30% of repeatIntervalInSeconds time for monitors.
     * If isFailureRetried is false, then timeout cannot be more than 50% of repeatIntervalInSeconds time for monitors.
     * Also, timeoutInSeconds should be a multiple of 60 for Scripted REST, Scripted Browser and Browser monitors.
     * Monitor will be allowed to run only for timeoutInSeconds time. It would be terminated after that.
     *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "timeoutInSeconds": number;
    /**
     * Specify the endpoint on which to run the monitor.
     * For BROWSER, REST and NETWORK monitor types, target is mandatory.
     * If target is specified in the SCRIPTED_BROWSER monitor type, then the monitor will run the selected script (specified by scriptId in monitor) against the specified target endpoint.
     * If target is not specified in the SCRIPTED_BROWSER monitor type, then the monitor will run the selected script as it is.
     * For NETWORK monitor with TCP protocol, a port needs to be provided along with target. Example: 192.168.0.1:80
     *
     */
    "target"?: string;
    /**
     * List of script parameters. Example: {@code [{\"monitorScriptParameter\": {\"paramName\": \"userid\", \"paramValue\":\"testuser\"}, \"isSecret\": false, \"isOverwritten\": false}]}
     *
     */
    "scriptParameters"?: Array<model.MonitorScriptParameterInfo>;
    "configuration"?: model.DnsSecMonitorConfiguration | model.DnsTraceMonitorConfiguration | model.ScriptedRestMonitorConfiguration | model.DnsServerMonitorConfiguration | model.ScriptedBrowserMonitorConfiguration | model.RestMonitorConfiguration | model.BrowserMonitorConfiguration | model.NetworkMonitorConfiguration;
    "availabilityConfiguration"?: model.AvailabilityConfiguration;
    "maintenanceWindowSchedule"?: model.MaintenanceWindowSchedule;
    /**
     * The time the resource was created, expressed in [RFC 3339](https://tools.ietf.org/html/rfc3339)
     * timestamp format.
     * Example: {@code 2020-02-12T22:47:12.613Z}
     *
     */
    "timeCreated"?: Date;
    /**
     * The time the resource was updated, expressed in [RFC 3339](https://tools.ietf.org/html/rfc3339)
     * timestamp format.
     * Example: {@code 2020-02-13T22:47:12.613Z}
     *
     */
    "timeUpdated"?: Date;
    /**
     * Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
     * Example: {@code {\"bar-key\": \"value\"}}
     *
     */
    "freeformTags"?: {
        [key: string]: string;
    };
    /**
     * Defined tags for this resource. Each key is predefined and scoped to a namespace.
     * Example: {@code {\"foo-namespace\": {\"bar-key\": \"value\"}}}
     *
     */
    "definedTags"?: {
        [key: string]: {
            [key: string]: any;
        };
    };
    /**
     * If isRunNow is enabled, then the monitor will run immediately.
     */
    "isRunNow": boolean;
    /**
     * Scheduling policy to decide the distribution of monitor executions on vantage points.
     */
    "schedulingPolicy": model.SchedulingPolicy;
    /**
     * Time interval between two runs in round robin batch mode (SchedulingPolicy - BATCHED_ROUND_ROBIN). Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "batchIntervalInSeconds": number;
}
export declare namespace Monitor {
    function getJsonObj(obj: Monitor): object;
    function getDeserializedJsonObj(obj: Monitor): object;
}
