/**
 * Application Performance Monitoring Synthetic Monitoring API
 * Use the Application Performance Monitoring Synthetic Monitoring API to query synthetic scripts and monitors. For more information, see [Application Performance Monitoring](https://docs.oracle.com/iaas/application-performance-monitoring/index.html).
 * OpenAPI spec version: 20200630
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * The information about an On-premise VP worker.
 */
export interface Worker {
    /**
     * The [OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the On-premise VP worker.
     */
    "id": string;
    /**
     * The runtime assigned id of the On-premise VP worker.
     */
    "runtimeId": string;
    /**
     * Unique On-premise VP worker name that cannot be edited. The name should not contain any confidential information.
     */
    "displayName": string;
    /**
     * Unique permanent name of the On-premise VP worker. This is the same as the displayName.
     */
    "name": string;
    /**
     * The [OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the On-premise vantage point.
     */
    "opvpId": string;
    /**
     * On-premise vantage point name.
     */
    "opvpName": string;
    "versionDetails": model.OnPremiseVpWorkerVersionDetails;
    /**
     * Configuration details of the On-premise VP worker.
     */
    "configurationDetails"?: any;
    /**
     * Type of the On-premise VP worker.
     */
    "workerType": model.OnPremiseVantagePointWorkerType;
    /**
     * Enables or disables the On-premise VP worker.
     */
    "status": model.OnPremiseVantagePointWorkerStatus;
    /**
     * Priority of the On-premise VP worker to schedule monitors. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "priority": number;
    /**
     * Geographical information of the On-premise VP worker.
     */
    "geoInfo"?: string;
    /**
     * Monitors list assigned to the On-premise VP worker.
     */
    "monitorList"?: Array<model.WorkerMonitorList>;
    "identityInfo"?: model.IdentityInfoDetails;
    /**
     * The time the resource was last synced, expressed in [RFC 3339](https://tools.ietf.org/html/rfc3339)
     * timestamp format.
     * Example: {@code 2020-02-12T22:47:12.613Z}
     *
     */
    "timeLastSyncUp"?: Date;
    /**
     * The time the resource was created, expressed in [RFC 3339](https://tools.ietf.org/html/rfc3339)
     * timestamp format.
     * Example: {@code 2020-02-12T22:47:12.613Z}
     *
     */
    "timeCreated"?: Date;
    /**
     * The time the resource was updated, expressed in [RFC 3339](https://tools.ietf.org/html/rfc3339)
     * timestamp format.
     * Example: {@code 2020-02-13T22:47:12.613Z}
     *
     */
    "timeUpdated"?: Date;
    /**
     * Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
     * Example: {@code {\"bar-key\": \"value\"}}
     *
     */
    "freeformTags"?: {
        [key: string]: string;
    };
    /**
     * Defined tags for this resource. Each key is predefined and scoped to a namespace.
     * Example: {@code {\"foo-namespace\": {\"bar-key\": \"value\"}}}
     *
     */
    "definedTags"?: {
        [key: string]: {
            [key: string]: any;
        };
    };
}
export declare namespace Worker {
    function getJsonObj(obj: Worker): object;
    function getDeserializedJsonObj(obj: Worker): object;
}
