/**
 * Application Performance Monitoring Trace Explorer API
 * Use the Application Performance Monitoring Trace Explorer API to query traces and associated spans in Trace Explorer. For more information, see [Application Performance Monitoring](https://docs.oracle.com/iaas/application-performance-monitoring/index.html).

 * OpenAPI spec version: 20200630
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
/**
 * Response of an individual attribute item in the bulk pin operation.
 *
 */
export interface AttributePinResponse {
    /**
     * Attribute that was pinned by this bulk operation.
     *
     */
    "attributeName": string;
    /**
     * Notes added to this attribute.
     *
     */
    "notes": string;
    /**
     * Type of operation - pin.
     *
     */
    "operationType": AttributePinResponse.OperationType;
    /**
     * Namespace of the attribute whose properties were updated.  The attributeNameSpace will default to TRACES if it is
     * not passed in.
     *
     */
    "attributeNameSpace": AttributePinResponse.AttributeNameSpace;
    /**
     * Status of the attribute after this operation.  The attribute can have one of the following statuses after the pin operation.  The attribute
     * can have either a success status or an error status.  The status of the attribute must be correlated with the operation status property in the bulk operation metadata
     * object.  The bulk operation will be successful only when all attributes in the bulk request are processed successfully and they get a success status back.
     * The following are successful status values of individual attribute items in a bulk attribute pin operation.
     * ATTRIBUTE_PINNED - The attribute is marked pinned and associated notes have been added.
     * ATTRIBUTE_ALREADY_PINNED - The caller is trying to pin an attribute that has already been pinned.
     * DUPLICATE_ATTRIBUTE - The attribute is a duplicate of an attribute that was present in this bulk request.  Note that we deduplicate the attribute collection, process only unique attributes,
     * and call out duplicates.  A duplicate attribute in a bulk request will not prevent the processing of further attributes in the bulk operation.
     * The following values are error statuses and the bulk processing is stopped when the first error is encountered.
     * PIN_NOT_ALLOWED - The caller has asked to pin an active attribute which is not allowed.
     * INVALID_ATTRIBUTE - The attribute is invalid.
     * ATTRIBUTE_NOT_PROCESSED - The attribute was not processed, as there was another attribute in this bulk request collection that resulted in a processing error.
     *
     */
    "attributeStatus": AttributePinResponse.AttributeStatus;
    /**
     * Time when the attribute was activated or deactivated.  Note that ingest might not have picked up the changes even if this time has elapsed.
     *
     */
    "timeUpdated": Date;
}
export declare namespace AttributePinResponse {
    enum OperationType {
        Pin = "PIN",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    enum AttributeNameSpace {
        Traces = "TRACES",
        Synthetic = "SYNTHETIC",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    enum AttributeStatus {
        AttributeAlreadyPinned = "ATTRIBUTE_ALREADY_PINNED",
        AttributePinned = "ATTRIBUTE_PINNED",
        PinNotAllowed = "PIN_NOT_ALLOWED",
        DuplicateAttribute = "DUPLICATE_ATTRIBUTE",
        InvalidAttribute = "INVALID_ATTRIBUTE",
        AttributeNotProcessed = "ATTRIBUTE_NOT_PROCESSED",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    function getJsonObj(obj: AttributePinResponse): object;
    function getDeserializedJsonObj(obj: AttributePinResponse): object;
}
