/**
 * Application Performance Monitoring Trace Explorer API
 * Use the Application Performance Monitoring Trace Explorer API to query traces and associated spans in Trace Explorer. For more information, see [Application Performance Monitoring](https://docs.oracle.com/iaas/application-performance-monitoring/index.html).

 * OpenAPI spec version: 20200630
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
/**
 * Response of an individual attribute item in the bulk update attribute operation.
 *
 */
export interface AttributeUpdateResponse {
    /**
     * Attribute for which properties were updated in this bulk operation.
     *
     */
    "attributeName": string;
    /**
     * Type of the attribute.
     *
     */
    "attributeType"?: AttributeUpdateResponse.AttributeType;
    /**
     * Unit updated for this attribute.
     *
     */
    "unit"?: AttributeUpdateResponse.Unit;
    /**
     * Notes for the attribute.
     *
     */
    "notes"?: string;
    /**
     * Type of operation - UPDATE_ATTRIBUTE_PROPERTIES.
     *
     */
    "operationType"?: AttributeUpdateResponse.OperationType;
    /**
     * Status of the attribute after this operation.  The attribute can have one of the following statuses after the update operation.  The attribute
     * can have either a success status or an error status.  The status of the attribute must be correlated with the operation status property in the bulk operation metadata
     * object.  The bulk operation will be successful only when all attributes in the bulk request are processed successfully and they get a success status back.
     * The following are successful status values of individual attribute items in a bulk update attribute operation.
     * ATTRIBUTE_UPDATED - The attribute's properites have been updated with the given properties.
     * DUPLICATE_ATTRIBUTE - The attribute is a duplicate of an attribute that was present in this bulk request.  Note that we deduplicate the attribute collection, process only unique attributes,
     * and call out duplicates.  A duplicate attribute in a bulk request will not prevent the processing of further attributes in the bulk operation.
     * The following values are error statuses and the bulk processing is stopped when the first error is encountered.
     * INVALID_ATTRIBUTE - The attribute is invalid.
     * ATTRIBUTE_NOT_PROCESSED - The attribute was not processed, as there was another attribute in this bulk request collection that resulted in a processing error.
     * ATTRIBUTE_DOES_NOT_EXIST - Attribute was neither active nor pinned inactive.
     * ATTRIBUTE_UPDATE_NOT_ALLOWED - Attribute update is not allowed as it is an in-built system attribute.
     *
     */
    "attributeStatus"?: AttributeUpdateResponse.AttributeStatus;
    /**
     * Namespace of the attribute whose properties were updated.  The attributeNameSpace will default to TRACES if it is
     * not passed in.
     *
     */
    "attributeNameSpace": AttributeUpdateResponse.AttributeNameSpace;
    /**
     * Time when the attribute's properties were updated.
     *
     */
    "timeUpdated": Date;
}
export declare namespace AttributeUpdateResponse {
    enum AttributeType {
        Numeric = "NUMERIC",
        String = "STRING",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    enum Unit {
        None = "NONE",
        EpochTimeMs = "EPOCH_TIME_MS",
        Bytes = "BYTES",
        Count = "COUNT",
        DurationMs = "DURATION_MS",
        TraceStatus = "TRACE_STATUS",
        Percentage = "PERCENTAGE",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    enum OperationType {
        UpdateAttributeProperties = "UPDATE_ATTRIBUTE_PROPERTIES",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    enum AttributeStatus {
        AttributeUpdated = "ATTRIBUTE_UPDATED",
        DuplicateAttribute = "DUPLICATE_ATTRIBUTE",
        InvalidAttribute = "INVALID_ATTRIBUTE",
        AttributeNotProcessed = "ATTRIBUTE_NOT_PROCESSED",
        AttributeDoesNotExist = "ATTRIBUTE_DOES_NOT_EXIST",
        AttributeUpdateNotAllowed = "ATTRIBUTE_UPDATE_NOT_ALLOWED",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    enum AttributeNameSpace {
        Traces = "TRACES",
        Synthetic = "SYNTHETIC",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    function getJsonObj(obj: AttributeUpdateResponse): object;
    function getDeserializedJsonObj(obj: AttributeUpdateResponse): object;
}
