/**
 * Application Performance Monitoring Trace Explorer API
 * Use the Application Performance Monitoring Trace Explorer API to query traces and associated spans in Trace Explorer. For more information, see [Application Performance Monitoring](https://docs.oracle.com/iaas/application-performance-monitoring/index.html).

 * OpenAPI spec version: 20200630
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
/**
 * Metadata about the bulk activation operation.  The bulk activation operation is atomic and binary.  If the processing of any of the attributes in the bulk
 * activation request results in a processing or validation error, then none of the attributes in the request are activated.  The bulk activation request succeeds
 * only when all the attributes in the bulk activation request are processed and they get a successful attributeStatus back.
 *
 */
export interface BulkActivationMetadata {
    /**
     * Operation status of the bulk activation operation.  The bulk  activation operation could have either a success or an error status as defined below.
     * The following is a success status for the bulk activation operation.
     * SUCCESS - The bulk activation operation has succeeded and all the attributes in the bulk activation request have been activated by this operation or activated earlier.
     * The following are error statuses for the bulk activation operation.  Note that none of the attributes (string or numeric) in the bulk request have been activated by this bulk
     * activation operation if any of the below statuses.
     * EMPTY_ATTRIBUTE_LIST - The bulk activation request object was empty and did not contain any attributes to be activated.
     * NUMERIC_ATTRIBUTE_LIMIT_EXCEEDED - The number of numeric attributes in the bulk request exceeded the maximum limit (100) of numeric attributes that could be activated in the APM Domain.
     * STRING_ATTRIBUTE_LIMIT_EXCEEDED - The number of string attributes in the bulk request exceeded the maximum limit (700) of string attributes that could be activated in the APM Domain.
     * INSUFFICIENT_STRING_SPACE - There are not enough free slots available in the APM Domain to activate the string attributes present in the bulk request.
     * INSUFFICIENT_NUMERIC_SPACE - There are not enough free slots available in the APM Domain to activate the numeric attributes present in the bulk request.
     * INVALID_BULK_REQUEST - The bulk request contains invalid attribute(s), or attribute(s) that resulted in a validation error, or an attribute that resulted
     * in a processing error.
     *
     */
    "operationStatus": BulkActivationMetadata.OperationStatus;
    /**
     * Type of operation.
     *
     */
    "operationType": BulkActivationMetadata.OperationType;
    /**
     * Total number of string attributes in TRACES namespace that were activated.
     *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "stringAttributesActivated"?: number;
    /**
     * Total number of numeric attributes in TRACES namespace that were activated.
     *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "numericAttributesActivated"?: number;
    /**
     * Total number of string attributes in SYNTHETIC namespace that were activated.
     *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "syntheticStringAttributesActivated"?: number;
    /**
     * Total number of numeric attributes in SYNTHETIC namespace that were activated.
     *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "syntheticNumericAttributesActivated"?: number;
    /**
     * Total number of free slots available to activate string attributes in the TRACES namespace in the APM Domain.  Note that if a bulk request has succeeded, this
     * number reflects the total number of free slots available for activation of additional string attributes in the TRACES namespace in the APM Domain.
     *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "availableStringAttributes"?: number;
    /**
     * Total number of free slots available to activate numeric attributes in the TRACES namespace in the APM Domain.  Note that if a bulk request has succeeded, this
     * number reflects the total number of free slots available for activation of additional numeric attributes in the TRACES namespace in the APM Domain.
     *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "availableNumericAttributes"?: number;
    /**
     * Total number of free slots available to activate string attributes in the SYNTHETIC namespace in the APM Domain.  Note that if a bulk request has succeeded, this
     * number reflects the total number of free synthetic slots available for activation of additional string attributes in the SYNTHETIC namespace in the APM Domain.
     *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "availableSyntheticStringAttributes"?: number;
    /**
     * Total number of free slots available to activate numeric attributes in the SYNTHETIC namespace in the APM Domain.  Note that if a bulk request has succeeded, this
     * number reflects the total number of free synthetic slots available for activation of additional numeric attributes in the SYNTHETIC namespace in the APM Domain.
     *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "availableSyntheticNumericAttributes"?: number;
}
export declare namespace BulkActivationMetadata {
    enum OperationStatus {
        Success = "SUCCESS",
        EmptyAttributeList = "EMPTY_ATTRIBUTE_LIST",
        NumericAttributeLimitExceeded = "NUMERIC_ATTRIBUTE_LIMIT_EXCEEDED",
        StringAttributeLimitExceeded = "STRING_ATTRIBUTE_LIMIT_EXCEEDED",
        InsufficientStringSpace = "INSUFFICIENT_STRING_SPACE",
        InsufficientNumericSpace = "INSUFFICIENT_NUMERIC_SPACE",
        InvalidBulkRequest = "INVALID_BULK_REQUEST",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    enum OperationType {
        Activate = "ACTIVATE",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    function getJsonObj(obj: BulkActivationMetadata): object;
    function getDeserializedJsonObj(obj: BulkActivationMetadata): object;
}
