/**
 * Application Performance Monitoring Trace Explorer API
 * Use the Application Performance Monitoring Trace Explorer API to query traces and associated spans in Trace Explorer. For more information, see [Application Performance Monitoring](https://docs.oracle.com/iaas/application-performance-monitoring/index.html).

 * OpenAPI spec version: 20200630
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
/**
 * Metadata about the bulk attribute update operation.  The bulk attribute update operation is atomic and binary.  If the processing of any of the attributes
 * in the bulk attribute update request results in a processing or validation error, then none of the attributes updated.
 *
 */
export interface BulkUpdateAttributeMetadata {
    /**
     * Operation status of the bulk update attribute operation.
     * SUCCESS - The bulk attribute update request has succeeded and all the attributes in the request have been updated.
     * The following are error statuses for the bulk update attributes operation.
     * EMPTY_ATTRIBUTE_LIST - The bulk update attributes request object was empty and did not contain any attributes for which properties had to be updated.
     * INVALID_BULK_REQUEST - The bulk request contains invalid attribute(s), or attribute(s) that resulted in a validation error, or an attribute that resulted
     * in a processing error.
     *
     */
    "operationStatus": BulkUpdateAttributeMetadata.OperationStatus;
    /**
     * Type of operation.
     *
     */
    "operationType": BulkUpdateAttributeMetadata.OperationType;
    /**
     * Total number attributes (both string and numeric) in TRACES namespace for which properties were updated.
     *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "attributesUpdated": number;
    /**
     * Total number attributes (both string and numeric) in SYNTHETIC namespace for which properties were updated.
     *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "syntheticAttributesUpdated"?: number;
}
export declare namespace BulkUpdateAttributeMetadata {
    enum OperationStatus {
        Success = "SUCCESS",
        EmptyAttributeList = "EMPTY_ATTRIBUTE_LIST",
        InvalidBulkRequest = "INVALID_BULK_REQUEST",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    enum OperationType {
        UpdateAttributeProperties = "UPDATE_ATTRIBUTE_PROPERTIES",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    function getJsonObj(obj: BulkUpdateAttributeMetadata): object;
    function getDeserializedJsonObj(obj: BulkUpdateAttributeMetadata): object;
}
