/**
 * Application Performance Monitoring Trace Explorer API
 * Use the Application Performance Monitoring Trace Explorer API to query traces and associated spans in Trace Explorer. For more information, see [Application Performance Monitoring](https://docs.oracle.com/iaas/application-performance-monitoring/index.html).

 * OpenAPI spec version: 20200630
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
/**
 * Metadata about the bulk update notes operation.  The bulk update notes operation is atomic and binary.  If the processing of any of the attributes
 * in the bulk update notes request results in a processing or validation error, then none of the notes in the update notes request are updated.
 *
 */
export interface BulkUpdateNotesMetadata {
    /**
     * Operation status of the bulk update notes operation.
     * SUCCESS - The bulk updates notes request has succeeded and all the attributes in the bulk update notes request have been updated with the provided notes.
     * The following are error statuses for the bulk update notes operation.
     * EMPTY_ATTRIBUTE_LIST - The bulk update notes request object was empty and did not contain any attributes for which notes had to be updated.
     * INVALID_BULK_REQUEST - The bulk request contains invalid attribute(s), or attribute(s) that resulted in a validation error, or an attribute that resulted
     * in a processing error.
     *
     */
    "operationStatus": BulkUpdateNotesMetadata.OperationStatus;
    /**
     * Type of operation.
     *
     */
    "operationType": BulkUpdateNotesMetadata.OperationType;
    /**
     * Total number attributes (both string and numeric) in TRACES namespace for which notes were updated.
     *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "attributesNotesUpdated": number;
    /**
     * Total number attributes (both string and numeric) in SYNTHETIC namespace that were pinned.
     *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "syntheticAttributesPinned"?: number;
}
export declare namespace BulkUpdateNotesMetadata {
    enum OperationStatus {
        Success = "SUCCESS",
        EmptyAttributeList = "EMPTY_ATTRIBUTE_LIST",
        InvalidBulkRequest = "INVALID_BULK_REQUEST",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    enum OperationType {
        UpdateNotes = "UPDATE_NOTES",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    function getJsonObj(obj: BulkUpdateNotesMetadata): object;
    function getDeserializedJsonObj(obj: BulkUpdateNotesMetadata): object;
}
