/**
 * Autoscaling API
 * APIs for dynamically scaling Compute resources to meet application requirements. For more information about
autoscaling, see [Autoscaling](/Content/Compute/Tasks/autoscalinginstancepools.htm). For information about the
Compute service, see [Overview of the Compute Service](/Content/Compute/Concepts/computeoverview.htm).

**Note:** Autoscaling is not available in US Government Cloud tenancies. For more information, see
[Oracle Cloud Infrastructure US Government Cloud](/Content/General/Concepts/govoverview.htm).

 * OpenAPI spec version: 20181001
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import common = require("oci-common");
import * as requests from "./request";
import * as model from "./model";
import * as responses from "./response";
declare const Breaker: any;
export declare enum AutoScalingApiKeys {
}
/**
 * This service client uses {@link common.CircuitBreaker.DefaultConfiguration} for all the operations by default if no circuit breaker configuration is defined by the user.
 */
export declare class AutoScalingClient {
    protected static serviceEndpointTemplate: string;
    protected static endpointServiceName: string;
    protected "_realmSpecificEndpointTemplateEnabled": boolean | undefined;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: typeof Breaker | null;
    protected _httpOptions: any;
    protected _bodyDuplexMode: any;
    targetService: string;
    protected _regionId: string;
    protected "_region": common.Region;
    protected _lastSetRegionOrRegionId: string;
    protected _httpClient: common.HttpClient;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    get endpoint(): string;
    /**
     * Sets the endpoint to call (ex, https://www.example.com).
     * @param endpoint The endpoint of the service.
     */
    set endpoint(endpoint: string);
    get logger(): import("oci-common/lib/log").Logger;
    /**
     * Determines whether realm specific endpoint should be used or not.
     * Set realmSpecificEndpointTemplateEnabled to "true" if the user wants to enable use of realm specific endpoint template, otherwise set it to "false"
     * @param realmSpecificEndpointTemplateEnabled flag to enable the use of realm specific endpoint template
     */
    set useRealmSpecificEndpointTemplate(realmSpecificEndpointTemplateEnabled: boolean);
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    set region(region: common.Region);
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    set regionId(regionId: string);
    /**
     * Shutdown the circuit breaker used by the client when it is no longer needed
     */
    shutdownCircuitBreaker(): void;
    /**
     * Close the client once it is no longer needed
     */
    close(): void;
    /**
       * Moves an autoscaling configuration into a different compartment within the same tenancy. For information
  * about moving resources between compartments, see
  * [Moving Resources to a Different Compartment](https://docs.cloud.oracle.com/iaas/Content/Identity/Tasks/managingcompartments.htm#moveRes).
  * <p>
  When you move an autoscaling configuration to a different compartment, associated resources such as instance
  * pools are not moved.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param ChangeAutoScalingConfigurationCompartmentRequest
       * @return ChangeAutoScalingConfigurationCompartmentResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/autoscaling/ChangeAutoScalingConfigurationCompartment.ts.html |here} to see how to use ChangeAutoScalingConfigurationCompartment API.
       */
    changeAutoScalingConfigurationCompartment(changeAutoScalingConfigurationCompartmentRequest: requests.ChangeAutoScalingConfigurationCompartmentRequest): Promise<responses.ChangeAutoScalingConfigurationCompartmentResponse>;
    /**
     * Creates an autoscaling configuration.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateAutoScalingConfigurationRequest
     * @return CreateAutoScalingConfigurationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/autoscaling/CreateAutoScalingConfiguration.ts.html |here} to see how to use CreateAutoScalingConfiguration API.
     */
    createAutoScalingConfiguration(createAutoScalingConfigurationRequest: requests.CreateAutoScalingConfigurationRequest): Promise<responses.CreateAutoScalingConfigurationResponse>;
    /**
       * Creates an autoscaling policy for the specified autoscaling configuration.
  * <p>
  You can create the following types of autoscaling policies:
  * <p>
  - **Schedule-based:** Autoscaling events take place at the specific times that you schedule.
  * - **Threshold-based:** An autoscaling action is triggered when a performance metric meets or exceeds a threshold.
  * <p>
  An autoscaling configuration can either have multiple schedule-based autoscaling policies, or one
  * threshold-based autoscaling policy.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param CreateAutoScalingPolicyRequest
       * @return CreateAutoScalingPolicyResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/autoscaling/CreateAutoScalingPolicy.ts.html |here} to see how to use CreateAutoScalingPolicy API.
       */
    createAutoScalingPolicy(createAutoScalingPolicyRequest: requests.CreateAutoScalingPolicyRequest): Promise<responses.CreateAutoScalingPolicyResponse>;
    /**
     * Deletes an autoscaling configuration.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteAutoScalingConfigurationRequest
     * @return DeleteAutoScalingConfigurationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/autoscaling/DeleteAutoScalingConfiguration.ts.html |here} to see how to use DeleteAutoScalingConfiguration API.
     */
    deleteAutoScalingConfiguration(deleteAutoScalingConfigurationRequest: requests.DeleteAutoScalingConfigurationRequest): Promise<responses.DeleteAutoScalingConfigurationResponse>;
    /**
     * Deletes an autoscaling policy for the specified autoscaling configuration.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteAutoScalingPolicyRequest
     * @return DeleteAutoScalingPolicyResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/autoscaling/DeleteAutoScalingPolicy.ts.html |here} to see how to use DeleteAutoScalingPolicy API.
     */
    deleteAutoScalingPolicy(deleteAutoScalingPolicyRequest: requests.DeleteAutoScalingPolicyRequest): Promise<responses.DeleteAutoScalingPolicyResponse>;
    /**
     * Gets information about the specified autoscaling configuration.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetAutoScalingConfigurationRequest
     * @return GetAutoScalingConfigurationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/autoscaling/GetAutoScalingConfiguration.ts.html |here} to see how to use GetAutoScalingConfiguration API.
     */
    getAutoScalingConfiguration(getAutoScalingConfigurationRequest: requests.GetAutoScalingConfigurationRequest): Promise<responses.GetAutoScalingConfigurationResponse>;
    /**
     * Gets information about the specified autoscaling policy in the specified autoscaling configuration.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetAutoScalingPolicyRequest
     * @return GetAutoScalingPolicyResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/autoscaling/GetAutoScalingPolicy.ts.html |here} to see how to use GetAutoScalingPolicy API.
     */
    getAutoScalingPolicy(getAutoScalingPolicyRequest: requests.GetAutoScalingPolicyRequest): Promise<responses.GetAutoScalingPolicyResponse>;
    /**
     * Lists autoscaling configurations in the specifed compartment.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListAutoScalingConfigurationsRequest
     * @return ListAutoScalingConfigurationsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/autoscaling/ListAutoScalingConfigurations.ts.html |here} to see how to use ListAutoScalingConfigurations API.
     */
    listAutoScalingConfigurations(listAutoScalingConfigurationsRequest: requests.ListAutoScalingConfigurationsRequest): Promise<responses.ListAutoScalingConfigurationsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listAutoScalingConfigurationsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.AutoScalingConfigurationSummary objects
     * contained in responses from the listAutoScalingConfigurations operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllAutoScalingConfigurations(request: requests.ListAutoScalingConfigurationsRequest): AsyncIterableIterator<model.AutoScalingConfigurationSummary>;
    /**
     * NOTE: This function is deprecated in favor of listAutoScalingConfigurationsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listAutoScalingConfigurations operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllAutoScalingConfigurationsResponses(request: requests.ListAutoScalingConfigurationsRequest): AsyncIterableIterator<responses.ListAutoScalingConfigurationsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.AutoScalingConfigurationSummary objects
     * contained in responses from the listAutoScalingConfigurations operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAutoScalingConfigurationsRecordIterator(request: requests.ListAutoScalingConfigurationsRequest): AsyncIterableIterator<model.AutoScalingConfigurationSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listAutoScalingConfigurations operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAutoScalingConfigurationsResponseIterator(request: requests.ListAutoScalingConfigurationsRequest): AsyncIterableIterator<responses.ListAutoScalingConfigurationsResponse>;
    /**
     * Lists the autoscaling policies in the specified autoscaling configuration.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListAutoScalingPoliciesRequest
     * @return ListAutoScalingPoliciesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/autoscaling/ListAutoScalingPolicies.ts.html |here} to see how to use ListAutoScalingPolicies API.
     */
    listAutoScalingPolicies(listAutoScalingPoliciesRequest: requests.ListAutoScalingPoliciesRequest): Promise<responses.ListAutoScalingPoliciesResponse>;
    /**
     * NOTE: This function is deprecated in favor of listAutoScalingPoliciesRecordIterator function.
     * Creates a new async iterator which will iterate over the models.AutoScalingPolicySummary objects
     * contained in responses from the listAutoScalingPolicies operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllAutoScalingPolicies(request: requests.ListAutoScalingPoliciesRequest): AsyncIterableIterator<model.AutoScalingPolicySummary>;
    /**
     * NOTE: This function is deprecated in favor of listAutoScalingPoliciesResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listAutoScalingPolicies operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllAutoScalingPoliciesResponses(request: requests.ListAutoScalingPoliciesRequest): AsyncIterableIterator<responses.ListAutoScalingPoliciesResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.AutoScalingPolicySummary objects
     * contained in responses from the listAutoScalingPolicies operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAutoScalingPoliciesRecordIterator(request: requests.ListAutoScalingPoliciesRequest): AsyncIterableIterator<model.AutoScalingPolicySummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listAutoScalingPolicies operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAutoScalingPoliciesResponseIterator(request: requests.ListAutoScalingPoliciesRequest): AsyncIterableIterator<responses.ListAutoScalingPoliciesResponse>;
    /**
     * Updates certain fields on the specified autoscaling configuration, such as the name, the cooldown period,
     * and whether the autoscaling configuration is enabled.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateAutoScalingConfigurationRequest
     * @return UpdateAutoScalingConfigurationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/autoscaling/UpdateAutoScalingConfiguration.ts.html |here} to see how to use UpdateAutoScalingConfiguration API.
     */
    updateAutoScalingConfiguration(updateAutoScalingConfigurationRequest: requests.UpdateAutoScalingConfigurationRequest): Promise<responses.UpdateAutoScalingConfigurationResponse>;
    /**
     * Updates an autoscaling policy in the specified autoscaling configuration.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateAutoScalingPolicyRequest
     * @return UpdateAutoScalingPolicyResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/autoscaling/UpdateAutoScalingPolicy.ts.html |here} to see how to use UpdateAutoScalingPolicy API.
     */
    updateAutoScalingPolicy(updateAutoScalingPolicyRequest: requests.UpdateAutoScalingPolicyRequest): Promise<responses.UpdateAutoScalingPolicyResponse>;
}
export {};
