/**
 * Big Data Service API
 * REST API for Oracle Big Data Service. Use this API to build, deploy, and manage fully elastic Big Data Service clusters. Build on Hadoop, Spark and Data Science distributions, which can be fully integrated with existing enterprise data in Oracle Database and Oracle applications.

 * OpenAPI spec version: 20190531
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import common = require("oci-common");
import * as requests from "./request";
import * as model from "./model";
import * as responses from "./response";
import { BdsWaiter } from "./bds-waiter";
declare const Breaker: any;
export declare enum BdsApiKeys {
}
/**
 * This service client uses {@link common.CircuitBreaker.DefaultConfiguration} for all the operations by default if no circuit breaker configuration is defined by the user.
 */
export declare class BdsClient {
    protected static serviceEndpointTemplate: string;
    protected static endpointServiceName: string;
    protected "_realmSpecificEndpointTemplateEnabled": boolean | undefined;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_waiters": BdsWaiter;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: typeof Breaker | null;
    protected _httpOptions: any;
    protected _bodyDuplexMode: any;
    targetService: string;
    protected _regionId: string;
    protected "_region": common.Region;
    protected _lastSetRegionOrRegionId: string;
    protected _httpClient: common.HttpClient;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    get endpoint(): string;
    /**
     * Sets the endpoint to call (ex, https://www.example.com).
     * @param endpoint The endpoint of the service.
     */
    set endpoint(endpoint: string);
    get logger(): import("oci-common/lib/log").Logger;
    /**
     * Determines whether realm specific endpoint should be used or not.
     * Set realmSpecificEndpointTemplateEnabled to "true" if the user wants to enable use of realm specific endpoint template, otherwise set it to "false"
     * @param realmSpecificEndpointTemplateEnabled flag to enable the use of realm specific endpoint template
     */
    set useRealmSpecificEndpointTemplate(realmSpecificEndpointTemplateEnabled: boolean);
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    set region(region: common.Region);
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    set regionId(regionId: string);
    /**
     * Creates a new BdsWaiter for resources for this service.
     *
     * @param config The waiter configuration for termination and delay strategy
     * @return The service waiters.
     */
    createWaiters(config?: common.WaiterConfiguration): BdsWaiter;
    /**
     * Gets the waiters available for resources for this service.
     *
     * @return The service waiters.
     */
    getWaiters(): BdsWaiter;
    /**
     * Shutdown the circuit breaker used by the client when it is no longer needed
     */
    shutdownCircuitBreaker(): void;
    /**
     * Close the client once it is no longer needed
     */
    close(): void;
    /**
     * Activate specified metastore configuration.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ActivateBdsMetastoreConfigurationRequest
     * @return ActivateBdsMetastoreConfigurationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/bds/ActivateBdsMetastoreConfiguration.ts.html |here} to see how to use ActivateBdsMetastoreConfiguration API.
     */
    activateBdsMetastoreConfiguration(activateBdsMetastoreConfigurationRequest: requests.ActivateBdsMetastoreConfigurationRequest): Promise<responses.ActivateBdsMetastoreConfigurationResponse>;
    /**
     * Add an autoscale configuration to the cluster.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param AddAutoScalingConfigurationRequest
     * @return AddAutoScalingConfigurationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/bds/AddAutoScalingConfiguration.ts.html |here} to see how to use AddAutoScalingConfiguration API.
     */
    addAutoScalingConfiguration(addAutoScalingConfigurationRequest: requests.AddAutoScalingConfigurationRequest): Promise<responses.AddAutoScalingConfigurationResponse>;
    /**
     * Adds block storage to existing worker/compute only worker nodes. The same amount of  storage will be added to all worker/compute only worker nodes. No change will be made to storage that is already attached. Block storage cannot be removed.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param AddBlockStorageRequest
     * @return AddBlockStorageResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/bds/AddBlockStorage.ts.html |here} to see how to use AddBlockStorage API.
     */
    addBlockStorage(addBlockStorageRequest: requests.AddBlockStorageRequest): Promise<responses.AddBlockStorageResponse>;
    /**
     * Adds Cloud SQL to your cluster. You can use Cloud SQL to query against non-relational data stored in multiple big data sources, including Apache Hive, HDFS, Oracle NoSQL Database, and Apache HBase. Adding Cloud SQL adds a query server node to the cluster and creates cell servers on all the worker nodes in the cluster.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param AddCloudSqlRequest
     * @return AddCloudSqlResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/bds/AddCloudSql.ts.html |here} to see how to use AddCloudSql API.
     */
    addCloudSql(addCloudSqlRequest: requests.AddCloudSqlRequest): Promise<responses.AddCloudSqlResponse>;
    /**
     * Adds Kafka to a cluster.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param AddKafkaRequest
     * @return AddKafkaResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/bds/AddKafka.ts.html |here} to see how to use AddKafka API.
     */
    addKafka(addKafkaRequest: requests.AddKafkaRequest): Promise<responses.AddKafkaResponse>;
    /**
     * Increases the size (scales out) of a cluster by adding master nodes. The added master nodes will have the same shape and will have the same amount of attached block storage as other master nodes in the cluster.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param AddMasterNodesRequest
     * @return AddMasterNodesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/bds/AddMasterNodes.ts.html |here} to see how to use AddMasterNodes API.
     */
    addMasterNodes(addMasterNodesRequest: requests.AddMasterNodesRequest): Promise<responses.AddMasterNodesResponse>;
    /**
     * Increases the size (scales out) of a cluster by adding utility nodes. The added utility nodes will have the same shape and will have the same amount of attached block storage as other utility nodes in the cluster.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param AddUtilityNodesRequest
     * @return AddUtilityNodesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/bds/AddUtilityNodes.ts.html |here} to see how to use AddUtilityNodes API.
     */
    addUtilityNodes(addUtilityNodesRequest: requests.AddUtilityNodesRequest): Promise<responses.AddUtilityNodesResponse>;
    /**
     * Increases the size (scales out) a cluster by adding worker nodes(data/compute). The added worker nodes will have the same shape and will have the same amount of attached block storage as other worker nodes in the cluster.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param AddWorkerNodesRequest
     * @return AddWorkerNodesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/bds/AddWorkerNodes.ts.html |here} to see how to use AddWorkerNodes API.
     */
    addWorkerNodes(addWorkerNodesRequest: requests.AddWorkerNodesRequest): Promise<responses.AddWorkerNodesResponse>;
    /**
     * Takes a backup of of given nodes.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param BackupNodeRequest
     * @return BackupNodeResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/bds/BackupNode.ts.html |here} to see how to use BackupNode API.
     */
    backupNode(backupNodeRequest: requests.BackupNodeRequest): Promise<responses.BackupNodeResponse>;
    /**
     * A list of services and their certificate details.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CertificateServiceInfoRequest
     * @return CertificateServiceInfoResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/bds/CertificateServiceInfo.ts.html |here} to see how to use CertificateServiceInfo API.
     */
    certificateServiceInfo(certificateServiceInfoRequest: requests.CertificateServiceInfoRequest): Promise<responses.CertificateServiceInfoResponse>;
    /**
     * Moves a Big Data Service cluster into a different compartment.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangeBdsInstanceCompartmentRequest
     * @return ChangeBdsInstanceCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/bds/ChangeBdsInstanceCompartment.ts.html |here} to see how to use ChangeBdsInstanceCompartment API.
     */
    changeBdsInstanceCompartment(changeBdsInstanceCompartmentRequest: requests.ChangeBdsInstanceCompartmentRequest): Promise<responses.ChangeBdsInstanceCompartmentResponse>;
    /**
     * Changes the size of a cluster by scaling up or scaling down the nodes. Nodes are scaled up or down by changing the shapes of all the nodes of the same type to the next larger or smaller shape. The node types are master, utility, worker, and Cloud SQL. Only nodes with VM-STANDARD shapes can be scaled.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangeShapeRequest
     * @return ChangeShapeResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/bds/ChangeShape.ts.html |here} to see how to use ChangeShape API.
     */
    changeShape(changeShapeRequest: requests.ChangeShapeRequest): Promise<responses.ChangeShapeResponse>;
    /**
     * Create an API key on behalf of the specified user.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateBdsApiKeyRequest
     * @return CreateBdsApiKeyResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/bds/CreateBdsApiKey.ts.html |here} to see how to use CreateBdsApiKey API.
     */
    createBdsApiKey(createBdsApiKeyRequest: requests.CreateBdsApiKeyRequest): Promise<responses.CreateBdsApiKeyResponse>;
    /**
     * Creates a Big Data Service cluster.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateBdsInstanceRequest
     * @return CreateBdsInstanceResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/bds/CreateBdsInstance.ts.html |here} to see how to use CreateBdsInstance API.
     */
    createBdsInstance(createBdsInstanceRequest: requests.CreateBdsInstanceRequest): Promise<responses.CreateBdsInstanceResponse>;
    /**
     * Create and activate external metastore configuration.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateBdsMetastoreConfigurationRequest
     * @return CreateBdsMetastoreConfigurationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/bds/CreateBdsMetastoreConfiguration.ts.html |here} to see how to use CreateBdsMetastoreConfiguration API.
     */
    createBdsMetastoreConfiguration(createBdsMetastoreConfigurationRequest: requests.CreateBdsMetastoreConfigurationRequest): Promise<responses.CreateBdsMetastoreConfigurationResponse>;
    /**
     * Add a node volume backup configuration to the cluster for an indicated node type or node.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateNodeBackupConfigurationRequest
     * @return CreateNodeBackupConfigurationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/bds/CreateNodeBackupConfiguration.ts.html |here} to see how to use CreateNodeBackupConfiguration API.
     */
    createNodeBackupConfiguration(createNodeBackupConfigurationRequest: requests.CreateNodeBackupConfigurationRequest): Promise<responses.CreateNodeBackupConfigurationResponse>;
    /**
     * Add a nodeReplaceConfigurations to the cluster.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateNodeReplaceConfigurationRequest
     * @return CreateNodeReplaceConfigurationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/bds/CreateNodeReplaceConfiguration.ts.html |here} to see how to use CreateNodeReplaceConfiguration API.
     */
    createNodeReplaceConfiguration(createNodeReplaceConfigurationRequest: requests.CreateNodeReplaceConfigurationRequest): Promise<responses.CreateNodeReplaceConfigurationResponse>;
    /**
     * Deletes the user's API key represented by the provided ID.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteBdsApiKeyRequest
     * @return DeleteBdsApiKeyResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/bds/DeleteBdsApiKey.ts.html |here} to see how to use DeleteBdsApiKey API.
     */
    deleteBdsApiKey(deleteBdsApiKeyRequest: requests.DeleteBdsApiKeyRequest): Promise<responses.DeleteBdsApiKeyResponse>;
    /**
     * Deletes the cluster identified by the given ID.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteBdsInstanceRequest
     * @return DeleteBdsInstanceResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/bds/DeleteBdsInstance.ts.html |here} to see how to use DeleteBdsInstance API.
     */
    deleteBdsInstance(deleteBdsInstanceRequest: requests.DeleteBdsInstanceRequest): Promise<responses.DeleteBdsInstanceResponse>;
    /**
     * Delete the BDS metastore configuration represented by the provided ID.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteBdsMetastoreConfigurationRequest
     * @return DeleteBdsMetastoreConfigurationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/bds/DeleteBdsMetastoreConfiguration.ts.html |here} to see how to use DeleteBdsMetastoreConfiguration API.
     */
    deleteBdsMetastoreConfiguration(deleteBdsMetastoreConfigurationRequest: requests.DeleteBdsMetastoreConfigurationRequest): Promise<responses.DeleteBdsMetastoreConfigurationResponse>;
    /**
     * Delete the NodeBackup represented by the provided ID.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteNodeBackupRequest
     * @return DeleteNodeBackupResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/bds/DeleteNodeBackup.ts.html |here} to see how to use DeleteNodeBackup API.
     */
    deleteNodeBackup(deleteNodeBackupRequest: requests.DeleteNodeBackupRequest): Promise<responses.DeleteNodeBackupResponse>;
    /**
     * Delete the NodeBackupConfiguration represented by the provided ID.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteNodeBackupConfigurationRequest
     * @return DeleteNodeBackupConfigurationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/bds/DeleteNodeBackupConfiguration.ts.html |here} to see how to use DeleteNodeBackupConfiguration API.
     */
    deleteNodeBackupConfiguration(deleteNodeBackupConfigurationRequest: requests.DeleteNodeBackupConfigurationRequest): Promise<responses.DeleteNodeBackupConfigurationResponse>;
    /**
     * Disabling TLS/SSL for various ODH services running on the BDS cluster.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DisableCertificateRequest
     * @return DisableCertificateResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/bds/DisableCertificate.ts.html |here} to see how to use DisableCertificate API.
     */
    disableCertificate(disableCertificateRequest: requests.DisableCertificateRequest): Promise<responses.DisableCertificateResponse>;
    /**
     * Configuring TLS/SSL for various ODH services running on the BDS cluster.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param EnableCertificateRequest
     * @return EnableCertificateResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/bds/EnableCertificate.ts.html |here} to see how to use EnableCertificate API.
     */
    enableCertificate(enableCertificateRequest: requests.EnableCertificateRequest): Promise<responses.EnableCertificateResponse>;
    /**
     * Execute bootstrap script.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ExecuteBootstrapScriptRequest
     * @return ExecuteBootstrapScriptResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/bds/ExecuteBootstrapScript.ts.html |here} to see how to use ExecuteBootstrapScript API.
     */
    executeBootstrapScript(executeBootstrapScriptRequest: requests.ExecuteBootstrapScriptRequest): Promise<responses.ExecuteBootstrapScriptResponse>;
    /**
     * Returns details of the autoscale configuration identified by the given ID.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetAutoScalingConfigurationRequest
     * @return GetAutoScalingConfigurationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/bds/GetAutoScalingConfiguration.ts.html |here} to see how to use GetAutoScalingConfiguration API.
     */
    getAutoScalingConfiguration(getAutoScalingConfigurationRequest: requests.GetAutoScalingConfigurationRequest): Promise<responses.GetAutoScalingConfigurationResponse>;
    /**
     * Returns the user's API key information for the given ID.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetBdsApiKeyRequest
     * @return GetBdsApiKeyResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/bds/GetBdsApiKey.ts.html |here} to see how to use GetBdsApiKey API.
     */
    getBdsApiKey(getBdsApiKeyRequest: requests.GetBdsApiKeyRequest): Promise<responses.GetBdsApiKeyResponse>;
    /**
     * Returns information about the Big Data Service cluster identified by the given ID.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetBdsInstanceRequest
     * @return GetBdsInstanceResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/bds/GetBdsInstance.ts.html |here} to see how to use GetBdsInstance API.
     */
    getBdsInstance(getBdsInstanceRequest: requests.GetBdsInstanceRequest): Promise<responses.GetBdsInstanceResponse>;
    /**
     * Returns the BDS Metastore configuration information for the given ID.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetBdsMetastoreConfigurationRequest
     * @return GetBdsMetastoreConfigurationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/bds/GetBdsMetastoreConfiguration.ts.html |here} to see how to use GetBdsMetastoreConfiguration API.
     */
    getBdsMetastoreConfiguration(getBdsMetastoreConfigurationRequest: requests.GetBdsMetastoreConfigurationRequest): Promise<responses.GetBdsMetastoreConfigurationResponse>;
    /**
     * Returns details of NodeBackup identified by the given ID.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetNodeBackupRequest
     * @return GetNodeBackupResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/bds/GetNodeBackup.ts.html |here} to see how to use GetNodeBackup API.
     */
    getNodeBackup(getNodeBackupRequest: requests.GetNodeBackupRequest): Promise<responses.GetNodeBackupResponse>;
    /**
     * Returns details of the NodeBackupConfiguration identified by the given ID.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetNodeBackupConfigurationRequest
     * @return GetNodeBackupConfigurationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/bds/GetNodeBackupConfiguration.ts.html |here} to see how to use GetNodeBackupConfiguration API.
     */
    getNodeBackupConfiguration(getNodeBackupConfigurationRequest: requests.GetNodeBackupConfigurationRequest): Promise<responses.GetNodeBackupConfigurationResponse>;
    /**
     * Returns details of the nodeReplaceConfiguration identified by the given ID.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetNodeReplaceConfigurationRequest
     * @return GetNodeReplaceConfigurationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/bds/GetNodeReplaceConfiguration.ts.html |here} to see how to use GetNodeReplaceConfiguration API.
     */
    getNodeReplaceConfiguration(getNodeReplaceConfigurationRequest: requests.GetNodeReplaceConfigurationRequest): Promise<responses.GetNodeReplaceConfigurationResponse>;
    /**
     * Get the details of an os patch
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetOsPatchDetailsRequest
     * @return GetOsPatchDetailsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/bds/GetOsPatchDetails.ts.html |here} to see how to use GetOsPatchDetails API.
     */
    getOsPatchDetails(getOsPatchDetailsRequest: requests.GetOsPatchDetailsRequest): Promise<responses.GetOsPatchDetailsResponse>;
    /**
     * Returns the status of the work request identified by the given ID.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetWorkRequestRequest
     * @return GetWorkRequestResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/bds/GetWorkRequest.ts.html |here} to see how to use GetWorkRequest API.
     */
    getWorkRequest(getWorkRequestRequest: requests.GetWorkRequestRequest): Promise<responses.GetWorkRequestResponse>;
    /**
     * Install an os patch on a cluster
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param InstallOsPatchRequest
     * @return InstallOsPatchResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/bds/InstallOsPatch.ts.html |here} to see how to use InstallOsPatch API.
     */
    installOsPatch(installOsPatchRequest: requests.InstallOsPatchRequest): Promise<responses.InstallOsPatchResponse>;
    /**
     * Install the specified patch to this cluster.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param InstallPatchRequest
     * @return InstallPatchResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/bds/InstallPatch.ts.html |here} to see how to use InstallPatch API.
     */
    installPatch(installPatchRequest: requests.InstallPatchRequest): Promise<responses.InstallPatchResponse>;
    /**
     * Returns information about the autoscaling configurations for a cluster.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListAutoScalingConfigurationsRequest
     * @return ListAutoScalingConfigurationsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/bds/ListAutoScalingConfigurations.ts.html |here} to see how to use ListAutoScalingConfigurations API.
     */
    listAutoScalingConfigurations(listAutoScalingConfigurationsRequest: requests.ListAutoScalingConfigurationsRequest): Promise<responses.ListAutoScalingConfigurationsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listAutoScalingConfigurationsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.AutoScalingConfigurationSummary objects
     * contained in responses from the listAutoScalingConfigurations operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllAutoScalingConfigurations(request: requests.ListAutoScalingConfigurationsRequest): AsyncIterableIterator<model.AutoScalingConfigurationSummary>;
    /**
     * NOTE: This function is deprecated in favor of listAutoScalingConfigurationsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listAutoScalingConfigurations operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllAutoScalingConfigurationsResponses(request: requests.ListAutoScalingConfigurationsRequest): AsyncIterableIterator<responses.ListAutoScalingConfigurationsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.AutoScalingConfigurationSummary objects
     * contained in responses from the listAutoScalingConfigurations operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAutoScalingConfigurationsRecordIterator(request: requests.ListAutoScalingConfigurationsRequest): AsyncIterableIterator<model.AutoScalingConfigurationSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listAutoScalingConfigurations operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAutoScalingConfigurationsResponseIterator(request: requests.ListAutoScalingConfigurationsRequest): AsyncIterableIterator<responses.ListAutoScalingConfigurationsResponse>;
    /**
     * Returns a list of all API keys associated with this Big Data Service cluster.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListBdsApiKeysRequest
     * @return ListBdsApiKeysResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/bds/ListBdsApiKeys.ts.html |here} to see how to use ListBdsApiKeys API.
     */
    listBdsApiKeys(listBdsApiKeysRequest: requests.ListBdsApiKeysRequest): Promise<responses.ListBdsApiKeysResponse>;
    /**
     * NOTE: This function is deprecated in favor of listBdsApiKeysRecordIterator function.
     * Creates a new async iterator which will iterate over the models.BdsApiKeySummary objects
     * contained in responses from the listBdsApiKeys operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllBdsApiKeys(request: requests.ListBdsApiKeysRequest): AsyncIterableIterator<model.BdsApiKeySummary>;
    /**
     * NOTE: This function is deprecated in favor of listBdsApiKeysResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listBdsApiKeys operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllBdsApiKeysResponses(request: requests.ListBdsApiKeysRequest): AsyncIterableIterator<responses.ListBdsApiKeysResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.BdsApiKeySummary objects
     * contained in responses from the listBdsApiKeys operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listBdsApiKeysRecordIterator(request: requests.ListBdsApiKeysRequest): AsyncIterableIterator<model.BdsApiKeySummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listBdsApiKeys operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listBdsApiKeysResponseIterator(request: requests.ListBdsApiKeysRequest): AsyncIterableIterator<responses.ListBdsApiKeysResponse>;
    /**
     * Returns a list of all Big Data Service clusters in a compartment.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListBdsInstancesRequest
     * @return ListBdsInstancesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/bds/ListBdsInstances.ts.html |here} to see how to use ListBdsInstances API.
     */
    listBdsInstances(listBdsInstancesRequest: requests.ListBdsInstancesRequest): Promise<responses.ListBdsInstancesResponse>;
    /**
     * NOTE: This function is deprecated in favor of listBdsInstancesRecordIterator function.
     * Creates a new async iterator which will iterate over the models.BdsInstanceSummary objects
     * contained in responses from the listBdsInstances operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllBdsInstances(request: requests.ListBdsInstancesRequest): AsyncIterableIterator<model.BdsInstanceSummary>;
    /**
     * NOTE: This function is deprecated in favor of listBdsInstancesResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listBdsInstances operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllBdsInstancesResponses(request: requests.ListBdsInstancesRequest): AsyncIterableIterator<responses.ListBdsInstancesResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.BdsInstanceSummary objects
     * contained in responses from the listBdsInstances operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listBdsInstancesRecordIterator(request: requests.ListBdsInstancesRequest): AsyncIterableIterator<model.BdsInstanceSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listBdsInstances operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listBdsInstancesResponseIterator(request: requests.ListBdsInstancesRequest): AsyncIterableIterator<responses.ListBdsInstancesResponse>;
    /**
     * Returns a list of metastore configurations ssociated with this Big Data Service cluster.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListBdsMetastoreConfigurationsRequest
     * @return ListBdsMetastoreConfigurationsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/bds/ListBdsMetastoreConfigurations.ts.html |here} to see how to use ListBdsMetastoreConfigurations API.
     */
    listBdsMetastoreConfigurations(listBdsMetastoreConfigurationsRequest: requests.ListBdsMetastoreConfigurationsRequest): Promise<responses.ListBdsMetastoreConfigurationsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listBdsMetastoreConfigurationsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.BdsMetastoreConfigurationSummary objects
     * contained in responses from the listBdsMetastoreConfigurations operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllBdsMetastoreConfigurations(request: requests.ListBdsMetastoreConfigurationsRequest): AsyncIterableIterator<model.BdsMetastoreConfigurationSummary>;
    /**
     * NOTE: This function is deprecated in favor of listBdsMetastoreConfigurationsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listBdsMetastoreConfigurations operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllBdsMetastoreConfigurationsResponses(request: requests.ListBdsMetastoreConfigurationsRequest): AsyncIterableIterator<responses.ListBdsMetastoreConfigurationsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.BdsMetastoreConfigurationSummary objects
     * contained in responses from the listBdsMetastoreConfigurations operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listBdsMetastoreConfigurationsRecordIterator(request: requests.ListBdsMetastoreConfigurationsRequest): AsyncIterableIterator<model.BdsMetastoreConfigurationSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listBdsMetastoreConfigurations operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listBdsMetastoreConfigurationsResponseIterator(request: requests.ListBdsMetastoreConfigurationsRequest): AsyncIterableIterator<responses.ListBdsMetastoreConfigurationsResponse>;
    /**
     * Returns information about the NodeBackupConfigurations.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListNodeBackupConfigurationsRequest
     * @return ListNodeBackupConfigurationsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/bds/ListNodeBackupConfigurations.ts.html |here} to see how to use ListNodeBackupConfigurations API.
     */
    listNodeBackupConfigurations(listNodeBackupConfigurationsRequest: requests.ListNodeBackupConfigurationsRequest): Promise<responses.ListNodeBackupConfigurationsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listNodeBackupConfigurationsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.NodeBackupConfigurationSummary objects
     * contained in responses from the listNodeBackupConfigurations operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllNodeBackupConfigurations(request: requests.ListNodeBackupConfigurationsRequest): AsyncIterableIterator<model.NodeBackupConfigurationSummary>;
    /**
     * NOTE: This function is deprecated in favor of listNodeBackupConfigurationsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listNodeBackupConfigurations operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllNodeBackupConfigurationsResponses(request: requests.ListNodeBackupConfigurationsRequest): AsyncIterableIterator<responses.ListNodeBackupConfigurationsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.NodeBackupConfigurationSummary objects
     * contained in responses from the listNodeBackupConfigurations operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listNodeBackupConfigurationsRecordIterator(request: requests.ListNodeBackupConfigurationsRequest): AsyncIterableIterator<model.NodeBackupConfigurationSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listNodeBackupConfigurations operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listNodeBackupConfigurationsResponseIterator(request: requests.ListNodeBackupConfigurationsRequest): AsyncIterableIterator<responses.ListNodeBackupConfigurationsResponse>;
    /**
     * Returns information about the node Backups.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListNodeBackupsRequest
     * @return ListNodeBackupsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/bds/ListNodeBackups.ts.html |here} to see how to use ListNodeBackups API.
     */
    listNodeBackups(listNodeBackupsRequest: requests.ListNodeBackupsRequest): Promise<responses.ListNodeBackupsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listNodeBackupsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.NodeBackupSummary objects
     * contained in responses from the listNodeBackups operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllNodeBackups(request: requests.ListNodeBackupsRequest): AsyncIterableIterator<model.NodeBackupSummary>;
    /**
     * NOTE: This function is deprecated in favor of listNodeBackupsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listNodeBackups operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllNodeBackupsResponses(request: requests.ListNodeBackupsRequest): AsyncIterableIterator<responses.ListNodeBackupsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.NodeBackupSummary objects
     * contained in responses from the listNodeBackups operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listNodeBackupsRecordIterator(request: requests.ListNodeBackupsRequest): AsyncIterableIterator<model.NodeBackupSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listNodeBackups operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listNodeBackupsResponseIterator(request: requests.ListNodeBackupsRequest): AsyncIterableIterator<responses.ListNodeBackupsResponse>;
    /**
     * Returns information about the NodeReplaceConfiguration.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListNodeReplaceConfigurationsRequest
     * @return ListNodeReplaceConfigurationsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/bds/ListNodeReplaceConfigurations.ts.html |here} to see how to use ListNodeReplaceConfigurations API.
     */
    listNodeReplaceConfigurations(listNodeReplaceConfigurationsRequest: requests.ListNodeReplaceConfigurationsRequest): Promise<responses.ListNodeReplaceConfigurationsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listNodeReplaceConfigurationsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.NodeReplaceConfigurationSummary objects
     * contained in responses from the listNodeReplaceConfigurations operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllNodeReplaceConfigurations(request: requests.ListNodeReplaceConfigurationsRequest): AsyncIterableIterator<model.NodeReplaceConfigurationSummary>;
    /**
     * NOTE: This function is deprecated in favor of listNodeReplaceConfigurationsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listNodeReplaceConfigurations operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllNodeReplaceConfigurationsResponses(request: requests.ListNodeReplaceConfigurationsRequest): AsyncIterableIterator<responses.ListNodeReplaceConfigurationsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.NodeReplaceConfigurationSummary objects
     * contained in responses from the listNodeReplaceConfigurations operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listNodeReplaceConfigurationsRecordIterator(request: requests.ListNodeReplaceConfigurationsRequest): AsyncIterableIterator<model.NodeReplaceConfigurationSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listNodeReplaceConfigurations operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listNodeReplaceConfigurationsResponseIterator(request: requests.ListNodeReplaceConfigurationsRequest): AsyncIterableIterator<responses.ListNodeReplaceConfigurationsResponse>;
    /**
     * List all available os patches for a given cluster
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListOsPatchesRequest
     * @return ListOsPatchesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/bds/ListOsPatches.ts.html |here} to see how to use ListOsPatches API.
     */
    listOsPatches(listOsPatchesRequest: requests.ListOsPatchesRequest): Promise<responses.ListOsPatchesResponse>;
    /**
     * NOTE: This function is deprecated in favor of listOsPatchesRecordIterator function.
     * Creates a new async iterator which will iterate over the models.OsPatchSummary objects
     * contained in responses from the listOsPatches operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllOsPatches(request: requests.ListOsPatchesRequest): AsyncIterableIterator<model.OsPatchSummary>;
    /**
     * NOTE: This function is deprecated in favor of listOsPatchesResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listOsPatches operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllOsPatchesResponses(request: requests.ListOsPatchesRequest): AsyncIterableIterator<responses.ListOsPatchesResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.OsPatchSummary objects
     * contained in responses from the listOsPatches operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listOsPatchesRecordIterator(request: requests.ListOsPatchesRequest): AsyncIterableIterator<model.OsPatchSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listOsPatches operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listOsPatchesResponseIterator(request: requests.ListOsPatchesRequest): AsyncIterableIterator<responses.ListOsPatchesResponse>;
    /**
     * List the patch history of this cluster.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListPatchHistoriesRequest
     * @return ListPatchHistoriesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/bds/ListPatchHistories.ts.html |here} to see how to use ListPatchHistories API.
     */
    listPatchHistories(listPatchHistoriesRequest: requests.ListPatchHistoriesRequest): Promise<responses.ListPatchHistoriesResponse>;
    /**
     * NOTE: This function is deprecated in favor of listPatchHistoriesRecordIterator function.
     * Creates a new async iterator which will iterate over the models.PatchHistorySummary objects
     * contained in responses from the listPatchHistories operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllPatchHistories(request: requests.ListPatchHistoriesRequest): AsyncIterableIterator<model.PatchHistorySummary>;
    /**
     * NOTE: This function is deprecated in favor of listPatchHistoriesResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listPatchHistories operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllPatchHistoriesResponses(request: requests.ListPatchHistoriesRequest): AsyncIterableIterator<responses.ListPatchHistoriesResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.PatchHistorySummary objects
     * contained in responses from the listPatchHistories operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listPatchHistoriesRecordIterator(request: requests.ListPatchHistoriesRequest): AsyncIterableIterator<model.PatchHistorySummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listPatchHistories operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listPatchHistoriesResponseIterator(request: requests.ListPatchHistoriesRequest): AsyncIterableIterator<responses.ListPatchHistoriesResponse>;
    /**
     * List all the available patches for this cluster.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListPatchesRequest
     * @return ListPatchesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/bds/ListPatches.ts.html |here} to see how to use ListPatches API.
     */
    listPatches(listPatchesRequest: requests.ListPatchesRequest): Promise<responses.ListPatchesResponse>;
    /**
     * NOTE: This function is deprecated in favor of listPatchesRecordIterator function.
     * Creates a new async iterator which will iterate over the models.PatchSummary objects
     * contained in responses from the listPatches operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllPatches(request: requests.ListPatchesRequest): AsyncIterableIterator<model.PatchSummary>;
    /**
     * NOTE: This function is deprecated in favor of listPatchesResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listPatches operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllPatchesResponses(request: requests.ListPatchesRequest): AsyncIterableIterator<responses.ListPatchesResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.PatchSummary objects
     * contained in responses from the listPatches operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listPatchesRecordIterator(request: requests.ListPatchesRequest): AsyncIterableIterator<model.PatchSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listPatches operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listPatchesResponseIterator(request: requests.ListPatchesRequest): AsyncIterableIterator<responses.ListPatchesResponse>;
    /**
     * Returns a paginated list of errors for a work request identified by the given ID.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListWorkRequestErrorsRequest
     * @return ListWorkRequestErrorsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/bds/ListWorkRequestErrors.ts.html |here} to see how to use ListWorkRequestErrors API.
     */
    listWorkRequestErrors(listWorkRequestErrorsRequest: requests.ListWorkRequestErrorsRequest): Promise<responses.ListWorkRequestErrorsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listWorkRequestErrorsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.WorkRequestError objects
     * contained in responses from the listWorkRequestErrors operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllWorkRequestErrors(request: requests.ListWorkRequestErrorsRequest): AsyncIterableIterator<model.WorkRequestError>;
    /**
     * NOTE: This function is deprecated in favor of listWorkRequestErrorsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listWorkRequestErrors operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllWorkRequestErrorsResponses(request: requests.ListWorkRequestErrorsRequest): AsyncIterableIterator<responses.ListWorkRequestErrorsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.WorkRequestError objects
     * contained in responses from the listWorkRequestErrors operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listWorkRequestErrorsRecordIterator(request: requests.ListWorkRequestErrorsRequest): AsyncIterableIterator<model.WorkRequestError>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listWorkRequestErrors operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listWorkRequestErrorsResponseIterator(request: requests.ListWorkRequestErrorsRequest): AsyncIterableIterator<responses.ListWorkRequestErrorsResponse>;
    /**
     * Returns a paginated list of logs for a given work request.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListWorkRequestLogsRequest
     * @return ListWorkRequestLogsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/bds/ListWorkRequestLogs.ts.html |here} to see how to use ListWorkRequestLogs API.
     */
    listWorkRequestLogs(listWorkRequestLogsRequest: requests.ListWorkRequestLogsRequest): Promise<responses.ListWorkRequestLogsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listWorkRequestLogsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.WorkRequestLogEntry objects
     * contained in responses from the listWorkRequestLogs operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllWorkRequestLogs(request: requests.ListWorkRequestLogsRequest): AsyncIterableIterator<model.WorkRequestLogEntry>;
    /**
     * NOTE: This function is deprecated in favor of listWorkRequestLogsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listWorkRequestLogs operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllWorkRequestLogsResponses(request: requests.ListWorkRequestLogsRequest): AsyncIterableIterator<responses.ListWorkRequestLogsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.WorkRequestLogEntry objects
     * contained in responses from the listWorkRequestLogs operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listWorkRequestLogsRecordIterator(request: requests.ListWorkRequestLogsRequest): AsyncIterableIterator<model.WorkRequestLogEntry>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listWorkRequestLogs operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listWorkRequestLogsResponseIterator(request: requests.ListWorkRequestLogsRequest): AsyncIterableIterator<responses.ListWorkRequestLogsResponse>;
    /**
     * Lists the work requests in a compartment.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListWorkRequestsRequest
     * @return ListWorkRequestsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/bds/ListWorkRequests.ts.html |here} to see how to use ListWorkRequests API.
     */
    listWorkRequests(listWorkRequestsRequest: requests.ListWorkRequestsRequest): Promise<responses.ListWorkRequestsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listWorkRequestsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.WorkRequest objects
     * contained in responses from the listWorkRequests operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllWorkRequests(request: requests.ListWorkRequestsRequest): AsyncIterableIterator<model.WorkRequest>;
    /**
     * NOTE: This function is deprecated in favor of listWorkRequestsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listWorkRequests operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllWorkRequestsResponses(request: requests.ListWorkRequestsRequest): AsyncIterableIterator<responses.ListWorkRequestsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.WorkRequest objects
     * contained in responses from the listWorkRequests operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listWorkRequestsRecordIterator(request: requests.ListWorkRequestsRequest): AsyncIterableIterator<model.WorkRequest>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listWorkRequests operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listWorkRequestsResponseIterator(request: requests.ListWorkRequestsRequest): AsyncIterableIterator<responses.ListWorkRequestsResponse>;
    /**
     * Deletes an autoscale configuration.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param RemoveAutoScalingConfigurationRequest
     * @return RemoveAutoScalingConfigurationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/bds/RemoveAutoScalingConfiguration.ts.html |here} to see how to use RemoveAutoScalingConfiguration API.
     */
    removeAutoScalingConfiguration(removeAutoScalingConfigurationRequest: requests.RemoveAutoScalingConfigurationRequest): Promise<responses.RemoveAutoScalingConfigurationResponse>;
    /**
     * Removes Cloud SQL from the cluster.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param RemoveCloudSqlRequest
     * @return RemoveCloudSqlResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/bds/RemoveCloudSql.ts.html |here} to see how to use RemoveCloudSql API.
     */
    removeCloudSql(removeCloudSqlRequest: requests.RemoveCloudSqlRequest): Promise<responses.RemoveCloudSqlResponse>;
    /**
     * Remove Kafka from the cluster.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param RemoveKafkaRequest
     * @return RemoveKafkaResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/bds/RemoveKafka.ts.html |here} to see how to use RemoveKafka API.
     */
    removeKafka(removeKafkaRequest: requests.RemoveKafkaRequest): Promise<responses.RemoveKafkaResponse>;
    /**
     * Remove a single node of a Big Data Service cluster
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param RemoveNodeRequest
     * @return RemoveNodeResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/bds/RemoveNode.ts.html |here} to see how to use RemoveNode API.
     */
    removeNode(removeNodeRequest: requests.RemoveNodeRequest): Promise<responses.RemoveNodeResponse>;
    /**
     * Deletes a nodeReplaceConfiguration
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param RemoveNodeReplaceConfigurationRequest
     * @return RemoveNodeReplaceConfigurationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/bds/RemoveNodeReplaceConfiguration.ts.html |here} to see how to use RemoveNodeReplaceConfiguration API.
     */
    removeNodeReplaceConfiguration(removeNodeReplaceConfigurationRequest: requests.RemoveNodeReplaceConfigurationRequest): Promise<responses.RemoveNodeReplaceConfigurationResponse>;
    /**
     * Renewing TLS/SSL for various ODH services running on the BDS cluster.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param RenewCertificateRequest
     * @return RenewCertificateResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/bds/RenewCertificate.ts.html |here} to see how to use RenewCertificate API.
     */
    renewCertificate(renewCertificateRequest: requests.RenewCertificateRequest): Promise<responses.RenewCertificateResponse>;
    /**
     * Replaces a node of a Big Data Service cluster from backup.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ReplaceNodeRequest
     * @return ReplaceNodeResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/bds/ReplaceNode.ts.html |here} to see how to use ReplaceNode API.
     */
    replaceNode(replaceNodeRequest: requests.ReplaceNodeRequest): Promise<responses.ReplaceNodeResponse>;
    /**
     * Restarts a single node of a Big Data Service cluster
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param RestartNodeRequest
     * @return RestartNodeResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/bds/RestartNode.ts.html |here} to see how to use RestartNode API.
     */
    restartNode(restartNodeRequest: requests.RestartNodeRequest): Promise<responses.RestartNodeResponse>;
    /**
     * Starts the BDS cluster that was stopped earlier.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param StartBdsInstanceRequest
     * @return StartBdsInstanceResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/bds/StartBdsInstance.ts.html |here} to see how to use StartBdsInstance API.
     */
    startBdsInstance(startBdsInstanceRequest: requests.StartBdsInstanceRequest): Promise<responses.StartBdsInstanceResponse>;
    /**
     * Stops the BDS cluster that can be started at later point of time.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param StopBdsInstanceRequest
     * @return StopBdsInstanceResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/bds/StopBdsInstance.ts.html |here} to see how to use StopBdsInstance API.
     */
    stopBdsInstance(stopBdsInstanceRequest: requests.StopBdsInstanceRequest): Promise<responses.StopBdsInstanceResponse>;
    /**
     * Test specified metastore configuration.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param TestBdsMetastoreConfigurationRequest
     * @return TestBdsMetastoreConfigurationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/bds/TestBdsMetastoreConfiguration.ts.html |here} to see how to use TestBdsMetastoreConfiguration API.
     */
    testBdsMetastoreConfiguration(testBdsMetastoreConfigurationRequest: requests.TestBdsMetastoreConfigurationRequest): Promise<responses.TestBdsMetastoreConfigurationResponse>;
    /**
     * Test access to specified Object Storage bucket using the API key.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param TestBdsObjectStorageConnectionRequest
     * @return TestBdsObjectStorageConnectionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/bds/TestBdsObjectStorageConnection.ts.html |here} to see how to use TestBdsObjectStorageConnection API.
     */
    testBdsObjectStorageConnection(testBdsObjectStorageConnectionRequest: requests.TestBdsObjectStorageConnectionRequest): Promise<responses.TestBdsObjectStorageConnectionResponse>;
    /**
     * Updates fields on an autoscale configuration, including the name, the threshold value, and whether the autoscale configuration is enabled.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateAutoScalingConfigurationRequest
     * @return UpdateAutoScalingConfigurationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/bds/UpdateAutoScalingConfiguration.ts.html |here} to see how to use UpdateAutoScalingConfiguration API.
     */
    updateAutoScalingConfiguration(updateAutoScalingConfigurationRequest: requests.UpdateAutoScalingConfigurationRequest): Promise<responses.UpdateAutoScalingConfigurationResponse>;
    /**
     * Updates the Big Data Service cluster identified by the given ID.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateBdsInstanceRequest
     * @return UpdateBdsInstanceResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/bds/UpdateBdsInstance.ts.html |here} to see how to use UpdateBdsInstance API.
     */
    updateBdsInstance(updateBdsInstanceRequest: requests.UpdateBdsInstanceRequest): Promise<responses.UpdateBdsInstanceResponse>;
    /**
     * Update the BDS metastore configuration represented by the provided ID.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateBdsMetastoreConfigurationRequest
     * @return UpdateBdsMetastoreConfigurationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/bds/UpdateBdsMetastoreConfiguration.ts.html |here} to see how to use UpdateBdsMetastoreConfiguration API.
     */
    updateBdsMetastoreConfiguration(updateBdsMetastoreConfigurationRequest: requests.UpdateBdsMetastoreConfigurationRequest): Promise<responses.UpdateBdsMetastoreConfigurationResponse>;
    /**
     * Updates fields on NodeBackupConfiguration, including the name, the schedule.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateNodeBackupConfigurationRequest
     * @return UpdateNodeBackupConfigurationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/bds/UpdateNodeBackupConfiguration.ts.html |here} to see how to use UpdateNodeBackupConfiguration API.
     */
    updateNodeBackupConfiguration(updateNodeBackupConfigurationRequest: requests.UpdateNodeBackupConfigurationRequest): Promise<responses.UpdateNodeBackupConfigurationResponse>;
    /**
     * Updates fields on nodeReplaceConfigurations, including the name, the schedule
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateNodeReplaceConfigurationRequest
     * @return UpdateNodeReplaceConfigurationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/bds/UpdateNodeReplaceConfiguration.ts.html |here} to see how to use UpdateNodeReplaceConfiguration API.
     */
    updateNodeReplaceConfiguration(updateNodeReplaceConfigurationRequest: requests.UpdateNodeReplaceConfigurationRequest): Promise<responses.UpdateNodeReplaceConfigurationResponse>;
}
export {};
