/**
 * Budgets API
 * Use the Budgets API to manage budgets and budget alerts. For more information, see [Budgets Overview](/iaas/Content/Billing/Concepts/budgetsoverview.htm).
 * OpenAPI spec version: 20190111
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import common = require("oci-common");
import * as requests from "./request";
import * as model from "./model";
import * as responses from "./response";
import { BudgetWaiter } from "./budget-waiter";
declare const Breaker: any;
export declare enum BudgetApiKeys {
}
/**
 * This service client uses {@link common.CircuitBreaker.DefaultConfiguration} for all the operations by default if no circuit breaker configuration is defined by the user.
 */
export declare class BudgetClient {
    protected static serviceEndpointTemplate: string;
    protected static endpointServiceName: string;
    protected "_realmSpecificEndpointTemplateEnabled": boolean | undefined;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_waiters": BudgetWaiter;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: typeof Breaker | null;
    protected _httpOptions: any;
    protected _bodyDuplexMode: any;
    targetService: string;
    protected _regionId: string;
    protected "_region": common.Region;
    protected _lastSetRegionOrRegionId: string;
    protected _httpClient: common.HttpClient;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    get endpoint(): string;
    /**
     * Sets the endpoint to call (ex, https://www.example.com).
     * @param endpoint The endpoint of the service.
     */
    set endpoint(endpoint: string);
    get logger(): import("oci-common/lib/log").Logger;
    /**
     * Determines whether realm specific endpoint should be used or not.
     * Set realmSpecificEndpointTemplateEnabled to "true" if the user wants to enable use of realm specific endpoint template, otherwise set it to "false"
     * @param realmSpecificEndpointTemplateEnabled flag to enable the use of realm specific endpoint template
     */
    set useRealmSpecificEndpointTemplate(realmSpecificEndpointTemplateEnabled: boolean);
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    set region(region: common.Region);
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    set regionId(regionId: string);
    /**
     * Creates a new BudgetWaiter for resources for this service.
     *
     * @param config The waiter configuration for termination and delay strategy
     * @return The service waiters.
     */
    createWaiters(config?: common.WaiterConfiguration): BudgetWaiter;
    /**
     * Gets the waiters available for resources for this service.
     *
     * @return The service waiters.
     */
    getWaiters(): BudgetWaiter;
    /**
     * Shutdown the circuit breaker used by the client when it is no longer needed
     */
    shutdownCircuitBreaker(): void;
    /**
     * Close the client once it is no longer needed
     */
    close(): void;
    /**
     * Creates a new Alert Rule.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateAlertRuleRequest
     * @return CreateAlertRuleResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/budget/CreateAlertRule.ts.html |here} to see how to use CreateAlertRule API.
     */
    createAlertRule(createAlertRuleRequest: requests.CreateAlertRuleRequest): Promise<responses.CreateAlertRuleResponse>;
    /**
     * Creates a new budget.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateBudgetRequest
     * @return CreateBudgetResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/budget/CreateBudget.ts.html |here} to see how to use CreateBudget API.
     */
    createBudget(createBudgetRequest: requests.CreateBudgetRequest): Promise<responses.CreateBudgetResponse>;
    /**
     * Deletes a specified Alert Rule resource.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteAlertRuleRequest
     * @return DeleteAlertRuleResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/budget/DeleteAlertRule.ts.html |here} to see how to use DeleteAlertRule API.
     */
    deleteAlertRule(deleteAlertRuleRequest: requests.DeleteAlertRuleRequest): Promise<responses.DeleteAlertRuleResponse>;
    /**
     * Deletes a specified budget resource.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteBudgetRequest
     * @return DeleteBudgetResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/budget/DeleteBudget.ts.html |here} to see how to use DeleteBudget API.
     */
    deleteBudget(deleteBudgetRequest: requests.DeleteBudgetRequest): Promise<responses.DeleteBudgetResponse>;
    /**
     * Gets an Alert Rule for a specified budget.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetAlertRuleRequest
     * @return GetAlertRuleResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/budget/GetAlertRule.ts.html |here} to see how to use GetAlertRule API.
     */
    getAlertRule(getAlertRuleRequest: requests.GetAlertRuleRequest): Promise<responses.GetAlertRuleResponse>;
    /**
     * Gets a budget by the identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetBudgetRequest
     * @return GetBudgetResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/budget/GetBudget.ts.html |here} to see how to use GetBudget API.
     */
    getBudget(getBudgetRequest: requests.GetBudgetRequest): Promise<responses.GetBudgetResponse>;
    /**
     * Returns a list of Alert Rules for a specified budget.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListAlertRulesRequest
     * @return ListAlertRulesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/budget/ListAlertRules.ts.html |here} to see how to use ListAlertRules API.
     */
    listAlertRules(listAlertRulesRequest: requests.ListAlertRulesRequest): Promise<responses.ListAlertRulesResponse>;
    /**
     * NOTE: This function is deprecated in favor of listAlertRulesRecordIterator function.
     * Creates a new async iterator which will iterate over the models.AlertRuleSummary objects
     * contained in responses from the listAlertRules operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllAlertRules(request: requests.ListAlertRulesRequest): AsyncIterableIterator<model.AlertRuleSummary>;
    /**
     * NOTE: This function is deprecated in favor of listAlertRulesResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listAlertRules operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllAlertRulesResponses(request: requests.ListAlertRulesRequest): AsyncIterableIterator<responses.ListAlertRulesResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.AlertRuleSummary objects
     * contained in responses from the listAlertRules operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAlertRulesRecordIterator(request: requests.ListAlertRulesRequest): AsyncIterableIterator<model.AlertRuleSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listAlertRules operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAlertRulesResponseIterator(request: requests.ListAlertRulesRequest): AsyncIterableIterator<responses.ListAlertRulesResponse>;
    /**
       * Gets a list of budgets in a compartment.
  * <p>
  By default, ListBudgets returns budgets of the 'COMPARTMENT' target type, and the budget records with only one target compartment OCID.
  * <p>
  To list all budgets, set the targetType query parameter to ALL (for example: 'targetType=ALL').
  * <p>
  Clients should ignore new targetTypes, or upgrade to the latest version of the client SDK to handle new targetTypes.
  *
       * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
       * @param ListBudgetsRequest
       * @return ListBudgetsResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/budget/ListBudgets.ts.html |here} to see how to use ListBudgets API.
       */
    listBudgets(listBudgetsRequest: requests.ListBudgetsRequest): Promise<responses.ListBudgetsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listBudgetsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.BudgetSummary objects
     * contained in responses from the listBudgets operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllBudgets(request: requests.ListBudgetsRequest): AsyncIterableIterator<model.BudgetSummary>;
    /**
     * NOTE: This function is deprecated in favor of listBudgetsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listBudgets operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllBudgetsResponses(request: requests.ListBudgetsRequest): AsyncIterableIterator<responses.ListBudgetsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.BudgetSummary objects
     * contained in responses from the listBudgets operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listBudgetsRecordIterator(request: requests.ListBudgetsRequest): AsyncIterableIterator<model.BudgetSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listBudgets operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listBudgetsResponseIterator(request: requests.ListBudgetsRequest): AsyncIterableIterator<responses.ListBudgetsResponse>;
    /**
     * Update an Alert Rule for the budget identified by the OCID.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateAlertRuleRequest
     * @return UpdateAlertRuleResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/budget/UpdateAlertRule.ts.html |here} to see how to use UpdateAlertRule API.
     */
    updateAlertRule(updateAlertRuleRequest: requests.UpdateAlertRuleRequest): Promise<responses.UpdateAlertRuleResponse>;
    /**
     * Update a budget identified by the OCID.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateBudgetRequest
     * @return UpdateBudgetResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/budget/UpdateBudget.ts.html |here} to see how to use UpdateBudget API.
     */
    updateBudget(updateBudgetRequest: requests.UpdateBudgetRequest): Promise<responses.UpdateBudgetResponse>;
}
export {};
