/**
 * OCI Control Center Capacity Management API
 * OCI Control Center (OCC) Capacity Management enables you to manage capacity requests in realms where OCI Control Center Capacity Management is available. For more information, see [OCI Control Center](/iaas/Content/control-center/home.htm).
 * OpenAPI spec version: 20231107
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import common = require("oci-common");
import * as requests from "./request";
import * as responses from "./response";
import { CapacityManagementWaiter } from "./capacitymanagement-waiter";
declare const Breaker: any;
export declare enum CapacityManagementApiKeys {
}
/**
 * This service client uses {@link common.CircuitBreaker.DefaultConfiguration} for all the operations by default if no circuit breaker configuration is defined by the user.
 */
export declare class CapacityManagementClient {
    protected static serviceEndpointTemplate: string;
    protected static endpointServiceName: string;
    protected "_realmSpecificEndpointTemplateEnabled": boolean | undefined;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_waiters": CapacityManagementWaiter;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: typeof Breaker | null;
    protected _httpOptions: any;
    protected _bodyDuplexMode: any;
    targetService: string;
    protected _regionId: string;
    protected "_region": common.Region;
    protected _lastSetRegionOrRegionId: string;
    protected _httpClient: common.HttpClient;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    get endpoint(): string;
    /**
     * Sets the endpoint to call (ex, https://www.example.com).
     * @param endpoint The endpoint of the service.
     */
    set endpoint(endpoint: string);
    get logger(): import("oci-common/lib/log").Logger;
    /**
     * Determines whether realm specific endpoint should be used or not.
     * Set realmSpecificEndpointTemplateEnabled to "true" if the user wants to enable use of realm specific endpoint template, otherwise set it to "false"
     * @param realmSpecificEndpointTemplateEnabled flag to enable the use of realm specific endpoint template
     */
    set useRealmSpecificEndpointTemplate(realmSpecificEndpointTemplateEnabled: boolean);
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    set region(region: common.Region);
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    set regionId(regionId: string);
    /**
     * Creates a new CapacityManagementWaiter for resources for this service.
     *
     * @param config The waiter configuration for termination and delay strategy
     * @return The service waiters.
     */
    createWaiters(config?: common.WaiterConfiguration): CapacityManagementWaiter;
    /**
     * Gets the waiters available for resources for this service.
     *
     * @return The service waiters.
     */
    getWaiters(): CapacityManagementWaiter;
    /**
     * Shutdown the circuit breaker used by the client when it is no longer needed
     */
    shutdownCircuitBreaker(): void;
    /**
     * Close the client once it is no longer needed
     */
    close(): void;
    /**
     * Create availability catalog
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateOccAvailabilityCatalogRequest
     * @return CreateOccAvailabilityCatalogResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/capacitymanagement/CreateOccAvailabilityCatalog.ts.html |here} to see how to use CreateOccAvailabilityCatalog API.
     */
    createOccAvailabilityCatalog(createOccAvailabilityCatalogRequest: requests.CreateOccAvailabilityCatalogRequest): Promise<responses.CreateOccAvailabilityCatalogResponse>;
    /**
     * Create Capacity Request.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateOccCapacityRequestRequest
     * @return CreateOccCapacityRequestResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/capacitymanagement/CreateOccCapacityRequest.ts.html |here} to see how to use CreateOccCapacityRequest API.
     */
    createOccCapacityRequest(createOccCapacityRequestRequest: requests.CreateOccCapacityRequestRequest): Promise<responses.CreateOccCapacityRequestResponse>;
    /**
     * Deletes the availability catalog resource.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteOccAvailabilityCatalogRequest
     * @return DeleteOccAvailabilityCatalogResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/capacitymanagement/DeleteOccAvailabilityCatalog.ts.html |here} to see how to use DeleteOccAvailabilityCatalog API.
     */
    deleteOccAvailabilityCatalog(deleteOccAvailabilityCatalogRequest: requests.DeleteOccAvailabilityCatalogRequest): Promise<responses.DeleteOccAvailabilityCatalogResponse>;
    /**
     * Deletes the capacity request resource.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteOccCapacityRequestRequest
     * @return DeleteOccCapacityRequestResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/capacitymanagement/DeleteOccCapacityRequest.ts.html |here} to see how to use DeleteOccCapacityRequest API.
     */
    deleteOccCapacityRequest(deleteOccCapacityRequestRequest: requests.DeleteOccCapacityRequestRequest): Promise<responses.DeleteOccCapacityRequestResponse>;
    /**
     * Get details about availability catalog.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetOccAvailabilityCatalogRequest
     * @return GetOccAvailabilityCatalogResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/capacitymanagement/GetOccAvailabilityCatalog.ts.html |here} to see how to use GetOccAvailabilityCatalog API.
     */
    getOccAvailabilityCatalog(getOccAvailabilityCatalogRequest: requests.GetOccAvailabilityCatalogRequest): Promise<responses.GetOccAvailabilityCatalogResponse>;
    /**
     * Returns the binary contents of the availability catalog. Can be saved as a csv file.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetOccAvailabilityCatalogContentRequest
     * @return GetOccAvailabilityCatalogContentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/capacitymanagement/GetOccAvailabilityCatalogContent.ts.html |here} to see how to use GetOccAvailabilityCatalogContent API.
     */
    getOccAvailabilityCatalogContent(getOccAvailabilityCatalogContentRequest: requests.GetOccAvailabilityCatalogContentRequest): Promise<responses.GetOccAvailabilityCatalogContentResponse>;
    /**
     * Get details about the capacity request.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetOccCapacityRequestRequest
     * @return GetOccCapacityRequestResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/capacitymanagement/GetOccCapacityRequest.ts.html |here} to see how to use GetOccCapacityRequest API.
     */
    getOccCapacityRequest(getOccCapacityRequestRequest: requests.GetOccCapacityRequestRequest): Promise<responses.GetOccCapacityRequestResponse>;
    /**
     * Gets information about the specified customer group.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetOccCustomerGroupRequest
     * @return GetOccCustomerGroupResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/capacitymanagement/GetOccCustomerGroup.ts.html |here} to see how to use GetOccCustomerGroup API.
     */
    getOccCustomerGroup(getOccCustomerGroupRequest: requests.GetOccCustomerGroupRequest): Promise<responses.GetOccCustomerGroupResponse>;
    /**
     * Lists an overview of all resources in that namespace in a given time interval.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListInternalNamespaceOccOverviewsRequest
     * @return ListInternalNamespaceOccOverviewsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/capacitymanagement/ListInternalNamespaceOccOverviews.ts.html |here} to see how to use ListInternalNamespaceOccOverviews API.
     */
    listInternalNamespaceOccOverviews(listInternalNamespaceOccOverviewsRequest: requests.ListInternalNamespaceOccOverviewsRequest): Promise<responses.ListInternalNamespaceOccOverviewsResponse>;
    /**
     * Lists availabilities for a particular availability catalog.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListOccAvailabilitiesRequest
     * @return ListOccAvailabilitiesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/capacitymanagement/ListOccAvailabilities.ts.html |here} to see how to use ListOccAvailabilities API.
     */
    listOccAvailabilities(listOccAvailabilitiesRequest: requests.ListOccAvailabilitiesRequest): Promise<responses.ListOccAvailabilitiesResponse>;
    /**
     * Lists all availability catalogs.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListOccAvailabilityCatalogsRequest
     * @return ListOccAvailabilityCatalogsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/capacitymanagement/ListOccAvailabilityCatalogs.ts.html |here} to see how to use ListOccAvailabilityCatalogs API.
     */
    listOccAvailabilityCatalogs(listOccAvailabilityCatalogsRequest: requests.ListOccAvailabilityCatalogsRequest): Promise<responses.ListOccAvailabilityCatalogsResponse>;
    /**
     * An internal api to list availability catalogs.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListOccAvailabilityCatalogsInternalRequest
     * @return ListOccAvailabilityCatalogsInternalResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/capacitymanagement/ListOccAvailabilityCatalogsInternal.ts.html |here} to see how to use ListOccAvailabilityCatalogsInternal API.
     */
    listOccAvailabilityCatalogsInternal(listOccAvailabilityCatalogsInternalRequest: requests.ListOccAvailabilityCatalogsInternalRequest): Promise<responses.ListOccAvailabilityCatalogsInternalResponse>;
    /**
     * Lists all capacity requests.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListOccCapacityRequestsRequest
     * @return ListOccCapacityRequestsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/capacitymanagement/ListOccCapacityRequests.ts.html |here} to see how to use ListOccCapacityRequests API.
     */
    listOccCapacityRequests(listOccCapacityRequestsRequest: requests.ListOccCapacityRequestsRequest): Promise<responses.ListOccCapacityRequestsResponse>;
    /**
     * An internal api to list all capacity requests.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListOccCapacityRequestsInternalRequest
     * @return ListOccCapacityRequestsInternalResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/capacitymanagement/ListOccCapacityRequestsInternal.ts.html |here} to see how to use ListOccCapacityRequestsInternal API.
     */
    listOccCapacityRequestsInternal(listOccCapacityRequestsInternalRequest: requests.ListOccCapacityRequestsInternalRequest): Promise<responses.ListOccCapacityRequestsInternalResponse>;
    /**
     * Lists all the customer groups.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListOccCustomerGroupsRequest
     * @return ListOccCustomerGroupsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/capacitymanagement/ListOccCustomerGroups.ts.html |here} to see how to use ListOccCustomerGroups API.
     */
    listOccCustomerGroups(listOccCustomerGroupsRequest: requests.ListOccCustomerGroupsRequest): Promise<responses.ListOccCustomerGroupsResponse>;
    /**
     * Lists an overview of all resources in that namespace in a given time interval.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListOccOverviewsRequest
     * @return ListOccOverviewsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/capacitymanagement/ListOccOverviews.ts.html |here} to see how to use ListOccOverviews API.
     */
    listOccOverviews(listOccOverviewsRequest: requests.ListOccOverviewsRequest): Promise<responses.ListOccOverviewsResponse>;
    /**
     * Updates the OccCapacityRequest by evaluating a sequence of instructions.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param PatchInternalOccCapacityRequestRequest
     * @return PatchInternalOccCapacityRequestResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/capacitymanagement/PatchInternalOccCapacityRequest.ts.html |here} to see how to use PatchInternalOccCapacityRequest API.
     */
    patchInternalOccCapacityRequest(patchInternalOccCapacityRequestRequest: requests.PatchInternalOccCapacityRequestRequest): Promise<responses.PatchInternalOccCapacityRequestResponse>;
    /**
     * Updates the OccCapacityRequest by evaluating a sequence of instructions.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param PatchOccCapacityRequestRequest
     * @return PatchOccCapacityRequestResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/capacitymanagement/PatchOccCapacityRequest.ts.html |here} to see how to use PatchOccCapacityRequest API.
     */
    patchOccCapacityRequest(patchOccCapacityRequestRequest: requests.PatchOccCapacityRequestRequest): Promise<responses.PatchOccCapacityRequestResponse>;
    /**
     * Publishes the version of availability catalog specified by the operator. This makes that catalog version visible to customers.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param PublishOccAvailabilityCatalogRequest
     * @return PublishOccAvailabilityCatalogResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/capacitymanagement/PublishOccAvailabilityCatalog.ts.html |here} to see how to use PublishOccAvailabilityCatalog API.
     */
    publishOccAvailabilityCatalog(publishOccAvailabilityCatalogRequest: requests.PublishOccAvailabilityCatalogRequest): Promise<responses.PublishOccAvailabilityCatalogResponse>;
    /**
     * The internal api to update the capacity request. This api will be used by operators for updating the capacity request to either completed, resubmitted or rejected.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateInternalOccCapacityRequestRequest
     * @return UpdateInternalOccCapacityRequestResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/capacitymanagement/UpdateInternalOccCapacityRequest.ts.html |here} to see how to use UpdateInternalOccCapacityRequest API.
     */
    updateInternalOccCapacityRequest(updateInternalOccCapacityRequestRequest: requests.UpdateInternalOccCapacityRequestRequest): Promise<responses.UpdateInternalOccCapacityRequestResponse>;
    /**
     * The request to update the availability catalog. Currently only freeform tags can be updated via this api.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateOccAvailabilityCatalogRequest
     * @return UpdateOccAvailabilityCatalogResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/capacitymanagement/UpdateOccAvailabilityCatalog.ts.html |here} to see how to use UpdateOccAvailabilityCatalog API.
     */
    updateOccAvailabilityCatalog(updateOccAvailabilityCatalogRequest: requests.UpdateOccAvailabilityCatalogRequest): Promise<responses.UpdateOccAvailabilityCatalogResponse>;
    /**
     * The request to update the capacity request. The user can perform actions like closing a partially completed request so that it doesn't go ahead for full completion.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateOccCapacityRequestRequest
     * @return UpdateOccCapacityRequestResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/capacitymanagement/UpdateOccCapacityRequest.ts.html |here} to see how to use UpdateOccCapacityRequest API.
     */
    updateOccCapacityRequest(updateOccCapacityRequestRequest: requests.UpdateOccCapacityRequestRequest): Promise<responses.UpdateOccCapacityRequestResponse>;
}
export {};
