/**
 * Certificates Service Retrieval API
 * API for retrieving certificates.
 * OpenAPI spec version: 20210224
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import common = require("oci-common");
import * as requests from "./request";
import * as responses from "./response";
declare const Breaker: any;
export declare enum CertificatesApiKeys {
}
/**
 * This service client uses {@link common.CircuitBreaker.DefaultConfiguration} for all the operations by default if no circuit breaker configuration is defined by the user.
 */
export declare class CertificatesClient {
    protected static serviceEndpointTemplate: string;
    protected static endpointServiceName: string;
    protected "_realmSpecificEndpointTemplateEnabled": boolean | undefined;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: typeof Breaker | null;
    protected _httpOptions: any;
    protected _bodyDuplexMode: any;
    targetService: string;
    protected _regionId: string;
    protected "_region": common.Region;
    protected _lastSetRegionOrRegionId: string;
    protected _httpClient: common.HttpClient;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    get endpoint(): string;
    /**
     * Sets the endpoint to call (ex, https://www.example.com).
     * @param endpoint The endpoint of the service.
     */
    set endpoint(endpoint: string);
    get logger(): import("oci-common/lib/log").Logger;
    /**
     * Determines whether realm specific endpoint should be used or not.
     * Set realmSpecificEndpointTemplateEnabled to "true" if the user wants to enable use of realm specific endpoint template, otherwise set it to "false"
     * @param realmSpecificEndpointTemplateEnabled flag to enable the use of realm specific endpoint template
     */
    set useRealmSpecificEndpointTemplate(realmSpecificEndpointTemplateEnabled: boolean);
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    set region(region: common.Region);
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    set regionId(regionId: string);
    /**
     * Shutdown the circuit breaker used by the client when it is no longer needed
     */
    shutdownCircuitBreaker(): void;
    /**
     * Close the client once it is no longer needed
     */
    close(): void;
    /**
     * Gets a ca-bundle bundle.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetCaBundleRequest
     * @return GetCaBundleResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/certificates/GetCaBundle.ts.html |here} to see how to use GetCaBundle API.
     */
    getCaBundle(getCaBundleRequest: requests.GetCaBundleRequest): Promise<responses.GetCaBundleResponse>;
    /**
     * Gets a certificate authority bundle that matches either the specified `stage`, `name`, or `versionNumber` parameter.
     * If none of these parameters are provided, the bundle for the certificate authority version marked as `CURRENT` will be returned.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetCertificateAuthorityBundleRequest
     * @return GetCertificateAuthorityBundleResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/certificates/GetCertificateAuthorityBundle.ts.html |here} to see how to use GetCertificateAuthorityBundle API.
     */
    getCertificateAuthorityBundle(getCertificateAuthorityBundleRequest: requests.GetCertificateAuthorityBundleRequest): Promise<responses.GetCertificateAuthorityBundleResponse>;
    /**
       * Gets a certificate bundle that matches either the specified `stage`, `versionName`, or `versionNumber` parameter.
  * If none of these parameters are provided, the bundle for the certificate version marked as `CURRENT` will be returned.
  * <p>
  By default, the private key is not included in the query result, and a CertificateBundlePublicOnly is returned.
  * If the private key is needed, use the CertificateBundleTypeQueryParam parameter to get a CertificateBundleWithPrivateKey response.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param GetCertificateBundleRequest
       * @return GetCertificateBundleResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/certificates/GetCertificateBundle.ts.html |here} to see how to use GetCertificateBundle API.
       */
    getCertificateBundle(getCertificateBundleRequest: requests.GetCertificateBundleRequest): Promise<responses.GetCertificateBundleResponse>;
    /**
     * Lists all certificate authority bundle versions for the specified certificate authority.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListCertificateAuthorityBundleVersionsRequest
     * @return ListCertificateAuthorityBundleVersionsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/certificates/ListCertificateAuthorityBundleVersions.ts.html |here} to see how to use ListCertificateAuthorityBundleVersions API.
     */
    listCertificateAuthorityBundleVersions(listCertificateAuthorityBundleVersionsRequest: requests.ListCertificateAuthorityBundleVersionsRequest): Promise<responses.ListCertificateAuthorityBundleVersionsResponse>;
    /**
     * Lists all certificate bundle versions for the specified certificate.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListCertificateBundleVersionsRequest
     * @return ListCertificateBundleVersionsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/certificates/ListCertificateBundleVersions.ts.html |here} to see how to use ListCertificateBundleVersions API.
     */
    listCertificateBundleVersions(listCertificateBundleVersionsRequest: requests.ListCertificateBundleVersionsRequest): Promise<responses.ListCertificateBundleVersionsResponse>;
}
export {};
