/**
 * Certificates Service Management API
 * API for managing certificates.
 * OpenAPI spec version: 20210224
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * The metadata details of the certificate authority (CA) version. This summary object does not contain the CA contents.
 */
export interface CertificateAuthorityVersionSummary {
    /**
     * The OCID of the CA.
     */
    "certificateAuthorityId": string;
    /**
     * The version number of the issuing CA. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "issuerCaVersionNumber"?: number;
    /**
     * A unique certificate identifier used in certificate revocation tracking, formatted as octets.
     * Example: {@code 03 AC FC FA CC B3 CB 02 B8 F8 DE F5 85 E7 7B FF}
     *
     */
    "serialNumber"?: string;
    /**
     * A optional property indicating when the CA version was created, expressed in [RFC 3339](https://tools.ietf.org/html/rfc3339) timestamp format.
     * Example: {@code 2019-04-03T21:10:29.600Z}
     *
     */
    "timeCreated": Date;
    /**
     * The version number of the CA. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "versionNumber": number;
    /**
     * The name of the CA version. When this value is not null, the name is unique across CA versions for a given CA.
     *
     */
    "versionName"?: string;
    /**
     * An optional property indicating when to delete the CA version, expressed in [RFC 3339](https://tools.ietf.org/html/rfc3339) timestamp format.
     * Example: {@code 2019-04-03T21:10:29.600Z}
     *
     */
    "timeOfDeletion"?: Date;
    "validity"?: model.Validity;
    /**
     * A list of rotation states for this CA version.
     */
    "stages": Array<model.VersionStage>;
    "revocationStatus"?: model.RevocationStatus;
}
export declare namespace CertificateAuthorityVersionSummary {
    function getJsonObj(obj: CertificateAuthorityVersionSummary): object;
    function getDeserializedJsonObj(obj: CertificateAuthorityVersionSummary): object;
}
