/**
 * Oracle Cloud Bridge API
 * API for Oracle Cloud Bridge service.
 * OpenAPI spec version: 20220509
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import common = require("oci-common");
import * as requests from "./request";
import * as responses from "./response";
import { CommonWaiter } from "./common-waiter";
import { DiscoveryWaiter } from "./discovery-waiter";
import { InventoryWaiter } from "./inventory-waiter";
import { OcbAgentSvcWaiter } from "./ocbagentsvc-waiter";
declare const Breaker: any;
export declare enum CommonApiKeys {
}
/**
 * This service client uses {@link common.CircuitBreaker.DefaultConfiguration} for all the operations by default if no circuit breaker configuration is defined by the user.
 */
export declare class CommonClient {
    protected static serviceEndpointTemplate: string;
    protected static endpointServiceName: string;
    protected "_realmSpecificEndpointTemplateEnabled": boolean | undefined;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_waiters": CommonWaiter;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: typeof Breaker | null;
    protected _httpOptions: any;
    protected _bodyDuplexMode: any;
    targetService: string;
    protected _regionId: string;
    protected "_region": common.Region;
    protected _lastSetRegionOrRegionId: string;
    protected _httpClient: common.HttpClient;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    get endpoint(): string;
    /**
     * Sets the endpoint to call (ex, https://www.example.com).
     * @param endpoint The endpoint of the service.
     */
    set endpoint(endpoint: string);
    get logger(): import("oci-common/lib/log").Logger;
    /**
     * Determines whether realm specific endpoint should be used or not.
     * Set realmSpecificEndpointTemplateEnabled to "true" if the user wants to enable use of realm specific endpoint template, otherwise set it to "false"
     * @param realmSpecificEndpointTemplateEnabled flag to enable the use of realm specific endpoint template
     */
    set useRealmSpecificEndpointTemplate(realmSpecificEndpointTemplateEnabled: boolean);
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    set region(region: common.Region);
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    set regionId(regionId: string);
    /**
     * Creates a new CommonWaiter for resources for this service.
     *
     * @param config The waiter configuration for termination and delay strategy
     * @return The service waiters.
     */
    createWaiters(config?: common.WaiterConfiguration): CommonWaiter;
    /**
     * Gets the waiters available for resources for this service.
     *
     * @return The service waiters.
     */
    getWaiters(): CommonWaiter;
    /**
     * Shutdown the circuit breaker used by the client when it is no longer needed
     */
    shutdownCircuitBreaker(): void;
    /**
     * Close the client once it is no longer needed
     */
    close(): void;
    /**
     * Cancels the work request with the given ID.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CancelWorkRequestRequest
     * @return CancelWorkRequestResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudbridge/CancelWorkRequest.ts.html |here} to see how to use CancelWorkRequest API.
     */
    cancelWorkRequest(cancelWorkRequestRequest: requests.CancelWorkRequestRequest): Promise<responses.CancelWorkRequestResponse>;
    /**
     * Gets details of the work request with the given ID.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetWorkRequestRequest
     * @return GetWorkRequestResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudbridge/GetWorkRequest.ts.html |here} to see how to use GetWorkRequest API.
     */
    getWorkRequest(getWorkRequestRequest: requests.GetWorkRequestRequest): Promise<responses.GetWorkRequestResponse>;
    /**
     * Returns a (paginated) list of errors for the work request with the given ID.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListWorkRequestErrorsRequest
     * @return ListWorkRequestErrorsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudbridge/ListWorkRequestErrors.ts.html |here} to see how to use ListWorkRequestErrors API.
     */
    listWorkRequestErrors(listWorkRequestErrorsRequest: requests.ListWorkRequestErrorsRequest): Promise<responses.ListWorkRequestErrorsResponse>;
    /**
     * Returns a (paginated) list of logs for the work request with the given ID.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListWorkRequestLogsRequest
     * @return ListWorkRequestLogsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudbridge/ListWorkRequestLogs.ts.html |here} to see how to use ListWorkRequestLogs API.
     */
    listWorkRequestLogs(listWorkRequestLogsRequest: requests.ListWorkRequestLogsRequest): Promise<responses.ListWorkRequestLogsResponse>;
    /**
     * Lists the work requests in a compartment.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListWorkRequestsRequest
     * @return ListWorkRequestsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudbridge/ListWorkRequests.ts.html |here} to see how to use ListWorkRequests API.
     */
    listWorkRequests(listWorkRequestsRequest: requests.ListWorkRequestsRequest): Promise<responses.ListWorkRequestsResponse>;
}
export declare enum DiscoveryApiKeys {
}
/**
 * This service client uses {@link common.CircuitBreaker.DefaultConfiguration} for all the operations by default if no circuit breaker configuration is defined by the user.
 */
export declare class DiscoveryClient {
    protected static serviceEndpointTemplate: string;
    protected static endpointServiceName: string;
    protected "_realmSpecificEndpointTemplateEnabled": boolean | undefined;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_waiters": DiscoveryWaiter;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: typeof Breaker | null;
    protected _httpOptions: any;
    protected _bodyDuplexMode: any;
    targetService: string;
    protected _regionId: string;
    protected "_region": common.Region;
    protected _lastSetRegionOrRegionId: string;
    protected _httpClient: common.HttpClient;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    get endpoint(): string;
    /**
     * Sets the endpoint to call (ex, https://www.example.com).
     * @param endpoint The endpoint of the service.
     */
    set endpoint(endpoint: string);
    get logger(): import("oci-common/lib/log").Logger;
    /**
     * Determines whether realm specific endpoint should be used or not.
     * Set realmSpecificEndpointTemplateEnabled to "true" if the user wants to enable use of realm specific endpoint template, otherwise set it to "false"
     * @param realmSpecificEndpointTemplateEnabled flag to enable the use of realm specific endpoint template
     */
    set useRealmSpecificEndpointTemplate(realmSpecificEndpointTemplateEnabled: boolean);
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    set region(region: common.Region);
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    set regionId(regionId: string);
    /**
     * Creates a new DiscoveryWaiter for resources for this service.
     *
     * @param config The waiter configuration for termination and delay strategy
     * @return The service waiters.
     */
    createWaiters(config?: common.WaiterConfiguration): DiscoveryWaiter;
    /**
     * Gets the waiters available for resources for this service.
     *
     * @return The service waiters.
     */
    getWaiters(): DiscoveryWaiter;
    /**
     * Shutdown the circuit breaker used by the client when it is no longer needed
     */
    shutdownCircuitBreaker(): void;
    /**
     * Close the client once it is no longer needed
     */
    close(): void;
    /**
     * Moves a resource into a different compartment. When provided, If-Match is checked against ETag values of the resource.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ChangeAssetSourceCompartmentRequest
     * @return ChangeAssetSourceCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudbridge/ChangeAssetSourceCompartment.ts.html |here} to see how to use ChangeAssetSourceCompartment API.
     */
    changeAssetSourceCompartment(changeAssetSourceCompartmentRequest: requests.ChangeAssetSourceCompartmentRequest): Promise<responses.ChangeAssetSourceCompartmentResponse>;
    /**
     * Moves the specified discovery schedule into a different compartment. When provided, If-Match is checked against ETag values of the resource.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ChangeDiscoveryScheduleCompartmentRequest
     * @return ChangeDiscoveryScheduleCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudbridge/ChangeDiscoveryScheduleCompartment.ts.html |here} to see how to use ChangeDiscoveryScheduleCompartment API.
     */
    changeDiscoveryScheduleCompartment(changeDiscoveryScheduleCompartmentRequest: requests.ChangeDiscoveryScheduleCompartmentRequest): Promise<responses.ChangeDiscoveryScheduleCompartmentResponse>;
    /**
     * Creates an asset source.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateAssetSourceRequest
     * @return CreateAssetSourceResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudbridge/CreateAssetSource.ts.html |here} to see how to use CreateAssetSource API.
     */
    createAssetSource(createAssetSourceRequest: requests.CreateAssetSourceRequest): Promise<responses.CreateAssetSourceResponse>;
    /**
     * Creates the discovery schedule.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateDiscoveryScheduleRequest
     * @return CreateDiscoveryScheduleResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudbridge/CreateDiscoverySchedule.ts.html |here} to see how to use CreateDiscoverySchedule API.
     */
    createDiscoverySchedule(createDiscoveryScheduleRequest: requests.CreateDiscoveryScheduleRequest): Promise<responses.CreateDiscoveryScheduleResponse>;
    /**
     * Deletes the asset source by ID.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteAssetSourceRequest
     * @return DeleteAssetSourceResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudbridge/DeleteAssetSource.ts.html |here} to see how to use DeleteAssetSource API.
     */
    deleteAssetSource(deleteAssetSourceRequest: requests.DeleteAssetSourceRequest): Promise<responses.DeleteAssetSourceResponse>;
    /**
     * Deletes the specified discovery schedule.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteDiscoveryScheduleRequest
     * @return DeleteDiscoveryScheduleResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudbridge/DeleteDiscoverySchedule.ts.html |here} to see how to use DeleteDiscoverySchedule API.
     */
    deleteDiscoverySchedule(deleteDiscoveryScheduleRequest: requests.DeleteDiscoveryScheduleRequest): Promise<responses.DeleteDiscoveryScheduleResponse>;
    /**
     * Gets the asset source by ID.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetAssetSourceRequest
     * @return GetAssetSourceResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudbridge/GetAssetSource.ts.html |here} to see how to use GetAssetSource API.
     */
    getAssetSource(getAssetSourceRequest: requests.GetAssetSourceRequest): Promise<responses.GetAssetSourceResponse>;
    /**
     * Reads information about the specified discovery schedule.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetDiscoveryScheduleRequest
     * @return GetDiscoveryScheduleResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudbridge/GetDiscoverySchedule.ts.html |here} to see how to use GetDiscoverySchedule API.
     */
    getDiscoverySchedule(getDiscoveryScheduleRequest: requests.GetDiscoveryScheduleRequest): Promise<responses.GetDiscoveryScheduleResponse>;
    /**
     * Gets known connections to the asset source by the asset source ID.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListAssetSourceConnectionsRequest
     * @return ListAssetSourceConnectionsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudbridge/ListAssetSourceConnections.ts.html |here} to see how to use ListAssetSourceConnections API.
     */
    listAssetSourceConnections(listAssetSourceConnectionsRequest: requests.ListAssetSourceConnectionsRequest): Promise<responses.ListAssetSourceConnectionsResponse>;
    /**
     * Returns a list of asset sources.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListAssetSourcesRequest
     * @return ListAssetSourcesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudbridge/ListAssetSources.ts.html |here} to see how to use ListAssetSources API.
     */
    listAssetSources(listAssetSourcesRequest: requests.ListAssetSourcesRequest): Promise<responses.ListAssetSourcesResponse>;
    /**
     * Lists discovery schedules.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListDiscoverySchedulesRequest
     * @return ListDiscoverySchedulesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudbridge/ListDiscoverySchedules.ts.html |here} to see how to use ListDiscoverySchedules API.
     */
    listDiscoverySchedules(listDiscoverySchedulesRequest: requests.ListDiscoverySchedulesRequest): Promise<responses.ListDiscoverySchedulesResponse>;
    /**
     * Initiates the process of asset metadata synchronization with the related asset source.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param RefreshAssetSourceRequest
     * @return RefreshAssetSourceResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudbridge/RefreshAssetSource.ts.html |here} to see how to use RefreshAssetSource API.
     */
    refreshAssetSource(refreshAssetSourceRequest: requests.RefreshAssetSourceRequest): Promise<responses.RefreshAssetSourceResponse>;
    /**
     * Updates the asset source.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateAssetSourceRequest
     * @return UpdateAssetSourceResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudbridge/UpdateAssetSource.ts.html |here} to see how to use UpdateAssetSource API.
     */
    updateAssetSource(updateAssetSourceRequest: requests.UpdateAssetSourceRequest): Promise<responses.UpdateAssetSourceResponse>;
    /**
     * Updates the specified discovery schedule.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateDiscoveryScheduleRequest
     * @return UpdateDiscoveryScheduleResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudbridge/UpdateDiscoverySchedule.ts.html |here} to see how to use UpdateDiscoverySchedule API.
     */
    updateDiscoverySchedule(updateDiscoveryScheduleRequest: requests.UpdateDiscoveryScheduleRequest): Promise<responses.UpdateDiscoveryScheduleResponse>;
}
export declare enum InventoryApiKeys {
}
/**
 * This service client uses {@link common.CircuitBreaker.DefaultConfiguration} for all the operations by default if no circuit breaker configuration is defined by the user.
 */
export declare class InventoryClient {
    protected static serviceEndpointTemplate: string;
    protected static endpointServiceName: string;
    protected "_realmSpecificEndpointTemplateEnabled": boolean | undefined;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_waiters": InventoryWaiter;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: typeof Breaker | null;
    protected _httpOptions: any;
    protected _bodyDuplexMode: any;
    targetService: string;
    protected _regionId: string;
    protected "_region": common.Region;
    protected _lastSetRegionOrRegionId: string;
    protected _httpClient: common.HttpClient;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    get endpoint(): string;
    /**
     * Sets the endpoint to call (ex, https://www.example.com).
     * @param endpoint The endpoint of the service.
     */
    set endpoint(endpoint: string);
    get logger(): import("oci-common/lib/log").Logger;
    /**
     * Determines whether realm specific endpoint should be used or not.
     * Set realmSpecificEndpointTemplateEnabled to "true" if the user wants to enable use of realm specific endpoint template, otherwise set it to "false"
     * @param realmSpecificEndpointTemplateEnabled flag to enable the use of realm specific endpoint template
     */
    set useRealmSpecificEndpointTemplate(realmSpecificEndpointTemplateEnabled: boolean);
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    set region(region: common.Region);
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    set regionId(regionId: string);
    /**
     * Creates a new InventoryWaiter for resources for this service.
     *
     * @param config The waiter configuration for termination and delay strategy
     * @return The service waiters.
     */
    createWaiters(config?: common.WaiterConfiguration): InventoryWaiter;
    /**
     * Gets the waiters available for resources for this service.
     *
     * @return The service waiters.
     */
    getWaiters(): InventoryWaiter;
    /**
     * Shutdown the circuit breaker used by the client when it is no longer needed
     */
    shutdownCircuitBreaker(): void;
    /**
     * Close the client once it is no longer needed
     */
    close(): void;
    /**
     * Returns an aggregation of assets. Aggregation groups are sorted by groupBy property.
     * Default sort order is ascending, but can be overridden by the sortOrder parameter.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param AnalyzeAssetsRequest
     * @return AnalyzeAssetsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudbridge/AnalyzeAssets.ts.html |here} to see how to use AnalyzeAssets API.
     */
    analyzeAssets(analyzeAssetsRequest: requests.AnalyzeAssetsRequest): Promise<responses.AnalyzeAssetsResponse>;
    /**
     * Moves an asset resource from one compartment to another. When provided, If-Match is checked against ETag values of the resource.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ChangeAssetCompartmentRequest
     * @return ChangeAssetCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudbridge/ChangeAssetCompartment.ts.html |here} to see how to use ChangeAssetCompartment API.
     */
    changeAssetCompartment(changeAssetCompartmentRequest: requests.ChangeAssetCompartmentRequest): Promise<responses.ChangeAssetCompartmentResponse>;
    /**
     * Change an asset's tag.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ChangeAssetTagsRequest
     * @return ChangeAssetTagsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudbridge/ChangeAssetTags.ts.html |here} to see how to use ChangeAssetTags API.
     */
    changeAssetTags(changeAssetTagsRequest: requests.ChangeAssetTagsRequest): Promise<responses.ChangeAssetTagsResponse>;
    /**
     * Creates an asset.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateAssetRequest
     * @return CreateAssetResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudbridge/CreateAsset.ts.html |here} to see how to use CreateAsset API.
     */
    createAsset(createAssetRequest: requests.CreateAssetRequest): Promise<responses.CreateAssetResponse>;
    /**
     * Creates an inventory.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateInventoryRequest
     * @return CreateInventoryResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudbridge/CreateInventory.ts.html |here} to see how to use CreateInventory API.
     */
    createInventory(createInventoryRequest: requests.CreateInventoryRequest): Promise<responses.CreateInventoryResponse>;
    /**
     * Deletes an asset resource by identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteAssetRequest
     * @return DeleteAssetResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudbridge/DeleteAsset.ts.html |here} to see how to use DeleteAsset API.
     */
    deleteAsset(deleteAssetRequest: requests.DeleteAssetRequest): Promise<responses.DeleteAssetResponse>;
    /**
     * Deletes an inventory resource by identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteInventoryRequest
     * @return DeleteInventoryResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudbridge/DeleteInventory.ts.html |here} to see how to use DeleteInventory API.
     */
    deleteInventory(deleteInventoryRequest: requests.DeleteInventoryRequest): Promise<responses.DeleteInventoryResponse>;
    /**
     * Gets an asset by identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetAssetRequest
     * @return GetAssetResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudbridge/GetAsset.ts.html |here} to see how to use GetAsset API.
     */
    getAsset(getAssetRequest: requests.GetAssetRequest): Promise<responses.GetAssetResponse>;
    /**
     * Gets an inventory by identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetInventoryRequest
     * @return GetInventoryResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudbridge/GetInventory.ts.html |here} to see how to use GetInventory API.
     */
    getInventory(getInventoryRequest: requests.GetInventoryRequest): Promise<responses.GetInventoryResponse>;
    /**
     * Import resources in inventory.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ImportInventoryRequest
     * @return ImportInventoryResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudbridge/ImportInventory.ts.html |here} to see how to use ImportInventory API.
     */
    importInventory(importInventoryRequest: requests.ImportInventoryRequest): Promise<responses.ImportInventoryResponse>;
    /**
     * Returns a list of assets.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListAssetsRequest
     * @return ListAssetsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudbridge/ListAssets.ts.html |here} to see how to use ListAssets API.
     */
    listAssets(listAssetsRequest: requests.ListAssetsRequest): Promise<responses.ListAssetsResponse>;
    /**
     * List asset historical metrics.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListHistoricalMetricsRequest
     * @return ListHistoricalMetricsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudbridge/ListHistoricalMetrics.ts.html |here} to see how to use ListHistoricalMetrics API.
     */
    listHistoricalMetrics(listHistoricalMetricsRequest: requests.ListHistoricalMetricsRequest): Promise<responses.ListHistoricalMetricsResponse>;
    /**
     * Returns a list of inventories.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListInventoriesRequest
     * @return ListInventoriesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudbridge/ListInventories.ts.html |here} to see how to use ListInventories API.
     */
    listInventories(listInventoriesRequest: requests.ListInventoriesRequest): Promise<responses.ListInventoriesResponse>;
    /**
     * Creates or updates all metrics related to the asset.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SubmitHistoricalMetricsRequest
     * @return SubmitHistoricalMetricsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudbridge/SubmitHistoricalMetrics.ts.html |here} to see how to use SubmitHistoricalMetrics API.
     */
    submitHistoricalMetrics(submitHistoricalMetricsRequest: requests.SubmitHistoricalMetricsRequest): Promise<responses.SubmitHistoricalMetricsResponse>;
    /**
     * Updates the asset.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateAssetRequest
     * @return UpdateAssetResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudbridge/UpdateAsset.ts.html |here} to see how to use UpdateAsset API.
     */
    updateAsset(updateAssetRequest: requests.UpdateAssetRequest): Promise<responses.UpdateAssetResponse>;
    /**
     * Updates an inventory.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateInventoryRequest
     * @return UpdateInventoryResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudbridge/UpdateInventory.ts.html |here} to see how to use UpdateInventory API.
     */
    updateInventory(updateInventoryRequest: requests.UpdateInventoryRequest): Promise<responses.UpdateInventoryResponse>;
}
export declare enum OcbAgentSvcApiKeys {
}
/**
 * This service client uses {@link common.CircuitBreaker.DefaultConfiguration} for all the operations by default if no circuit breaker configuration is defined by the user.
 */
export declare class OcbAgentSvcClient {
    protected static serviceEndpointTemplate: string;
    protected static endpointServiceName: string;
    protected "_realmSpecificEndpointTemplateEnabled": boolean | undefined;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_waiters": OcbAgentSvcWaiter;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: typeof Breaker | null;
    protected _httpOptions: any;
    protected _bodyDuplexMode: any;
    targetService: string;
    protected _regionId: string;
    protected "_region": common.Region;
    protected _lastSetRegionOrRegionId: string;
    protected _httpClient: common.HttpClient;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    get endpoint(): string;
    /**
     * Sets the endpoint to call (ex, https://www.example.com).
     * @param endpoint The endpoint of the service.
     */
    set endpoint(endpoint: string);
    get logger(): import("oci-common/lib/log").Logger;
    /**
     * Determines whether realm specific endpoint should be used or not.
     * Set realmSpecificEndpointTemplateEnabled to "true" if the user wants to enable use of realm specific endpoint template, otherwise set it to "false"
     * @param realmSpecificEndpointTemplateEnabled flag to enable the use of realm specific endpoint template
     */
    set useRealmSpecificEndpointTemplate(realmSpecificEndpointTemplateEnabled: boolean);
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    set region(region: common.Region);
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    set regionId(regionId: string);
    /**
     * Creates a new OcbAgentSvcWaiter for resources for this service.
     *
     * @param config The waiter configuration for termination and delay strategy
     * @return The service waiters.
     */
    createWaiters(config?: common.WaiterConfiguration): OcbAgentSvcWaiter;
    /**
     * Gets the waiters available for resources for this service.
     *
     * @return The service waiters.
     */
    getWaiters(): OcbAgentSvcWaiter;
    /**
     * Shutdown the circuit breaker used by the client when it is no longer needed
     */
    shutdownCircuitBreaker(): void;
    /**
     * Close the client once it is no longer needed
     */
    close(): void;
    /**
     * Add a dependency to the environment. When provided, If-Match is checked against ETag values of the resource.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param AddAgentDependencyRequest
     * @return AddAgentDependencyResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudbridge/AddAgentDependency.ts.html |here} to see how to use AddAgentDependency API.
     */
    addAgentDependency(addAgentDependencyRequest: requests.AddAgentDependencyRequest): Promise<responses.AddAgentDependencyResponse>;
    /**
     * Moves an Agent resource from one compartment identifier to another. When provided, If-Match is checked against ETag values of the resource.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ChangeAgentCompartmentRequest
     * @return ChangeAgentCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudbridge/ChangeAgentCompartment.ts.html |here} to see how to use ChangeAgentCompartment API.
     */
    changeAgentCompartment(changeAgentCompartmentRequest: requests.ChangeAgentCompartmentRequest): Promise<responses.ChangeAgentCompartmentResponse>;
    /**
     * Moves a AgentDependency resource from one compartment identifier to another. When provided, If-Match is checked against ETag values of the resource.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ChangeAgentDependencyCompartmentRequest
     * @return ChangeAgentDependencyCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudbridge/ChangeAgentDependencyCompartment.ts.html |here} to see how to use ChangeAgentDependencyCompartment API.
     */
    changeAgentDependencyCompartment(changeAgentDependencyCompartmentRequest: requests.ChangeAgentDependencyCompartmentRequest): Promise<responses.ChangeAgentDependencyCompartmentResponse>;
    /**
     * Moves a source environment resource from one compartment identifier to another. When provided, If-Match is checked against ETag values of the resource.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ChangeEnvironmentCompartmentRequest
     * @return ChangeEnvironmentCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudbridge/ChangeEnvironmentCompartment.ts.html |here} to see how to use ChangeEnvironmentCompartment API.
     */
    changeEnvironmentCompartment(changeEnvironmentCompartmentRequest: requests.ChangeEnvironmentCompartmentRequest): Promise<responses.ChangeEnvironmentCompartmentResponse>;
    /**
     * Creates an Agent.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateAgentRequest
     * @return CreateAgentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudbridge/CreateAgent.ts.html |here} to see how to use CreateAgent API.
     */
    createAgent(createAgentRequest: requests.CreateAgentRequest): Promise<responses.CreateAgentResponse>;
    /**
     * Creates an AgentDependency.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateAgentDependencyRequest
     * @return CreateAgentDependencyResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudbridge/CreateAgentDependency.ts.html |here} to see how to use CreateAgentDependency API.
     */
    createAgentDependency(createAgentDependencyRequest: requests.CreateAgentDependencyRequest): Promise<responses.CreateAgentDependencyResponse>;
    /**
     * Creates a source environment.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateEnvironmentRequest
     * @return CreateEnvironmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudbridge/CreateEnvironment.ts.html |here} to see how to use CreateEnvironment API.
     */
    createEnvironment(createEnvironmentRequest: requests.CreateEnvironmentRequest): Promise<responses.CreateEnvironmentResponse>;
    /**
     * Deletes an Agent resource identified by an identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteAgentRequest
     * @return DeleteAgentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudbridge/DeleteAgent.ts.html |here} to see how to use DeleteAgent API.
     */
    deleteAgent(deleteAgentRequest: requests.DeleteAgentRequest): Promise<responses.DeleteAgentResponse>;
    /**
     * Deletes the AgentDependency resource based on an identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteAgentDependencyRequest
     * @return DeleteAgentDependencyResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudbridge/DeleteAgentDependency.ts.html |here} to see how to use DeleteAgentDependency API.
     */
    deleteAgentDependency(deleteAgentDependencyRequest: requests.DeleteAgentDependencyRequest): Promise<responses.DeleteAgentDependencyResponse>;
    /**
     * Deletes a the source environment resource identified by an identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteEnvironmentRequest
     * @return DeleteEnvironmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudbridge/DeleteEnvironment.ts.html |here} to see how to use DeleteEnvironment API.
     */
    deleteEnvironment(deleteEnvironmentRequest: requests.DeleteEnvironmentRequest): Promise<responses.DeleteEnvironmentResponse>;
    /**
     * Gets an Agent by identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetAgentRequest
     * @return GetAgentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudbridge/GetAgent.ts.html |here} to see how to use GetAgent API.
     */
    getAgent(getAgentRequest: requests.GetAgentRequest): Promise<responses.GetAgentResponse>;
    /**
     * Gets an AgentDependency by identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetAgentDependencyRequest
     * @return GetAgentDependencyResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudbridge/GetAgentDependency.ts.html |here} to see how to use GetAgentDependency API.
     */
    getAgentDependency(getAgentDependencyRequest: requests.GetAgentDependencyRequest): Promise<responses.GetAgentDependencyResponse>;
    /**
     * Gets a source environment by identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetEnvironmentRequest
     * @return GetEnvironmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudbridge/GetEnvironment.ts.html |here} to see how to use GetEnvironment API.
     */
    getEnvironment(getEnvironmentRequest: requests.GetEnvironmentRequest): Promise<responses.GetEnvironmentResponse>;
    /**
     * Gets a plugin by identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetPluginRequest
     * @return GetPluginResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudbridge/GetPlugin.ts.html |here} to see how to use GetPlugin API.
     */
    getPlugin(getPluginRequest: requests.GetPluginRequest): Promise<responses.GetPluginResponse>;
    /**
     * Returns a list of AgentDependencies such as AgentDependencyCollection.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListAgentDependenciesRequest
     * @return ListAgentDependenciesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudbridge/ListAgentDependencies.ts.html |here} to see how to use ListAgentDependencies API.
     */
    listAgentDependencies(listAgentDependenciesRequest: requests.ListAgentDependenciesRequest): Promise<responses.ListAgentDependenciesResponse>;
    /**
     * Returns a list of Agents.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListAgentsRequest
     * @return ListAgentsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudbridge/ListAgents.ts.html |here} to see how to use ListAgents API.
     */
    listAgents(listAgentsRequest: requests.ListAgentsRequest): Promise<responses.ListAgentsResponse>;
    /**
     * Returns a list of Appliance Images.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListApplianceImagesRequest
     * @return ListApplianceImagesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudbridge/ListApplianceImages.ts.html |here} to see how to use ListApplianceImages API.
     */
    listApplianceImages(listApplianceImagesRequest: requests.ListApplianceImagesRequest): Promise<responses.ListApplianceImagesResponse>;
    /**
     * Returns a list of source environments.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListEnvironmentsRequest
     * @return ListEnvironmentsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudbridge/ListEnvironments.ts.html |here} to see how to use ListEnvironments API.
     */
    listEnvironments(listEnvironmentsRequest: requests.ListEnvironmentsRequest): Promise<responses.ListEnvironmentsResponse>;
    /**
     * Adds a dependency to the source environment. When provided, If-Match is checked against ETag values of the resource.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param RemoveAgentDependencyRequest
     * @return RemoveAgentDependencyResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudbridge/RemoveAgentDependency.ts.html |here} to see how to use RemoveAgentDependency API.
     */
    removeAgentDependency(removeAgentDependencyRequest: requests.RemoveAgentDependencyRequest): Promise<responses.RemoveAgentDependencyResponse>;
    /**
     * Updates the Agent.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateAgentRequest
     * @return UpdateAgentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudbridge/UpdateAgent.ts.html |here} to see how to use UpdateAgent API.
     */
    updateAgent(updateAgentRequest: requests.UpdateAgentRequest): Promise<responses.UpdateAgentResponse>;
    /**
     * Updates the AgentDependency.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateAgentDependencyRequest
     * @return UpdateAgentDependencyResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudbridge/UpdateAgentDependency.ts.html |here} to see how to use UpdateAgentDependency API.
     */
    updateAgentDependency(updateAgentDependencyRequest: requests.UpdateAgentDependencyRequest): Promise<responses.UpdateAgentDependencyResponse>;
    /**
     * Updates the source environment.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateEnvironmentRequest
     * @return UpdateEnvironmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudbridge/UpdateEnvironment.ts.html |here} to see how to use UpdateEnvironment API.
     */
    updateEnvironment(updateEnvironmentRequest: requests.UpdateEnvironmentRequest): Promise<responses.UpdateEnvironmentResponse>;
    /**
     * Updates the plugin.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdatePluginRequest
     * @return UpdatePluginResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudbridge/UpdatePlugin.ts.html |here} to see how to use UpdatePlugin API.
     */
    updatePlugin(updatePluginRequest: requests.UpdatePluginRequest): Promise<responses.UpdatePluginResponse>;
}
export {};
