/**
 * Cloud Guard and Security Zones API
 * Use the Cloud Guard and Security Zones API to automate processes that you would otherwise perform through the Cloud Guard Console or the Security Zones Console. For more information on these services, see the [Cloud Guard](/iaas/cloud-guard/home.htm) and [Security Zones](/iaas/security-zone/home.htm) documentation.

**Note:** For Cloud Guard, you can perform Create, Update, and Delete operations only from the reporting region of your Cloud Guard tenancy. You can perform Read operations from any region.

 * OpenAPI spec version: 20200131
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * A data mask rule specifies the conditions in which the value for a sensitive data field in the UI is to be hidden or displayed when viewed by specified groups of users. The DataMaskRule resource contains the parameters for a data mask rule.
 */
export interface DataMaskRule {
    /**
     * Unique identifier that can't be changed after creation
     */
    "id": string;
    /**
     * Data mask rule display name
     */
    "displayName"?: string;
    /**
     * Compartment OCID where the resource is created
     */
    "compartmentId": string;
    /**
     * The data mask rule description
     */
    "description"?: string;
    /**
     * IAM Group ID associated with the data mask rule
     */
    "iamGroupId": string;
    "targetSelected": model.AllTargetsSelected | model.TargetResourceTypesSelected | model.TargetIdsSelected;
    /**
     * List of data mask rule categories
     */
    "dataMaskCategories"?: Array<DataMaskRule.DataMaskCategories>;
    /**
     * The date and time the target was created. Format defined by RFC3339.
     */
    "timeCreated"?: Date;
    /**
     * The date and time the target was updated. Format defined by RFC3339.
     */
    "timeUpdated"?: Date;
    /**
     * The current status of the data mask rule
     */
    "dataMaskRuleStatus"?: model.DataMaskRuleStatus;
    /**
     * The current lifecycle state of the data mask rule
     */
    "lifecycleState"?: model.LifecycleState;
    /**
     * Additional details on the substate of the lifecycle state [DEPRECATE]
     */
    "lifecyleDetails"?: string;
    /**
     * Locks associated with this resource.
     */
    "locks"?: Array<model.ResourceLock>;
    /**
      * Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
  * Example: {@code {\"bar-key\": \"value\"}}
  * <p>
  Avoid entering confidential information.
  *
      */
    "freeformTags"?: {
        [key: string]: string;
    };
    /**
     * Defined tags for this resource. Each key is predefined and scoped to a namespace.
     * Example: {@code {\"foo-namespace\": {\"bar-key\": \"value\"}}}
     *
     */
    "definedTags"?: {
        [key: string]: {
            [key: string]: any;
        };
    };
    /**
      * System tags for this resource. Each key is predefined and scoped to a namespace.
  * For more information, see [Resource Tags](https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
  * System tags can be viewed by users, but can only be created by the system.
  * <p>
  Example: {@code {\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}}
  *
      */
    "systemTags"?: {
        [key: string]: {
            [key: string]: any;
        };
    };
}
export declare namespace DataMaskRule {
    enum DataMaskCategories {
        Actor = "ACTOR",
        Pii = "PII",
        Phi = "PHI",
        Financial = "FINANCIAL",
        Location = "LOCATION",
        Custom = "CUSTOM",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    function getJsonObj(obj: DataMaskRule): object;
    function getDeserializedJsonObj(obj: DataMaskRule): object;
}
