/**
 * Cloud Guard and Security Zones API
 * Use the Cloud Guard and Security Zones API to automate processes that you would otherwise perform through the Cloud Guard Console or the Security Zones Console. For more information on these services, see the [Cloud Guard](/iaas/cloud-guard/home.htm) and [Security Zones](/iaas/security-zone/home.htm) documentation.

**Note:** For Cloud Guard, you can perform Create, Update, and Delete operations only from the reporting region of your Cloud Guard tenancy. You can perform Read operations from any region.

 * OpenAPI spec version: 20200131
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
* A ResponderRecipe resource contains a specific instance of one of
* the supported detector types (for example, activity, configuration,
* or threat).
* <p>
A ResponderRecipe resource:
* * Is effectively a copy of a Responder resource in which users can make
* very limited changes if it\u2019s Oracle-managed, and more changes if it\u2019s user-managed.
* * Can also be created by cloning an existing ResponderRecipe resource, either
* user-managed or Oracle-managed.
* * Is visible on Cloud Guard\u2019s Responder Recipes page.
* * Is located in a specific OCI compartment.
* * Can be modified by users, programmatically or through the UI.
* * Changes that can be made here apply globally, to resources in all OCI compartments
* mapped to a target that attaches the responder recipe, but are overridden by
* any changes made in the corresponding TargetResponderRecipe resource (effectively
* created when the responder recipe is attached to the target).
*
*/
export interface ResponderRecipe {
    /**
     * Unique identifier for the responder recip
     */
    "id": string;
    /**
     * Responder recipe display name
     */
    "displayName"?: string;
    /**
     * Responder recipe description
     */
    "description"?: string;
    /**
     * Owner of responder recipe
     */
    "owner"?: model.OwnerType;
    /**
     * List of responder rules associated with the recipe
     */
    "responderRules"?: Array<model.ResponderRecipeResponderRule>;
    /**
     * List of currently enabled responder rules for the responder type, for recipe after applying defaults
     */
    "effectiveResponderRules"?: Array<model.ResponderRecipeResponderRule>;
    /**
     * The unique identifier of the source responder recipe
     */
    "sourceResponderRecipeId"?: string;
    /**
     * Compartment OCID
     */
    "compartmentId": string;
    /**
     * The date and time the responder recipe was created. Format defined by RFC3339.
     */
    "timeCreated"?: Date;
    /**
     * The date and time the responder recipe was last updated. Format defined by RFC3339.
     */
    "timeUpdated"?: Date;
    /**
     * The current lifecycle state of the example
     */
    "lifecycleState"?: model.LifecycleState;
    /**
     * A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.
     */
    "lifecycleDetails"?: string;
    /**
      * Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
  * Example: {@code {\"bar-key\": \"value\"}}
  * <p>
  Avoid entering confidential information.
  *
      */
    "freeformTags"?: {
        [key: string]: string;
    };
    /**
     * Defined tags for this resource. Each key is predefined and scoped to a namespace.
     * Example: {@code {\"foo-namespace\": {\"bar-key\": \"value\"}}}
     *
     */
    "definedTags"?: {
        [key: string]: {
            [key: string]: any;
        };
    };
    /**
      * System tags for this resource. Each key is predefined and scoped to a namespace.
  * For more information, see [Resource Tags](https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
  * System tags can be viewed by users, but can only be created by the system.
  * <p>
  Example: {@code {\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}}
  *
      */
    "systemTags"?: {
        [key: string]: {
            [key: string]: any;
        };
    };
}
export declare namespace ResponderRecipe {
    function getJsonObj(obj: ResponderRecipe): object;
    function getDeserializedJsonObj(obj: ResponderRecipe): object;
}
