/**
 * Cloud Guard and Security Zones API
 * Use the Cloud Guard and Security Zones API to automate processes that you would otherwise perform through the Cloud Guard Console or the Security Zones Console. For more information on these services, see the [Cloud Guard](/iaas/cloud-guard/home.htm) and [Security Zones](/iaas/security-zone/home.htm) documentation.

**Note:** For Cloud Guard, you can perform Create, Update, and Delete operations only from the reporting region of your Cloud Guard tenancy. You can perform Read operations from any region.

 * OpenAPI spec version: 20200131
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * Sighting details.
 */
export interface Sighting {
    /**
     * Unique identifier for the sighting
     */
    "id": string;
    /**
     * Description of the sighting
     */
    "description": string;
    /**
     * Problem ID associated the sighting
     */
    "problemId"?: string;
    /**
     * Compartment OCID where the resource is created
     */
    "compartmentId": string;
    /**
     * Unique identifier for principal actor
     */
    "actorPrincipalId"?: string;
    /**
     * Name of the principal actor
     */
    "actorPrincipalName"?: string;
    /**
     * Type of the principal actor
     */
    "actorPrincipalType"?: string;
    /**
     * Classification status of the sighting
     */
    "classificationStatus": model.ClassificationStatus;
    /**
     * Type of sighting
     */
    "sightingType": string;
    /**
     * Display name of the sighting type
     */
    "sightingTypeDisplayName": string;
    /**
     * Name of the MITRE ATT@CK framework tactic
     */
    "tacticName": string;
    /**
     * Name of the MITRE ATT@CK framework technique
     */
    "techniqueName": string;
    /**
     * Score for the sighting Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "sightingScore": number;
    /**
     * Severity of the sighting
     */
    "severity": model.Severity;
    /**
     * Level of confidence that the sighting is not a false positive
     */
    "confidence": model.Confidence;
    /**
     * Time the activities were first detected. Format defined by RFC3339.
     */
    "timeFirstDetected": Date;
    /**
     * Time the activities were last detected. Format defined by RFC3339.
     */
    "timeLastDetected": Date;
    /**
     * Time the activities were first performed. Format defined by RFC3339.
     */
    "timeFirstOccurred"?: Date;
    /**
     * Time the activities were last performed. Format defined by RFC3339.
     */
    "timeLastOccurred"?: Date;
    /**
     * List of regions involved in the sighting
     */
    "regions": Array<string>;
    /**
     * The additional details for the sighting
     */
    "additionalDetails"?: {
        [key: string]: string;
    };
    /**
     * Locks associated with this resource.
     */
    "locks"?: Array<model.ResourceLock>;
}
export declare namespace Sighting {
    function getJsonObj(obj: Sighting): object;
    function getDeserializedJsonObj(obj: Sighting): object;
}
