/**
 * Cloud Guard and Security Zones API
 * Use the Cloud Guard and Security Zones API to automate processes that you would otherwise perform through the Cloud Guard Console or the Security Zones Console. For more information on these services, see the [Cloud Guard](/iaas/cloud-guard/home.htm) and [Security Zones](/iaas/security-zone/home.htm) documentation.

**Note:** For Cloud Guard, you can perform Create, Update, and Delete operations only from the reporting region of your Cloud Guard tenancy. You can perform Read operations from any region.

 * OpenAPI spec version: 20200131
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
* A TargetResponderRecipe resource contains a specific instance of one of the
* supported detector types (for example, activity, configuration, or threat)
* in which some settings can be modified specifically for a single target.
* <p>
A TargetResponderRecipe resource:
* * Is effectively a copy of a ResponderRecipe resource in which users can make
* very limited changes if it\u2019s Oracle-managed, and more changes if it\u2019s user-managed.
* * Is visible on the Cloud Guard Targets, Target Details page.
* * Is located in a specific OCI compartment.
* * Can be modified by users, programmatically or through the UI.
* * Changes that can be made here override any settings in the corresponding
* ResponderRecipe, of which the TargetResponderRecipe resource is effectively a copy
* of the ResponderRecipe resource (effectively created when the detector recipe
* is attached to the target).
*
*/
export interface TargetResponderRecipe {
    /**
     * Unique identifier of target responder recipe that can't be changed after creation
     */
    "id": string;
    /**
     * Unique identifier for the Oracle-managed responder recipe from which this recipe was cloned
     */
    "responderRecipeId": string;
    /**
     * Compartment OCID
     */
    "compartmentId": string;
    /**
     * Target responder recipe display name
     */
    "displayName": string;
    /**
     * Target responder description
     */
    "description": string;
    /**
     * Owner of target responder recipe
     */
    "owner": model.OwnerType;
    /**
     * The date and time the target responder recipe rule was created. Format defined by RFC3339.
     */
    "timeCreated"?: Date;
    /**
     * The date and time the target responder recipe rule was last updated. Format defined by RFC3339.
     */
    "timeUpdated"?: Date;
    /**
     * List of responder rules associated with the recipe - user input
     */
    "responderRules"?: Array<model.TargetResponderRecipeResponderRule>;
    /**
     * List of currently enabled responder rules for the responder type for recipe after applying defaults
     */
    "effectiveResponderRules"?: Array<model.TargetResponderRecipeResponderRule>;
    /**
     * Locks associated with this resource.
     */
    "locks"?: Array<model.ResourceLock>;
}
export declare namespace TargetResponderRecipe {
    function getJsonObj(obj: TargetResponderRecipe): object;
    function getDeserializedJsonObj(obj: TargetResponderRecipe): object;
}
