/**
 * Oracle Cloud Migrations API
 * A description of the Oracle Cloud Migrations API.
 * OpenAPI spec version: 20220919
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import common = require("oci-common");
import * as requests from "./request";
import * as responses from "./response";
import { MigrationWaiter } from "./migration-waiter";
declare const Breaker: any;
export declare enum MigrationApiKeys {
}
/**
 * This service client uses {@link common.CircuitBreaker.DefaultConfiguration} for all the operations by default if no circuit breaker configuration is defined by the user.
 */
export declare class MigrationClient {
    protected static serviceEndpointTemplate: string;
    protected static endpointServiceName: string;
    protected "_realmSpecificEndpointTemplateEnabled": boolean | undefined;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_waiters": MigrationWaiter;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: typeof Breaker | null;
    protected _httpOptions: any;
    protected _bodyDuplexMode: any;
    targetService: string;
    protected _regionId: string;
    protected "_region": common.Region;
    protected _lastSetRegionOrRegionId: string;
    protected _httpClient: common.HttpClient;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    get endpoint(): string;
    /**
     * Sets the endpoint to call (ex, https://www.example.com).
     * @param endpoint The endpoint of the service.
     */
    set endpoint(endpoint: string);
    get logger(): import("oci-common/lib/log").Logger;
    /**
     * Determines whether realm specific endpoint should be used or not.
     * Set realmSpecificEndpointTemplateEnabled to "true" if the user wants to enable use of realm specific endpoint template, otherwise set it to "false"
     * @param realmSpecificEndpointTemplateEnabled flag to enable the use of realm specific endpoint template
     */
    set useRealmSpecificEndpointTemplate(realmSpecificEndpointTemplateEnabled: boolean);
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    set region(region: common.Region);
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    set regionId(regionId: string);
    /**
     * Creates a new MigrationWaiter for resources for this service.
     *
     * @param config The waiter configuration for termination and delay strategy
     * @return The service waiters.
     */
    createWaiters(config?: common.WaiterConfiguration): MigrationWaiter;
    /**
     * Gets the waiters available for resources for this service.
     *
     * @return The service waiters.
     */
    getWaiters(): MigrationWaiter;
    /**
     * Shutdown the circuit breaker used by the client when it is no longer needed
     */
    shutdownCircuitBreaker(): void;
    /**
     * Close the client once it is no longer needed
     */
    close(): void;
    /**
     * Cancels work request with the given ID.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CancelWorkRequestRequest
     * @return CancelWorkRequestResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudmigrations/CancelWorkRequest.ts.html |here} to see how to use CancelWorkRequest API.
     */
    cancelWorkRequest(cancelWorkRequestRequest: requests.CancelWorkRequestRequest): Promise<responses.CancelWorkRequestResponse>;
    /**
     * Moves a migration resource from one compartment identifier to another. When provided, If-Match is checked against ETag values of the resource.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ChangeMigrationCompartmentRequest
     * @return ChangeMigrationCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudmigrations/ChangeMigrationCompartment.ts.html |here} to see how to use ChangeMigrationCompartment API.
     */
    changeMigrationCompartment(changeMigrationCompartmentRequest: requests.ChangeMigrationCompartmentRequest): Promise<responses.ChangeMigrationCompartmentResponse>;
    /**
     * Moves a resource into a different compartment. When provided, If-Match is checked against ETag values of the resource.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ChangeMigrationPlanCompartmentRequest
     * @return ChangeMigrationPlanCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudmigrations/ChangeMigrationPlanCompartment.ts.html |here} to see how to use ChangeMigrationPlanCompartment API.
     */
    changeMigrationPlanCompartment(changeMigrationPlanCompartmentRequest: requests.ChangeMigrationPlanCompartmentRequest): Promise<responses.ChangeMigrationPlanCompartmentResponse>;
    /**
     * Moves a resource into a different compartment. When provided, If-Match is checked against ETag values of the resource.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ChangeReplicationScheduleCompartmentRequest
     * @return ChangeReplicationScheduleCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudmigrations/ChangeReplicationScheduleCompartment.ts.html |here} to see how to use ChangeReplicationScheduleCompartment API.
     */
    changeReplicationScheduleCompartment(changeReplicationScheduleCompartmentRequest: requests.ChangeReplicationScheduleCompartmentRequest): Promise<responses.ChangeReplicationScheduleCompartmentResponse>;
    /**
     * Creates a migration.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateMigrationRequest
     * @return CreateMigrationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudmigrations/CreateMigration.ts.html |here} to see how to use CreateMigration API.
     */
    createMigration(createMigrationRequest: requests.CreateMigrationRequest): Promise<responses.CreateMigrationResponse>;
    /**
     * Creates a migration asset.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateMigrationAssetRequest
     * @return CreateMigrationAssetResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudmigrations/CreateMigrationAsset.ts.html |here} to see how to use CreateMigrationAsset API.
     */
    createMigrationAsset(createMigrationAssetRequest: requests.CreateMigrationAssetRequest): Promise<responses.CreateMigrationAssetResponse>;
    /**
     * Creates a migration plan.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateMigrationPlanRequest
     * @return CreateMigrationPlanResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudmigrations/CreateMigrationPlan.ts.html |here} to see how to use CreateMigrationPlan API.
     */
    createMigrationPlan(createMigrationPlanRequest: requests.CreateMigrationPlanRequest): Promise<responses.CreateMigrationPlanResponse>;
    /**
     * Creates a replication schedule.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateReplicationScheduleRequest
     * @return CreateReplicationScheduleResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudmigrations/CreateReplicationSchedule.ts.html |here} to see how to use CreateReplicationSchedule API.
     */
    createReplicationSchedule(createReplicationScheduleRequest: requests.CreateReplicationScheduleRequest): Promise<responses.CreateReplicationScheduleResponse>;
    /**
     * Creates a target asset.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateTargetAssetRequest
     * @return CreateTargetAssetResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudmigrations/CreateTargetAsset.ts.html |here} to see how to use CreateTargetAsset API.
     */
    createTargetAsset(createTargetAssetRequest: requests.CreateTargetAssetRequest): Promise<responses.CreateTargetAssetResponse>;
    /**
     * Deletes a migration resource by identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteMigrationRequest
     * @return DeleteMigrationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudmigrations/DeleteMigration.ts.html |here} to see how to use DeleteMigration API.
     */
    deleteMigration(deleteMigrationRequest: requests.DeleteMigrationRequest): Promise<responses.DeleteMigrationResponse>;
    /**
     * Deletes a migration asset resource by an identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteMigrationAssetRequest
     * @return DeleteMigrationAssetResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudmigrations/DeleteMigrationAsset.ts.html |here} to see how to use DeleteMigrationAsset API.
     */
    deleteMigrationAsset(deleteMigrationAssetRequest: requests.DeleteMigrationAssetRequest): Promise<responses.DeleteMigrationAssetResponse>;
    /**
     * Deletes a migration plan resource by an identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteMigrationPlanRequest
     * @return DeleteMigrationPlanResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudmigrations/DeleteMigrationPlan.ts.html |here} to see how to use DeleteMigrationPlan API.
     */
    deleteMigrationPlan(deleteMigrationPlanRequest: requests.DeleteMigrationPlanRequest): Promise<responses.DeleteMigrationPlanResponse>;
    /**
     * Deletes a replication schedule resource by identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteReplicationScheduleRequest
     * @return DeleteReplicationScheduleResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudmigrations/DeleteReplicationSchedule.ts.html |here} to see how to use DeleteReplicationSchedule API.
     */
    deleteReplicationSchedule(deleteReplicationScheduleRequest: requests.DeleteReplicationScheduleRequest): Promise<responses.DeleteReplicationScheduleResponse>;
    /**
     * Deletes a target asset resource by identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteTargetAssetRequest
     * @return DeleteTargetAssetResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudmigrations/DeleteTargetAsset.ts.html |here} to see how to use DeleteTargetAsset API.
     */
    deleteTargetAsset(deleteTargetAssetRequest: requests.DeleteTargetAssetRequest): Promise<responses.DeleteTargetAssetResponse>;
    /**
     * Executes the migration plan with the migration plan ID.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ExecuteMigrationPlanRequest
     * @return ExecuteMigrationPlanResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudmigrations/ExecuteMigrationPlan.ts.html |here} to see how to use ExecuteMigrationPlan API.
     */
    executeMigrationPlan(executeMigrationPlanRequest: requests.ExecuteMigrationPlanRequest): Promise<responses.ExecuteMigrationPlanResponse>;
    /**
     * Exports the migration plan to a csv file.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ExportMigrationPlanRequest
     * @return ExportMigrationPlanResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudmigrations/ExportMigrationPlan.ts.html |here} to see how to use ExportMigrationPlan API.
     */
    exportMigrationPlan(exportMigrationPlanRequest: requests.ExportMigrationPlanRequest): Promise<responses.ExportMigrationPlanResponse>;
    /**
     * Gets a migration by identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetMigrationRequest
     * @return GetMigrationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudmigrations/GetMigration.ts.html |here} to see how to use GetMigration API.
     */
    getMigration(getMigrationRequest: requests.GetMigrationRequest): Promise<responses.GetMigrationResponse>;
    /**
     * Gets a migration asset by identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetMigrationAssetRequest
     * @return GetMigrationAssetResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudmigrations/GetMigrationAsset.ts.html |here} to see how to use GetMigrationAsset API.
     */
    getMigrationAsset(getMigrationAssetRequest: requests.GetMigrationAssetRequest): Promise<responses.GetMigrationAssetResponse>;
    /**
     * Gets a migration plan by identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetMigrationPlanRequest
     * @return GetMigrationPlanResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudmigrations/GetMigrationPlan.ts.html |here} to see how to use GetMigrationPlan API.
     */
    getMigrationPlan(getMigrationPlanRequest: requests.GetMigrationPlanRequest): Promise<responses.GetMigrationPlanResponse>;
    /**
     * Gets the progress percentage of a migration asset's replication process.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetReplicationProgressRequest
     * @return GetReplicationProgressResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudmigrations/GetReplicationProgress.ts.html |here} to see how to use GetReplicationProgress API.
     */
    getReplicationProgress(getReplicationProgressRequest: requests.GetReplicationProgressRequest): Promise<responses.GetReplicationProgressResponse>;
    /**
     * Gets a replication schedule by identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetReplicationScheduleRequest
     * @return GetReplicationScheduleResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudmigrations/GetReplicationSchedule.ts.html |here} to see how to use GetReplicationSchedule API.
     */
    getReplicationSchedule(getReplicationScheduleRequest: requests.GetReplicationScheduleRequest): Promise<responses.GetReplicationScheduleResponse>;
    /**
     * Gets a target asset by identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetTargetAssetRequest
     * @return GetTargetAssetResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudmigrations/GetTargetAsset.ts.html |here} to see how to use GetTargetAsset API.
     */
    getTargetAsset(getTargetAssetRequest: requests.GetTargetAssetRequest): Promise<responses.GetTargetAssetResponse>;
    /**
     * Gets the status of the work request with the given ID.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetWorkRequestRequest
     * @return GetWorkRequestResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudmigrations/GetWorkRequest.ts.html |here} to see how to use GetWorkRequest API.
     */
    getWorkRequest(getWorkRequestRequest: requests.GetWorkRequestRequest): Promise<responses.GetWorkRequestResponse>;
    /**
     * Imports a migration plan from a csv file.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ImportMigrationPlanRequest
     * @return ImportMigrationPlanResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudmigrations/ImportMigrationPlan.ts.html |here} to see how to use ImportMigrationPlan API.
     */
    importMigrationPlan(importMigrationPlanRequest: requests.ImportMigrationPlanRequest): Promise<responses.ImportMigrationPlanResponse>;
    /**
     * List of shapes by parameters.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListAvailableShapesRequest
     * @return ListAvailableShapesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudmigrations/ListAvailableShapes.ts.html |here} to see how to use ListAvailableShapes API.
     */
    listAvailableShapes(listAvailableShapesRequest: requests.ListAvailableShapesRequest): Promise<responses.ListAvailableShapesResponse>;
    /**
     * Returns a list of migration assets.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListMigrationAssetsRequest
     * @return ListMigrationAssetsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudmigrations/ListMigrationAssets.ts.html |here} to see how to use ListMigrationAssets API.
     */
    listMigrationAssets(listMigrationAssetsRequest: requests.ListMigrationAssetsRequest): Promise<responses.ListMigrationAssetsResponse>;
    /**
     * Returns a list of migration plans.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListMigrationPlansRequest
     * @return ListMigrationPlansResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudmigrations/ListMigrationPlans.ts.html |here} to see how to use ListMigrationPlans API.
     */
    listMigrationPlans(listMigrationPlansRequest: requests.ListMigrationPlansRequest): Promise<responses.ListMigrationPlansResponse>;
    /**
     * Returns a list of migrations.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListMigrationsRequest
     * @return ListMigrationsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudmigrations/ListMigrations.ts.html |here} to see how to use ListMigrations API.
     */
    listMigrations(listMigrationsRequest: requests.ListMigrationsRequest): Promise<responses.ListMigrationsResponse>;
    /**
     * Returns a list of replication schedules.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListReplicationSchedulesRequest
     * @return ListReplicationSchedulesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudmigrations/ListReplicationSchedules.ts.html |here} to see how to use ListReplicationSchedules API.
     */
    listReplicationSchedules(listReplicationSchedulesRequest: requests.ListReplicationSchedulesRequest): Promise<responses.ListReplicationSchedulesResponse>;
    /**
     * Returns a list of target assets.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListTargetAssetsRequest
     * @return ListTargetAssetsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudmigrations/ListTargetAssets.ts.html |here} to see how to use ListTargetAssets API.
     */
    listTargetAssets(listTargetAssetsRequest: requests.ListTargetAssetsRequest): Promise<responses.ListTargetAssetsResponse>;
    /**
     * Returns a paginated list of errors for a given work request.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListWorkRequestErrorsRequest
     * @return ListWorkRequestErrorsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudmigrations/ListWorkRequestErrors.ts.html |here} to see how to use ListWorkRequestErrors API.
     */
    listWorkRequestErrors(listWorkRequestErrorsRequest: requests.ListWorkRequestErrorsRequest): Promise<responses.ListWorkRequestErrorsResponse>;
    /**
     * Returns a paginated list of logs for a given work request.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListWorkRequestLogsRequest
     * @return ListWorkRequestLogsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudmigrations/ListWorkRequestLogs.ts.html |here} to see how to use ListWorkRequestLogs API.
     */
    listWorkRequestLogs(listWorkRequestLogsRequest: requests.ListWorkRequestLogsRequest): Promise<responses.ListWorkRequestLogsResponse>;
    /**
     * List of work requests in a compartment.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListWorkRequestsRequest
     * @return ListWorkRequestsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudmigrations/ListWorkRequests.ts.html |here} to see how to use ListWorkRequests API.
     */
    listWorkRequests(listWorkRequestsRequest: requests.ListWorkRequestsRequest): Promise<responses.ListWorkRequestsResponse>;
    /**
     * Refreshes migration based on the migration ID.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param RefreshMigrationRequest
     * @return RefreshMigrationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudmigrations/RefreshMigration.ts.html |here} to see how to use RefreshMigration API.
     */
    refreshMigration(refreshMigrationRequest: requests.RefreshMigrationRequest): Promise<responses.RefreshMigrationResponse>;
    /**
     * Refreshes the migration asset with the migration asset ID.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param RefreshMigrationAssetRequest
     * @return RefreshMigrationAssetResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudmigrations/RefreshMigrationAsset.ts.html |here} to see how to use RefreshMigrationAsset API.
     */
    refreshMigrationAsset(refreshMigrationAssetRequest: requests.RefreshMigrationAssetRequest): Promise<responses.RefreshMigrationAssetResponse>;
    /**
     * Refreshes the migration plan with the migration plan ID.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param RefreshMigrationPlanRequest
     * @return RefreshMigrationPlanResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudmigrations/RefreshMigrationPlan.ts.html |here} to see how to use RefreshMigrationPlan API.
     */
    refreshMigrationPlan(refreshMigrationPlanRequest: requests.RefreshMigrationPlanRequest): Promise<responses.RefreshMigrationPlanResponse>;
    /**
     * Starts replication for the asset with the migration asset ID.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param StartAssetReplicationRequest
     * @return StartAssetReplicationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudmigrations/StartAssetReplication.ts.html |here} to see how to use StartAssetReplication API.
     */
    startAssetReplication(startAssetReplicationRequest: requests.StartAssetReplicationRequest): Promise<responses.StartAssetReplicationResponse>;
    /**
     * Starts replication for a migration or for some asset.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param StartMigrationReplicationRequest
     * @return StartMigrationReplicationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudmigrations/StartMigrationReplication.ts.html |here} to see how to use StartMigrationReplication API.
     */
    startMigrationReplication(startMigrationReplicationRequest: requests.StartMigrationReplicationRequest): Promise<responses.StartMigrationReplicationResponse>;
    /**
     * Updates the migration.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateMigrationRequest
     * @return UpdateMigrationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudmigrations/UpdateMigration.ts.html |here} to see how to use UpdateMigration API.
     */
    updateMigration(updateMigrationRequest: requests.UpdateMigrationRequest): Promise<responses.UpdateMigrationResponse>;
    /**
     * Updates the migration asset.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateMigrationAssetRequest
     * @return UpdateMigrationAssetResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudmigrations/UpdateMigrationAsset.ts.html |here} to see how to use UpdateMigrationAsset API.
     */
    updateMigrationAsset(updateMigrationAssetRequest: requests.UpdateMigrationAssetRequest): Promise<responses.UpdateMigrationAssetResponse>;
    /**
     * Updates the migration plan.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateMigrationPlanRequest
     * @return UpdateMigrationPlanResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudmigrations/UpdateMigrationPlan.ts.html |here} to see how to use UpdateMigrationPlan API.
     */
    updateMigrationPlan(updateMigrationPlanRequest: requests.UpdateMigrationPlanRequest): Promise<responses.UpdateMigrationPlanResponse>;
    /**
     * Updates the replication schedule.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateReplicationScheduleRequest
     * @return UpdateReplicationScheduleResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudmigrations/UpdateReplicationSchedule.ts.html |here} to see how to use UpdateReplicationSchedule API.
     */
    updateReplicationSchedule(updateReplicationScheduleRequest: requests.UpdateReplicationScheduleRequest): Promise<responses.UpdateReplicationScheduleResponse>;
    /**
     * Updates the target asset.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateTargetAssetRequest
     * @return UpdateTargetAssetResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/cloudmigrations/UpdateTargetAsset.ts.html |here} to see how to use UpdateTargetAsset API.
     */
    updateTargetAsset(updateTargetAssetRequest: requests.UpdateTargetAssetRequest): Promise<responses.UpdateTargetAssetResponse>;
}
export {};
