/**
 * Oracle Cloud Migrations API
 * A description of the Oracle Cloud Migrations API.
 * OpenAPI spec version: 20220919
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * Description of the target asset.
 */
export interface TargetAsset {
    /**
     * Unique identifier that is immutable on creation.
     */
    "id": string;
    /**
     * A user-friendly name. Does not have to be unique, and it's changeable. Avoid entering confidential information.
     */
    "displayName"?: string;
    /**
     * The current state of the target asset.
     */
    "lifecycleState": TargetAsset.LifecycleState;
    /**
     * A message describing the current state in more detail. For example, it can be used to provide actionable information for a resource in Failed state.
     */
    "lifecycleDetails"?: string;
    /**
     * OCID of the associated migration plan.
     */
    "migrationPlanId": string;
    /**
     * Compartment identifier
     */
    "compartmentId"?: string;
    /**
     * Created resource identifier
     */
    "createdResourceId"?: string;
    /**
     * A boolean indicating whether the asset should be migrated.
     */
    "isExcludedFromExecution": boolean;
    /**
     * Messages about the compatibility issues.
     */
    "compatibilityMessages"?: Array<model.CompatibilityMessage>;
    "estimatedCost": model.CostEstimation;
    /**
     * The time when the target asset was created. An RFC3339 formatted datetime string.
     */
    "timeCreated": Date;
    /**
     * The time when the target asset was updated. An RFC3339 formatted datetime string.
     */
    "timeUpdated": Date;
    /**
     * The time when the assessment was done. An RFC3339 formatted datetime string.
     */
    "timeAssessed": Date;
    "migrationAsset"?: model.MigrationAsset;
    "type": string;
}
export declare namespace TargetAsset {
    enum LifecycleState {
        Creating = "CREATING",
        Updating = "UPDATING",
        NeedsAttention = "NEEDS_ATTENTION",
        Active = "ACTIVE",
        Deleting = "DELETING",
        Deleted = "DELETED",
        Failed = "FAILED",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    function getJsonObj(obj: TargetAsset): object;
    function getDeserializedJsonObj(obj: TargetAsset): object;
}
