/**
 * Cluster Placement Groups API
 * API for managing cluster placement groups.
 * OpenAPI spec version: 20230801
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * A cluster placement group, which is a logical grouping of resources that offer low latency within an availability domain by being placed in close physical proximity.
 *
 */
export interface ClusterPlacementGroup {
    /**
     * The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the cluster placement group.
     *
     */
    "id": string;
    /**
     * The user-friendly name of the cluster placement group. The display name for a cluster placement must be unique and you cannot change it. Avoid entering confidential information.
     *
     */
    "name": string;
    /**
     * A description of the cluster placement group.
     */
    "description": string;
    /**
     * The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment that contains the cluster placement group.
     *
     */
    "compartmentId": string;
    /**
     * The availability domain of the cluster placement group.
     */
    "availabilityDomain": string;
    /**
     * The type of cluster placement group.
     */
    "clusterPlacementGroupType": model.ClusterPlacementGroupType;
    /**
     * The time the cluster placement group was created, expressed in [RFC 3339](https://tools.ietf.org/html/rfc3339) timestamp format.
     */
    "timeCreated": Date;
    /**
     * The time the cluster placement group was updated, expressed in [RFC 3339](https://tools.ietf.org/html/rfc3339) timestamp format.
     */
    "timeUpdated"?: Date;
    /**
     * The current state of the ClusterPlacementGroup.
     */
    "lifecycleState": ClusterPlacementGroup.LifecycleState;
    /**
     * A message describing the current state in more detail. For example, lifecycle details for a resource in a Failed state might include information to act on.
     *
     */
    "lifecycleDetails"?: string;
    "placementInstruction"?: model.PlacementInstructionDetails;
    "capabilities"?: model.CapabilitiesCollection;
    /**
     * Simple key-value pair that is applied without any predefined name, type, or scope. Exists for cross-compatibility only.
     * Example: {@code {\"bar-key\": \"value\"}}
     *
     */
    "freeformTags": {
        [key: string]: string;
    };
    /**
     * Defined tags for this resource. Each key is predefined and scoped to a namespace.
     * Example: {@code {\"foo-namespace\": {\"bar-key\": \"value\"}}}
     *
     */
    "definedTags": {
        [key: string]: {
            [key: string]: any;
        };
    };
    /**
     * System tags for this resource. Each key is predefined and scoped to a namespace.
     * Example: {@code {\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}}
     *
     */
    "systemTags"?: {
        [key: string]: {
            [key: string]: any;
        };
    };
}
export declare namespace ClusterPlacementGroup {
    enum LifecycleState {
        Creating = "CREATING",
        Updating = "UPDATING",
        Active = "ACTIVE",
        Inactive = "INACTIVE",
        Deleting = "DELETING",
        Deleted = "DELETED",
        Failed = "FAILED",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    function getJsonObj(obj: ClusterPlacementGroup): object;
    function getDeserializedJsonObj(obj: ClusterPlacementGroup): object;
}
