/**
 * Core Services API
 * Use the Core Services API to manage resources such as virtual cloud networks (VCNs),
compute instances, and block storage volumes. For more information, see the console
documentation for the [Networking](/iaas/Content/Network/Concepts/overview.htm),
[Compute](/iaas/Content/Compute/Concepts/computeoverview.htm), and
[Block Volume](/iaas/Content/Block/Concepts/overview.htm) services.
The required permissions are documented in the
[Details for the Core Services](/iaas/Content/Identity/Reference/corepolicyreference.htm) article.

 * OpenAPI spec version: 20160918
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
export interface CreateSubnetDetails {
    /**
      * Controls whether the subnet is regional or specific to an availability domain. Oracle
  * recommends creating regional subnets because they're more flexible and make it easier to
  * implement failover across availability domains. Originally, AD-specific subnets were the
  * only kind available to use.
  * <p>
  To create a regional subnet, omit this attribute. Then any resources later created in this
  * subnet (such as a Compute instance) can be created in any availability domain in the region.
  * <p>
  To instead create an AD-specific subnet, set this attribute to the availability domain you
  * want this subnet to be in. Then any resources later created in this subnet can only be
  * created in that availability domain.
  * <p>
  Example: {@code Uocm:PHX-AD-1}
  *
      */
    "availabilityDomain"?: string;
    /**
      * The CIDR IP address range of the subnet. The CIDR must maintain the following rules -
  * <p>
  a. The CIDR block is valid and correctly formatted.
  * b. The new range is within one of the parent VCN ranges.
  * <p>
  Example: {@code 10.0.1.0/24}
  *
      */
    "cidrBlock": string;
    /**
     * The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment to contain the subnet.
     */
    "compartmentId": string;
    /**
      * Defined tags for this resource. Each key is predefined and scoped to a
  * namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
  * <p>
  Example: {@code {\"Operations\": {\"CostCenter\": \"42\"}}}
  *
      */
    "definedTags"?: {
        [key: string]: {
            [key: string]: any;
        };
    };
    /**
     * The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the set of DHCP options the subnet will use. If you don't
     * provide a value, the subnet uses the VCN's default set of DHCP options.
     *
     */
    "dhcpOptionsId"?: string;
    /**
     * A user-friendly name. Does not have to be unique, and it's changeable.
     * Avoid entering confidential information.
     *
     */
    "displayName"?: string;
    /**
      * A DNS label for the subnet, used in conjunction with the VNIC's hostname and
  * VCN's DNS label to form a fully qualified domain name (FQDN) for each VNIC
  * within this subnet (for example, {@code bminstance1.subnet123.vcn1.oraclevcn.com}).
  * Must be an alphanumeric string that begins with a letter and is unique within the VCN.
  * The value cannot be changed.
  * <p>
  This value must be set if you want to use the Internet and VCN Resolver to resolve the
  * hostnames of instances in the subnet. It can only be set if the VCN itself
  * was created with a DNS label.
  * <p>
  For more information, see
  * [DNS in Your Virtual Cloud Network](https://docs.cloud.oracle.com/iaas/Content/Network/Concepts/dns.htm).
  * <p>
  Example: {@code subnet123}
  *
      */
    "dnsLabel"?: string;
    /**
      * Free-form tags for this resource. Each tag is a simple key-value pair with no
  * predefined name, type, or namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
  * <p>
  Example: {@code {\"Department\": \"Finance\"}}
  *
      */
    "freeformTags"?: {
        [key: string]: string;
    };
    /**
      * Use this to enable IPv6 addressing for this subnet. The VCN must be enabled for IPv6.
  * You can't change this subnet characteristic later. All subnets are /64 in size. The subnet
  * portion of the IPv6 address is the fourth hextet from the left (1111 in the following example).
  * <p>
  For important details about IPv6 addressing in a VCN, see [IPv6 Addresses](https://docs.cloud.oracle.com/iaas/Content/Network/Concepts/ipv6.htm).
  * <p>
  Example: {@code 2001:0db8:0123:1111::/64}
  *
      */
    "ipv6CidrBlock"?: string;
    /**
     * The list of all IPv6 prefixes (Oracle allocated IPv6 GUA, ULA or private IPv6 prefixes, BYOIPv6 prefixes) for the subnet that meets the following criteria:
     * - The prefixes must be valid.
     * - Multiple prefixes must not overlap each other or the on-premises network prefix.
     * - The number of prefixes must not exceed the limit of IPv6 prefixes allowed to a subnet.
     *
     */
    "ipv6CidrBlocks"?: Array<string>;
    /**
      * Whether to disallow ingress internet traffic to VNICs within this subnet. Defaults to false.
  * <p>
  For IPv6, if {@code prohibitInternetIngress} is set to {@code true}, internet access is not allowed for any
  * IPv6s assigned to VNICs in the subnet. Otherwise, ingress internet traffic is allowed by default.
  * <p>
  {@code prohibitPublicIpOnVnic} will be set to the value of {@code prohibitInternetIngress} to dictate IPv4
  * behavior in this subnet. Only one or the other flag should be specified.
  * <p>
  Example: {@code true}
  *
      */
    "prohibitInternetIngress"?: boolean;
    /**
      * Whether VNICs within this subnet can have public IP addresses.
  * Defaults to false, which means VNICs created in this subnet will
  * automatically be assigned public IP addresses unless specified
  * otherwise during instance launch or VNIC creation (with the
  * {@code assignPublicIp} flag in {@link CreateVnicDetails}).
  * If {@code prohibitPublicIpOnVnic} is set to true, VNICs created in this
  * subnet cannot have public IP addresses (that is, it's a private
  * subnet).
  * <p>
  If you intend to use an IPv6 prefix, you should use the flag {@code prohibitInternetIngress} to
  * specify ingress internet traffic behavior of the subnet.
  * <p>
  Example: {@code true}
  *
      */
    "prohibitPublicIpOnVnic"?: boolean;
    /**
     * The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the route table the subnet will use. If you don't provide a value,
     * the subnet uses the VCN's default route table.
     *
     */
    "routeTableId"?: string;
    /**
     * The OCIDs of the security list or lists the subnet will use. If you don't
     * provide a value, the subnet uses the VCN's default security list.
     * Remember that security lists are associated *with the subnet*, but the
     * rules are applied to the individual VNICs in the subnet.
     *
     */
    "securityListIds"?: Array<string>;
    /**
     * The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the VCN to contain the subnet.
     */
    "vcnId": string;
}
export declare namespace CreateSubnetDetails {
    function getJsonObj(obj: CreateSubnetDetails): object;
    function getDeserializedJsonObj(obj: CreateSubnetDetails): object;
}
