/**
 * Core Services API
 * Use the Core Services API to manage resources such as virtual cloud networks (VCNs),
compute instances, and block storage volumes. For more information, see the console
documentation for the [Networking](/iaas/Content/Network/Concepts/overview.htm),
[Compute](/iaas/Content/Compute/Concepts/computeoverview.htm), and
[Block Volume](/iaas/Content/Block/Concepts/overview.htm) services.
The required permissions are documented in the
[Details for the Core Services](/iaas/Content/Identity/Reference/corepolicyreference.htm) article.

 * OpenAPI spec version: 20160918
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * The location for where an instance pool will place instances.
 */
export interface InstancePoolPlacementConfiguration {
    /**
      * The availability domain to place instances.
  * <p>
  Example: {@code Uocm:PHX-AD-1}
  *
      */
    "availabilityDomain": string;
    /**
     * The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the primary subnet in which to place instances. This field is deprecated.
     * Use {@code primaryVnicSubnets} instead to set VNIC data for instances in the pool.
     *
     */
    "primarySubnetId"?: string;
    /**
      * The fault domains to place instances.
  * <p>
  If you don't provide any values, the system makes a best effort to distribute
  * instances across all fault domains based on capacity.
  * <p>
  To distribute the instances evenly across selected fault domains, provide a
  * set of fault domains. For example, you might want instances to be evenly
  * distributed if your applications require high availability.
  * <p>
  To get a list of fault domains, use the
  * {@link #listFaultDomains(ListFaultDomainsRequest) listFaultDomains} operation
  * in the Identity and Access Management Service API.
  * <p>
  Example: {@code [FAULT-DOMAIN-1, FAULT-DOMAIN-2, FAULT-DOMAIN-3]}
  *
      */
    "faultDomains"?: Array<string>;
    "primaryVnicSubnets"?: model.InstancePoolPlacementPrimarySubnet;
    /**
     * The set of secondary VNIC data for instances in the pool.
     */
    "secondaryVnicSubnets"?: Array<model.InstancePoolPlacementSecondaryVnicSubnet>;
}
export declare namespace InstancePoolPlacementConfiguration {
    function getJsonObj(obj: InstancePoolPlacementConfiguration): object;
    function getDeserializedJsonObj(obj: InstancePoolPlacementConfiguration): object;
}
