/**
 * Core Services API
 * Use the Core Services API to manage resources such as virtual cloud networks (VCNs),
compute instances, and block storage volumes. For more information, see the console
documentation for the [Networking](/iaas/Content/Network/Concepts/overview.htm),
[Compute](/iaas/Content/Compute/Concepts/computeoverview.htm), and
[Block Volume](/iaas/Content/Block/Concepts/overview.htm) services.
The required permissions are documented in the
[Details for the Core Services](/iaas/Content/Identity/Reference/corepolicyreference.htm) article.

 * OpenAPI spec version: 20160918
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * A compute instance shape that can be used in {@link #launchInstance(LaunchInstanceRequest) launchInstance}.
 * For more information, see [Overview of the Compute Service](https://docs.cloud.oracle.com/iaas/Content/Compute/Concepts/computeoverview.htm) and
 * [Compute Shapes](https://docs.cloud.oracle.com/iaas/Content/Compute/References/computeshapes.htm).
 *
 */
export interface Shape {
    /**
     * For a subcore burstable VM, the supported baseline OCPU utilization for instances that use this shape.
     *
     */
    "baselineOcpuUtilizations"?: Array<Shape.BaselineOcpuUtilizations>;
    /**
     * For a subcore burstable VM, the minimum total baseline OCPUs required. The total baseline OCPUs is equal to
     * baselineOcpuUtilization chosen multiplied by the number of OCPUs chosen.
     *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "minTotalBaselineOcpusRequired"?: number;
    /**
     * The name of the shape. You can enumerate all available shapes by calling
     * {@link #listShapes(ListShapesRequest) listShapes}.
     *
     */
    "shape": string;
    /**
     * A short description of the shape's processor (CPU).
     *
     */
    "processorDescription"?: string;
    /**
     * The default number of OCPUs available for this shape.
     *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "ocpus"?: number;
    /**
     * The default amount of memory available for this shape, in gigabytes.
     *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "memoryInGBs"?: number;
    /**
     * The number of physical network interface card (NIC) ports available for this shape.
     *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "networkPorts"?: number;
    /**
     * The networking bandwidth available for this shape, in gigabits per second.
     *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "networkingBandwidthInGbps"?: number;
    /**
     * The maximum number of VNIC attachments available for this shape.
     *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "maxVnicAttachments"?: number;
    /**
     * The number of GPUs available for this shape.
     *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "gpus"?: number;
    /**
      * A short description of the graphics processing unit (GPU) available for this shape.
  * <p>
  If the shape does not have any GPUs, this field is {@code null}.
  *
      */
    "gpuDescription"?: string;
    /**
     * The number of local disks available for this shape.
     *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "localDisks"?: number;
    /**
      * The aggregate size of the local disks available for this shape, in gigabytes.
  * <p>
  If the shape does not have any local disks, this field is {@code null}.
  *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
      */
    "localDisksTotalSizeInGBs"?: number;
    /**
      * A short description of the local disks available for this shape.
  * <p>
  If the shape does not have any local disks, this field is {@code null}.
  *
      */
    "localDiskDescription"?: string;
    /**
     * The number of networking ports available for the remote direct memory access (RDMA) network between nodes in
     * a high performance computing (HPC) cluster network. If the shape does not support cluster networks, this
     * value is {@code 0}.
     *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "rdmaPorts"?: number;
    /**
     * The networking bandwidth available for the remote direct memory access (RDMA) network for this shape, in
     * gigabits per second.
     *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "rdmaBandwidthInGbps"?: number;
    /**
     * Whether live migration is supported for this shape.
     *
     */
    "isLiveMigrationSupported"?: boolean;
    "ocpuOptions"?: model.ShapeOcpuOptions;
    "memoryOptions"?: model.ShapeMemoryOptions;
    "networkingBandwidthOptions"?: model.ShapeNetworkingBandwidthOptions;
    "maxVnicAttachmentOptions"?: model.ShapeMaxVnicAttachmentOptions;
    "platformConfigOptions"?: model.ShapePlatformConfigOptions;
    /**
     * Whether billing continues when the instances that use this shape are in the stopped state.
     *
     */
    "isBilledForStoppedInstance"?: boolean;
    /**
     * How instances that use this shape are charged.
     *
     */
    "billingType"?: Shape.BillingType;
    /**
     * The list of of compartment quotas for the shape.
     *
     */
    "quotaNames"?: Array<string>;
    /**
     * Whether the shape supports creating subcore or burstable instances. A [burstable instance](https://docs.cloud.oracle.com/iaas/Content/Compute/References/burstable-instances.htm)
     * is a virtual machine (VM) instance that provides a baseline level of CPU performance with the ability to burst to a higher level to support occasional
     * spikes in usage.
     *
     */
    "isSubcore"?: boolean;
    /**
     * Whether the shape supports creating flexible instances. A [flexible shape](https://docs.cloud.oracle.com/iaas/Content/Compute/References/computeshapes.htm#flexible)
     * is a shape that lets you customize the number of OCPUs and the amount of memory when launching or resizing your instance.
     *
     */
    "isFlexible"?: boolean;
    /**
     * The list of compatible shapes that this shape can be changed to. For more information,
     * see [Changing the Shape of an Instance](https://docs.cloud.oracle.com/iaas/Content/Compute/Tasks/resizinginstances.htm).
     *
     */
    "resizeCompatibleShapes"?: Array<string>;
    /**
     * The list of shapes and shape details (if applicable) that Oracle recommends that you use as an alternative to the current shape.
     *
     */
    "recommendedAlternatives"?: Array<model.ShapeAlternativeObject>;
}
export declare namespace Shape {
    enum BaselineOcpuUtilizations {
        Baseline18 = "BASELINE_1_8",
        Baseline12 = "BASELINE_1_2",
        Baseline11 = "BASELINE_1_1",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    enum BillingType {
        AlwaysFree = "ALWAYS_FREE",
        LimitedFree = "LIMITED_FREE",
        Paid = "PAID",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    function getJsonObj(obj: Shape): object;
    function getDeserializedJsonObj(obj: Shape): object;
}
