/**
 * Core Services API
 * Use the Core Services API to manage resources such as virtual cloud networks (VCNs),
compute instances, and block storage volumes. For more information, see the console
documentation for the [Networking](/iaas/Content/Network/Concepts/overview.htm),
[Compute](/iaas/Content/Compute/Concepts/computeoverview.htm), and
[Block Volume](/iaas/Content/Block/Concepts/overview.htm) services.
The required permissions are documented in the
[Details for the Core Services](/iaas/Content/Identity/Reference/corepolicyreference.htm) article.

 * OpenAPI spec version: 20160918
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
export interface UpdateSubnetDetails {
    /**
      * Defined tags for this resource. Each key is predefined and scoped to a
  * namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
  * <p>
  Example: {@code {\"Operations\": {\"CostCenter\": \"42\"}}}
  *
      */
    "definedTags"?: {
        [key: string]: {
            [key: string]: any;
        };
    };
    /**
     * The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the set of DHCP options the subnet will use.
     *
     */
    "dhcpOptionsId"?: string;
    /**
     * A user-friendly name. Does not have to be unique, and it's changeable.
     * Avoid entering confidential information.
     *
     */
    "displayName"?: string;
    /**
      * Free-form tags for this resource. Each tag is a simple key-value pair with no
  * predefined name, type, or namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
  * <p>
  Example: {@code {\"Department\": \"Finance\"}}
  *
      */
    "freeformTags"?: {
        [key: string]: string;
    };
    /**
     * The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the route table the subnet will use.
     *
     */
    "routeTableId"?: string;
    /**
     * The OCIDs of the security list or lists the subnet will use. This
     * replaces the entire current set of security lists. Remember that
     * security lists are associated *with the subnet*, but the rules are
     * applied to the individual VNICs in the subnet.
     *
     */
    "securityListIds"?: Array<string>;
    /**
      * The CIDR block of the subnet. The new CIDR block must meet the following criteria:
  * <p>
  - Must be valid.
  * - The CIDR block's IP range must be completely within one of the VCN's CIDR block ranges.
  * - The old and new CIDR block ranges must use the same network address. Example: {@code 10.0.0.0/25} and {@code 10.0.0.0/24}.
  * - Must contain all IP addresses in use in the old CIDR range.
  * - The new CIDR range's broadcast address (last IP address of CIDR range) must not be an IP address in use in the old CIDR range.
  * <p>
  **Note:** If you are changing the CIDR block, you cannot create VNICs or private IPs for this resource while the update is in progress.
  * <p>
  Example: {@code 172.16.0.0/16}
  *
      */
    "cidrBlock"?: string;
    /**
      * This is the IPv6 prefix for the subnet's IP address space.
  * The subnet size is always /64.
  * See [IPv6 Addresses](https://docs.cloud.oracle.com/iaas/Content/Network/Concepts/ipv6.htm).
  * The provided prefix must maintain the following rules -
  * <p>
  a. The IPv6 prefix is valid and correctly formatted.
  * b. The IPv6 prefix is within the parent VCN IPv6 range.
  * <p>
  Example: {@code 2001:0db8:0123:1111::/64}
  *
      */
    "ipv6CidrBlock"?: string;
    /**
     * The list of all IPv6 prefixes (Oracle allocated IPv6 GUA, ULA or private IPv6 prefix, BYOIPv6 prefixes) for the subnet that meets the following criteria:
     * - The prefixes must be valid.
     * - Multiple prefixes must not overlap each other or the on-premises network prefix.
     * - The number of prefixes must not exceed the limit of IPv6 prefixes allowed to a subnet.
     *
     */
    "ipv6CidrBlocks"?: Array<string>;
}
export declare namespace UpdateSubnetDetails {
    function getJsonObj(obj: UpdateSubnetDetails): object;
    function getDeserializedJsonObj(obj: UpdateSubnetDetails): object;
}
