/**
 * Dashboards API
 * Use the Oracle Cloud Infrastructure Dashboards service API to manage dashboards in the Console.
Dashboards provide an organized and customizable view of resources and their metrics in the Console.
For more information, see [Dashboards](/Content/Dashboards/home.htm).

**Important:** Resources for the Dashboards service are created in the tenacy's home region.
Although it is possible to create dashboard and dashboard group resources in regions other than the home region,
you won't be able to view those resources in the Console.
Therefore, creating resources outside of the home region is not recommended.

 * OpenAPI spec version: 20210731
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import common = require("oci-common");
import * as requests from "./request";
import * as responses from "./response";
import { DashboardWaiter } from "./dashboard-waiter";
import { DashboardGroupWaiter } from "./dashboardgroup-waiter";
declare const Breaker: any;
export declare enum DashboardApiKeys {
}
/**
 * This service client uses {@link common.CircuitBreaker.DefaultConfiguration} for all the operations by default if no circuit breaker configuration is defined by the user.
 */
export declare class DashboardClient {
    protected static serviceEndpointTemplate: string;
    protected static endpointServiceName: string;
    protected "_realmSpecificEndpointTemplateEnabled": boolean | undefined;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_waiters": DashboardWaiter;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: typeof Breaker | null;
    protected _httpOptions: any;
    protected _bodyDuplexMode: any;
    targetService: string;
    protected _regionId: string;
    protected "_region": common.Region;
    protected _lastSetRegionOrRegionId: string;
    protected _httpClient: common.HttpClient;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    get endpoint(): string;
    /**
     * Sets the endpoint to call (ex, https://www.example.com).
     * @param endpoint The endpoint of the service.
     */
    set endpoint(endpoint: string);
    get logger(): import("oci-common/lib/log").Logger;
    /**
     * Determines whether realm specific endpoint should be used or not.
     * Set realmSpecificEndpointTemplateEnabled to "true" if the user wants to enable use of realm specific endpoint template, otherwise set it to "false"
     * @param realmSpecificEndpointTemplateEnabled flag to enable the use of realm specific endpoint template
     */
    set useRealmSpecificEndpointTemplate(realmSpecificEndpointTemplateEnabled: boolean);
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    set region(region: common.Region);
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    set regionId(regionId: string);
    /**
     * Creates a new DashboardWaiter for resources for this service.
     *
     * @param config The waiter configuration for termination and delay strategy
     * @return The service waiters.
     */
    createWaiters(config?: common.WaiterConfiguration): DashboardWaiter;
    /**
     * Gets the waiters available for resources for this service.
     *
     * @return The service waiters.
     */
    getWaiters(): DashboardWaiter;
    /**
     * Shutdown the circuit breaker used by the client when it is no longer needed
     */
    shutdownCircuitBreaker(): void;
    /**
     * Close the client once it is no longer needed
     */
    close(): void;
    /**
     * Moves a Dashboard resource from one dashboardGroup identifier to another. When provided, If-Match is checked against ETag values of the resource.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangeDashboardGroupRequest
     * @return ChangeDashboardGroupResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dashboardservice/ChangeDashboardGroup.ts.html |here} to see how to use ChangeDashboardGroup API.
     */
    changeDashboardGroup(changeDashboardGroupRequest: requests.ChangeDashboardGroupRequest): Promise<responses.ChangeDashboardGroupResponse>;
    /**
     * Creates a new dashboard in the dashboard group's compartment using the details provided in request body.
     * <p>
     **Caution:** Resources for the Dashboard service are created in the tenacy's home region.
     * Although it is possible to create dashboard resource in regions other than the home region,
     * you won't be able to view those resources in the Console.
     * Therefore, creating resources outside of the home region is not recommended.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateDashboardRequest
     * @return CreateDashboardResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dashboardservice/CreateDashboard.ts.html |here} to see how to use CreateDashboard API.
     */
    createDashboard(createDashboardRequest: requests.CreateDashboardRequest): Promise<responses.CreateDashboardResponse>;
    /**
     * Deletes the specified dashboard. Uses the dashboard's OCID to determine which dashboard to delete.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteDashboardRequest
     * @return DeleteDashboardResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dashboardservice/DeleteDashboard.ts.html |here} to see how to use DeleteDashboard API.
     */
    deleteDashboard(deleteDashboardRequest: requests.DeleteDashboardRequest): Promise<responses.DeleteDashboardResponse>;
    /**
     * Gets the specified dashboard's information. Uses the dashboard's OCID to determine which dashboard to retrieve.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetDashboardRequest
     * @return GetDashboardResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dashboardservice/GetDashboard.ts.html |here} to see how to use GetDashboard API.
     */
    getDashboard(getDashboardRequest: requests.GetDashboardRequest): Promise<responses.GetDashboardResponse>;
    /**
     * Returns a list of dashboards with a specific dashboard group ID.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListDashboardsRequest
     * @return ListDashboardsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dashboardservice/ListDashboards.ts.html |here} to see how to use ListDashboards API.
     */
    listDashboards(listDashboardsRequest: requests.ListDashboardsRequest): Promise<responses.ListDashboardsResponse>;
    /**
     * Updates the specified dashboard. Uses the dashboard's OCID to determine which dashboard to update.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateDashboardRequest
     * @return UpdateDashboardResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dashboardservice/UpdateDashboard.ts.html |here} to see how to use UpdateDashboard API.
     */
    updateDashboard(updateDashboardRequest: requests.UpdateDashboardRequest): Promise<responses.UpdateDashboardResponse>;
}
export declare enum DashboardGroupApiKeys {
}
/**
 * This service client uses {@link common.CircuitBreaker.DefaultConfiguration} for all the operations by default if no circuit breaker configuration is defined by the user.
 */
export declare class DashboardGroupClient {
    protected static serviceEndpointTemplate: string;
    protected static endpointServiceName: string;
    protected "_realmSpecificEndpointTemplateEnabled": boolean | undefined;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_waiters": DashboardGroupWaiter;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: typeof Breaker | null;
    protected _httpOptions: any;
    protected _bodyDuplexMode: any;
    targetService: string;
    protected _regionId: string;
    protected "_region": common.Region;
    protected _lastSetRegionOrRegionId: string;
    protected _httpClient: common.HttpClient;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    get endpoint(): string;
    /**
     * Sets the endpoint to call (ex, https://www.example.com).
     * @param endpoint The endpoint of the service.
     */
    set endpoint(endpoint: string);
    get logger(): import("oci-common/lib/log").Logger;
    /**
     * Determines whether realm specific endpoint should be used or not.
     * Set realmSpecificEndpointTemplateEnabled to "true" if the user wants to enable use of realm specific endpoint template, otherwise set it to "false"
     * @param realmSpecificEndpointTemplateEnabled flag to enable the use of realm specific endpoint template
     */
    set useRealmSpecificEndpointTemplate(realmSpecificEndpointTemplateEnabled: boolean);
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    set region(region: common.Region);
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    set regionId(regionId: string);
    /**
     * Creates a new DashboardGroupWaiter for resources for this service.
     *
     * @param config The waiter configuration for termination and delay strategy
     * @return The service waiters.
     */
    createWaiters(config?: common.WaiterConfiguration): DashboardGroupWaiter;
    /**
     * Gets the waiters available for resources for this service.
     *
     * @return The service waiters.
     */
    getWaiters(): DashboardGroupWaiter;
    /**
     * Shutdown the circuit breaker used by the client when it is no longer needed
     */
    shutdownCircuitBreaker(): void;
    /**
     * Close the client once it is no longer needed
     */
    close(): void;
    /**
     * Moves a DashboardGroup resource from one compartment identifier to another. When provided, If-Match is checked against ETag values of the resource.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangeDashboardGroupCompartmentRequest
     * @return ChangeDashboardGroupCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dashboardservice/ChangeDashboardGroupCompartment.ts.html |here} to see how to use ChangeDashboardGroupCompartment API.
     */
    changeDashboardGroupCompartment(changeDashboardGroupCompartmentRequest: requests.ChangeDashboardGroupCompartmentRequest): Promise<responses.ChangeDashboardGroupCompartmentResponse>;
    /**
     * Creates a new dashboard group using the details provided in request body.
     * <p>
     **Caution:** Resources for the Dashboard service are created in the tenacy's home region.
     * Although it is possible to create dashboard group resource in regions other than the home region,
     * you won't be able to view those resources in the Console.
     * Therefore, creating resources outside of the home region is not recommended.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateDashboardGroupRequest
     * @return CreateDashboardGroupResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dashboardservice/CreateDashboardGroup.ts.html |here} to see how to use CreateDashboardGroup API.
     */
    createDashboardGroup(createDashboardGroupRequest: requests.CreateDashboardGroupRequest): Promise<responses.CreateDashboardGroupResponse>;
    /**
     * Deletes the specified dashboard group. Uses the dashboard group's OCID to determine which dashboard group to delete.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteDashboardGroupRequest
     * @return DeleteDashboardGroupResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dashboardservice/DeleteDashboardGroup.ts.html |here} to see how to use DeleteDashboardGroup API.
     */
    deleteDashboardGroup(deleteDashboardGroupRequest: requests.DeleteDashboardGroupRequest): Promise<responses.DeleteDashboardGroupResponse>;
    /**
     * Gets the specified dashboard group's information. Uses the dashboard group's OCID to determine which dashboard to retrieve.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetDashboardGroupRequest
     * @return GetDashboardGroupResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dashboardservice/GetDashboardGroup.ts.html |here} to see how to use GetDashboardGroup API.
     */
    getDashboardGroup(getDashboardGroupRequest: requests.GetDashboardGroupRequest): Promise<responses.GetDashboardGroupResponse>;
    /**
     * Returns a list of dashboard groups with a specific compartment ID.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListDashboardGroupsRequest
     * @return ListDashboardGroupsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dashboardservice/ListDashboardGroups.ts.html |here} to see how to use ListDashboardGroups API.
     */
    listDashboardGroups(listDashboardGroupsRequest: requests.ListDashboardGroupsRequest): Promise<responses.ListDashboardGroupsResponse>;
    /**
     * Updates the specified dashboard group. Uses the dashboard group's OCID to determine which dashboard group to update.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateDashboardGroupRequest
     * @return UpdateDashboardGroupResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dashboardservice/UpdateDashboardGroup.ts.html |here} to see how to use UpdateDashboardGroup API.
     */
    updateDashboardGroup(updateDashboardGroupRequest: requests.UpdateDashboardGroupRequest): Promise<responses.UpdateDashboardGroupResponse>;
}
export {};
