/**
 * Database Service API
 * The API for the Database Service. Use this API to manage resources such as databases and DB Systems. For more information, see [Overview of the Database Service](/iaas/Content/Database/Concepts/databaseoverview.htm).

 * OpenAPI spec version: 20160918
 * Contact: sic_dbaas_cp_us_grp@oracle.com
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * **Deprecated.** See {@link #autonomousDatabase(AutonomousDatabaseRequest) autonomousDatabase} for reference information about Autonomous Databases with the warehouse workload type.
 * <p>
 **Warning:** Oracle recommends that you avoid using any confidential information when you supply string values using the API.
 *
 */
export interface AutonomousDataWarehouseSummary {
    /**
     * The [OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Autonomous Data Warehouse.
     */
    "id": string;
    /**
     * The [OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment.
     */
    "compartmentId": string;
    /**
     * The current state of the database.
     */
    "lifecycleState": AutonomousDataWarehouseSummary.LifecycleState;
    /**
     * Information about the current lifecycle state.
     */
    "lifecycleDetails"?: string;
    /**
     * The database name.
     */
    "dbName": string;
    /**
     * The number of CPU cores to be made available to the database. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "cpuCoreCount": number;
    /**
     * The quantity of data in the database, in terabytes. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "dataStorageSizeInTBs": number;
    /**
     * The date and time the database was created.
     */
    "timeCreated"?: Date;
    /**
     * The user-friendly name for the Autonomous Data Warehouse. The name does not have to be unique.
     */
    "displayName"?: string;
    /**
     * The URL of the Service Console for the Data Warehouse.
     */
    "serviceConsoleUrl"?: string;
    /**
     * The connection string used to connect to the Data Warehouse. The username for the Service Console is ADMIN. Use the password you entered when creating the Autonomous Data Warehouse for the password value.
     */
    "connectionStrings"?: model.AutonomousDataWarehouseConnectionStrings;
    /**
     * The Oracle license model that applies to the Oracle Autonomous Data Warehouse. The default is BRING_YOUR_OWN_LICENSE.
     *
     */
    "licenseModel"?: AutonomousDataWarehouseSummary.LicenseModel;
    /**
      * Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
  * For more information, see [Resource Tags](https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
  * <p>
  Example: {@code {\"Department\": \"Finance\"}}
  *
      */
    "freeformTags"?: {
        [key: string]: string;
    };
    /**
     * Defined tags for this resource. Each key is predefined and scoped to a namespace.
     * For more information, see [Resource Tags](https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
     *
     */
    "definedTags"?: {
        [key: string]: {
            [key: string]: any;
        };
    };
    /**
     * A valid Oracle Database version for Autonomous Data Warehouse.
     */
    "dbVersion"?: string;
}
export declare namespace AutonomousDataWarehouseSummary {
    enum LifecycleState {
        Provisioning = "PROVISIONING",
        Available = "AVAILABLE",
        Stopping = "STOPPING",
        Stopped = "STOPPED",
        Starting = "STARTING",
        Terminating = "TERMINATING",
        Terminated = "TERMINATED",
        Unavailable = "UNAVAILABLE",
        RestoreInProgress = "RESTORE_IN_PROGRESS",
        BackupInProgress = "BACKUP_IN_PROGRESS",
        ScaleInProgress = "SCALE_IN_PROGRESS",
        AvailableNeedsAttention = "AVAILABLE_NEEDS_ATTENTION",
        Updating = "UPDATING"
    }
    enum LicenseModel {
        LicenseIncluded = "LICENSE_INCLUDED",
        BringYourOwnLicense = "BRING_YOUR_OWN_LICENSE"
    }
    function getJsonObj(obj: AutonomousDataWarehouseSummary): object;
    function getDeserializedJsonObj(obj: AutonomousDataWarehouseSummary): object;
}
