/**
 * Database Service API
 * The API for the Database Service. Use this API to manage resources such as databases and DB Systems. For more information, see [Overview of the Database Service](/iaas/Content/Database/Concepts/databaseoverview.htm).

 * OpenAPI spec version: 20160918
 * Contact: sic_dbaas_cp_us_grp@oracle.com
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
/**
 * Autonomous Virtual Machine details.
 */
export interface AutonomousVirtualMachine {
    /**
     * The [OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Autonomous Virtual Machine.
     */
    "id": string;
    /**
     * The name of the Autonomous Virtual Machine.
     */
    "vmName"?: string;
    /**
     * The [OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Db server associated with the Autonomous Virtual Machine.
     */
    "dbServerId"?: string;
    /**
     * The display name of the dbServer associated with the Autonomous Virtual Machine.
     */
    "dbServerDisplayName"?: string;
    /**
     * The number of CPU cores enabled on the Autonomous Virtual Machine. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "cpuCoreCount"?: number;
    /**
     * The allocated memory in GBs on the Autonomous Virtual Machine. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "memorySizeInGBs"?: number;
    /**
     * The allocated local node storage in GBs on the Autonomous Virtual Machine. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "dbNodeStorageSizeInGBs"?: number;
    /**
     * The current state of the Autonomous Virtual Machine.
     */
    "lifecycleState": AutonomousVirtualMachine.LifecycleState;
    /**
     * Client IP Address.
     */
    "clientIpAddress"?: string;
    /**
     * The [OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment.
     */
    "compartmentId"?: string;
    /**
     * The [OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Autonomous VM Cluster associated with the Autonomous Virtual Machine.
     */
    "autonomousVmClusterId"?: string;
    /**
      * Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
  * For more information, see [Resource Tags](https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
  * <p>
  Example: {@code {\"Department\": \"Finance\"}}
  *
      */
    "freeformTags"?: {
        [key: string]: string;
    };
    /**
     * Defined tags for this resource. Each key is predefined and scoped to a namespace.
     * For more information, see [Resource Tags](https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
     *
     */
    "definedTags"?: {
        [key: string]: {
            [key: string]: any;
        };
    };
    /**
     * The [OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Cloud Autonomous VM Cluster associated with the Autonomous Virtual Machine.
     */
    "cloudAutonomousVmClusterId"?: string;
}
export declare namespace AutonomousVirtualMachine {
    enum LifecycleState {
        Provisioning = "PROVISIONING",
        Available = "AVAILABLE",
        Updating = "UPDATING",
        Terminating = "TERMINATING",
        Terminated = "TERMINATED",
        Failed = "FAILED",
        MaintenanceInProgress = "MAINTENANCE_IN_PROGRESS",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    function getJsonObj(obj: AutonomousVirtualMachine): object;
    function getDeserializedJsonObj(obj: AutonomousVirtualMachine): object;
}
