/**
 * Database Service API
 * The API for the Database Service. Use this API to manage resources such as databases and DB Systems. For more information, see [Overview of the Database Service](/iaas/Content/Database/Concepts/databaseoverview.htm).

 * OpenAPI spec version: 20160918
 * Contact: sic_dbaas_cp_us_grp@oracle.com
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * Details for the create Autonomous VM cluster operation.
 *
 */
export interface CreateAutonomousVmClusterDetails {
    /**
     * The [OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment.
     */
    "compartmentId": string;
    /**
     * The user-friendly name for the Autonomous VM cluster. The name does not need to be unique.
     */
    "displayName": string;
    /**
     * The [OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Exadata infrastructure.
     */
    "exadataInfrastructureId": string;
    /**
     * The [OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the VM cluster network.
     */
    "vmClusterNetworkId": string;
    /**
     * The time zone to use for the Autonomous VM cluster. For details, see [DB System Time Zones](https://docs.cloud.oracle.com/Content/Database/References/timezones.htm).
     */
    "timeZone"?: string;
    /**
     * If true, database backup on local Exadata storage is configured for the Autonomous VM cluster. If false, database backup on local Exadata storage is not available in the Autonomous VM cluster.
     *
     */
    "isLocalBackupEnabled"?: boolean;
    /**
     * The Oracle license model that applies to the Autonomous VM cluster. The default is BRING_YOUR_OWN_LICENSE.
     *
     */
    "licenseModel"?: CreateAutonomousVmClusterDetails.LicenseModel;
    /**
     * The total number of Autonomous Container Databases that can be created. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "totalContainerDatabases"?: number;
    /**
     * The number of CPU cores to enable per VM cluster node. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "cpuCoreCountPerNode"?: number;
    /**
     * The compute model of the Autonomous VM Cluster. ECPU compute model is the recommended model and OCPU compute model is legacy.
     *
     */
    "computeModel"?: CreateAutonomousVmClusterDetails.ComputeModel;
    /**
     * The amount of memory (in GBs) to be enabled per OCPU or ECPU.
     *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "memoryPerOracleComputeUnitInGBs"?: number;
    /**
     * The data disk group size to be allocated for Autonomous Databases, in TBs. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "autonomousDataStorageSizeInTBs"?: number;
    "maintenanceWindowDetails"?: model.MaintenanceWindow;
    /**
     * The list of [OCIDs](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Db servers.
     */
    "dbServers"?: Array<string>;
    /**
      * Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
  * For more information, see [Resource Tags](https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
  * <p>
  Example: {@code {\"Department\": \"Finance\"}}
  *
      */
    "freeformTags"?: {
        [key: string]: string;
    };
    /**
     * Defined tags for this resource. Each key is predefined and scoped to a namespace.
     * For more information, see [Resource Tags](https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
     *
     */
    "definedTags"?: {
        [key: string]: {
            [key: string]: any;
        };
    };
    /**
     * The SCAN Listener TLS port number. Default value is 2484. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "scanListenerPortTls"?: number;
    /**
     * The SCAN Listener Non TLS port number. Default value is 1521. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "scanListenerPortNonTls"?: number;
    /**
     * Enable mutual TLS(mTLS) authentication for database while provisioning a VMCluster. Default is TLS.
     */
    "isMtlsEnabled"?: boolean;
}
export declare namespace CreateAutonomousVmClusterDetails {
    enum LicenseModel {
        LicenseIncluded = "LICENSE_INCLUDED",
        BringYourOwnLicense = "BRING_YOUR_OWN_LICENSE"
    }
    enum ComputeModel {
        Ecpu = "ECPU",
        Ocpu = "OCPU"
    }
    function getJsonObj(obj: CreateAutonomousVmClusterDetails): object;
    function getDeserializedJsonObj(obj: CreateAutonomousVmClusterDetails): object;
}
