/**
 * Database Service API
 * The API for the Database Service. Use this API to manage resources such as databases and DB Systems. For more information, see [Overview of the Database Service](/iaas/Content/Database/Concepts/databaseoverview.htm).

 * OpenAPI spec version: 20160918
 * Contact: sic_dbaas_cp_us_grp@oracle.com
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * Parameters for creating a pluggable database in a specified container database (CDB).
 * Additional option {@code pdbCreationTypeDetails} can be used for creating Pluggable Database using different operations, e.g. LocalClone, Remote Clone, Relocate.
 * **Warning:** Oracle recommends that you avoid using any confidential information when you supply string values using the API.
 *
 */
export interface CreatePluggableDatabaseDetails {
    /**
     * The name for the pluggable database (PDB). The name is unique in the context of a {@link Database}. The name must begin with an alphabetic character and can contain a maximum of thirty alphanumeric characters. Special characters are not permitted. The pluggable database name should not be same as the container database name.
     */
    "pdbName": string;
    /**
     * The [OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the CDB
     */
    "containerDatabaseId": string;
    /**
     * A strong password for PDB Admin. The password must be at least nine characters and contain at least two uppercase, two lowercase, two numbers, and two special characters. The special characters must be _, \\#, or -.
     */
    "pdbAdminPassword"?: string;
    /**
     * The existing TDE wallet password of the CDB.
     */
    "tdeWalletPassword"?: string;
    /**
     * The locked mode of the pluggable database admin account. If false, the user needs to provide the PDB Admin Password to connect to it.
     * If true, the pluggable database will be locked and user cannot login to it.
     *
     */
    "shouldPdbAdminAccountBeLocked"?: boolean;
    /**
     * The DB system administrator password of the Container Database.
     */
    "containerDatabaseAdminPassword"?: string;
    /**
     * Indicates whether to take Pluggable Database Backup after the operation.
     */
    "shouldCreatePdbBackup"?: boolean;
    "pdbCreationTypeDetails"?: model.CreatePluggableDatabaseFromRelocateDetails | model.CreatePluggableDatabaseFromRemoteCloneDetails | model.CreatePluggableDatabaseFromLocalCloneDetails;
    /**
      * Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
  * For more information, see [Resource Tags](https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
  * <p>
  Example: {@code {\"Department\": \"Finance\"}}
  *
      */
    "freeformTags"?: {
        [key: string]: string;
    };
    /**
     * Defined tags for this resource. Each key is predefined and scoped to a namespace.
     * For more information, see [Resource Tags](https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
     *
     */
    "definedTags"?: {
        [key: string]: {
            [key: string]: any;
        };
    };
}
export declare namespace CreatePluggableDatabaseDetails {
    function getJsonObj(obj: CreatePluggableDatabaseDetails): object;
    function getDeserializedJsonObj(obj: CreatePluggableDatabaseDetails): object;
}
