/**
 * Database Service API
 * The API for the Database Service. Use this API to manage resources such as databases and DB Systems. For more information, see [Overview of the Database Service](/iaas/Content/Database/Concepts/databaseoverview.htm).

 * OpenAPI spec version: 20160918
 * Contact: sic_dbaas_cp_us_grp@oracle.com
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
/**
 * The configuration details for updating a Data Guard association for a database.
 * <p>
 **Warning:** Oracle recommends that you avoid using any confidential information when you supply string values using the API.
 *
 */
export interface UpdateDataGuardAssociationDetails {
    /**
      * A strong password for the 'SYS', 'SYSTEM', and 'PDB Admin' users to apply during standby creation.
  * <p>
  The password must contain no fewer than nine characters and include:
  * <p>
  * At least two uppercase characters.
  * <p>
  * At least two lowercase characters.
  * <p>
  * At least two numeric characters.
  * <p>
  * At least two special characters. Valid special characters include \"_\", \"#\", and \"-\" only.
  * <p>
  **The password MUST be the same as the primary admin password.**
  *
      */
    "databaseAdminPassword"?: string;
    /**
     * The protection mode for the Data Guard association's primary and standby database. For more information, see
     * [Oracle Data Guard Protection Modes](http://docs.oracle.com/database/122/SBYDB/oracle-data-guard-protection-modes.htm#SBYDB02000)
     * in the Oracle Data Guard documentation.
     *
     */
    "protectionMode"?: UpdateDataGuardAssociationDetails.ProtectionMode;
    /**
      * The redo transport type to use for this Data Guard association.  Valid values depend on the specified 'protectionMode':
  * * MAXIMUM_AVAILABILITY - Use SYNC or FASTSYNC
  * * MAXIMUM_PERFORMANCE - Use ASYNC
  * * MAXIMUM_PROTECTION - Use SYNC
  * <p>
  For more information, see
  * [Redo Transport Services](http://docs.oracle.com/database/122/SBYDB/oracle-data-guard-redo-transport-services.htm#SBYDB00400)
  * in the Oracle Data Guard documentation.
  *
      */
    "transportType"?: UpdateDataGuardAssociationDetails.TransportType;
    /**
     * True if active Data Guard is enabled. Update this parameter to change the Data Guard setting.
     */
    "isActiveDataGuardEnabled"?: boolean;
}
export declare namespace UpdateDataGuardAssociationDetails {
    enum ProtectionMode {
        MaximumAvailability = "MAXIMUM_AVAILABILITY",
        MaximumPerformance = "MAXIMUM_PERFORMANCE",
        MaximumProtection = "MAXIMUM_PROTECTION"
    }
    enum TransportType {
        Sync = "SYNC",
        Async = "ASYNC",
        Fastsync = "FASTSYNC"
    }
    function getJsonObj(obj: UpdateDataGuardAssociationDetails): object;
    function getDeserializedJsonObj(obj: UpdateDataGuardAssociationDetails): object;
}
