/**
 * Database Management API
 * Use the Database Management API to monitor and manage resources such as
Oracle Databases, MySQL Databases, and External Database Systems.
For more information, see [Database Management](/iaas/database-management/home.htm).

 * OpenAPI spec version: 20201101
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * The list of aggregated metrics for Managed Databases in the fleet.
 */
export interface DatabaseUsageMetrics {
    /**
     * The [OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Managed Database.
     */
    "dbId"?: string;
    /**
     * The [OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment where the Managed Database resides.
     */
    "compartmentId"?: string;
    /**
     * The type of Oracle Database installation.
     */
    "databaseType"?: model.DatabaseType;
    /**
     * The subtype of the Oracle Database. Indicates whether the database is a Container Database,
     * Pluggable Database, Non-container Database, Autonomous Database, or Autonomous Container Database.
     *
     */
    "databaseSubType"?: model.DatabaseSubType;
    /**
     * The infrastructure used to deploy the Oracle Database.
     */
    "deploymentType"?: model.DeploymentType;
    /**
     * The Oracle Database version.
     */
    "databaseVersion"?: string;
    /**
     * The workload type of the Autonomous Database.
     */
    "workloadType"?: model.WorkloadType;
    /**
     * The display name of the Managed Database.
     */
    "databaseName"?: string;
    /**
     * The [OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the parent Container Database, in the case of a Pluggable Database.
     */
    "databaseContainerId"?: string;
    /**
     * The Database id of the Managed Database. Every database had its own id and that value is captured here.
     */
    "databaseId"?: string;
    /**
     * The Primary Database id of the Managed Database.
     */
    "primaryDbId"?: string;
    /**
     * The Primary Database unique name of the Managed Database.
     */
    "primaryDbUniqueName"?: string;
    /**
     * The Database unique name of the Managed Database.
     */
    "dbUniqueName"?: string;
    /**
     * The Database role of the Managed Database.
     */
    "dbRole"?: model.DbRole;
    /**
     * A list of the database health metrics like CPU, Storage, and Memory.
     */
    "metrics"?: Array<model.FleetMetricDefinition>;
}
export declare namespace DatabaseUsageMetrics {
    function getJsonObj(obj: DatabaseUsageMetrics): object;
    function getDeserializedJsonObj(obj: DatabaseUsageMetrics): object;
}
