/**
 * Database Management API
 * Use the Database Management API to monitor and manage resources such as
Oracle Databases, MySQL Databases, and External Database Systems.
For more information, see [Database Management](/iaas/database-management/home.htm).

 * OpenAPI spec version: 20201101
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * The details required to fetch the Sql tuning set details.
 * It takes either credentialDetails or databaseCredential. It's recommended to provide databaseCredential
 *
 */
export interface FetchSqlTuningSetDetails {
    "credentialDetails"?: model.SqlTuningSetAdminPasswordCredentialDetails | model.SqlTuningSetAdminSecretCredentialDetails;
    "databaseCredential"?: model.DatabaseSecretCredentialDetails | model.DatabaseNamedCredentialDetails | model.DatabasePasswordCredentialDetails;
    /**
     * The owner of the Sql tuning set.
     */
    "owner": string;
    /**
     * The name of the Sql tuning set.
     */
    "name": string;
    /**
     * Specifies the Sql predicate to filter the Sql from the Sql tuning set defined on attributes of the SQLSET_ROW.
     * User could use any combination of the following columns with appropriate values as Sql predicate
     * Refer to the documentation https://docs.oracle.com/en/database/oracle/oracle-database/18/arpls/DBMS_SQLTUNE.html#GUID-1F4AFB03-7B29-46FC-B3F2-CB01EC36326C
     *
     */
    "basicFilter"?: string;
    /**
     * Specifies that the filter must include recursive Sql in the Sql tuning set.
     */
    "recursiveSql"?: FetchSqlTuningSetDetails.RecursiveSql;
    /**
     * Specifies a filter that picks the top n% according to the supplied ranking measure.
     * Note that this parameter applies only if one ranking measure is supplied.
     *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "resultPercentage"?: number;
    /**
     * The top limit Sql from the filtered source, ranked by the ranking measure. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "resultLimit"?: number;
    /**
     * Specifies an ORDER BY clause on the selected Sql. User can specify upto three ranking measures.
     *
     */
    "rankingMeasure1"?: model.RankingMeasure;
    /**
     * Specifies an ORDER BY clause on the selected Sql. User can specify upto three ranking measures.
     *
     */
    "rankingMeasure2"?: model.RankingMeasure;
    /**
     * Specifies an ORDER BY clause on the selected Sql. User can specify upto three ranking measures.
     *
     */
    "rankingMeasure3"?: model.RankingMeasure;
}
export declare namespace FetchSqlTuningSetDetails {
    enum RecursiveSql {
        HasRecursiveSql = "HAS_RECURSIVE_SQL",
        NoRecursiveSql = "NO_RECURSIVE_SQL"
    }
    function getJsonObj(obj: FetchSqlTuningSetDetails): object;
    function getDeserializedJsonObj(obj: FetchSqlTuningSetDetails): object;
}
