/**
 * Database Management API
 * Use the Database Management API to monitor and manage resources such as
Oracle Databases, MySQL Databases, and External Database Systems.
For more information, see [Database Management](/iaas/database-management/home.htm).

 * OpenAPI spec version: 20201101
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * A summary of a job execution on a Managed Database.
 */
export interface JobExecutionSummary {
    /**
     * The identifier of the job execution.
     */
    "id": string;
    /**
     * The name of the job execution.
     */
    "name": string;
    /**
     * The [OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment in which the parent job resides.
     */
    "compartmentId": string;
    /**
     * The [OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Managed Database Group where the parent job has to be executed.
     */
    "managedDatabaseGroupId"?: string;
    /**
     * The [OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of Managed Database associated with the job execution.
     */
    "managedDatabaseId": string;
    /**
     * The name of the Managed Database associated with the job execution.
     */
    "managedDatabaseName": string;
    /**
     * The type of Oracle Database installation.
     */
    "databaseType"?: model.DatabaseType;
    /**
     * The subtype of the Oracle Database. Indicates whether the database is a Container Database, Pluggable Database, or a Non-container Database.
     */
    "databaseSubType"?: model.DatabaseSubType;
    /**
     * A list of the supported infrastructure that can be used to deploy the database.
     */
    "deploymentType"?: model.DeploymentType;
    /**
     * Indicates whether the Oracle Database is part of a cluster.
     */
    "isCluster"?: boolean;
    /**
     * The workload type of the Autonomous Database.
     */
    "workloadType"?: model.WorkloadType;
    /**
     * The [OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the parent job.
     */
    "jobId": string;
    /**
     * The name of the parent job.
     */
    "jobName": string;
    /**
     * The status of the job execution.
     */
    "status": string;
    /**
     * The date and time when the job execution was created.
     */
    "timeCreated": Date;
    /**
     * The date and time when the job execution was completed.
     */
    "timeCompleted"?: Date;
}
export declare namespace JobExecutionSummary {
    function getJsonObj(obj: JobExecutionSummary): object;
    function getDeserializedJsonObj(obj: JobExecutionSummary): object;
}
