/**
 * Database Management API
 * Use the Database Management API to monitor and manage resources such as
Oracle Databases, MySQL Databases, and External Database Systems.
For more information, see [Database Management](/iaas/database-management/home.htm).

 * OpenAPI spec version: 20201101
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * The details of a job execution.
 */
export interface JobExecution {
    /**
     * The identifier of the job execution.
     */
    "id": string;
    /**
     * The name of the job execution.
     */
    "name": string;
    /**
     * The [OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment in which the parent job resides.
     */
    "compartmentId": string;
    /**
     * The [OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Managed Database Group where the parent job has to be executed.
     */
    "managedDatabaseGroupId"?: string;
    /**
     * The [OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Managed Database associated with the job execution.
     */
    "managedDatabaseId": string;
    /**
     * The name of the Managed Database associated with the job execution.
     */
    "managedDatabaseName": string;
    /**
     * The type of Oracle Database installation.
     */
    "databaseType"?: model.DatabaseType;
    /**
     * The subtype of the Oracle Database. Indicates whether the database is a Container Database, Pluggable Database, or a Non-container Database.
     */
    "databaseSubType"?: model.DatabaseSubType;
    /**
     * A list of the supported infrastructure that can be used to deploy the database.
     */
    "deploymentType"?: model.DeploymentType;
    /**
     * Indicates whether the Oracle Database is part of a cluster.
     */
    "isCluster"?: boolean;
    /**
     * The workload type of the Autonomous Database.
     */
    "workloadType"?: model.WorkloadType;
    /**
     * The [OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the parent job.
     */
    "jobId": string;
    /**
     * The name of the parent job.
     */
    "jobName": string;
    /**
     * The identifier of the associated job run.
     */
    "jobRunId": string;
    /**
     * The status of the job execution.
     */
    "status": JobExecution.Status;
    /**
     * The error message that is returned if the job execution fails. Null is returned if the job is
     * still running or if the job execution is successful.
     *
     */
    "errorMessage"?: string;
    "resultDetails"?: model.ObjectStorageJobExecutionResultDetails;
    /**
     * The date and time when the job execution was created.
     */
    "timeCreated": Date;
    /**
     * The date and time when the job execution completed.
     */
    "timeCompleted"?: Date;
    /**
     * The database user name used to execute the SQL job.
     */
    "userName"?: string;
    /**
     * The SQL text executed as part of the job.
     */
    "sqlText"?: string;
    "inBinds"?: model.JobInBindsDetails;
    "outBinds"?: model.JobOutBindsDetails;
    "scheduleDetails"?: model.JobScheduleDetails;
}
export declare namespace JobExecution {
    enum Status {
        Succeeded = "SUCCEEDED",
        Failed = "FAILED",
        InProgress = "IN_PROGRESS",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    function getJsonObj(obj: JobExecution): object;
    function getDeserializedJsonObj(obj: JobExecution): object;
}
