/**
 * Database Management API
 * Use the Database Management API to monitor and manage resources such as
Oracle Databases, MySQL Databases, and External Database Systems.
For more information, see [Database Management](/iaas/database-management/home.htm).

 * OpenAPI spec version: 20201101
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
/**
 * The SQL performance data record for a specific SQL query.
 */
export interface MySqlDataSummary {
    /**
     * The name of the default schema when executing the query. If a schema is not set as the default, then the value is NULL.
     */
    "schemaName": string;
    /**
     * The digest information of the normalized query.
     */
    "digest": string;
    /**
     * The normalized query.
     */
    "digestText": string;
    /**
     * The number Of times the query has been executed. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "countStar": number;
    /**
     * The total amount of time that has been spent executing the query. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "sumTimerWait": number;
    /**
     * The fastest the query has been executed. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "minTimerWait": number;
    /**
     * The average execution time. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "avgTimerWait": number;
    /**
     * The slowest the query has been executed. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "maxTimerWait": number;
    /**
     * The total amount of time that has been spent waiting for table locks. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "sumLockTime": number;
    /**
     * The total number of errors that have been encountered executing the query.  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "sumErrors": number;
    /**
     * The total number of warnings that have been encountered executing the query.  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "sumWarnings": number;
    /**
     * The total number of rows that have been modified by the query. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "sumRowsAffected": number;
    /**
     * The total number of rows that have been returned (sent) to the client. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "sumRowsSent": number;
    /**
     * The total number of rows that have been examined by the query. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "sumRowsExamined": number;
    /**
     * The total number of On-Disk internal temporary tables that have been created by the query. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "sumCreatedTempDiskTables": number;
    /**
     * The total number of internal temporary tables (in memory or on disk), which have been created by the query. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "sumCreatedTempTables": number;
    /**
     * The total number of joins that have performed full table scans as there was no join condition or no index for the join condition. This is the same as the select_full_join status variable. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "sumSelectFullJoin": number;
    /**
     * The total number of joins that use a full range search. This is the same as the select_full_range_join status variable. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "sumSelectFullRangeJoin": number;
    /**
     * The total number of times the query has used a range search. This is the same as the select_range status variable. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "sumSelectRange": number;
    /**
     * The total number of joins by the query where the join does not have an index that checks for the index usage after each row. This is the same as the select_range_check status variable. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "sumSelectRangeCheck": number;
    /**
     * The total number of times the query has performed a full table scan on the first table in the join. This is the same as the select_scan status variable. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "sumSelectScan": number;
    /**
     * The total number of sort merge passes that have been done to sort the result of the query. This is the same as the sort_merge_passes status variable. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "sumSortMergePasses": number;
    /**
     * The total number of times a sort was done using ranges. This is the same as the sort_range status variable. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "sumSortRange": number;
    /**
     * The total number of rows sorted. This is the same as the sort_rowsStatus variable. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "sumSortRows": number;
    /**
     * The total number of times a sort was done by scanning the table. This is the same as the sort_scan status variable. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "sumSortScan": number;
    /**
     * The total number of times no index was used to execute the query. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "sumNoIndexUsed": number;
    /**
     * The total number of times no good index was used. This means that the extra column in The EXPLAIN output includes \u201CRange Checked For Each Record.\u201D Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "sumNoGoodIndexUsed": number;
    /**
     * The date and time the query was first seen. If the table is truncated, the first seen value is reset.
     */
    "firstSeen": Date;
    /**
     * The date and time the query was last seen.
     */
    "lastSeen": Date;
    /**
     * The 95th percentile of the query latency. That is, 95% of the queries complete in the time given or in less time. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "quantile95": number;
    /**
     * The 99th percentile of the query latency. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "quantile99": number;
    /**
     * The 99.9th percentile of the query latency. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "quantile999": number;
    /**
     * The number of query executions offloaded to HeatWave. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "heatWaveOffloaded"?: number;
    /**
     * The number of query executions with HeatWave out-of-memory errors. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "heatWaveOutOfMemory"?: number;
}
export declare namespace MySqlDataSummary {
    function getJsonObj(obj: MySqlDataSummary): object;
    function getDeserializedJsonObj(obj: MySqlDataSummary): object;
}
