/**
 * Database Management API
 * Use the Database Management API to monitor and manage resources such as
Oracle Databases, MySQL Databases, and External Database Systems.
For more information, see [Database Management](/iaas/database-management/home.htm).

 * OpenAPI spec version: 20201101
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
* The configuration details of SQL plan baselines. The details include:
* <p>
- whether automatic initial plan capture is enabled or disabled
* - whether use of SQL plan baselines is enabled or disabled
* - whether Automatic SPM Evolve Advisor task is enabled or disabled
* - whether high-frequency Automatic SPM Evolve Advisor task is enabled or disabled
* - filters for the automatic initial plan capture
* - parameters for the Automatic SPM Evolve Advisor task
* - plan retention and allocated space for the plan baselines
*
*/
export interface SqlPlanBaselineConfiguration {
    /**
     * Indicates whether the automatic capture of SQL plan baselines is enabled ({@code true}) or not ({@code false}).
     */
    "isAutomaticInitialPlanCaptureEnabled": boolean;
    /**
     * Indicates whether the database uses SQL plan baselines ({@code true}) or not ({@code false}).
     */
    "isSqlPlanBaselinesUsageEnabled": boolean;
    /**
     * Indicates whether the Automatic SPM Evolve Advisor task is enabled ({@code true}) or not ({@code false}).
     */
    "isAutoSpmEvolveTaskEnabled": boolean;
    /**
     * Indicates whether the high frequency Automatic SPM Evolve Advisor task is enabled ({@code true}) or not ({@code false}).
     */
    "isHighFrequencyAutoSpmEvolveTaskEnabled": boolean;
    /**
     * The number of weeks to retain unused plans before they are purged. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "planRetentionWeeks": number;
    /**
     * The maximum percent of {@code SYSAUX} space that can be used for SQL Management Base. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "spaceBudgetPercent": number;
    /**
     * The maximum {@code SYSAUX} space that can be used for SQL Management Base in MB. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "spaceBudgetMB"?: number;
    /**
     * The space used by SQL Management Base in MB. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "spaceUsedMB"?: number;
    /**
     * The capture filters used in automatic initial plan capture.
     */
    "autoCaptureFilters"?: Array<model.AutomaticCaptureFilter>;
    "autoSpmEvolveTaskParameters"?: model.SpmEvolveTaskParameters;
}
export declare namespace SqlPlanBaselineConfiguration {
    function getJsonObj(obj: SqlPlanBaselineConfiguration): object;
    function getDeserializedJsonObj(obj: SqlPlanBaselineConfiguration): object;
}
