/**
 * Database Migration API
 * Use the Oracle Cloud Infrastructure Database Migration APIs to perform database migration operations.
 * OpenAPI spec version: 20230518
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * Represents the common details required for creating a new connection.
 */
export interface Connection {
    /**
     * The OCID of the connection being referenced.
     */
    "id": string;
    /**
     * A user-friendly name. Does not have to be unique, and it's changeable.
     * Avoid entering confidential information.
     *
     */
    "displayName": string;
    /**
     * A user-friendly description. Does not have to be unique, and it's changeable.
     * Avoid entering confidential information.
     *
     */
    "description"?: string;
    /**
     * The OCID of the compartment.
     */
    "compartmentId": string;
    /**
     * Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
     * For more information, see Resource Tags. Example: {\"Department\": \"Finance\"}
     *
     */
    "freeformTags"?: {
        [key: string]: string;
    };
    /**
     * Defined tags for this resource. Each key is predefined and scoped to a namespace.
     * Example: {@code {\"foo-namespace\": {\"bar-key\": \"value\"}}}
     *
     */
    "definedTags"?: {
        [key: string]: {
            [key: string]: any;
        };
    };
    /**
     * Usage of system tag keys. These predefined keys are scoped to namespaces.
     * Example: {@code {\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}}
     *
     */
    "systemTags"?: {
        [key: string]: {
            [key: string]: any;
        };
    };
    /**
     * The Connection's current lifecycle state.
     */
    "lifecycleState": Connection.LifecycleState;
    /**
     * The message describing the current state of the connection's lifecycle in detail.
     * For example, can be used to provide actionable information for a connection in a Failed state.
     *
     */
    "lifecycleDetails"?: string;
    /**
     * The time when this resource was created.
     * An RFC3339 formatted datetime string such as {@code 2016-08-25T21:10:29.600Z}.
     *
     */
    "timeCreated": Date;
    /**
     * The time when this resource was updated.
     * An RFC3339 formatted datetime string such as {@code 2016-08-25T21:10:29.600Z}.
     *
     */
    "timeUpdated": Date;
    /**
     * OCI resource ID.
     */
    "vaultId"?: string;
    /**
     * The OCID of the key used in cryptographic operations.
     */
    "keyId"?: string;
    /**
     * OCI resource ID.
     */
    "subnetId"?: string;
    /**
     * List of ingress IP addresses from where to connect to this connection's privateIp.
     */
    "ingressIps"?: Array<model.IngressIpDetails>;
    /**
     * An array of Network Security Group OCIDs used to define network access for Connections.
     *
     */
    "nsgIds"?: Array<string>;
    /**
     * The username (credential) used when creating or updating this resource.
     *
     */
    "username": string;
    /**
     * The password (credential) used when creating or updating this resource.
     *
     */
    "password"?: string;
    /**
     * The username (credential) used when creating or updating this resource.
     *
     */
    "replicationUsername"?: string;
    /**
     * The password (credential) used when creating or updating this resource.
     *
     */
    "replicationPassword"?: string;
    /**
     * The OCID of the resource being referenced.
     */
    "secretId"?: string;
    /**
     * The OCID of the resource being referenced.
     */
    "privateEndpointId"?: string;
    "connectionType": string;
}
export declare namespace Connection {
    enum LifecycleState {
        Creating = "CREATING",
        Updating = "UPDATING",
        Active = "ACTIVE",
        Inactive = "INACTIVE",
        Deleting = "DELETING",
        Deleted = "DELETED",
        Failed = "FAILED",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    function getJsonObj(obj: Connection): object;
    function getDeserializedJsonObj(obj: Connection): object;
}
