/**
 * Data Catalog API
 * Use the Data Catalog APIs to collect, organize, find, access, understand, enrich, and activate technical, business, and operational metadata.
For more information, see [Data Catalog](https://docs.oracle.com/iaas/data-catalog/home.htm).

 * OpenAPI spec version: 20190325
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * Properties for creating a new job execution.
 */
export interface CreateJobExecutionDetails {
    /**
     * Sub-type of this job execution.
     */
    "subType"?: string;
    /**
     * Type of the job execution.
     */
    "jobType"?: model.JobType;
    /**
     * The unique key of the parent execution or null if this job execution has no parent.
     */
    "parentKey"?: string;
    /**
     * Time that job execution started. An [RFC3339](https://tools.ietf.org/html/rfc3339) formatted datetime string.
     */
    "timeStarted"?: Date;
    /**
     * Time that the job execution ended or null if it hasn't yet completed.
     * An [RFC3339](https://tools.ietf.org/html/rfc3339) formatted datetime string.
     *
     */
    "timeEnded"?: Date;
    /**
     * Status of the job execution, such as running, paused, or completed.
     */
    "lifecycleState"?: model.JobExecutionState;
    /**
     * Error code returned from the job execution or null if job is still running or didn't return an error.
     *
     */
    "errorCode"?: string;
    /**
     * Error message returned from the job execution or null if job is still running or didn't return an error.
     *
     */
    "errorMessage"?: string;
    /**
     * The unique key of the triggering external scheduler resource or null if this job execution is not externally triggered.
     */
    "scheduleInstanceKey"?: string;
    /**
     * Process identifier related to the job execution if the job is an external job.
     */
    "processKey"?: string;
    /**
     * If the job is an external process, then a URL of the job for accessing this resource and its status.
     *
     */
    "externalUrl"?: string;
    /**
     * An identifier used for log message correlation.
     *
     */
    "eventKey"?: string;
    /**
     * The key of the associated data entity resource.
     */
    "dataEntityKey"?: string;
    /**
     * A map of maps that contains the execution context properties which are specific to a job execution. Each job
     * execution may define it's set of required and optional properties. The map keys are category names and the
     * values are maps of property name to property value. Every property is contained inside of a category. Most
     * job executions have required properties within the \"default\" category.
     * Example: {@code {\"properties\": { \"default\": { \"host\": \"host1\", \"port\": \"1521\", \"database\": \"orcl\"}}}}
     *
     */
    "properties"?: {
        [key: string]: {
            [key: string]: string;
        };
    };
}
export declare namespace CreateJobExecutionDetails {
    function getJsonObj(obj: CreateJobExecutionDetails): object;
    function getDeserializedJsonObj(obj: CreateJobExecutionDetails): object;
}
