/**
 * Data Catalog API
 * Use the Data Catalog APIs to collect, organize, find, access, understand, enrich, and activate technical, business, and operational metadata.
For more information, see [Data Catalog](https://docs.oracle.com/iaas/data-catalog/home.htm).

 * OpenAPI spec version: 20190325
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * A generic term used in the data catalog for an external organization concept used for a collection of data entities
 * or processes within a data asset. This term is an internal term which models multiple external types of folder,
 * such as file directories, database schemas, and so on. Some data assets, such as Object Store containers, may contain
 * many levels of folders.
 *
 */
export interface Folder {
    /**
     * Unique folder key that is immutable.
     */
    "key": string;
    /**
     * A user-friendly display name. Does not have to be unique, and it's changeable.
     * Avoid entering confidential information.
     *
     */
    "displayName"?: string;
    /**
     * Optional user friendly business name of the folder. If set, this supplements the harvested display name of the object.
     */
    "businessName"?: string;
    /**
     * Detailed description of a folder.
     */
    "description"?: string;
    /**
     * The unique key of the containing folder or null if there is no parent folder.
     */
    "parentFolderKey"?: string;
    /**
     * The type of folder object. Type keys can be found via the '/types' endpoint.
     */
    "typeKey"?: string;
    /**
     * The date and time the folder was harvested, in the format defined by [RFC3339](https://tools.ietf.org/html/rfc3339).
     *
     */
    "timeHarvested"?: Date;
    /**
     * List of objects and their relationships to this folder.
     */
    "objectRelationships"?: Array<model.ObjectRelationship>;
    /**
     * Full path of the folder.
     */
    "path"?: string;
    /**
     * The key of the associated data asset.
     */
    "dataAssetKey"?: string;
    /**
     * The list of customized properties along with the values for this object
     */
    "customPropertyMembers"?: Array<model.CustomPropertyGetUsage>;
    /**
     * A map of maps that contains the properties which are specific to the folder type. Each folder type
     * definition defines it's set of required and optional properties. The map keys are category names and the
     * values are maps of property name to property value. Every property is contained inside of a category. Most
     * folders have required properties within the \"default\" category.
     * Example: {@code {\"properties\": { \"default\": { \"key1\": \"value1\"}}}}
     *
     */
    "properties"?: {
        [key: string]: {
            [key: string]: string;
        };
    };
    /**
     * Unique external key of this object in the source system.
     */
    "externalKey"?: string;
    /**
     * The date and time the folder was created, in the format defined by [RFC3339](https://tools.ietf.org/html/rfc3339).
     * Example: {@code 2019-03-25T21:10:29.600Z}
     *
     */
    "timeCreated"?: Date;
    /**
     * The last time that any change was made to the folder. An [RFC3339](https://tools.ietf.org/html/rfc3339) formatted datetime string.
     *
     */
    "timeUpdated"?: Date;
    /**
     * OCID of the user who created the folder.
     */
    "createdById"?: string;
    /**
     * OCID of the user who modified the folder.
     */
    "updatedById"?: string;
    /**
     * Last modified timestamp of this object in the external system.
     */
    "timeExternal"?: Date;
    /**
     * The current state of the folder.
     */
    "lifecycleState"?: model.LifecycleState;
    /**
     * A message describing the current state in more detail. An object not in ACTIVE state may have functional limitations,
     * see service documentation for details.
     *
     */
    "lifecycleDetails"?: string;
    /**
     * Status of the object as updated by the harvest process.
     */
    "harvestStatus"?: model.HarvestStatus;
    /**
     * The key of the last harvest process to update the metadata of this object.
     */
    "lastJobKey"?: string;
    /**
     * URI to the folder instance in the API.
     */
    "uri"?: string;
    /**
     * URL of the folder in the object store.
     */
    "objectStorageUrl"?: string;
}
export declare namespace Folder {
    function getJsonObj(obj: Folder): object;
    function getDeserializedJsonObj(obj: Folder): object;
}
