/**
 * Data Integration API
 * Use the Data Integration API to organize your data integration projects, create data flows, pipelines and tasks, and then publish, schedule, and run tasks that extract, transform, and load data. For more information, see [Data Integration](https://docs.oracle.com/iaas/data-integration/home.htm).
 * OpenAPI spec version: 20200430
 * Contact: di_dis_ww_grp@oracle.com
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import common = require("oci-common");
import * as requests from "./request";
import * as model from "./model";
import * as responses from "./response";
import { DataIntegrationWaiter } from "./dataintegration-waiter";
declare const Breaker: any;
export declare enum DataIntegrationApiKeys {
}
/**
 * This service client uses {@link common.CircuitBreaker.DefaultConfiguration} for all the operations by default if no circuit breaker configuration is defined by the user.
 */
export declare class DataIntegrationClient {
    protected static serviceEndpointTemplate: string;
    protected static endpointServiceName: string;
    protected "_realmSpecificEndpointTemplateEnabled": boolean | undefined;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_waiters": DataIntegrationWaiter;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: typeof Breaker | null;
    protected _httpOptions: any;
    protected _bodyDuplexMode: any;
    targetService: string;
    protected _regionId: string;
    protected "_region": common.Region;
    protected _lastSetRegionOrRegionId: string;
    protected _httpClient: common.HttpClient;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    get endpoint(): string;
    /**
     * Sets the endpoint to call (ex, https://www.example.com).
     * @param endpoint The endpoint of the service.
     */
    set endpoint(endpoint: string);
    get logger(): import("oci-common/lib/log").Logger;
    /**
     * Determines whether realm specific endpoint should be used or not.
     * Set realmSpecificEndpointTemplateEnabled to "true" if the user wants to enable use of realm specific endpoint template, otherwise set it to "false"
     * @param realmSpecificEndpointTemplateEnabled flag to enable the use of realm specific endpoint template
     */
    set useRealmSpecificEndpointTemplate(realmSpecificEndpointTemplateEnabled: boolean);
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    set region(region: common.Region);
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    set regionId(regionId: string);
    /**
     * Creates a new DataIntegrationWaiter for resources for this service.
     *
     * @param config The waiter configuration for termination and delay strategy
     * @return The service waiters.
     */
    createWaiters(config?: common.WaiterConfiguration): DataIntegrationWaiter;
    /**
     * Gets the waiters available for resources for this service.
     *
     * @return The service waiters.
     */
    getWaiters(): DataIntegrationWaiter;
    /**
     * Shutdown the circuit breaker used by the client when it is no longer needed
     */
    shutdownCircuitBreaker(): void;
    /**
     * Close the client once it is no longer needed
     */
    close(): void;
    /**
     * Moves a workspace to a specified compartment.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangeCompartmentRequest
     * @return ChangeCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/ChangeCompartment.ts.html |here} to see how to use ChangeCompartment API.
     */
    changeCompartment(changeCompartmentRequest: requests.ChangeCompartmentRequest): Promise<responses.ChangeCompartmentResponse>;
    /**
     * Moves a DIS Application to a specified compartment.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangeDisApplicationCompartmentRequest
     * @return ChangeDisApplicationCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/ChangeDisApplicationCompartment.ts.html |here} to see how to use ChangeDisApplicationCompartment API.
     */
    changeDisApplicationCompartment(changeDisApplicationCompartmentRequest: requests.ChangeDisApplicationCompartmentRequest): Promise<responses.ChangeDisApplicationCompartmentResponse>;
    /**
     * Creates an application.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateApplicationRequest
     * @return CreateApplicationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/CreateApplication.ts.html |here} to see how to use CreateApplication API.
     */
    createApplication(createApplicationRequest: requests.CreateApplicationRequest): Promise<responses.CreateApplicationResponse>;
    /**
     * Creates detailed description for an application.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateApplicationDetailedDescriptionRequest
     * @return CreateApplicationDetailedDescriptionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/CreateApplicationDetailedDescription.ts.html |here} to see how to use CreateApplicationDetailedDescription API.
     */
    createApplicationDetailedDescription(createApplicationDetailedDescriptionRequest: requests.CreateApplicationDetailedDescriptionRequest): Promise<responses.CreateApplicationDetailedDescriptionResponse>;
    /**
     * Creates a connection under an existing data asset.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateConnectionRequest
     * @return CreateConnectionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/CreateConnection.ts.html |here} to see how to use CreateConnection API.
     */
    createConnection(createConnectionRequest: requests.CreateConnectionRequest): Promise<responses.CreateConnectionResponse>;
    /**
     * Creates a connection validation.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateConnectionValidationRequest
     * @return CreateConnectionValidationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/CreateConnectionValidation.ts.html |here} to see how to use CreateConnectionValidation API.
     */
    createConnectionValidation(createConnectionValidationRequest: requests.CreateConnectionValidationRequest): Promise<responses.CreateConnectionValidationResponse>;
    /**
     * Copy Metadata Object.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateCopyObjectRequestRequest
     * @return CreateCopyObjectRequestResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/CreateCopyObjectRequest.ts.html |here} to see how to use CreateCopyObjectRequest API.
     */
    createCopyObjectRequest(createCopyObjectRequestRequest: requests.CreateCopyObjectRequestRequest): Promise<responses.CreateCopyObjectRequestResponse>;
    /**
     * Creates a data asset with default connection.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateDataAssetRequest
     * @return CreateDataAssetResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/CreateDataAsset.ts.html |here} to see how to use CreateDataAsset API.
     */
    createDataAsset(createDataAssetRequest: requests.CreateDataAssetRequest): Promise<responses.CreateDataAssetResponse>;
    /**
     * Creates a new data flow in a project or folder ready for performing data integrations.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateDataFlowRequest
     * @return CreateDataFlowResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/CreateDataFlow.ts.html |here} to see how to use CreateDataFlow API.
     */
    createDataFlow(createDataFlowRequest: requests.CreateDataFlowRequest): Promise<responses.CreateDataFlowResponse>;
    /**
     * Accepts the data flow definition in the request payload and creates a data flow validation.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateDataFlowValidationRequest
     * @return CreateDataFlowValidationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/CreateDataFlowValidation.ts.html |here} to see how to use CreateDataFlowValidation API.
     */
    createDataFlowValidation(createDataFlowValidationRequest: requests.CreateDataFlowValidationRequest): Promise<responses.CreateDataFlowValidationResponse>;
    /**
     * Creates a DIS Application.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateDisApplicationRequest
     * @return CreateDisApplicationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/CreateDisApplication.ts.html |here} to see how to use CreateDisApplication API.
     */
    createDisApplication(createDisApplicationRequest: requests.CreateDisApplicationRequest): Promise<responses.CreateDisApplicationResponse>;
    /**
     * Creates detailed description for an application.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateDisApplicationDetailedDescriptionRequest
     * @return CreateDisApplicationDetailedDescriptionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/CreateDisApplicationDetailedDescription.ts.html |here} to see how to use CreateDisApplicationDetailedDescription API.
     */
    createDisApplicationDetailedDescription(createDisApplicationDetailedDescriptionRequest: requests.CreateDisApplicationDetailedDescriptionRequest): Promise<responses.CreateDisApplicationDetailedDescriptionResponse>;
    /**
     * Creates the data entity shape using the shape from the data asset.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateEntityShapeRequest
     * @return CreateEntityShapeResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/CreateEntityShape.ts.html |here} to see how to use CreateEntityShape API.
     */
    createEntityShape(createEntityShapeRequest: requests.CreateEntityShapeRequest): Promise<responses.CreateEntityShapeResponse>;
    /**
     * Export Metadata Object
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateExportRequestRequest
     * @return CreateExportRequestResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/CreateExportRequest.ts.html |here} to see how to use CreateExportRequest API.
     */
    createExportRequest(createExportRequestRequest: requests.CreateExportRequestRequest): Promise<responses.CreateExportRequestResponse>;
    /**
     * Publish a DataFlow in a OCI DataFlow application.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateExternalPublicationRequest
     * @return CreateExternalPublicationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/CreateExternalPublication.ts.html |here} to see how to use CreateExternalPublication API.
     */
    createExternalPublication(createExternalPublicationRequest: requests.CreateExternalPublicationRequest): Promise<responses.CreateExternalPublicationResponse>;
    /**
     * Validates a specific task.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateExternalPublicationValidationRequest
     * @return CreateExternalPublicationValidationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/CreateExternalPublicationValidation.ts.html |here} to see how to use CreateExternalPublicationValidation API.
     */
    createExternalPublicationValidation(createExternalPublicationValidationRequest: requests.CreateExternalPublicationValidationRequest): Promise<responses.CreateExternalPublicationValidationResponse>;
    /**
     * Creates a folder in a project or in another folder, limited to two levels of folders. |
     * Folders are used to organize your design-time resources, such as tasks or data flows.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateFolderRequest
     * @return CreateFolderResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/CreateFolder.ts.html |here} to see how to use CreateFolder API.
     */
    createFolder(createFolderRequest: requests.CreateFolderRequest): Promise<responses.CreateFolderResponse>;
    /**
     * Creates a function library in a project or in another function library, limited to two levels of function libraries. |
     * FunctionLibraries are used to organize your design-time resources, such as tasks or data flows.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateFunctionLibraryRequest
     * @return CreateFunctionLibraryResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/CreateFunctionLibrary.ts.html |here} to see how to use CreateFunctionLibrary API.
     */
    createFunctionLibrary(createFunctionLibraryRequest: requests.CreateFunctionLibraryRequest): Promise<responses.CreateFunctionLibraryResponse>;
    /**
     * Import Metadata Object
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateImportRequestRequest
     * @return CreateImportRequestResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/CreateImportRequest.ts.html |here} to see how to use CreateImportRequest API.
     */
    createImportRequest(createImportRequestRequest: requests.CreateImportRequestRequest): Promise<responses.CreateImportRequestResponse>;
    /**
     * Creates a patch in an application.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreatePatchRequest
     * @return CreatePatchResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/CreatePatch.ts.html |here} to see how to use CreatePatch API.
     */
    createPatch(createPatchRequest: requests.CreatePatchRequest): Promise<responses.CreatePatchResponse>;
    /**
     * Creates a new pipeline in a project or folder ready for performing task orchestration.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreatePipelineRequest
     * @return CreatePipelineResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/CreatePipeline.ts.html |here} to see how to use CreatePipeline API.
     */
    createPipeline(createPipelineRequest: requests.CreatePipelineRequest): Promise<responses.CreatePipelineResponse>;
    /**
     * Accepts the data flow definition in the request payload and creates a pipeline validation.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreatePipelineValidationRequest
     * @return CreatePipelineValidationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/CreatePipelineValidation.ts.html |here} to see how to use CreatePipelineValidation API.
     */
    createPipelineValidation(createPipelineValidationRequest: requests.CreatePipelineValidationRequest): Promise<responses.CreatePipelineValidationResponse>;
    /**
     * Creates a project. Projects are organizational constructs within a workspace that you use to organize your design-time resources, such as tasks or data flows. Projects can be organized into folders.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateProjectRequest
     * @return CreateProjectResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/CreateProject.ts.html |here} to see how to use CreateProject API.
     */
    createProject(createProjectRequest: requests.CreateProjectRequest): Promise<responses.CreateProjectResponse>;
    /**
     * Endpoint to create a new schedule
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateScheduleRequest
     * @return CreateScheduleResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/CreateSchedule.ts.html |here} to see how to use CreateSchedule API.
     */
    createSchedule(createScheduleRequest: requests.CreateScheduleRequest): Promise<responses.CreateScheduleResponse>;
    /**
     * Creates a new task ready for performing data integrations. There are specialized types of tasks that include data loader and integration tasks.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateTaskRequest
     * @return CreateTaskResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/CreateTask.ts.html |here} to see how to use CreateTask API.
     */
    createTask(createTaskRequest: requests.CreateTaskRequest): Promise<responses.CreateTaskResponse>;
    /**
     * Creates a data integration task run for the specified task.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateTaskRunRequest
     * @return CreateTaskRunResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/CreateTaskRun.ts.html |here} to see how to use CreateTaskRun API.
     */
    createTaskRun(createTaskRunRequest: requests.CreateTaskRunRequest): Promise<responses.CreateTaskRunResponse>;
    /**
     * Endpoint to be used create TaskSchedule.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateTaskScheduleRequest
     * @return CreateTaskScheduleResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/CreateTaskSchedule.ts.html |here} to see how to use CreateTaskSchedule API.
     */
    createTaskSchedule(createTaskScheduleRequest: requests.CreateTaskScheduleRequest): Promise<responses.CreateTaskScheduleResponse>;
    /**
     * Validates a specific task.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateTaskValidationRequest
     * @return CreateTaskValidationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/CreateTaskValidation.ts.html |here} to see how to use CreateTaskValidation API.
     */
    createTaskValidation(createTaskValidationRequest: requests.CreateTaskValidationRequest): Promise<responses.CreateTaskValidationResponse>;
    /**
     * Creates a new UserDefinedFunction in a function library ready for performing data integrations.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateUserDefinedFunctionRequest
     * @return CreateUserDefinedFunctionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/CreateUserDefinedFunction.ts.html |here} to see how to use CreateUserDefinedFunction API.
     */
    createUserDefinedFunction(createUserDefinedFunctionRequest: requests.CreateUserDefinedFunctionRequest): Promise<responses.CreateUserDefinedFunctionResponse>;
    /**
     * Accepts the UserDefinedFunction definition in the request payload and creates a UserDefinedFunction validation.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateUserDefinedFunctionValidationRequest
     * @return CreateUserDefinedFunctionValidationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/CreateUserDefinedFunctionValidation.ts.html |here} to see how to use CreateUserDefinedFunctionValidation API.
     */
    createUserDefinedFunctionValidation(createUserDefinedFunctionValidationRequest: requests.CreateUserDefinedFunctionValidationRequest): Promise<responses.CreateUserDefinedFunctionValidationResponse>;
    /**
     * Creates a new Data Integration workspace ready for performing data integration tasks. To retrieve the OCID for the new workspace, use the opc-work-request-id returned by this API and call the {@link #getWorkRequest(GetWorkRequestRequest) getWorkRequest} API.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateWorkspaceRequest
     * @return CreateWorkspaceResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/CreateWorkspace.ts.html |here} to see how to use CreateWorkspace API.
     */
    createWorkspace(createWorkspaceRequest: requests.CreateWorkspaceRequest): Promise<responses.CreateWorkspaceResponse>;
    /**
     * Removes an application using the specified identifier.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteApplicationRequest
     * @return DeleteApplicationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/DeleteApplication.ts.html |here} to see how to use DeleteApplication API.
     */
    deleteApplication(deleteApplicationRequest: requests.DeleteApplicationRequest): Promise<responses.DeleteApplicationResponse>;
    /**
     * Deletes detailed description of an Application.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteApplicationDetailedDescriptionRequest
     * @return DeleteApplicationDetailedDescriptionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/DeleteApplicationDetailedDescription.ts.html |here} to see how to use DeleteApplicationDetailedDescription API.
     */
    deleteApplicationDetailedDescription(deleteApplicationDetailedDescriptionRequest: requests.DeleteApplicationDetailedDescriptionRequest): Promise<responses.DeleteApplicationDetailedDescriptionResponse>;
    /**
     * Removes a connection using the specified identifier.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteConnectionRequest
     * @return DeleteConnectionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/DeleteConnection.ts.html |here} to see how to use DeleteConnection API.
     */
    deleteConnection(deleteConnectionRequest: requests.DeleteConnectionRequest): Promise<responses.DeleteConnectionResponse>;
    /**
     * Deletes a connection validation.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteConnectionValidationRequest
     * @return DeleteConnectionValidationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/DeleteConnectionValidation.ts.html |here} to see how to use DeleteConnectionValidation API.
     */
    deleteConnectionValidation(deleteConnectionValidationRequest: requests.DeleteConnectionValidationRequest): Promise<responses.DeleteConnectionValidationResponse>;
    /**
     * Delete copy object request using the specified identifier.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteCopyObjectRequestRequest
     * @return DeleteCopyObjectRequestResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/DeleteCopyObjectRequest.ts.html |here} to see how to use DeleteCopyObjectRequest API.
     */
    deleteCopyObjectRequest(deleteCopyObjectRequestRequest: requests.DeleteCopyObjectRequestRequest): Promise<responses.DeleteCopyObjectRequestResponse>;
    /**
     * Removes a data asset using the specified identifier.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteDataAssetRequest
     * @return DeleteDataAssetResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/DeleteDataAsset.ts.html |here} to see how to use DeleteDataAsset API.
     */
    deleteDataAsset(deleteDataAssetRequest: requests.DeleteDataAssetRequest): Promise<responses.DeleteDataAssetResponse>;
    /**
     * Removes a data flow from a project or folder using the specified identifier.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteDataFlowRequest
     * @return DeleteDataFlowResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/DeleteDataFlow.ts.html |here} to see how to use DeleteDataFlow API.
     */
    deleteDataFlow(deleteDataFlowRequest: requests.DeleteDataFlowRequest): Promise<responses.DeleteDataFlowResponse>;
    /**
     * Removes a data flow validation using the specified identifier.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteDataFlowValidationRequest
     * @return DeleteDataFlowValidationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/DeleteDataFlowValidation.ts.html |here} to see how to use DeleteDataFlowValidation API.
     */
    deleteDataFlowValidation(deleteDataFlowValidationRequest: requests.DeleteDataFlowValidationRequest): Promise<responses.DeleteDataFlowValidationResponse>;
    /**
     * Removes a DIS application using the specified identifier.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteDisApplicationRequest
     * @return DeleteDisApplicationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/DeleteDisApplication.ts.html |here} to see how to use DeleteDisApplication API.
     */
    deleteDisApplication(deleteDisApplicationRequest: requests.DeleteDisApplicationRequest): Promise<responses.DeleteDisApplicationResponse>;
    /**
     * Deletes detailed description of an Application.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteDisApplicationDetailedDescriptionRequest
     * @return DeleteDisApplicationDetailedDescriptionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/DeleteDisApplicationDetailedDescription.ts.html |here} to see how to use DeleteDisApplicationDetailedDescription API.
     */
    deleteDisApplicationDetailedDescription(deleteDisApplicationDetailedDescriptionRequest: requests.DeleteDisApplicationDetailedDescriptionRequest): Promise<responses.DeleteDisApplicationDetailedDescriptionResponse>;
    /**
     * Delete export object request using the specified identifier.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteExportRequestRequest
     * @return DeleteExportRequestResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/DeleteExportRequest.ts.html |here} to see how to use DeleteExportRequest API.
     */
    deleteExportRequest(deleteExportRequestRequest: requests.DeleteExportRequestRequest): Promise<responses.DeleteExportRequestResponse>;
    /**
     * Removes a published object using the specified identifier.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteExternalPublicationRequest
     * @return DeleteExternalPublicationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/DeleteExternalPublication.ts.html |here} to see how to use DeleteExternalPublication API.
     */
    deleteExternalPublication(deleteExternalPublicationRequest: requests.DeleteExternalPublicationRequest): Promise<responses.DeleteExternalPublicationResponse>;
    /**
     * Removes a task validation using the specified identifier.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteExternalPublicationValidationRequest
     * @return DeleteExternalPublicationValidationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/DeleteExternalPublicationValidation.ts.html |here} to see how to use DeleteExternalPublicationValidation API.
     */
    deleteExternalPublicationValidation(deleteExternalPublicationValidationRequest: requests.DeleteExternalPublicationValidationRequest): Promise<responses.DeleteExternalPublicationValidationResponse>;
    /**
     * Removes a folder from a project using the specified identifier.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteFolderRequest
     * @return DeleteFolderResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/DeleteFolder.ts.html |here} to see how to use DeleteFolder API.
     */
    deleteFolder(deleteFolderRequest: requests.DeleteFolderRequest): Promise<responses.DeleteFolderResponse>;
    /**
     * Removes a Function Library from a project using the specified identifier.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteFunctionLibraryRequest
     * @return DeleteFunctionLibraryResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/DeleteFunctionLibrary.ts.html |here} to see how to use DeleteFunctionLibrary API.
     */
    deleteFunctionLibrary(deleteFunctionLibraryRequest: requests.DeleteFunctionLibraryRequest): Promise<responses.DeleteFunctionLibraryResponse>;
    /**
     * Delete import object request using the specified identifier.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteImportRequestRequest
     * @return DeleteImportRequestResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/DeleteImportRequest.ts.html |here} to see how to use DeleteImportRequest API.
     */
    deleteImportRequest(deleteImportRequestRequest: requests.DeleteImportRequestRequest): Promise<responses.DeleteImportRequestResponse>;
    /**
     * Removes a patch using the specified identifier.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeletePatchRequest
     * @return DeletePatchResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/DeletePatch.ts.html |here} to see how to use DeletePatch API.
     */
    deletePatch(deletePatchRequest: requests.DeletePatchRequest): Promise<responses.DeletePatchResponse>;
    /**
     * Removes a pipeline from a project or folder using the specified identifier.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeletePipelineRequest
     * @return DeletePipelineResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/DeletePipeline.ts.html |here} to see how to use DeletePipeline API.
     */
    deletePipeline(deletePipelineRequest: requests.DeletePipelineRequest): Promise<responses.DeletePipelineResponse>;
    /**
     * Removes a pipeline validation using the specified identifier.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeletePipelineValidationRequest
     * @return DeletePipelineValidationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/DeletePipelineValidation.ts.html |here} to see how to use DeletePipelineValidation API.
     */
    deletePipelineValidation(deletePipelineValidationRequest: requests.DeletePipelineValidationRequest): Promise<responses.DeletePipelineValidationResponse>;
    /**
     * Removes a project from the workspace using the specified identifier.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteProjectRequest
     * @return DeleteProjectResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/DeleteProject.ts.html |here} to see how to use DeleteProject API.
     */
    deleteProject(deleteProjectRequest: requests.DeleteProjectRequest): Promise<responses.DeleteProjectResponse>;
    /**
     * Endpoint to delete schedule.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteScheduleRequest
     * @return DeleteScheduleResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/DeleteSchedule.ts.html |here} to see how to use DeleteSchedule API.
     */
    deleteSchedule(deleteScheduleRequest: requests.DeleteScheduleRequest): Promise<responses.DeleteScheduleResponse>;
    /**
     * Removes a task using the specified identifier.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteTaskRequest
     * @return DeleteTaskResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/DeleteTask.ts.html |here} to see how to use DeleteTask API.
     */
    deleteTask(deleteTaskRequest: requests.DeleteTaskRequest): Promise<responses.DeleteTaskResponse>;
    /**
     * Deletes a task run using the specified identifier.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteTaskRunRequest
     * @return DeleteTaskRunResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/DeleteTaskRun.ts.html |here} to see how to use DeleteTaskRun API.
     */
    deleteTaskRun(deleteTaskRunRequest: requests.DeleteTaskRunRequest): Promise<responses.DeleteTaskRunResponse>;
    /**
     * Endpoint to delete TaskSchedule.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteTaskScheduleRequest
     * @return DeleteTaskScheduleResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/DeleteTaskSchedule.ts.html |here} to see how to use DeleteTaskSchedule API.
     */
    deleteTaskSchedule(deleteTaskScheduleRequest: requests.DeleteTaskScheduleRequest): Promise<responses.DeleteTaskScheduleResponse>;
    /**
     * Removes a task validation using the specified identifier.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteTaskValidationRequest
     * @return DeleteTaskValidationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/DeleteTaskValidation.ts.html |here} to see how to use DeleteTaskValidation API.
     */
    deleteTaskValidation(deleteTaskValidationRequest: requests.DeleteTaskValidationRequest): Promise<responses.DeleteTaskValidationResponse>;
    /**
     * Removes a UserDefinedFunction from a function library using the specified identifier.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteUserDefinedFunctionRequest
     * @return DeleteUserDefinedFunctionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/DeleteUserDefinedFunction.ts.html |here} to see how to use DeleteUserDefinedFunction API.
     */
    deleteUserDefinedFunction(deleteUserDefinedFunctionRequest: requests.DeleteUserDefinedFunctionRequest): Promise<responses.DeleteUserDefinedFunctionResponse>;
    /**
     * Removes a UserDefinedFunction validation using the specified identifier.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteUserDefinedFunctionValidationRequest
     * @return DeleteUserDefinedFunctionValidationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/DeleteUserDefinedFunctionValidation.ts.html |here} to see how to use DeleteUserDefinedFunctionValidation API.
     */
    deleteUserDefinedFunctionValidation(deleteUserDefinedFunctionValidationRequest: requests.DeleteUserDefinedFunctionValidationRequest): Promise<responses.DeleteUserDefinedFunctionValidationResponse>;
    /**
     * Deletes a Data Integration workspace resource using the specified identifier.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteWorkspaceRequest
     * @return DeleteWorkspaceResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/DeleteWorkspace.ts.html |here} to see how to use DeleteWorkspace API.
     */
    deleteWorkspace(deleteWorkspaceRequest: requests.DeleteWorkspaceRequest): Promise<responses.DeleteWorkspaceResponse>;
    /**
     * Retrieves an application using the specified identifier.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetApplicationRequest
     * @return GetApplicationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/GetApplication.ts.html |here} to see how to use GetApplication API.
     */
    getApplication(getApplicationRequest: requests.GetApplicationRequest): Promise<responses.GetApplicationResponse>;
    /**
     * Retrieves detailed description of an Application
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetApplicationDetailedDescriptionRequest
     * @return GetApplicationDetailedDescriptionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/GetApplicationDetailedDescription.ts.html |here} to see how to use GetApplicationDetailedDescription API.
     */
    getApplicationDetailedDescription(getApplicationDetailedDescriptionRequest: requests.GetApplicationDetailedDescriptionRequest): Promise<responses.GetApplicationDetailedDescriptionResponse>;
    /**
     * This endpoint can be used to get composite state for a given aggregator
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetCompositeStateRequest
     * @return GetCompositeStateResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/GetCompositeState.ts.html |here} to see how to use GetCompositeState API.
     */
    getCompositeState(getCompositeStateRequest: requests.GetCompositeStateRequest): Promise<responses.GetCompositeStateResponse>;
    /**
     * Retrieves the connection details using the specified identifier.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetConnectionRequest
     * @return GetConnectionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/GetConnection.ts.html |here} to see how to use GetConnection API.
     */
    getConnection(getConnectionRequest: requests.GetConnectionRequest): Promise<responses.GetConnectionResponse>;
    /**
     * Retrieves a connection validation using the specified identifier.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetConnectionValidationRequest
     * @return GetConnectionValidationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/GetConnectionValidation.ts.html |here} to see how to use GetConnectionValidation API.
     */
    getConnectionValidation(getConnectionValidationRequest: requests.GetConnectionValidationRequest): Promise<responses.GetConnectionValidationResponse>;
    /**
     * This endpoint can be used to get the summary/details of object being copied.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetCopyObjectRequestRequest
     * @return GetCopyObjectRequestResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/GetCopyObjectRequest.ts.html |here} to see how to use GetCopyObjectRequest API.
     */
    getCopyObjectRequest(getCopyObjectRequestRequest: requests.GetCopyObjectRequestRequest): Promise<responses.GetCopyObjectRequestResponse>;
    /**
     * Retrieves statistics on a workspace. It returns an object with an array of property values, such as the number of projects, |
     *        applications, data assets, and so on.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetCountStatisticRequest
     * @return GetCountStatisticResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/GetCountStatistic.ts.html |here} to see how to use GetCountStatistic API.
     */
    getCountStatistic(getCountStatisticRequest: requests.GetCountStatisticRequest): Promise<responses.GetCountStatisticResponse>;
    /**
     * Retrieves details of a data asset using the specified identifier.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetDataAssetRequest
     * @return GetDataAssetResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/GetDataAsset.ts.html |here} to see how to use GetDataAsset API.
     */
    getDataAsset(getDataAssetRequest: requests.GetDataAssetRequest): Promise<responses.GetDataAssetResponse>;
    /**
     * Retrieves the data entity details with the given name from live schema.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetDataEntityRequest
     * @return GetDataEntityResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/GetDataEntity.ts.html |here} to see how to use GetDataEntity API.
     */
    getDataEntity(getDataEntityRequest: requests.GetDataEntityRequest): Promise<responses.GetDataEntityResponse>;
    /**
     * Retrieves a data flow using the specified identifier.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetDataFlowRequest
     * @return GetDataFlowResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/GetDataFlow.ts.html |here} to see how to use GetDataFlow API.
     */
    getDataFlow(getDataFlowRequest: requests.GetDataFlowRequest): Promise<responses.GetDataFlowResponse>;
    /**
     * Retrieves a data flow validation using the specified identifier.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetDataFlowValidationRequest
     * @return GetDataFlowValidationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/GetDataFlowValidation.ts.html |here} to see how to use GetDataFlowValidation API.
     */
    getDataFlowValidation(getDataFlowValidationRequest: requests.GetDataFlowValidationRequest): Promise<responses.GetDataFlowValidationResponse>;
    /**
     * Retrieves the details of a dependent object from an application.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetDependentObjectRequest
     * @return GetDependentObjectResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/GetDependentObject.ts.html |here} to see how to use GetDependentObject API.
     */
    getDependentObject(getDependentObjectRequest: requests.GetDependentObjectRequest): Promise<responses.GetDependentObjectResponse>;
    /**
     * Retrieves an application using the specified OCID.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetDisApplicationRequest
     * @return GetDisApplicationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/GetDisApplication.ts.html |here} to see how to use GetDisApplication API.
     */
    getDisApplication(getDisApplicationRequest: requests.GetDisApplicationRequest): Promise<responses.GetDisApplicationResponse>;
    /**
     * Retrieves detailed description of an Application.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetDisApplicationDetailedDescriptionRequest
     * @return GetDisApplicationDetailedDescriptionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/GetDisApplicationDetailedDescription.ts.html |here} to see how to use GetDisApplicationDetailedDescription API.
     */
    getDisApplicationDetailedDescription(getDisApplicationDetailedDescriptionRequest: requests.GetDisApplicationDetailedDescriptionRequest): Promise<responses.GetDisApplicationDetailedDescriptionResponse>;
    /**
     * This endpoint can be used to get the summary/details of object being exported.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetExportRequestRequest
     * @return GetExportRequestResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/GetExportRequest.ts.html |here} to see how to use GetExportRequest API.
     */
    getExportRequest(getExportRequestRequest: requests.GetExportRequestRequest): Promise<responses.GetExportRequestResponse>;
    /**
     * Retrieves a publshed object in an task using the specified identifier.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetExternalPublicationRequest
     * @return GetExternalPublicationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/GetExternalPublication.ts.html |here} to see how to use GetExternalPublication API.
     */
    getExternalPublication(getExternalPublicationRequest: requests.GetExternalPublicationRequest): Promise<responses.GetExternalPublicationResponse>;
    /**
     * Retrieves an external publication validation using the specified identifier.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetExternalPublicationValidationRequest
     * @return GetExternalPublicationValidationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/GetExternalPublicationValidation.ts.html |here} to see how to use GetExternalPublicationValidation API.
     */
    getExternalPublicationValidation(getExternalPublicationValidationRequest: requests.GetExternalPublicationValidationRequest): Promise<responses.GetExternalPublicationValidationResponse>;
    /**
     * Retrieves a folder using the specified identifier.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetFolderRequest
     * @return GetFolderResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/GetFolder.ts.html |here} to see how to use GetFolder API.
     */
    getFolder(getFolderRequest: requests.GetFolderRequest): Promise<responses.GetFolderResponse>;
    /**
     * Retrieves a Function Library using the specified identifier.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetFunctionLibraryRequest
     * @return GetFunctionLibraryResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/GetFunctionLibrary.ts.html |here} to see how to use GetFunctionLibrary API.
     */
    getFunctionLibrary(getFunctionLibraryRequest: requests.GetFunctionLibraryRequest): Promise<responses.GetFunctionLibraryResponse>;
    /**
     * This endpoint can be used to get the summary/details of object being imported.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetImportRequestRequest
     * @return GetImportRequestResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/GetImportRequest.ts.html |here} to see how to use GetImportRequest API.
     */
    getImportRequest(getImportRequestRequest: requests.GetImportRequestRequest): Promise<responses.GetImportRequestResponse>;
    /**
     * Retrieves a patch in an application using the specified identifier.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetPatchRequest
     * @return GetPatchResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/GetPatch.ts.html |here} to see how to use GetPatch API.
     */
    getPatch(getPatchRequest: requests.GetPatchRequest): Promise<responses.GetPatchResponse>;
    /**
     * Retrieves a pipeline using the specified identifier.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetPipelineRequest
     * @return GetPipelineResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/GetPipeline.ts.html |here} to see how to use GetPipeline API.
     */
    getPipeline(getPipelineRequest: requests.GetPipelineRequest): Promise<responses.GetPipelineResponse>;
    /**
     * Retrieves a pipeline validation using the specified identifier.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetPipelineValidationRequest
     * @return GetPipelineValidationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/GetPipelineValidation.ts.html |here} to see how to use GetPipelineValidation API.
     */
    getPipelineValidation(getPipelineValidationRequest: requests.GetPipelineValidationRequest): Promise<responses.GetPipelineValidationResponse>;
    /**
     * Retrieves a project using the specified identifier.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetProjectRequest
     * @return GetProjectResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/GetProject.ts.html |here} to see how to use GetProject API.
     */
    getProject(getProjectRequest: requests.GetProjectRequest): Promise<responses.GetProjectResponse>;
    /**
     * Retrieves the details of a published object from an application.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetPublishedObjectRequest
     * @return GetPublishedObjectResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/GetPublishedObject.ts.html |here} to see how to use GetPublishedObject API.
     */
    getPublishedObject(getPublishedObjectRequest: requests.GetPublishedObjectRequest): Promise<responses.GetPublishedObjectResponse>;
    /**
     * Retrieves a reference in an application.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetReferenceRequest
     * @return GetReferenceResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/GetReference.ts.html |here} to see how to use GetReference API.
     */
    getReference(getReferenceRequest: requests.GetReferenceRequest): Promise<responses.GetReferenceResponse>;
    /**
     * Retrieves a runtime operator using the specified identifier.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetRuntimeOperatorRequest
     * @return GetRuntimeOperatorResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/GetRuntimeOperator.ts.html |here} to see how to use GetRuntimeOperator API.
     */
    getRuntimeOperator(getRuntimeOperatorRequest: requests.GetRuntimeOperatorRequest): Promise<responses.GetRuntimeOperatorResponse>;
    /**
     * Retrieves a runtime pipeline using the specified identifier.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetRuntimePipelineRequest
     * @return GetRuntimePipelineResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/GetRuntimePipeline.ts.html |here} to see how to use GetRuntimePipeline API.
     */
    getRuntimePipeline(getRuntimePipelineRequest: requests.GetRuntimePipelineRequest): Promise<responses.GetRuntimePipelineResponse>;
    /**
     * Retrieves schedule by schedule key
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetScheduleRequest
     * @return GetScheduleResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/GetSchedule.ts.html |here} to see how to use GetSchedule API.
     */
    getSchedule(getScheduleRequest: requests.GetScheduleRequest): Promise<responses.GetScheduleResponse>;
    /**
     * Retrieves a schema that can be accessed using the specified connection.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetSchemaRequest
     * @return GetSchemaResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/GetSchema.ts.html |here} to see how to use GetSchema API.
     */
    getSchema(getSchemaRequest: requests.GetSchemaRequest): Promise<responses.GetSchemaResponse>;
    /**
     * Retrieves a task using the specified identifier.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetTaskRequest
     * @return GetTaskResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/GetTask.ts.html |here} to see how to use GetTask API.
     */
    getTask(getTaskRequest: requests.GetTaskRequest): Promise<responses.GetTaskResponse>;
    /**
     * Retrieves a task run using the specified identifier.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetTaskRunRequest
     * @return GetTaskRunResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/GetTaskRun.ts.html |here} to see how to use GetTaskRun API.
     */
    getTaskRun(getTaskRunRequest: requests.GetTaskRunRequest): Promise<responses.GetTaskRunResponse>;
    /**
     * Endpoint used to get taskSchedule by its key
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetTaskScheduleRequest
     * @return GetTaskScheduleResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/GetTaskSchedule.ts.html |here} to see how to use GetTaskSchedule API.
     */
    getTaskSchedule(getTaskScheduleRequest: requests.GetTaskScheduleRequest): Promise<responses.GetTaskScheduleResponse>;
    /**
     * Retrieves a task validation using the specified identifier.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetTaskValidationRequest
     * @return GetTaskValidationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/GetTaskValidation.ts.html |here} to see how to use GetTaskValidation API.
     */
    getTaskValidation(getTaskValidationRequest: requests.GetTaskValidationRequest): Promise<responses.GetTaskValidationResponse>;
    /**
     * This endpoint can be used to get an application template using a key.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetTemplateRequest
     * @return GetTemplateResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/GetTemplate.ts.html |here} to see how to use GetTemplate API.
     */
    getTemplate(getTemplateRequest: requests.GetTemplateRequest): Promise<responses.GetTemplateResponse>;
    /**
     * Retrieves a UserDefinedFunction using the specified identifier.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetUserDefinedFunctionRequest
     * @return GetUserDefinedFunctionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/GetUserDefinedFunction.ts.html |here} to see how to use GetUserDefinedFunction API.
     */
    getUserDefinedFunction(getUserDefinedFunctionRequest: requests.GetUserDefinedFunctionRequest): Promise<responses.GetUserDefinedFunctionResponse>;
    /**
     * Retrieves a UserDefinedFunction validation using the specified identifier.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetUserDefinedFunctionValidationRequest
     * @return GetUserDefinedFunctionValidationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/GetUserDefinedFunctionValidation.ts.html |here} to see how to use GetUserDefinedFunctionValidation API.
     */
    getUserDefinedFunctionValidation(getUserDefinedFunctionValidationRequest: requests.GetUserDefinedFunctionValidationRequest): Promise<responses.GetUserDefinedFunctionValidationResponse>;
    /**
     * Retrieves the status of the work request with the given ID.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetWorkRequestRequest
     * @return GetWorkRequestResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/GetWorkRequest.ts.html |here} to see how to use GetWorkRequest API.
     */
    getWorkRequest(getWorkRequestRequest: requests.GetWorkRequestRequest): Promise<responses.GetWorkRequestResponse>;
    /**
     * Retrieves a Data Integration workspace using the specified identifier.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetWorkspaceRequest
     * @return GetWorkspaceResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/GetWorkspace.ts.html |here} to see how to use GetWorkspace API.
     */
    getWorkspace(getWorkspaceRequest: requests.GetWorkspaceRequest): Promise<responses.GetWorkspaceResponse>;
    /**
     * Retrieves a list of applications and provides options to filter the list.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListApplicationsRequest
     * @return ListApplicationsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/ListApplications.ts.html |here} to see how to use ListApplications API.
     */
    listApplications(listApplicationsRequest: requests.ListApplicationsRequest): Promise<responses.ListApplicationsResponse>;
    /**
     * Retrieves a list of connection validations within the specified workspace.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListConnectionValidationsRequest
     * @return ListConnectionValidationsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/ListConnectionValidations.ts.html |here} to see how to use ListConnectionValidations API.
     */
    listConnectionValidations(listConnectionValidationsRequest: requests.ListConnectionValidationsRequest): Promise<responses.ListConnectionValidationsResponse>;
    /**
     * Retrieves a list of all connections.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListConnectionsRequest
     * @return ListConnectionsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/ListConnections.ts.html |here} to see how to use ListConnections API.
     */
    listConnections(listConnectionsRequest: requests.ListConnectionsRequest): Promise<responses.ListConnectionsResponse>;
    /**
     * This endpoint can be used to get the list of copy object requests.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListCopyObjectRequestsRequest
     * @return ListCopyObjectRequestsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/ListCopyObjectRequests.ts.html |here} to see how to use ListCopyObjectRequests API.
     */
    listCopyObjectRequests(listCopyObjectRequestsRequest: requests.ListCopyObjectRequestsRequest): Promise<responses.ListCopyObjectRequestsResponse>;
    /**
     * Retrieves a list of all data asset summaries.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListDataAssetsRequest
     * @return ListDataAssetsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/ListDataAssets.ts.html |here} to see how to use ListDataAssets API.
     */
    listDataAssets(listDataAssetsRequest: requests.ListDataAssetsRequest): Promise<responses.ListDataAssetsResponse>;
    /**
     * Lists a summary of data entities from the data asset using the specified connection.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListDataEntitiesRequest
     * @return ListDataEntitiesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/ListDataEntities.ts.html |here} to see how to use ListDataEntities API.
     */
    listDataEntities(listDataEntitiesRequest: requests.ListDataEntitiesRequest): Promise<responses.ListDataEntitiesResponse>;
    /**
     * Retrieves a list of data flow validations within the specified workspace.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListDataFlowValidationsRequest
     * @return ListDataFlowValidationsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/ListDataFlowValidations.ts.html |here} to see how to use ListDataFlowValidations API.
     */
    listDataFlowValidations(listDataFlowValidationsRequest: requests.ListDataFlowValidationsRequest): Promise<responses.ListDataFlowValidationsResponse>;
    /**
     * Retrieves a list of data flows in a project or folder.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListDataFlowsRequest
     * @return ListDataFlowsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/ListDataFlows.ts.html |here} to see how to use ListDataFlows API.
     */
    listDataFlows(listDataFlowsRequest: requests.ListDataFlowsRequest): Promise<responses.ListDataFlowsResponse>;
    /**
     * Retrieves a list of all dependent objects for a specific application.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListDependentObjectsRequest
     * @return ListDependentObjectsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/ListDependentObjects.ts.html |here} to see how to use ListDependentObjects API.
     */
    listDependentObjects(listDependentObjectsRequest: requests.ListDependentObjectsRequest): Promise<responses.ListDependentObjectsResponse>;
    /**
     * This endpoint can be used to list Task Run Lineages within a given time window.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListDisApplicationTaskRunLineagesRequest
     * @return ListDisApplicationTaskRunLineagesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/ListDisApplicationTaskRunLineages.ts.html |here} to see how to use ListDisApplicationTaskRunLineages API.
     */
    listDisApplicationTaskRunLineages(listDisApplicationTaskRunLineagesRequest: requests.ListDisApplicationTaskRunLineagesRequest): Promise<responses.ListDisApplicationTaskRunLineagesResponse>;
    /**
     * Retrieves a list of DIS Applications in a compartment and provides options to filter the list.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListDisApplicationsRequest
     * @return ListDisApplicationsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/ListDisApplications.ts.html |here} to see how to use ListDisApplications API.
     */
    listDisApplications(listDisApplicationsRequest: requests.ListDisApplicationsRequest): Promise<responses.ListDisApplicationsResponse>;
    /**
     * This endpoint can be used to get the list of export object requests.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListExportRequestsRequest
     * @return ListExportRequestsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/ListExportRequests.ts.html |here} to see how to use ListExportRequests API.
     */
    listExportRequests(listExportRequestsRequest: requests.ListExportRequestsRequest): Promise<responses.ListExportRequestsResponse>;
    /**
     * Retrieves a lists of external publication validations in a workspace and provides options to filter the list.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListExternalPublicationValidationsRequest
     * @return ListExternalPublicationValidationsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/ListExternalPublicationValidations.ts.html |here} to see how to use ListExternalPublicationValidations API.
     */
    listExternalPublicationValidations(listExternalPublicationValidationsRequest: requests.ListExternalPublicationValidationsRequest): Promise<responses.ListExternalPublicationValidationsResponse>;
    /**
     * Retrieves a list of external publications in an application and provides options to filter the list.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListExternalPublicationsRequest
     * @return ListExternalPublicationsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/ListExternalPublications.ts.html |here} to see how to use ListExternalPublications API.
     */
    listExternalPublications(listExternalPublicationsRequest: requests.ListExternalPublicationsRequest): Promise<responses.ListExternalPublicationsResponse>;
    /**
     * Retrieves a list of folders in a project and provides options to filter the list.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListFoldersRequest
     * @return ListFoldersResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/ListFolders.ts.html |here} to see how to use ListFolders API.
     */
    listFolders(listFoldersRequest: requests.ListFoldersRequest): Promise<responses.ListFoldersResponse>;
    /**
     * Retrieves a list of function libraries in a project and provides options to filter the list.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListFunctionLibrariesRequest
     * @return ListFunctionLibrariesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/ListFunctionLibraries.ts.html |here} to see how to use ListFunctionLibraries API.
     */
    listFunctionLibraries(listFunctionLibrariesRequest: requests.ListFunctionLibrariesRequest): Promise<responses.ListFunctionLibrariesResponse>;
    /**
     * This endpoint can be used to get the list of import object requests.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListImportRequestsRequest
     * @return ListImportRequestsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/ListImportRequests.ts.html |here} to see how to use ListImportRequests API.
     */
    listImportRequests(listImportRequestsRequest: requests.ListImportRequestsRequest): Promise<responses.ListImportRequestsResponse>;
    /**
     * Retrieves a list of patches in an application and provides options to filter the list.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListPatchChangesRequest
     * @return ListPatchChangesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/ListPatchChanges.ts.html |here} to see how to use ListPatchChanges API.
     */
    listPatchChanges(listPatchChangesRequest: requests.ListPatchChangesRequest): Promise<responses.ListPatchChangesResponse>;
    /**
     * Retrieves a list of patches in an application and provides options to filter the list. For listing changes based on a period and logical objects changed, see ListPatchChanges API.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListPatchesRequest
     * @return ListPatchesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/ListPatches.ts.html |here} to see how to use ListPatches API.
     */
    listPatches(listPatchesRequest: requests.ListPatchesRequest): Promise<responses.ListPatchesResponse>;
    /**
     * Retrieves a list of pipeline validations within the specified workspace.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListPipelineValidationsRequest
     * @return ListPipelineValidationsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/ListPipelineValidations.ts.html |here} to see how to use ListPipelineValidations API.
     */
    listPipelineValidations(listPipelineValidationsRequest: requests.ListPipelineValidationsRequest): Promise<responses.ListPipelineValidationsResponse>;
    /**
     * Retrieves a list of pipelines in a project or folder from within a workspace, the query parameter specifies the project or folder.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListPipelinesRequest
     * @return ListPipelinesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/ListPipelines.ts.html |here} to see how to use ListPipelines API.
     */
    listPipelines(listPipelinesRequest: requests.ListPipelinesRequest): Promise<responses.ListPipelinesResponse>;
    /**
     * Retrieves a lists of projects in a workspace and provides options to filter the list.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListProjectsRequest
     * @return ListProjectsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/ListProjects.ts.html |here} to see how to use ListProjects API.
     */
    listProjects(listProjectsRequest: requests.ListProjectsRequest): Promise<responses.ListProjectsResponse>;
    /**
     * Retrieves a list of all the published objects for a specified application.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListPublishedObjectsRequest
     * @return ListPublishedObjectsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/ListPublishedObjects.ts.html |here} to see how to use ListPublishedObjects API.
     */
    listPublishedObjects(listPublishedObjectsRequest: requests.ListPublishedObjectsRequest): Promise<responses.ListPublishedObjectsResponse>;
    /**
     * Retrieves a list of references in an application. Reference objects are created when dataflows and tasks use objects, such as data assets and connections.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListReferencesRequest
     * @return ListReferencesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/ListReferences.ts.html |here} to see how to use ListReferences API.
     */
    listReferences(listReferencesRequest: requests.ListReferencesRequest): Promise<responses.ListReferencesResponse>;
    /**
     * This endpoint can be used to list runtime operators with filtering options
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListRuntimeOperatorsRequest
     * @return ListRuntimeOperatorsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/ListRuntimeOperators.ts.html |here} to see how to use ListRuntimeOperators API.
     */
    listRuntimeOperators(listRuntimeOperatorsRequest: requests.ListRuntimeOperatorsRequest): Promise<responses.ListRuntimeOperatorsResponse>;
    /**
     * This endpoint can be used to list runtime pipelines with filtering options
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListRuntimePipelinesRequest
     * @return ListRuntimePipelinesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/ListRuntimePipelines.ts.html |here} to see how to use ListRuntimePipelines API.
     */
    listRuntimePipelines(listRuntimePipelinesRequest: requests.ListRuntimePipelinesRequest): Promise<responses.ListRuntimePipelinesResponse>;
    /**
     * Use this endpoint to list schedules.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListSchedulesRequest
     * @return ListSchedulesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/ListSchedules.ts.html |here} to see how to use ListSchedules API.
     */
    listSchedules(listSchedulesRequest: requests.ListSchedulesRequest): Promise<responses.ListSchedulesResponse>;
    /**
     * Retrieves a list of all the schemas that can be accessed using the specified connection.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListSchemasRequest
     * @return ListSchemasResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/ListSchemas.ts.html |here} to see how to use ListSchemas API.
     */
    listSchemas(listSchemasRequest: requests.ListSchemasRequest): Promise<responses.ListSchemasResponse>;
    /**
     * This endpoint can be used to list Task Run Lineages within a given time window.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListTaskRunLineagesRequest
     * @return ListTaskRunLineagesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/ListTaskRunLineages.ts.html |here} to see how to use ListTaskRunLineages API.
     */
    listTaskRunLineages(listTaskRunLineagesRequest: requests.ListTaskRunLineagesRequest): Promise<responses.ListTaskRunLineagesResponse>;
    /**
     * Gets log entries for task runs using its key.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListTaskRunLogsRequest
     * @return ListTaskRunLogsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/ListTaskRunLogs.ts.html |here} to see how to use ListTaskRunLogs API.
     */
    listTaskRunLogs(listTaskRunLogsRequest: requests.ListTaskRunLogsRequest): Promise<responses.ListTaskRunLogsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listTaskRunLogsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.TaskRunLogSummary objects
     * contained in responses from the listTaskRunLogs operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllTaskRunLogs(request: requests.ListTaskRunLogsRequest): AsyncIterableIterator<model.TaskRunLogSummary>;
    /**
     * NOTE: This function is deprecated in favor of listTaskRunLogsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listTaskRunLogs operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllTaskRunLogsResponses(request: requests.ListTaskRunLogsRequest): AsyncIterableIterator<responses.ListTaskRunLogsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.TaskRunLogSummary objects
     * contained in responses from the listTaskRunLogs operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listTaskRunLogsRecordIterator(request: requests.ListTaskRunLogsRequest): AsyncIterableIterator<model.TaskRunLogSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listTaskRunLogs operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listTaskRunLogsResponseIterator(request: requests.ListTaskRunLogsRequest): AsyncIterableIterator<responses.ListTaskRunLogsResponse>;
    /**
     * Retrieves a list of task runs and provides options to filter the list.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListTaskRunsRequest
     * @return ListTaskRunsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/ListTaskRuns.ts.html |here} to see how to use ListTaskRuns API.
     */
    listTaskRuns(listTaskRunsRequest: requests.ListTaskRunsRequest): Promise<responses.ListTaskRunsResponse>;
    /**
     * This endpoint can be used to get the list of all the TaskSchedule objects.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListTaskSchedulesRequest
     * @return ListTaskSchedulesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/ListTaskSchedules.ts.html |here} to see how to use ListTaskSchedules API.
     */
    listTaskSchedules(listTaskSchedulesRequest: requests.ListTaskSchedulesRequest): Promise<responses.ListTaskSchedulesResponse>;
    /**
     * Retrieves a list of task validations within the specified workspace.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListTaskValidationsRequest
     * @return ListTaskValidationsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/ListTaskValidations.ts.html |here} to see how to use ListTaskValidations API.
     */
    listTaskValidations(listTaskValidationsRequest: requests.ListTaskValidationsRequest): Promise<responses.ListTaskValidationsResponse>;
    /**
     * Retrieves a list of all tasks in a specified project or folder.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListTasksRequest
     * @return ListTasksResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/ListTasks.ts.html |here} to see how to use ListTasks API.
     */
    listTasks(listTasksRequest: requests.ListTasksRequest): Promise<responses.ListTasksResponse>;
    /**
     * This endpoint can be used to list application templates with filtering options.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListTemplatesRequest
     * @return ListTemplatesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/ListTemplates.ts.html |here} to see how to use ListTemplates API.
     */
    listTemplates(listTemplatesRequest: requests.ListTemplatesRequest): Promise<responses.ListTemplatesResponse>;
    /**
     * Retrieves a list of UserDefinedFunctionvalidations within the specified workspace.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListUserDefinedFunctionValidationsRequest
     * @return ListUserDefinedFunctionValidationsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/ListUserDefinedFunctionValidations.ts.html |here} to see how to use ListUserDefinedFunctionValidations API.
     */
    listUserDefinedFunctionValidations(listUserDefinedFunctionValidationsRequest: requests.ListUserDefinedFunctionValidationsRequest): Promise<responses.ListUserDefinedFunctionValidationsResponse>;
    /**
     * Retrieves a list of UserDefinedFunctions in a function library.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListUserDefinedFunctionsRequest
     * @return ListUserDefinedFunctionsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/ListUserDefinedFunctions.ts.html |here} to see how to use ListUserDefinedFunctions API.
     */
    listUserDefinedFunctions(listUserDefinedFunctionsRequest: requests.ListUserDefinedFunctionsRequest): Promise<responses.ListUserDefinedFunctionsResponse>;
    /**
     * Retrieves a paginated list of errors for a given work request.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListWorkRequestErrorsRequest
     * @return ListWorkRequestErrorsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/ListWorkRequestErrors.ts.html |here} to see how to use ListWorkRequestErrors API.
     */
    listWorkRequestErrors(listWorkRequestErrorsRequest: requests.ListWorkRequestErrorsRequest): Promise<responses.ListWorkRequestErrorsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listWorkRequestErrorsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.WorkRequestError objects
     * contained in responses from the listWorkRequestErrors operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllWorkRequestErrors(request: requests.ListWorkRequestErrorsRequest): AsyncIterableIterator<model.WorkRequestError>;
    /**
     * NOTE: This function is deprecated in favor of listWorkRequestErrorsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listWorkRequestErrors operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllWorkRequestErrorsResponses(request: requests.ListWorkRequestErrorsRequest): AsyncIterableIterator<responses.ListWorkRequestErrorsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.WorkRequestError objects
     * contained in responses from the listWorkRequestErrors operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listWorkRequestErrorsRecordIterator(request: requests.ListWorkRequestErrorsRequest): AsyncIterableIterator<model.WorkRequestError>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listWorkRequestErrors operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listWorkRequestErrorsResponseIterator(request: requests.ListWorkRequestErrorsRequest): AsyncIterableIterator<responses.ListWorkRequestErrorsResponse>;
    /**
     * Retrieves a paginated list of logs for a given work request.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListWorkRequestLogsRequest
     * @return ListWorkRequestLogsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/ListWorkRequestLogs.ts.html |here} to see how to use ListWorkRequestLogs API.
     */
    listWorkRequestLogs(listWorkRequestLogsRequest: requests.ListWorkRequestLogsRequest): Promise<responses.ListWorkRequestLogsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listWorkRequestLogsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.WorkRequestLogEntry objects
     * contained in responses from the listWorkRequestLogs operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllWorkRequestLogs(request: requests.ListWorkRequestLogsRequest): AsyncIterableIterator<model.WorkRequestLogEntry>;
    /**
     * NOTE: This function is deprecated in favor of listWorkRequestLogsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listWorkRequestLogs operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllWorkRequestLogsResponses(request: requests.ListWorkRequestLogsRequest): AsyncIterableIterator<responses.ListWorkRequestLogsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.WorkRequestLogEntry objects
     * contained in responses from the listWorkRequestLogs operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listWorkRequestLogsRecordIterator(request: requests.ListWorkRequestLogsRequest): AsyncIterableIterator<model.WorkRequestLogEntry>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listWorkRequestLogs operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listWorkRequestLogsResponseIterator(request: requests.ListWorkRequestLogsRequest): AsyncIterableIterator<responses.ListWorkRequestLogsResponse>;
    /**
     * Lists the work requests in a compartment.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListWorkRequestsRequest
     * @return ListWorkRequestsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/ListWorkRequests.ts.html |here} to see how to use ListWorkRequests API.
     */
    listWorkRequests(listWorkRequestsRequest: requests.ListWorkRequestsRequest): Promise<responses.ListWorkRequestsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listWorkRequestsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.WorkRequestSummary objects
     * contained in responses from the listWorkRequests operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllWorkRequests(request: requests.ListWorkRequestsRequest): AsyncIterableIterator<model.WorkRequestSummary>;
    /**
     * NOTE: This function is deprecated in favor of listWorkRequestsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listWorkRequests operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllWorkRequestsResponses(request: requests.ListWorkRequestsRequest): AsyncIterableIterator<responses.ListWorkRequestsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.WorkRequestSummary objects
     * contained in responses from the listWorkRequests operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listWorkRequestsRecordIterator(request: requests.ListWorkRequestsRequest): AsyncIterableIterator<model.WorkRequestSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listWorkRequests operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listWorkRequestsResponseIterator(request: requests.ListWorkRequestsRequest): AsyncIterableIterator<responses.ListWorkRequestsResponse>;
    /**
     * Retrieves a list of Data Integration workspaces.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListWorkspacesRequest
     * @return ListWorkspacesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/ListWorkspaces.ts.html |here} to see how to use ListWorkspaces API.
     */
    listWorkspaces(listWorkspacesRequest: requests.ListWorkspacesRequest): Promise<responses.ListWorkspacesResponse>;
    /**
     * NOTE: This function is deprecated in favor of listWorkspacesRecordIterator function.
     * Creates a new async iterator which will iterate over the models.WorkspaceSummary objects
     * contained in responses from the listWorkspaces operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllWorkspaces(request: requests.ListWorkspacesRequest): AsyncIterableIterator<model.WorkspaceSummary>;
    /**
     * NOTE: This function is deprecated in favor of listWorkspacesResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listWorkspaces operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllWorkspacesResponses(request: requests.ListWorkspacesRequest): AsyncIterableIterator<responses.ListWorkspacesResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.WorkspaceSummary objects
     * contained in responses from the listWorkspaces operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listWorkspacesRecordIterator(request: requests.ListWorkspacesRequest): AsyncIterableIterator<model.WorkspaceSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listWorkspaces operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listWorkspacesResponseIterator(request: requests.ListWorkspacesRequest): AsyncIterableIterator<responses.ListWorkspacesResponse>;
    /**
     * Starts a workspace.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param StartWorkspaceRequest
     * @return StartWorkspaceResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/StartWorkspace.ts.html |here} to see how to use StartWorkspace API.
     */
    startWorkspace(startWorkspaceRequest: requests.StartWorkspaceRequest): Promise<responses.StartWorkspaceResponse>;
    /**
     * Stops a workspace.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param StopWorkspaceRequest
     * @return StopWorkspaceResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/StopWorkspace.ts.html |here} to see how to use StopWorkspace API.
     */
    stopWorkspace(stopWorkspaceRequest: requests.StopWorkspaceRequest): Promise<responses.StopWorkspaceResponse>;
    /**
     * Updates an application.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateApplicationRequest
     * @return UpdateApplicationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/UpdateApplication.ts.html |here} to see how to use UpdateApplication API.
     */
    updateApplication(updateApplicationRequest: requests.UpdateApplicationRequest): Promise<responses.UpdateApplicationResponse>;
    /**
     * Updates the detailed description of an Application.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateApplicationDetailedDescriptionRequest
     * @return UpdateApplicationDetailedDescriptionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/UpdateApplicationDetailedDescription.ts.html |here} to see how to use UpdateApplicationDetailedDescription API.
     */
    updateApplicationDetailedDescription(updateApplicationDetailedDescriptionRequest: requests.UpdateApplicationDetailedDescriptionRequest): Promise<responses.UpdateApplicationDetailedDescriptionResponse>;
    /**
     * Updates a connection under a data asset.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateConnectionRequest
     * @return UpdateConnectionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/UpdateConnection.ts.html |here} to see how to use UpdateConnection API.
     */
    updateConnection(updateConnectionRequest: requests.UpdateConnectionRequest): Promise<responses.UpdateConnectionResponse>;
    /**
     * Updates the status of a copy object request.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateCopyObjectRequestRequest
     * @return UpdateCopyObjectRequestResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/UpdateCopyObjectRequest.ts.html |here} to see how to use UpdateCopyObjectRequest API.
     */
    updateCopyObjectRequest(updateCopyObjectRequestRequest: requests.UpdateCopyObjectRequestRequest): Promise<responses.UpdateCopyObjectRequestResponse>;
    /**
     * Updates a specific data asset with default connection.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateDataAssetRequest
     * @return UpdateDataAssetResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/UpdateDataAsset.ts.html |here} to see how to use UpdateDataAsset API.
     */
    updateDataAsset(updateDataAssetRequest: requests.UpdateDataAssetRequest): Promise<responses.UpdateDataAssetResponse>;
    /**
     * Updates a specific data flow.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateDataFlowRequest
     * @return UpdateDataFlowResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/UpdateDataFlow.ts.html |here} to see how to use UpdateDataFlow API.
     */
    updateDataFlow(updateDataFlowRequest: requests.UpdateDataFlowRequest): Promise<responses.UpdateDataFlowResponse>;
    /**
     * Updates a DIS Application.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateDisApplicationRequest
     * @return UpdateDisApplicationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/UpdateDisApplication.ts.html |here} to see how to use UpdateDisApplication API.
     */
    updateDisApplication(updateDisApplicationRequest: requests.UpdateDisApplicationRequest): Promise<responses.UpdateDisApplicationResponse>;
    /**
     * Updates the detailed description of an Application.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateDisApplicationDetailedDescriptionRequest
     * @return UpdateDisApplicationDetailedDescriptionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/UpdateDisApplicationDetailedDescription.ts.html |here} to see how to use UpdateDisApplicationDetailedDescription API.
     */
    updateDisApplicationDetailedDescription(updateDisApplicationDetailedDescriptionRequest: requests.UpdateDisApplicationDetailedDescriptionRequest): Promise<responses.UpdateDisApplicationDetailedDescriptionResponse>;
    /**
     * Updates the status of a export object request.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateExportRequestRequest
     * @return UpdateExportRequestResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/UpdateExportRequest.ts.html |here} to see how to use UpdateExportRequest API.
     */
    updateExportRequest(updateExportRequestRequest: requests.UpdateExportRequestRequest): Promise<responses.UpdateExportRequestResponse>;
    /**
     * Updates the external publication object.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateExternalPublicationRequest
     * @return UpdateExternalPublicationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/UpdateExternalPublication.ts.html |here} to see how to use UpdateExternalPublication API.
     */
    updateExternalPublication(updateExternalPublicationRequest: requests.UpdateExternalPublicationRequest): Promise<responses.UpdateExternalPublicationResponse>;
    /**
     * Updates a specific folder.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateFolderRequest
     * @return UpdateFolderResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/UpdateFolder.ts.html |here} to see how to use UpdateFolder API.
     */
    updateFolder(updateFolderRequest: requests.UpdateFolderRequest): Promise<responses.UpdateFolderResponse>;
    /**
     * Updates a specific Function Library.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateFunctionLibraryRequest
     * @return UpdateFunctionLibraryResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/UpdateFunctionLibrary.ts.html |here} to see how to use UpdateFunctionLibrary API.
     */
    updateFunctionLibrary(updateFunctionLibraryRequest: requests.UpdateFunctionLibraryRequest): Promise<responses.UpdateFunctionLibraryResponse>;
    /**
     * Updates the status of a import object request.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateImportRequestRequest
     * @return UpdateImportRequestResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/UpdateImportRequest.ts.html |here} to see how to use UpdateImportRequest API.
     */
    updateImportRequest(updateImportRequestRequest: requests.UpdateImportRequestRequest): Promise<responses.UpdateImportRequestResponse>;
    /**
     * Updates a specific pipeline.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdatePipelineRequest
     * @return UpdatePipelineResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/UpdatePipeline.ts.html |here} to see how to use UpdatePipeline API.
     */
    updatePipeline(updatePipelineRequest: requests.UpdatePipelineRequest): Promise<responses.UpdatePipelineResponse>;
    /**
     * Updates a specific project.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateProjectRequest
     * @return UpdateProjectResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/UpdateProject.ts.html |here} to see how to use UpdateProject API.
     */
    updateProject(updateProjectRequest: requests.UpdateProjectRequest): Promise<responses.UpdateProjectResponse>;
    /**
     * Updates the application references. For example, to map a data asset to a different target object.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateReferenceRequest
     * @return UpdateReferenceResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/UpdateReference.ts.html |here} to see how to use UpdateReference API.
     */
    updateReference(updateReferenceRequest: requests.UpdateReferenceRequest): Promise<responses.UpdateReferenceResponse>;
    /**
     * Endpoint used to update the schedule
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateScheduleRequest
     * @return UpdateScheduleResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/UpdateSchedule.ts.html |here} to see how to use UpdateSchedule API.
     */
    updateSchedule(updateScheduleRequest: requests.UpdateScheduleRequest): Promise<responses.UpdateScheduleResponse>;
    /**
     * Updates a specific task. For example, you can update the task description or move the task to a different folder by changing the `aggregatorKey` to a different folder in the registry.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateTaskRequest
     * @return UpdateTaskResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/UpdateTask.ts.html |here} to see how to use UpdateTask API.
     */
    updateTask(updateTaskRequest: requests.UpdateTaskRequest): Promise<responses.UpdateTaskResponse>;
    /**
     * Updates the status of the task run. For example, aborts a task run.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateTaskRunRequest
     * @return UpdateTaskRunResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/UpdateTaskRun.ts.html |here} to see how to use UpdateTaskRun API.
     */
    updateTaskRun(updateTaskRunRequest: requests.UpdateTaskRunRequest): Promise<responses.UpdateTaskRunResponse>;
    /**
     * Endpoint used to update the TaskSchedule
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateTaskScheduleRequest
     * @return UpdateTaskScheduleResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/UpdateTaskSchedule.ts.html |here} to see how to use UpdateTaskSchedule API.
     */
    updateTaskSchedule(updateTaskScheduleRequest: requests.UpdateTaskScheduleRequest): Promise<responses.UpdateTaskScheduleResponse>;
    /**
     * Updates a specific UserDefinedFunction.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateUserDefinedFunctionRequest
     * @return UpdateUserDefinedFunctionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/UpdateUserDefinedFunction.ts.html |here} to see how to use UpdateUserDefinedFunction API.
     */
    updateUserDefinedFunction(updateUserDefinedFunctionRequest: requests.UpdateUserDefinedFunctionRequest): Promise<responses.UpdateUserDefinedFunctionResponse>;
    /**
     * Updates the specified Data Integration workspace.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateWorkspaceRequest
     * @return UpdateWorkspaceResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/dataintegration/UpdateWorkspace.ts.html |here} to see how to use UpdateWorkspace API.
     */
    updateWorkspace(updateWorkspaceRequest: requests.UpdateWorkspaceRequest): Promise<responses.UpdateWorkspaceResponse>;
}
export {};
