/**
 * Data Integration API
 * Use the Data Integration API to organize your data integration projects, create data flows, pipelines and tasks, and then publish, schedule, and run tasks that extract, transform, and load data. For more information, see [Data Integration](https://docs.oracle.com/iaas/data-integration/home.htm).
 * OpenAPI spec version: 20200430
 * Contact: di_dis_ww_grp@oracle.com
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * The patch object contains the audit summary information and the definition of the patch.
 */
export interface Patch {
    /**
     * The object key.
     */
    "key"?: string;
    /**
     * The object type.
     */
    "modelType"?: string;
    /**
     * The object's model version.
     */
    "modelVersion"?: string;
    /**
     * Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.
     */
    "name"?: string;
    /**
     * Detailed description for the object.
     */
    "description"?: string;
    /**
     * The version of the object that is used to track changes in the object instance. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "objectVersion"?: number;
    /**
     * The status of an object that can be set to value 1 for shallow references across objects, other values reserved. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "objectStatus"?: number;
    /**
     * Value can only contain upper case letters, underscore, and numbers. It should begin with upper case letter or underscore. The value can be modified.
     */
    "identifier"?: string;
    /**
     * The date and time the patch was applied, in the timestamp format defined by [RFC3339](https://tools.ietf.org/html/rfc3339).
     */
    "timePatched"?: Date;
    /**
     * The errors encountered while applying the patch, if any.
     */
    "errorMessages"?: {
        [key: string]: string;
    };
    /**
     * The application version of the patch. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "applicationVersion"?: number;
    /**
     * The type of the patch applied or being applied on the application.
     */
    "patchType"?: Patch.PatchType;
    /**
     * Status of the patch applied or being applied on the application
     */
    "patchStatus"?: Patch.PatchStatus;
    /**
     * List of dependent objects in this patch.
     */
    "dependentObjectMetadata"?: Array<model.PatchObjectMetadata>;
    /**
     * List of objects that are published or unpublished in this patch.
     */
    "patchObjectMetadata"?: Array<model.PatchObjectMetadata>;
    "parentRef"?: model.ParentReference;
    "metadata"?: model.ObjectMetadata;
    /**
     * A key map. If provided, key is replaced with generated key. This structure provides mapping between user provided key and generated key.
     */
    "keyMap"?: {
        [key: string]: string;
    };
}
export declare namespace Patch {
    enum PatchType {
        Publish = "PUBLISH",
        Refresh = "REFRESH",
        Unpublish = "UNPUBLISH",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    enum PatchStatus {
        Queued = "QUEUED",
        Successful = "SUCCESSFUL",
        Failed = "FAILED",
        InProgress = "IN_PROGRESS",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    function getJsonObj(obj: Patch): object;
    function getDeserializedJsonObj(obj: Patch): object;
}
