/**
 * Data Integration API
 * Use the Data Integration API to organize your data integration projects, create data flows, pipelines and tasks, and then publish, schedule, and run tasks that extract, transform, and load data. For more information, see [Data Integration](https://docs.oracle.com/iaas/data-integration/home.htm).
 * OpenAPI spec version: 20200430
 * Contact: di_dis_ww_grp@oracle.com
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * The task run object provides information on the execution of a task.
 */
export interface TaskRunDetails {
    /**
     * The object key.
     */
    "key"?: string;
    /**
     * The object type.
     */
    "modelType"?: string;
    /**
     * The object's model version.
     */
    "modelVersion"?: string;
    "parentRef"?: model.ParentReference;
    /**
     * Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.
     */
    "name"?: string;
    /**
     * Detailed description for the object.
     */
    "description"?: string;
    /**
     * The version of the object that is used to track changes in the object instance. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "objectVersion"?: number;
    /**
     * status
     */
    "status"?: TaskRunDetails.Status;
    /**
     * The task run start time. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "startTimeMillis"?: number;
    /**
     * The task run end time. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "endTimeMillis"?: number;
    /**
     * The date and time the task run was last updated. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "lastUpdated"?: number;
    /**
     * Number of records processed in task run. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "recordsWritten"?: number;
    /**
     * Number of bytes processed in task run. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "bytesProcessed"?: number;
    /**
     * The status of an object that can be set to value 1 for shallow references across objects, other values reserved. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "objectStatus"?: number;
    /**
     * The type of the task for the run.
     */
    "taskType"?: TaskRunDetails.TaskType;
    /**
     * Value can only contain upper case letters, underscore, and numbers. It should begin with upper case letter or underscore. The value can be modified.
     */
    "identifier"?: string;
    /**
     * Reference Task Run Id to be used for re-run
     */
    "refTaskRunId"?: string;
    /**
     * Supported re-run types
     */
    "reRunType"?: TaskRunDetails.ReRunType;
    /**
     * Step Id for running from a certain step.
     */
    "stepId"?: string;
    /**
     * A map of the configuration provider input bindings of the run.
     */
    "inputs"?: {
        [key: string]: model.ParameterValue;
    };
    "metadata"?: model.ObjectMetadata;
}
export declare namespace TaskRunDetails {
    enum Status {
        NotStarted = "NOT_STARTED",
        Queued = "QUEUED",
        Running = "RUNNING",
        Terminating = "TERMINATING",
        Terminated = "TERMINATED",
        Success = "SUCCESS",
        Error = "ERROR",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    enum TaskType {
        IntegrationTask = "INTEGRATION_TASK",
        DataLoaderTask = "DATA_LOADER_TASK",
        PipelineTask = "PIPELINE_TASK",
        SqlTask = "SQL_TASK",
        OciDataflowTask = "OCI_DATAFLOW_TASK",
        RestTask = "REST_TASK",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    enum ReRunType {
        Beginning = "BEGINNING",
        Failed = "FAILED",
        Step = "STEP",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    function getJsonObj(obj: TaskRunDetails): object;
    function getDeserializedJsonObj(obj: TaskRunDetails): object;
}
