/**
 * Data Safe API
 * APIs for using Oracle Data Safe.
 * OpenAPI spec version: 20181201
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * Summary of an audit profile.
 */
export interface AuditProfileSummary {
    /**
     * The OCID of the audit profile.
     */
    "id": string;
    /**
     * The OCID of the compartment that contains the audit profile.
     */
    "compartmentId": string;
    /**
     * The display name of the audit profile.
     */
    "displayName": string;
    /**
     * The date and time the audit profile was created, in the format defined by RFC3339.
     */
    "timeCreated": Date;
    /**
     * The date and time the audit profile was updated, in the format defined by RFC3339.
     */
    "timeUpdated": Date;
    /**
     * The OCID of the Data Safe target for which the audit profile is created.
     */
    "targetId": string;
    /**
     * The current state of the audit profile.
     */
    "lifecycleState": model.AuditProfileLifecycleState;
    /**
     * The description of audit profile.
     */
    "description"?: string;
    /**
     * Details about the current state of the audit profile in Data Safe.
     */
    "lifecycleDetails"?: string;
    /**
     * Indicates if you want to continue collecting audit records beyond the free limit of one million audit records per month per target database,
     * potentially incurring additional charges. The default value is inherited from the global settings.
     * You can change at the global level or at the target level.
     *
     */
    "isPaidUsageEnabled": boolean;
    /**
     * Indicates the number of months the audit records will be stored online in Oracle Data Safe audit repository for immediate reporting and analysis.
     * Minimum: 1; Maximum:12 months
     *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "onlineMonths": number;
    /**
     * Indicates the number of months the audit records will be stored offline in the Data Safe audit archive.
     * Minimum: 0; Maximum: 72 months.
     * If you have a requirement to store the audit data even longer in archive, please contact the Oracle Support.
     *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "offlineMonths": number;
    /**
     * Indicates count of audit records collected by Data Safe from the target which is eligible
     * for the current month's billing cycle. Audit records for actions performed by Data Safe service
     * account on the target is excluded.
     *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "auditCollectedVolume"?: number;
    /**
     * Indicates whether audit retention settings like online and offline months is set at the
     * target level overriding the global audit retention settings.
     *
     */
    "isOverrideGlobalRetentionSetting": boolean;
    /**
      * Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm)
  * <p>
  Example: {@code {\"Department\": \"Finance\"}}
  *
      */
    "freeformTags"?: {
        [key: string]: string;
    };
    /**
      * Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm)
  * <p>
  Example: {@code {\"Operations\": {\"CostCenter\": \"42\"}}}
  *
      */
    "definedTags"?: {
        [key: string]: {
            [key: string]: any;
        };
    };
}
export declare namespace AuditProfileSummary {
    function getJsonObj(obj: AuditProfileSummary): object;
    function getDeserializedJsonObj(obj: AuditProfileSummary): object;
}
