/**
 * Data Safe API
 * APIs for using Oracle Data Safe.
 * OpenAPI spec version: 20181201
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * Summary of an audit trail.
 */
export interface AuditTrailSummary {
    /**
     * The OCID of the audit trail.
     */
    "id": string;
    /**
     * The OCID of the  parent audit.
     */
    "auditProfileId": string;
    /**
     * The display name of the audit trail.
     */
    "displayName": string;
    /**
     * The date and time the audit trail was created, in the format defined by RFC3339.
     */
    "timeCreated": Date;
    /**
     * The date and time the audit trail was updated, in the format defined by RFC3339.
     */
    "timeUpdated": Date;
    /**
     * The current sub-state of the audit trail.
     */
    "status": model.AuditTrailStatus;
    /**
     * The description of audit trail.
     */
    "description"?: string;
    /**
     * An audit trail location represents the source of audit records that provides documentary evidence of the sequence of activities in the target database.
     */
    "trailLocation"?: string;
    /**
     * The OCID of the compartment that contains the audit.
     */
    "compartmentId": string;
    /**
     * The OCID of the Data Safe target for which the audit trail is created.
     */
    "targetId": string;
    /**
     * The current state of the audit trail.
     */
    "lifecycleState": model.AuditTrailLifecycleState;
    /**
     * Details about the current state of the audit trail in Data Safe.
     */
    "lifecycleDetails"?: string;
    /**
     * Indicates if auto purge is enabled on the target database, which helps delete audit data in the
     * target database every seven days so that the database's audit trail does not become too large.
     *
     */
    "isAutoPurgeEnabled"?: boolean;
    /**
     * The date from which the audit trail must start collecting data, in the format defined by RFC3339.
     */
    "auditCollectionStartTime"?: Date;
    /**
     * The secondary id assigned for the peer database registered with Data Safe. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "peerTargetDatabaseKey"?: number;
    /**
      * Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm)
  * <p>
  Example: {@code {\"Department\": \"Finance\"}}
  *
      */
    "freeformTags"?: {
        [key: string]: string;
    };
    /**
      * Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm)
  * <p>
  Example: {@code {\"Operations\": {\"CostCenter\": \"42\"}}}
  *
      */
    "definedTags"?: {
        [key: string]: {
            [key: string]: any;
        };
    };
}
export declare namespace AuditTrailSummary {
    function getJsonObj(obj: AuditTrailSummary): object;
    function getDeserializedJsonObj(obj: AuditTrailSummary): object;
}
