/**
 * Data Safe API
 * APIs for using Oracle Data Safe.
 * OpenAPI spec version: 20181201
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
/**
 * Details to create a new data discovery job.
 */
export interface CreateDiscoveryJobDetails {
    /**
     * The type of the discovery job. It defines the job's scope.
     * NEW identifies new sensitive columns in the target database that are not in the sensitive data model.
     * DELETED identifies columns that are present in the sensitive data model but have been deleted from the target database.
     * MODIFIED identifies columns that are present in the target database as well as the sensitive data model but some of their attributes have been modified.
     * ALL covers all the above three scenarios and reports new, deleted and modified columns.
     *
     */
    "discoveryType"?: string;
    /**
     * The OCID of the sensitive data model.
     */
    "sensitiveDataModelId": string;
    /**
     * The OCID of the compartment where the discovery job resource should be created.
     */
    "compartmentId": string;
    /**
     * A user-friendly name for the discovery job. Does not have to be unique, and it is changeable. Avoid entering confidential information.
     */
    "displayName"?: string;
    /**
     * The schemas to be scanned by the discovery job. If not provided, the schemasForDiscovery attribute of the sensitive
     * data model is used to get the list of schemas.
     *
     */
    "schemasForDiscovery"?: Array<string>;
    /**
     * The OCIDs of the sensitive types to be used by the discovery job. If not provided, the sensitiveTypeIdsForDiscovery
     * attribute of the sensitive data model is used to get the list of sensitive types.
     *
     */
    "sensitiveTypeIdsForDiscovery"?: Array<string>;
    /**
     * Indicates if the discovery job should collect and store sample data values for the discovered columns. Sample data
     * helps review the discovered columns and ensure that they actually contain sensitive data. As it collects original
     * data from the target database, it's disabled by default and should be used only if it's acceptable to store sample
     * data in Data Safe's repository in Oracle Cloud. Note that sample data values are not collected for columns with the
     * following data types: LONG, LOB, RAW, XMLTYPE and BFILE.
     *
     */
    "isSampleDataCollectionEnabled"?: boolean;
    /**
     * Indicates if the discovery job should identify potential application-level (non-dictionary) referential relationships
     * between columns. Note that data discovery automatically identifies and adds database-level (dictionary-defined)
     * relationships. This option helps identify application-level relationships that are not defined in the database
     * dictionary, which in turn, helps identify additional sensitive columns and preserve referential integrity during
     * data masking. It's disabled by default and should be used only if there is a need to identify application-level
     * relationships.
     *
     */
    "isAppDefinedRelationDiscoveryEnabled"?: boolean;
    /**
     * Indicates if all the schemas should be scanned by the discovery job. If it is set to true, sensitive data is discovered
     * in all schemas (except for schemas maintained by Oracle). If both attributes are not provided, the configuration
     * from the sensitive data model is used.
     *
     */
    "isIncludeAllSchemas"?: boolean;
    /**
     * Indicates if all the existing sensitive types should be used by the discovery job. If it's set to true, the
     * sensitiveTypeIdsForDiscovery attribute is ignored and all sensitive types are used for data discovery. If both
     * attributes are not provided, the configuration from the sensitive data model is used.
     *
     */
    "isIncludeAllSensitiveTypes"?: boolean;
    /**
      * Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm)
  * <p>
  Example: {@code {\"Department\": \"Finance\"}}
  *
      */
    "freeformTags"?: {
        [key: string]: string;
    };
    /**
      * Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm)
  * <p>
  Example: {@code {\"Operations\": {\"CostCenter\": \"42\"}}}
  *
      */
    "definedTags"?: {
        [key: string]: {
            [key: string]: any;
        };
    };
}
export declare namespace CreateDiscoveryJobDetails {
    function getJsonObj(obj: CreateDiscoveryJobDetails): object;
    function getDeserializedJsonObj(obj: CreateDiscoveryJobDetails): object;
}
