/**
 * Data Safe API
 * APIs for using Oracle Data Safe.
 * OpenAPI spec version: 20181201
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
/**
 * A SDM masking policy difference column. It can be one of the following three types:
 * NEW: A new column in the sensitive data model that is not in the masking policy.
 * DELETED: A column that is present in the masking policy but has been deleted from the sensitive data model.
 * MODIFIED: A column that is present in the masking policy as well as the sensitive data model but some of its attributes have been modified.
 *
 */
export interface DifferenceColumn {
    /**
     * The unique key that identifies the SDM masking policy difference column.
     */
    "key": string;
    /**
     * The type of the SDM masking policy difference column. It can be one of the following three types:
     * NEW: A new sensitive column in the sensitive data model that is not in the masking policy.
     * DELETED: A column that is present in the masking policy but has been deleted from the sensitive data model.
     * MODIFIED: A column that is present in the masking policy as well as the sensitive data model but some of its attributes have been modified.
     *
     */
    "differenceType": DifferenceColumn.DifferenceType;
    /**
     * The unique key that identifies the sensitive column represented by the SDM masking policy difference column.
     */
    "sensitiveColumnkey"?: string;
    /**
     * The unique key that identifies the masking column represented by the SDM masking policy difference column.
     */
    "maskingColumnkey"?: string;
    /**
     * The database schema that contains the difference column.
     */
    "schemaName": string;
    /**
     * The database object that contains the difference column.
     */
    "objectName": string;
    /**
     * The name of the difference column.
     */
    "columnName": string;
    /**
     * The OCID of the sensitive type associated with the difference column.
     */
    "sensitiveTypeId"?: string;
    /**
     * Specifies how to process the difference column. It's set to SYNC by default. Use the PatchSdmMaskingPolicyDifferenceColumns operation to update this attribute. You can choose one of the following options:
     * SYNC: To sync the difference column and update the masking policy to reflect the changes.
     * NO_SYNC: To not sync the difference column so that it doesn't change the masking policy.
     * After specifying the planned action, you can use the ApplySdmMaskingPolicyDifference operation to automatically process the difference columns.
     *
     */
    "plannedAction": DifferenceColumn.PlannedAction;
    /**
     * Indicates if the difference column has been processed. Use GetDifferenceColumn operation to
     * track whether the difference column has already been processed and applied to the masking policy.
     *
     */
    "syncStatus": DifferenceColumn.SyncStatus;
    /**
     * The date and time the SDM masking policy difference column was last synced, in the format defined by [RFC3339](https://tools.ietf.org/html/rfc3339).
     */
    "timeLastSynced"?: Date;
}
export declare namespace DifferenceColumn {
    enum DifferenceType {
        New = "NEW",
        Modified = "MODIFIED",
        Deleted = "DELETED",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    enum PlannedAction {
        Sync = "SYNC",
        NoSync = "NO_SYNC",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    enum SyncStatus {
        Synced = "SYNCED",
        NotSynced = "NOT_SYNCED",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    function getJsonObj(obj: DifferenceColumn): object;
    function getDeserializedJsonObj(obj: DifferenceColumn): object;
}
