/**
 * Data Safe API
 * APIs for using Oracle Data Safe.
 * OpenAPI spec version: 20181201
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
/**
 * The summary of information about the user profiles. It includes details such as profile name, failed login attempts,
 * sessions per user, inactive account time, password lock time, user created, target id, and the compartment id.
 *
 */
export interface ProfileSummary {
    /**
     * The OCID of the latest user assessment corresponding to the target under consideration. A compartment
     * type assessment can also be passed to profiles from all the targets from the corresponding compartment.
     *
     */
    "userAssessmentId": string;
    /**
     * The OCID of the compartment that contains the user assessment.
     */
    "compartmentId": string;
    /**
     * The OCID of the target database.
     */
    "targetId"?: string;
    /**
     * The name of the profile.
     */
    "profileName"?: string;
    /**
     * The number of users having a given profile. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "userCount"?: number;
    /**
     * Maximum times the user is allowed to fail login before the user account is locked.
     */
    "failedLoginAttempts"?: string;
    /**
     * PL/SQL that can be used for password verification.
     */
    "passwordVerificationFunction"?: string;
    /**
     * The maximum number of sessions a user is allowed to create.
     */
    "sessionsPerUser"?: string;
    /**
     * The permitted periods of continuous inactive time during a session, expressed in minutes.
     * Long-running queries and other operations are not subjected to this limit.
     *
     */
    "inactiveAccountTime"?: string;
    /**
     * Number of days the user account remains locked after failed login
     */
    "passwordLockTime"?: string;
    /**
     * Represents if the profile is created by user.
     */
    "isUserCreated"?: boolean;
    /**
      * Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm)
  * <p>
  Example: {@code {\"Department\": \"Finance\"}}
  *
      */
    "freeformTags"?: {
        [key: string]: string;
    };
    /**
      * Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm)
  * <p>
  Example: {@code {\"Operations\": {\"CostCenter\": \"42\"}}}
  *
      */
    "definedTags"?: {
        [key: string]: {
            [key: string]: any;
        };
    };
}
export declare namespace ProfileSummary {
    function getJsonObj(obj: ProfileSummary): object;
    function getDeserializedJsonObj(obj: ProfileSummary): object;
}
