/**
 * Data Safe API
 * APIs for using Oracle Data Safe.
 * OpenAPI spec version: 20181201
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * Description of report definition.
 */
export interface ReportDefinition {
    /**
     * Name of the report definition.
     */
    "displayName": string;
    /**
     * The OCID of the report definition.
     */
    "id": string;
    /**
     * The OCID of the parent report definition. In the case of seeded report definition, this is same as definition OCID.
     */
    "parentId"?: string;
    /**
     * Specifies the name of the category that this report belongs to.
     */
    "category"?: ReportDefinition.Category;
    /**
     * A description of the report definition.
     */
    "description"?: string;
    /**
     * Specifies the name of a resource that provides data for the report. For example alerts, events.
     */
    "dataSource"?: model.ReportDefinitionDataSource;
    /**
     * Signifies whether the definition is seeded or user defined. Values can either be 'true' or 'false'.
     */
    "isSeeded"?: boolean;
    /**
     * Specifies how the report definitions are ordered in the display. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "displayOrder"?: number;
    /**
     * Specifies the date and time the report definition was created.
     */
    "timeCreated"?: Date;
    /**
     * The date and time the report definition was updated.
     */
    "timeUpdated"?: Date;
    /**
     * Additional SCIM filters used to define the report.
     */
    "scimFilter"?: string;
    /**
     * An array of column objects in the order (left to right) displayed in the report. A column object stores all information about a column, including the name displayed on the UI, corresponding field name in the data source, data type of the column, and column visibility (if the column is visible to the user).
     */
    "columnInfo"?: Array<model.Column>;
    /**
     * An array of columnFilter objects. A columnFilter object stores all information about a column filter including field name, an operator, one or more expressions, if the filter is enabled, or if the filter is hidden.
     */
    "columnFilters"?: Array<model.ColumnFilter>;
    /**
     * An array of column sorting objects. Each column sorting object stores the column name to be sorted and if the sorting is in ascending order; sorting is done by the first column in the array, then by the second column in the array, etc.
     */
    "columnSortings"?: Array<model.ColumnSorting>;
    /**
     * An array of report summary objects in the order (left to right)  displayed in the report.  A  report summary object stores all information about summary of report to be displayed, including the name displayed on UI, the display order, corresponding group by and count of values, summary visibility (if the summary is visible to user).
     */
    "summary"?: Array<model.Summary>;
    /**
     * The OCID of the compartment containing the report definition.
     */
    "compartmentId": string;
    /**
     * The current state of the report.
     */
    "lifecycleState": model.ReportDefinitionLifecycleState;
    /**
      * The schedule to generate the report periodically in the specified format:
  * <version-string>;<version-specific-schedule>
  * <p>
  Allowed version strings - \"v1\"
  * v1's version specific schedule -<ss> <mm> <hh> <day-of-week> <day-of-month>
  * Each of the above fields potentially introduce constraints. A workrequest is created only
  * when clock time satisfies all the constraints. Constraints introduced:
  * 1. seconds = <ss> (So, the allowed range for <ss> is [0, 59])
  * 2. minutes = <mm> (So, the allowed range for <mm> is [0, 59])
  * 3. hours = <hh> (So, the allowed range for <hh> is [0, 23])
  * 4. <day-of-week> can be either '*' (without quotes or a number between 1(Monday) and 7(Sunday))
  * No constraint introduced when it is '*'. When not, day of week must equal the given value
  * 5. <day-of-month> can be either '*' (without quotes or a number between 1 and 28)
  * No constraint introduced when it is '*'. When not, day of month must equal the given value
  *
      */
    "schedule"?: string;
    /**
     * Specifies the format of the report ( either .xls or .pdf )
     */
    "scheduledReportMimeType"?: ReportDefinition.ScheduledReportMimeType;
    /**
     * Specifies the limit on the number of rows in the report. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "scheduledReportRowLimit"?: number;
    /**
     * The name of the report to be scheduled.
     */
    "scheduledReportName"?: string;
    /**
     * The OCID of the compartment in which the scheduled resource will be created.
     *
     */
    "scheduledReportCompartmentId"?: string;
    /**
     * The time span for the records in the report to be scheduled.
     * <period-value><period>
     * Allowed period strings - \"H\",\"D\",\"M\",\"Y\"
     * Each of the above fields potentially introduce constraints. A workRequest is created only
     * when period-value satisfies all the constraints. Constraints introduced:
     * 1. period = H (The allowed range for period-value is [1, 23])
     * 2. period = D (The allowed range for period-value is [1, 30])
     * 3. period = M (The allowed range for period-value is [1, 11])
     * 4. period = Y (The minimum period-value is 1)
     *
     */
    "recordTimeSpan"?: string;
    /**
     * The list of the data protection regulations/standards used in the report that will help demonstrate compliance.
     */
    "complianceStandards"?: Array<string>;
    /**
      * Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm)
  * <p>
  Example: {@code {\"Department\": \"Finance\"}}
  *
      */
    "freeformTags"?: {
        [key: string]: string;
    };
    /**
      * Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm)
  * <p>
  Example: {@code {\"Operations\": {\"CostCenter\": \"42\"}}}
  *
      */
    "definedTags"?: {
        [key: string]: {
            [key: string]: any;
        };
    };
    /**
     * System tags for this resource. Each key is predefined and scoped to a namespace. For more information, see Resource Tags.
     * Example: {@code {\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}}
     *
     */
    "systemTags"?: {
        [key: string]: {
            [key: string]: any;
        };
    };
}
export declare namespace ReportDefinition {
    enum Category {
        CustomReports = "CUSTOM_REPORTS",
        Summary = "SUMMARY",
        ActivityAuditing = "ACTIVITY_AUDITING",
        FirewallViolations = "FIREWALL_VIOLATIONS",
        AllowedSql = "ALLOWED_SQL",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    enum ScheduledReportMimeType {
        Pdf = "PDF",
        Xls = "XLS",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    function getJsonObj(obj: ReportDefinition): object;
    function getDeserializedJsonObj(obj: ReportDefinition): object;
}
