/**
 * Data Safe API
 * APIs for using Oracle Data Safe.
 * OpenAPI spec version: 20181201
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
/**
 * A resource that tracks the differences between sensitive columns in the sensitive data model and masking columns in the masking policy
 */
export interface SdmMaskingPolicyDifference {
    /**
     * The OCID of the Sensitive data model and masking policy difference resource.
     */
    "id": string;
    /**
     * The OCID of the compartment that contains the Sensitive data model and masking policy difference resource.
     */
    "compartmentId": string;
    /**
     * The type of the SDM masking policy difference. It defines the difference scope.
     * NEW identifies new sensitive columns in the sensitive data model that are not in the masking policy.
     * DELETED identifies columns that are present in the masking policy but have been deleted from the sensitive data model.
     * MODIFIED identifies columns that are present in the sensitive data model as well as the masking policy but some of their attributes have been modified.
     * ALL covers all the above three scenarios and reports new, deleted and modified columns.
     *
     */
    "differenceType": SdmMaskingPolicyDifference.DifferenceType;
    /**
     * The display name of the SDM masking policy difference.
     */
    "displayName": string;
    /**
     * The date and time the SDM masking policy difference was created, in the format defined by [RFC3339](https://tools.ietf.org/html/rfc3339).
     *
     */
    "timeCreated": Date;
    /**
     * The date and time the SDM masking policy difference creation started, in the format defined by [RFC3339](https://tools.ietf.org/html/rfc3339).
     */
    "timeCreationStarted": Date;
    /**
     * The current state of the SDM masking policy difference.
     */
    "lifecycleState": SdmMaskingPolicyDifference.LifecycleState;
    /**
     * The OCID of the sensitive data model associated with the SDM masking policy difference.
     */
    "sensitiveDataModelId": string;
    /**
     * The OCID of the masking policy associated with the SDM masking policy difference.
     */
    "maskingPolicyId": string;
    /**
      * Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm)
  * <p>
  Example: {@code {\"Department\": \"Finance\"}}
  *
      */
    "freeformTags"?: {
        [key: string]: string;
    };
    /**
      * Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm)
  * <p>
  Example: {@code {\"Operations\": {\"CostCenter\": \"42\"}}}
  *
      */
    "definedTags"?: {
        [key: string]: {
            [key: string]: any;
        };
    };
    /**
     * System tags for this resource. Each key is predefined and scoped to a namespace. For more information, see Resource Tags.
     * Example: {@code {\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}}
     *
     */
    "systemTags"?: {
        [key: string]: {
            [key: string]: any;
        };
    };
}
export declare namespace SdmMaskingPolicyDifference {
    enum DifferenceType {
        All = "ALL",
        New = "NEW",
        Modified = "MODIFIED",
        Deleted = "DELETED",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    enum LifecycleState {
        Creating = "CREATING",
        Active = "ACTIVE",
        Updating = "UPDATING",
        Deleting = "DELETING",
        Deleted = "DELETED",
        Failed = "FAILED",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    function getJsonObj(obj: SdmMaskingPolicyDifference): object;
    function getDeserializedJsonObj(obj: SdmMaskingPolicyDifference): object;
}
