/**
 * Data Safe API
 * APIs for using Oracle Data Safe.
 * OpenAPI spec version: 20181201
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * The resource represents SQL collection for a specific database user in a target.
 * SqlCollection encapsulates the SQL commands issued in the user\u2019s database sessions, and its execution context.
 *
 */
export interface SqlCollectionSummary {
    /**
     * The OCID of the SQL collection.
     */
    "id": string;
    /**
     * The OCID of the compartment containing the SQL collection.
     */
    "compartmentId": string;
    /**
     * The display name of the SQL collection.
     */
    "displayName": string;
    /**
     * The description of the SQL collection.
     */
    "description"?: string;
    /**
     * The OCID of the target corresponding to the security policy deployment.
     */
    "targetId": string;
    /**
     * Specifies if the status of the SqlCollection. Enabled indicates that the collecting is in progress.
     */
    "status": SqlCollectionSummary.Status;
    /**
     * The database user name.
     */
    "dbUserName": string;
    /**
     * The timestamp of the most recent SqlCollection start operation, in the format defined by RFC3339.
     */
    "timeLastStarted"?: Date;
    /**
     * The timestamp of the most recent SqlCollection stop operation, in the format defined by RFC3339.
     */
    "timeLastStopped"?: Date;
    /**
     * Specifies the level of SQL that will be collected.
     * USER_ISSUED_SQL - User issued SQL statements only.
     * ALL_SQL - Includes all SQL statements including SQL statement issued inside PL/SQL units.
     *
     */
    "sqlLevel"?: SqlCollectionSummary.SqlLevel;
    /**
     * The time that the SQL collection was created, in the format defined by RFC3339.
     */
    "timeCreated": Date;
    /**
     * The last date and time the SQL collection was updated, in the format defined by RFC3339.
     */
    "timeUpdated"?: Date;
    /**
     * The current state of the SQL collection.
     */
    "lifecycleState": model.SqlCollectionLifecycleState;
    /**
     * Details about the current state of the SQL collection in Data Safe.
     */
    "lifecycleDetails"?: string;
    /**
      * Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm)
  * <p>
  Example: {@code {\"Department\": \"Finance\"}}
  *
      */
    "freeformTags"?: {
        [key: string]: string;
    };
    /**
      * Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm)
  * <p>
  Example: {@code {\"Operations\": {\"CostCenter\": \"42\"}}}
  *
      */
    "definedTags"?: {
        [key: string]: {
            [key: string]: any;
        };
    };
}
export declare namespace SqlCollectionSummary {
    enum Status {
        Enabled = "ENABLED",
        Disabled = "DISABLED",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    enum SqlLevel {
        UserIssuedSql = "USER_ISSUED_SQL",
        AllSql = "ALL_SQL",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    function getJsonObj(obj: SqlCollectionSummary): object;
    function getDeserializedJsonObj(obj: SqlCollectionSummary): object;
}
