/**
 * Data Science API
 * Use the Data Science API to organize your data science work, access data and computing resources, and build, train, deploy and manage models and model deployments. For more information, see [Data Science](https://docs.oracle.com/iaas/data-science/using/data-science.htm).

 * OpenAPI spec version: 20190101
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import common = require("oci-common");
import * as requests from "./request";
import * as model from "./model";
import * as responses from "./response";
import { DataScienceWaiter } from "./datascience-waiter";
declare const Breaker: any;
export declare enum DataScienceApiKeys {
}
/**
 * This service client uses {@link common.CircuitBreaker.DefaultConfiguration} for all the operations by default if no circuit breaker configuration is defined by the user.
 */
export declare class DataScienceClient {
    protected static serviceEndpointTemplate: string;
    protected static endpointServiceName: string;
    protected "_realmSpecificEndpointTemplateEnabled": boolean | undefined;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_waiters": DataScienceWaiter;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: typeof Breaker | null;
    protected _httpOptions: any;
    protected _bodyDuplexMode: any;
    targetService: string;
    protected _regionId: string;
    protected "_region": common.Region;
    protected _lastSetRegionOrRegionId: string;
    protected _httpClient: common.HttpClient;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    get endpoint(): string;
    /**
     * Sets the endpoint to call (ex, https://www.example.com).
     * @param endpoint The endpoint of the service.
     */
    set endpoint(endpoint: string);
    get logger(): import("oci-common/lib/log").Logger;
    /**
     * Determines whether realm specific endpoint should be used or not.
     * Set realmSpecificEndpointTemplateEnabled to "true" if the user wants to enable use of realm specific endpoint template, otherwise set it to "false"
     * @param realmSpecificEndpointTemplateEnabled flag to enable the use of realm specific endpoint template
     */
    set useRealmSpecificEndpointTemplate(realmSpecificEndpointTemplateEnabled: boolean);
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    set region(region: common.Region);
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    set regionId(regionId: string);
    /**
     * Creates a new DataScienceWaiter for resources for this service.
     *
     * @param config The waiter configuration for termination and delay strategy
     * @return The service waiters.
     */
    createWaiters(config?: common.WaiterConfiguration): DataScienceWaiter;
    /**
     * Gets the waiters available for resources for this service.
     *
     * @return The service waiters.
     */
    getWaiters(): DataScienceWaiter;
    /**
     * Shutdown the circuit breaker used by the client when it is no longer needed
     */
    shutdownCircuitBreaker(): void;
    /**
     * Close the client once it is no longer needed
     */
    close(): void;
    /**
     * Activates the model.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ActivateModelRequest
     * @return ActivateModelResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/datascience/ActivateModel.ts.html |here} to see how to use ActivateModel API.
     */
    activateModel(activateModelRequest: requests.ActivateModelRequest): Promise<responses.ActivateModelResponse>;
    /**
     * Activates the model deployment.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ActivateModelDeploymentRequest
     * @return ActivateModelDeploymentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/datascience/ActivateModelDeployment.ts.html |here} to see how to use ActivateModelDeployment API.
     */
    activateModelDeployment(activateModelDeploymentRequest: requests.ActivateModelDeploymentRequest): Promise<responses.ActivateModelDeploymentResponse>;
    /**
     * Activates the notebook session.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ActivateNotebookSessionRequest
     * @return ActivateNotebookSessionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/datascience/ActivateNotebookSession.ts.html |here} to see how to use ActivateNotebookSession API.
     */
    activateNotebookSession(activateNotebookSessionRequest: requests.ActivateNotebookSessionRequest): Promise<responses.ActivateNotebookSessionResponse>;
    /**
     * Cancels an IN_PROGRESS job run.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CancelJobRunRequest
     * @return CancelJobRunResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/datascience/CancelJobRun.ts.html |here} to see how to use CancelJobRun API.
     */
    cancelJobRun(cancelJobRunRequest: requests.CancelJobRunRequest): Promise<responses.CancelJobRunResponse>;
    /**
     * Cancel a PipelineRun.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CancelPipelineRunRequest
     * @return CancelPipelineRunResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/datascience/CancelPipelineRun.ts.html |here} to see how to use CancelPipelineRun API.
     */
    cancelPipelineRun(cancelPipelineRunRequest: requests.CancelPipelineRunRequest): Promise<responses.CancelPipelineRunResponse>;
    /**
     * Cancels a work request that has not started.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CancelWorkRequestRequest
     * @return CancelWorkRequestResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/datascience/CancelWorkRequest.ts.html |here} to see how to use CancelWorkRequest API.
     */
    cancelWorkRequest(cancelWorkRequestRequest: requests.CancelWorkRequestRequest): Promise<responses.CancelWorkRequestResponse>;
    /**
     * Moves a private endpoint into a different compartment. When provided, If-Match is checked against ETag values of the resource.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ChangeDataSciencePrivateEndpointCompartmentRequest
     * @return ChangeDataSciencePrivateEndpointCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/datascience/ChangeDataSciencePrivateEndpointCompartment.ts.html |here} to see how to use ChangeDataSciencePrivateEndpointCompartment API.
     */
    changeDataSciencePrivateEndpointCompartment(changeDataSciencePrivateEndpointCompartmentRequest: requests.ChangeDataSciencePrivateEndpointCompartmentRequest): Promise<responses.ChangeDataSciencePrivateEndpointCompartmentResponse>;
    /**
     * Changes a job's compartment
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangeJobCompartmentRequest
     * @return ChangeJobCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/datascience/ChangeJobCompartment.ts.html |here} to see how to use ChangeJobCompartment API.
     */
    changeJobCompartment(changeJobCompartmentRequest: requests.ChangeJobCompartmentRequest): Promise<responses.ChangeJobCompartmentResponse>;
    /**
     * Changes a job run's compartment
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangeJobRunCompartmentRequest
     * @return ChangeJobRunCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/datascience/ChangeJobRunCompartment.ts.html |here} to see how to use ChangeJobRunCompartment API.
     */
    changeJobRunCompartment(changeJobRunCompartmentRequest: requests.ChangeJobRunCompartmentRequest): Promise<responses.ChangeJobRunCompartmentResponse>;
    /**
     * Moves a model resource into a different compartment.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangeModelCompartmentRequest
     * @return ChangeModelCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/datascience/ChangeModelCompartment.ts.html |here} to see how to use ChangeModelCompartment API.
     */
    changeModelCompartment(changeModelCompartmentRequest: requests.ChangeModelCompartmentRequest): Promise<responses.ChangeModelCompartmentResponse>;
    /**
     * Moves a model deployment into a different compartment. When provided, If-Match is checked against ETag values of the resource.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangeModelDeploymentCompartmentRequest
     * @return ChangeModelDeploymentCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/datascience/ChangeModelDeploymentCompartment.ts.html |here} to see how to use ChangeModelDeploymentCompartment API.
     */
    changeModelDeploymentCompartment(changeModelDeploymentCompartmentRequest: requests.ChangeModelDeploymentCompartmentRequest): Promise<responses.ChangeModelDeploymentCompartmentResponse>;
    /**
     * Moves a modelVersionSet resource into a different compartment.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangeModelVersionSetCompartmentRequest
     * @return ChangeModelVersionSetCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/datascience/ChangeModelVersionSetCompartment.ts.html |here} to see how to use ChangeModelVersionSetCompartment API.
     */
    changeModelVersionSetCompartment(changeModelVersionSetCompartmentRequest: requests.ChangeModelVersionSetCompartmentRequest): Promise<responses.ChangeModelVersionSetCompartmentResponse>;
    /**
     * Moves a notebook session resource into a different compartment.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangeNotebookSessionCompartmentRequest
     * @return ChangeNotebookSessionCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/datascience/ChangeNotebookSessionCompartment.ts.html |here} to see how to use ChangeNotebookSessionCompartment API.
     */
    changeNotebookSessionCompartment(changeNotebookSessionCompartmentRequest: requests.ChangeNotebookSessionCompartmentRequest): Promise<responses.ChangeNotebookSessionCompartmentResponse>;
    /**
     * Moves a resource into a different compartment. When provided, If-Match is checked against ETag values of the resource.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangePipelineCompartmentRequest
     * @return ChangePipelineCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/datascience/ChangePipelineCompartment.ts.html |here} to see how to use ChangePipelineCompartment API.
     */
    changePipelineCompartment(changePipelineCompartmentRequest: requests.ChangePipelineCompartmentRequest): Promise<responses.ChangePipelineCompartmentResponse>;
    /**
     * Moves a resource into a different compartment. When provided, If-Match is checked against ETag values of the resource.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangePipelineRunCompartmentRequest
     * @return ChangePipelineRunCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/datascience/ChangePipelineRunCompartment.ts.html |here} to see how to use ChangePipelineRunCompartment API.
     */
    changePipelineRunCompartment(changePipelineRunCompartmentRequest: requests.ChangePipelineRunCompartmentRequest): Promise<responses.ChangePipelineRunCompartmentResponse>;
    /**
     * Moves a project resource into a different compartment.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangeProjectCompartmentRequest
     * @return ChangeProjectCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/datascience/ChangeProjectCompartment.ts.html |here} to see how to use ChangeProjectCompartment API.
     */
    changeProjectCompartment(changeProjectCompartmentRequest: requests.ChangeProjectCompartmentRequest): Promise<responses.ChangeProjectCompartmentResponse>;
    /**
     * Creates a Data Science private endpoint to be used by a Data Science resource.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateDataSciencePrivateEndpointRequest
     * @return CreateDataSciencePrivateEndpointResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/datascience/CreateDataSciencePrivateEndpoint.ts.html |here} to see how to use CreateDataSciencePrivateEndpoint API.
     */
    createDataSciencePrivateEndpoint(createDataSciencePrivateEndpointRequest: requests.CreateDataSciencePrivateEndpointRequest): Promise<responses.CreateDataSciencePrivateEndpointResponse>;
    /**
     * Creates a job.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateJobRequest
     * @return CreateJobResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/datascience/CreateJob.ts.html |here} to see how to use CreateJob API.
     */
    createJob(createJobRequest: requests.CreateJobRequest): Promise<responses.CreateJobResponse>;
    /**
     * Uploads a job artifact.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateJobArtifactRequest
     * @return CreateJobArtifactResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/datascience/CreateJobArtifact.ts.html |here} to see how to use CreateJobArtifact API.
     */
    createJobArtifact(createJobArtifactRequest: requests.CreateJobArtifactRequest): Promise<responses.CreateJobArtifactResponse>;
    /**
     * Creates a job run.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateJobRunRequest
     * @return CreateJobRunResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/datascience/CreateJobRun.ts.html |here} to see how to use CreateJobRun API.
     */
    createJobRun(createJobRunRequest: requests.CreateJobRunRequest): Promise<responses.CreateJobRunResponse>;
    /**
     * Creates a new model.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateModelRequest
     * @return CreateModelResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/datascience/CreateModel.ts.html |here} to see how to use CreateModel API.
     */
    createModel(createModelRequest: requests.CreateModelRequest): Promise<responses.CreateModelResponse>;
    /**
     * Creates model artifact for specified model.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateModelArtifactRequest
     * @return CreateModelArtifactResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/datascience/CreateModelArtifact.ts.html |here} to see how to use CreateModelArtifact API.
     */
    createModelArtifact(createModelArtifactRequest: requests.CreateModelArtifactRequest): Promise<responses.CreateModelArtifactResponse>;
    /**
     * Creates a new model deployment.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateModelDeploymentRequest
     * @return CreateModelDeploymentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/datascience/CreateModelDeployment.ts.html |here} to see how to use CreateModelDeployment API.
     */
    createModelDeployment(createModelDeploymentRequest: requests.CreateModelDeploymentRequest): Promise<responses.CreateModelDeploymentResponse>;
    /**
     * Creates provenance information for the specified model.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateModelProvenanceRequest
     * @return CreateModelProvenanceResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/datascience/CreateModelProvenance.ts.html |here} to see how to use CreateModelProvenance API.
     */
    createModelProvenance(createModelProvenanceRequest: requests.CreateModelProvenanceRequest): Promise<responses.CreateModelProvenanceResponse>;
    /**
     * Creates a new modelVersionSet.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateModelVersionSetRequest
     * @return CreateModelVersionSetResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/datascience/CreateModelVersionSet.ts.html |here} to see how to use CreateModelVersionSet API.
     */
    createModelVersionSet(createModelVersionSetRequest: requests.CreateModelVersionSetRequest): Promise<responses.CreateModelVersionSetResponse>;
    /**
     * Creates a new notebook session.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateNotebookSessionRequest
     * @return CreateNotebookSessionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/datascience/CreateNotebookSession.ts.html |here} to see how to use CreateNotebookSession API.
     */
    createNotebookSession(createNotebookSessionRequest: requests.CreateNotebookSessionRequest): Promise<responses.CreateNotebookSessionResponse>;
    /**
     * Creates a new Pipeline.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreatePipelineRequest
     * @return CreatePipelineResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/datascience/CreatePipeline.ts.html |here} to see how to use CreatePipeline API.
     */
    createPipeline(createPipelineRequest: requests.CreatePipelineRequest): Promise<responses.CreatePipelineResponse>;
    /**
     * Creates a new PipelineRun.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreatePipelineRunRequest
     * @return CreatePipelineRunResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/datascience/CreatePipelineRun.ts.html |here} to see how to use CreatePipelineRun API.
     */
    createPipelineRun(createPipelineRunRequest: requests.CreatePipelineRunRequest): Promise<responses.CreatePipelineRunResponse>;
    /**
     * Creates a new project.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateProjectRequest
     * @return CreateProjectResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/datascience/CreateProject.ts.html |here} to see how to use CreateProject API.
     */
    createProject(createProjectRequest: requests.CreateProjectRequest): Promise<responses.CreateProjectResponse>;
    /**
     * Upload the artifact for a step in the pipeline.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateStepArtifactRequest
     * @return CreateStepArtifactResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/datascience/CreateStepArtifact.ts.html |here} to see how to use CreateStepArtifact API.
     */
    createStepArtifact(createStepArtifactRequest: requests.CreateStepArtifactRequest): Promise<responses.CreateStepArtifactResponse>;
    /**
     * Deactivates the model.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeactivateModelRequest
     * @return DeactivateModelResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/datascience/DeactivateModel.ts.html |here} to see how to use DeactivateModel API.
     */
    deactivateModel(deactivateModelRequest: requests.DeactivateModelRequest): Promise<responses.DeactivateModelResponse>;
    /**
     * Deactivates the model deployment.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeactivateModelDeploymentRequest
     * @return DeactivateModelDeploymentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/datascience/DeactivateModelDeployment.ts.html |here} to see how to use DeactivateModelDeployment API.
     */
    deactivateModelDeployment(deactivateModelDeploymentRequest: requests.DeactivateModelDeploymentRequest): Promise<responses.DeactivateModelDeploymentResponse>;
    /**
     * Deactivates the notebook session.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeactivateNotebookSessionRequest
     * @return DeactivateNotebookSessionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/datascience/DeactivateNotebookSession.ts.html |here} to see how to use DeactivateNotebookSession API.
     */
    deactivateNotebookSession(deactivateNotebookSessionRequest: requests.DeactivateNotebookSessionRequest): Promise<responses.DeactivateNotebookSessionResponse>;
    /**
     * Deletes a private endpoint using `privateEndpointId`.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteDataSciencePrivateEndpointRequest
     * @return DeleteDataSciencePrivateEndpointResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/datascience/DeleteDataSciencePrivateEndpoint.ts.html |here} to see how to use DeleteDataSciencePrivateEndpoint API.
     */
    deleteDataSciencePrivateEndpoint(deleteDataSciencePrivateEndpointRequest: requests.DeleteDataSciencePrivateEndpointRequest): Promise<responses.DeleteDataSciencePrivateEndpointResponse>;
    /**
     * Deletes a job.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteJobRequest
     * @return DeleteJobResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/datascience/DeleteJob.ts.html |here} to see how to use DeleteJob API.
     */
    deleteJob(deleteJobRequest: requests.DeleteJobRequest): Promise<responses.DeleteJobResponse>;
    /**
     * Deletes a job run.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteJobRunRequest
     * @return DeleteJobRunResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/datascience/DeleteJobRun.ts.html |here} to see how to use DeleteJobRun API.
     */
    deleteJobRun(deleteJobRunRequest: requests.DeleteJobRunRequest): Promise<responses.DeleteJobRunResponse>;
    /**
     * Deletes the specified model.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteModelRequest
     * @return DeleteModelResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/datascience/DeleteModel.ts.html |here} to see how to use DeleteModel API.
     */
    deleteModel(deleteModelRequest: requests.DeleteModelRequest): Promise<responses.DeleteModelResponse>;
    /**
     * Deletes the specified model deployment. Any unsaved work in this model deployment is lost.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteModelDeploymentRequest
     * @return DeleteModelDeploymentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/datascience/DeleteModelDeployment.ts.html |here} to see how to use DeleteModelDeployment API.
     */
    deleteModelDeployment(deleteModelDeploymentRequest: requests.DeleteModelDeploymentRequest): Promise<responses.DeleteModelDeploymentResponse>;
    /**
     * Deletes the specified modelVersionSet.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteModelVersionSetRequest
     * @return DeleteModelVersionSetResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/datascience/DeleteModelVersionSet.ts.html |here} to see how to use DeleteModelVersionSet API.
     */
    deleteModelVersionSet(deleteModelVersionSetRequest: requests.DeleteModelVersionSetRequest): Promise<responses.DeleteModelVersionSetResponse>;
    /**
     * Deletes the specified notebook session. Any unsaved work in this notebook session are lost.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteNotebookSessionRequest
     * @return DeleteNotebookSessionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/datascience/DeleteNotebookSession.ts.html |here} to see how to use DeleteNotebookSession API.
     */
    deleteNotebookSession(deleteNotebookSessionRequest: requests.DeleteNotebookSessionRequest): Promise<responses.DeleteNotebookSessionResponse>;
    /**
     * Deletes a Pipeline resource by identifier.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeletePipelineRequest
     * @return DeletePipelineResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/datascience/DeletePipeline.ts.html |here} to see how to use DeletePipeline API.
     */
    deletePipeline(deletePipelineRequest: requests.DeletePipelineRequest): Promise<responses.DeletePipelineResponse>;
    /**
     * Deletes a PipelineRun resource by identifier.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeletePipelineRunRequest
     * @return DeletePipelineRunResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/datascience/DeletePipelineRun.ts.html |here} to see how to use DeletePipelineRun API.
     */
    deletePipelineRun(deletePipelineRunRequest: requests.DeletePipelineRunRequest): Promise<responses.DeletePipelineRunResponse>;
    /**
     * Deletes the specified project. This operation fails unless all associated resources (notebook sessions or models) are in a DELETED state. You must delete all associated resources before deleting a project.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteProjectRequest
     * @return DeleteProjectResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/datascience/DeleteProject.ts.html |here} to see how to use DeleteProject API.
     */
    deleteProject(deleteProjectRequest: requests.DeleteProjectRequest): Promise<responses.DeleteProjectResponse>;
    /**
     * Export model artifact from source to the service bucket
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ExportModelArtifactRequest
     * @return ExportModelArtifactResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/datascience/ExportModelArtifact.ts.html |here} to see how to use ExportModelArtifact API.
     */
    exportModelArtifact(exportModelArtifactRequest: requests.ExportModelArtifactRequest): Promise<responses.ExportModelArtifactResponse>;
    /**
     * Retrieves an private endpoint using a `privateEndpointId`.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetDataSciencePrivateEndpointRequest
     * @return GetDataSciencePrivateEndpointResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/datascience/GetDataSciencePrivateEndpoint.ts.html |here} to see how to use GetDataSciencePrivateEndpoint API.
     */
    getDataSciencePrivateEndpoint(getDataSciencePrivateEndpointRequest: requests.GetDataSciencePrivateEndpointRequest): Promise<responses.GetDataSciencePrivateEndpointResponse>;
    /**
     * Gets a job.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetJobRequest
     * @return GetJobResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/datascience/GetJob.ts.html |here} to see how to use GetJob API.
     */
    getJob(getJobRequest: requests.GetJobRequest): Promise<responses.GetJobResponse>;
    /**
     * Downloads job artifact content for specified job.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetJobArtifactContentRequest
     * @return GetJobArtifactContentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/datascience/GetJobArtifactContent.ts.html |here} to see how to use GetJobArtifactContent API.
     */
    getJobArtifactContent(getJobArtifactContentRequest: requests.GetJobArtifactContentRequest): Promise<responses.GetJobArtifactContentResponse>;
    /**
     * Gets a job run.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetJobRunRequest
     * @return GetJobRunResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/datascience/GetJobRun.ts.html |here} to see how to use GetJobRun API.
     */
    getJobRun(getJobRunRequest: requests.GetJobRunRequest): Promise<responses.GetJobRunResponse>;
    /**
     * Gets the specified model's information.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetModelRequest
     * @return GetModelResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/datascience/GetModel.ts.html |here} to see how to use GetModel API.
     */
    getModel(getModelRequest: requests.GetModelRequest): Promise<responses.GetModelResponse>;
    /**
     * Downloads model artifact content for specified model.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetModelArtifactContentRequest
     * @return GetModelArtifactContentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/datascience/GetModelArtifactContent.ts.html |here} to see how to use GetModelArtifactContent API.
     */
    getModelArtifactContent(getModelArtifactContentRequest: requests.GetModelArtifactContentRequest): Promise<responses.GetModelArtifactContentResponse>;
    /**
     * Retrieves the model deployment for the specified `modelDeploymentId`.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetModelDeploymentRequest
     * @return GetModelDeploymentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/datascience/GetModelDeployment.ts.html |here} to see how to use GetModelDeployment API.
     */
    getModelDeployment(getModelDeploymentRequest: requests.GetModelDeploymentRequest): Promise<responses.GetModelDeploymentResponse>;
    /**
     * Gets provenance information for specified model.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetModelProvenanceRequest
     * @return GetModelProvenanceResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/datascience/GetModelProvenance.ts.html |here} to see how to use GetModelProvenance API.
     */
    getModelProvenance(getModelProvenanceRequest: requests.GetModelProvenanceRequest): Promise<responses.GetModelProvenanceResponse>;
    /**
     * Gets the specified model version set information.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetModelVersionSetRequest
     * @return GetModelVersionSetResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/datascience/GetModelVersionSet.ts.html |here} to see how to use GetModelVersionSet API.
     */
    getModelVersionSet(getModelVersionSetRequest: requests.GetModelVersionSetRequest): Promise<responses.GetModelVersionSetResponse>;
    /**
     * Gets the specified notebook session's information.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetNotebookSessionRequest
     * @return GetNotebookSessionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/datascience/GetNotebookSession.ts.html |here} to see how to use GetNotebookSession API.
     */
    getNotebookSession(getNotebookSessionRequest: requests.GetNotebookSessionRequest): Promise<responses.GetNotebookSessionResponse>;
    /**
     * Gets a Pipeline by identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetPipelineRequest
     * @return GetPipelineResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/datascience/GetPipeline.ts.html |here} to see how to use GetPipeline API.
     */
    getPipeline(getPipelineRequest: requests.GetPipelineRequest): Promise<responses.GetPipelineResponse>;
    /**
     * Gets a PipelineRun by identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetPipelineRunRequest
     * @return GetPipelineRunResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/datascience/GetPipelineRun.ts.html |here} to see how to use GetPipelineRun API.
     */
    getPipelineRun(getPipelineRunRequest: requests.GetPipelineRunRequest): Promise<responses.GetPipelineRunResponse>;
    /**
     * Gets the specified project's information.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetProjectRequest
     * @return GetProjectResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/datascience/GetProject.ts.html |here} to see how to use GetProject API.
     */
    getProject(getProjectRequest: requests.GetProjectRequest): Promise<responses.GetProjectResponse>;
    /**
     * Download the artifact for a step in the pipeline.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetStepArtifactContentRequest
     * @return GetStepArtifactContentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/datascience/GetStepArtifactContent.ts.html |here} to see how to use GetStepArtifactContent API.
     */
    getStepArtifactContent(getStepArtifactContentRequest: requests.GetStepArtifactContentRequest): Promise<responses.GetStepArtifactContentResponse>;
    /**
     * Gets the specified work request's information.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetWorkRequestRequest
     * @return GetWorkRequestResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/datascience/GetWorkRequest.ts.html |here} to see how to use GetWorkRequest API.
     */
    getWorkRequest(getWorkRequestRequest: requests.GetWorkRequestRequest): Promise<responses.GetWorkRequestResponse>;
    /**
     * Gets job artifact metadata.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param HeadJobArtifactRequest
     * @return HeadJobArtifactResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/datascience/HeadJobArtifact.ts.html |here} to see how to use HeadJobArtifact API.
     */
    headJobArtifact(headJobArtifactRequest: requests.HeadJobArtifactRequest): Promise<responses.HeadJobArtifactResponse>;
    /**
     * Gets model artifact metadata for specified model.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param HeadModelArtifactRequest
     * @return HeadModelArtifactResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/datascience/HeadModelArtifact.ts.html |here} to see how to use HeadModelArtifact API.
     */
    headModelArtifact(headModelArtifactRequest: requests.HeadModelArtifactRequest): Promise<responses.HeadModelArtifactResponse>;
    /**
     * Get the artifact metadata for a step in the pipeline.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param HeadStepArtifactRequest
     * @return HeadStepArtifactResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/datascience/HeadStepArtifact.ts.html |here} to see how to use HeadStepArtifact API.
     */
    headStepArtifact(headStepArtifactRequest: requests.HeadStepArtifactRequest): Promise<responses.HeadStepArtifactResponse>;
    /**
     * Import model artifact from service bucket
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ImportModelArtifactRequest
     * @return ImportModelArtifactResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/datascience/ImportModelArtifact.ts.html |here} to see how to use ImportModelArtifact API.
     */
    importModelArtifact(importModelArtifactRequest: requests.ImportModelArtifactRequest): Promise<responses.ImportModelArtifactResponse>;
    /**
     * Lists all Data Science private endpoints in the specified compartment. The query must include compartmentId. The query can also include one other parameter. If the query doesn't include compartmentId, or includes compartmentId with two or more other parameters, then an error is returned.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListDataSciencePrivateEndpointsRequest
     * @return ListDataSciencePrivateEndpointsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/datascience/ListDataSciencePrivateEndpoints.ts.html |here} to see how to use ListDataSciencePrivateEndpoints API.
     */
    listDataSciencePrivateEndpoints(listDataSciencePrivateEndpointsRequest: requests.ListDataSciencePrivateEndpointsRequest): Promise<responses.ListDataSciencePrivateEndpointsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listDataSciencePrivateEndpointsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.DataSciencePrivateEndpointSummary objects
     * contained in responses from the listDataSciencePrivateEndpoints operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllDataSciencePrivateEndpoints(request: requests.ListDataSciencePrivateEndpointsRequest): AsyncIterableIterator<model.DataSciencePrivateEndpointSummary>;
    /**
     * NOTE: This function is deprecated in favor of listDataSciencePrivateEndpointsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listDataSciencePrivateEndpoints operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllDataSciencePrivateEndpointsResponses(request: requests.ListDataSciencePrivateEndpointsRequest): AsyncIterableIterator<responses.ListDataSciencePrivateEndpointsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.DataSciencePrivateEndpointSummary objects
     * contained in responses from the listDataSciencePrivateEndpoints operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listDataSciencePrivateEndpointsRecordIterator(request: requests.ListDataSciencePrivateEndpointsRequest): AsyncIterableIterator<model.DataSciencePrivateEndpointSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listDataSciencePrivateEndpoints operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listDataSciencePrivateEndpointsResponseIterator(request: requests.ListDataSciencePrivateEndpointsRequest): AsyncIterableIterator<responses.ListDataSciencePrivateEndpointsResponse>;
    /**
     * List fast launch capable job configs in the specified compartment.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListFastLaunchJobConfigsRequest
     * @return ListFastLaunchJobConfigsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/datascience/ListFastLaunchJobConfigs.ts.html |here} to see how to use ListFastLaunchJobConfigs API.
     */
    listFastLaunchJobConfigs(listFastLaunchJobConfigsRequest: requests.ListFastLaunchJobConfigsRequest): Promise<responses.ListFastLaunchJobConfigsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listFastLaunchJobConfigsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.FastLaunchJobConfigSummary objects
     * contained in responses from the listFastLaunchJobConfigs operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllFastLaunchJobConfigs(request: requests.ListFastLaunchJobConfigsRequest): AsyncIterableIterator<model.FastLaunchJobConfigSummary>;
    /**
     * NOTE: This function is deprecated in favor of listFastLaunchJobConfigsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listFastLaunchJobConfigs operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllFastLaunchJobConfigsResponses(request: requests.ListFastLaunchJobConfigsRequest): AsyncIterableIterator<responses.ListFastLaunchJobConfigsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.FastLaunchJobConfigSummary objects
     * contained in responses from the listFastLaunchJobConfigs operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listFastLaunchJobConfigsRecordIterator(request: requests.ListFastLaunchJobConfigsRequest): AsyncIterableIterator<model.FastLaunchJobConfigSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listFastLaunchJobConfigs operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listFastLaunchJobConfigsResponseIterator(request: requests.ListFastLaunchJobConfigsRequest): AsyncIterableIterator<responses.ListFastLaunchJobConfigsResponse>;
    /**
     * List out job runs.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListJobRunsRequest
     * @return ListJobRunsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/datascience/ListJobRuns.ts.html |here} to see how to use ListJobRuns API.
     */
    listJobRuns(listJobRunsRequest: requests.ListJobRunsRequest): Promise<responses.ListJobRunsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listJobRunsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.JobRunSummary objects
     * contained in responses from the listJobRuns operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllJobRuns(request: requests.ListJobRunsRequest): AsyncIterableIterator<model.JobRunSummary>;
    /**
     * NOTE: This function is deprecated in favor of listJobRunsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listJobRuns operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllJobRunsResponses(request: requests.ListJobRunsRequest): AsyncIterableIterator<responses.ListJobRunsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.JobRunSummary objects
     * contained in responses from the listJobRuns operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listJobRunsRecordIterator(request: requests.ListJobRunsRequest): AsyncIterableIterator<model.JobRunSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listJobRuns operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listJobRunsResponseIterator(request: requests.ListJobRunsRequest): AsyncIterableIterator<responses.ListJobRunsResponse>;
    /**
     * List job shapes available in the specified compartment.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListJobShapesRequest
     * @return ListJobShapesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/datascience/ListJobShapes.ts.html |here} to see how to use ListJobShapes API.
     */
    listJobShapes(listJobShapesRequest: requests.ListJobShapesRequest): Promise<responses.ListJobShapesResponse>;
    /**
     * NOTE: This function is deprecated in favor of listJobShapesRecordIterator function.
     * Creates a new async iterator which will iterate over the models.JobShapeSummary objects
     * contained in responses from the listJobShapes operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllJobShapes(request: requests.ListJobShapesRequest): AsyncIterableIterator<model.JobShapeSummary>;
    /**
     * NOTE: This function is deprecated in favor of listJobShapesResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listJobShapes operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllJobShapesResponses(request: requests.ListJobShapesRequest): AsyncIterableIterator<responses.ListJobShapesResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.JobShapeSummary objects
     * contained in responses from the listJobShapes operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listJobShapesRecordIterator(request: requests.ListJobShapesRequest): AsyncIterableIterator<model.JobShapeSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listJobShapes operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listJobShapesResponseIterator(request: requests.ListJobShapesRequest): AsyncIterableIterator<responses.ListJobShapesResponse>;
    /**
     * List jobs in the specified compartment.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListJobsRequest
     * @return ListJobsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/datascience/ListJobs.ts.html |here} to see how to use ListJobs API.
     */
    listJobs(listJobsRequest: requests.ListJobsRequest): Promise<responses.ListJobsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listJobsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.JobSummary objects
     * contained in responses from the listJobs operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllJobs(request: requests.ListJobsRequest): AsyncIterableIterator<model.JobSummary>;
    /**
     * NOTE: This function is deprecated in favor of listJobsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listJobs operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllJobsResponses(request: requests.ListJobsRequest): AsyncIterableIterator<responses.ListJobsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.JobSummary objects
     * contained in responses from the listJobs operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listJobsRecordIterator(request: requests.ListJobsRequest): AsyncIterableIterator<model.JobSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listJobs operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listJobsResponseIterator(request: requests.ListJobsRequest): AsyncIterableIterator<responses.ListJobsResponse>;
    /**
     * Lists the valid model deployment shapes.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListModelDeploymentShapesRequest
     * @return ListModelDeploymentShapesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/datascience/ListModelDeploymentShapes.ts.html |here} to see how to use ListModelDeploymentShapes API.
     */
    listModelDeploymentShapes(listModelDeploymentShapesRequest: requests.ListModelDeploymentShapesRequest): Promise<responses.ListModelDeploymentShapesResponse>;
    /**
     * NOTE: This function is deprecated in favor of listModelDeploymentShapesRecordIterator function.
     * Creates a new async iterator which will iterate over the models.ModelDeploymentShapeSummary objects
     * contained in responses from the listModelDeploymentShapes operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllModelDeploymentShapes(request: requests.ListModelDeploymentShapesRequest): AsyncIterableIterator<model.ModelDeploymentShapeSummary>;
    /**
     * NOTE: This function is deprecated in favor of listModelDeploymentShapesResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listModelDeploymentShapes operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllModelDeploymentShapesResponses(request: requests.ListModelDeploymentShapesRequest): AsyncIterableIterator<responses.ListModelDeploymentShapesResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.ModelDeploymentShapeSummary objects
     * contained in responses from the listModelDeploymentShapes operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listModelDeploymentShapesRecordIterator(request: requests.ListModelDeploymentShapesRequest): AsyncIterableIterator<model.ModelDeploymentShapeSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listModelDeploymentShapes operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listModelDeploymentShapesResponseIterator(request: requests.ListModelDeploymentShapesRequest): AsyncIterableIterator<responses.ListModelDeploymentShapesResponse>;
    /**
     * Lists all model deployments in the specified compartment. Only one parameter other than compartmentId may also be included in a query. The query must include compartmentId. If the query does not include compartmentId, or includes compartmentId but two or more other parameters an error is returned.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListModelDeploymentsRequest
     * @return ListModelDeploymentsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/datascience/ListModelDeployments.ts.html |here} to see how to use ListModelDeployments API.
     */
    listModelDeployments(listModelDeploymentsRequest: requests.ListModelDeploymentsRequest): Promise<responses.ListModelDeploymentsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listModelDeploymentsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.ModelDeploymentSummary objects
     * contained in responses from the listModelDeployments operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllModelDeployments(request: requests.ListModelDeploymentsRequest): AsyncIterableIterator<model.ModelDeploymentSummary>;
    /**
     * NOTE: This function is deprecated in favor of listModelDeploymentsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listModelDeployments operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllModelDeploymentsResponses(request: requests.ListModelDeploymentsRequest): AsyncIterableIterator<responses.ListModelDeploymentsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.ModelDeploymentSummary objects
     * contained in responses from the listModelDeployments operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listModelDeploymentsRecordIterator(request: requests.ListModelDeploymentsRequest): AsyncIterableIterator<model.ModelDeploymentSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listModelDeployments operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listModelDeploymentsResponseIterator(request: requests.ListModelDeploymentsRequest): AsyncIterableIterator<responses.ListModelDeploymentsResponse>;
    /**
     * Lists model version sets in the specified compartment.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListModelVersionSetsRequest
     * @return ListModelVersionSetsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/datascience/ListModelVersionSets.ts.html |here} to see how to use ListModelVersionSets API.
     */
    listModelVersionSets(listModelVersionSetsRequest: requests.ListModelVersionSetsRequest): Promise<responses.ListModelVersionSetsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listModelVersionSetsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.ModelVersionSetSummary objects
     * contained in responses from the listModelVersionSets operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllModelVersionSets(request: requests.ListModelVersionSetsRequest): AsyncIterableIterator<model.ModelVersionSetSummary>;
    /**
     * NOTE: This function is deprecated in favor of listModelVersionSetsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listModelVersionSets operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllModelVersionSetsResponses(request: requests.ListModelVersionSetsRequest): AsyncIterableIterator<responses.ListModelVersionSetsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.ModelVersionSetSummary objects
     * contained in responses from the listModelVersionSets operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listModelVersionSetsRecordIterator(request: requests.ListModelVersionSetsRequest): AsyncIterableIterator<model.ModelVersionSetSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listModelVersionSets operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listModelVersionSetsResponseIterator(request: requests.ListModelVersionSetsRequest): AsyncIterableIterator<responses.ListModelVersionSetsResponse>;
    /**
     * Lists models in the specified compartment.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListModelsRequest
     * @return ListModelsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/datascience/ListModels.ts.html |here} to see how to use ListModels API.
     */
    listModels(listModelsRequest: requests.ListModelsRequest): Promise<responses.ListModelsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listModelsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.ModelSummary objects
     * contained in responses from the listModels operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllModels(request: requests.ListModelsRequest): AsyncIterableIterator<model.ModelSummary>;
    /**
     * NOTE: This function is deprecated in favor of listModelsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listModels operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllModelsResponses(request: requests.ListModelsRequest): AsyncIterableIterator<responses.ListModelsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.ModelSummary objects
     * contained in responses from the listModels operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listModelsRecordIterator(request: requests.ListModelsRequest): AsyncIterableIterator<model.ModelSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listModels operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listModelsResponseIterator(request: requests.ListModelsRequest): AsyncIterableIterator<responses.ListModelsResponse>;
    /**
     * Lists the valid notebook session shapes.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListNotebookSessionShapesRequest
     * @return ListNotebookSessionShapesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/datascience/ListNotebookSessionShapes.ts.html |here} to see how to use ListNotebookSessionShapes API.
     */
    listNotebookSessionShapes(listNotebookSessionShapesRequest: requests.ListNotebookSessionShapesRequest): Promise<responses.ListNotebookSessionShapesResponse>;
    /**
     * NOTE: This function is deprecated in favor of listNotebookSessionShapesRecordIterator function.
     * Creates a new async iterator which will iterate over the models.NotebookSessionShapeSummary objects
     * contained in responses from the listNotebookSessionShapes operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllNotebookSessionShapes(request: requests.ListNotebookSessionShapesRequest): AsyncIterableIterator<model.NotebookSessionShapeSummary>;
    /**
     * NOTE: This function is deprecated in favor of listNotebookSessionShapesResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listNotebookSessionShapes operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllNotebookSessionShapesResponses(request: requests.ListNotebookSessionShapesRequest): AsyncIterableIterator<responses.ListNotebookSessionShapesResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.NotebookSessionShapeSummary objects
     * contained in responses from the listNotebookSessionShapes operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listNotebookSessionShapesRecordIterator(request: requests.ListNotebookSessionShapesRequest): AsyncIterableIterator<model.NotebookSessionShapeSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listNotebookSessionShapes operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listNotebookSessionShapesResponseIterator(request: requests.ListNotebookSessionShapesRequest): AsyncIterableIterator<responses.ListNotebookSessionShapesResponse>;
    /**
     * Lists the notebook sessions in the specified compartment.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListNotebookSessionsRequest
     * @return ListNotebookSessionsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/datascience/ListNotebookSessions.ts.html |here} to see how to use ListNotebookSessions API.
     */
    listNotebookSessions(listNotebookSessionsRequest: requests.ListNotebookSessionsRequest): Promise<responses.ListNotebookSessionsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listNotebookSessionsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.NotebookSessionSummary objects
     * contained in responses from the listNotebookSessions operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllNotebookSessions(request: requests.ListNotebookSessionsRequest): AsyncIterableIterator<model.NotebookSessionSummary>;
    /**
     * NOTE: This function is deprecated in favor of listNotebookSessionsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listNotebookSessions operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllNotebookSessionsResponses(request: requests.ListNotebookSessionsRequest): AsyncIterableIterator<responses.ListNotebookSessionsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.NotebookSessionSummary objects
     * contained in responses from the listNotebookSessions operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listNotebookSessionsRecordIterator(request: requests.ListNotebookSessionsRequest): AsyncIterableIterator<model.NotebookSessionSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listNotebookSessions operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listNotebookSessionsResponseIterator(request: requests.ListNotebookSessionsRequest): AsyncIterableIterator<responses.ListNotebookSessionsResponse>;
    /**
     * Returns a list of PipelineRuns.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListPipelineRunsRequest
     * @return ListPipelineRunsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/datascience/ListPipelineRuns.ts.html |here} to see how to use ListPipelineRuns API.
     */
    listPipelineRuns(listPipelineRunsRequest: requests.ListPipelineRunsRequest): Promise<responses.ListPipelineRunsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listPipelineRunsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.PipelineRunSummary objects
     * contained in responses from the listPipelineRuns operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllPipelineRuns(request: requests.ListPipelineRunsRequest): AsyncIterableIterator<model.PipelineRunSummary>;
    /**
     * NOTE: This function is deprecated in favor of listPipelineRunsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listPipelineRuns operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllPipelineRunsResponses(request: requests.ListPipelineRunsRequest): AsyncIterableIterator<responses.ListPipelineRunsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.PipelineRunSummary objects
     * contained in responses from the listPipelineRuns operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listPipelineRunsRecordIterator(request: requests.ListPipelineRunsRequest): AsyncIterableIterator<model.PipelineRunSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listPipelineRuns operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listPipelineRunsResponseIterator(request: requests.ListPipelineRunsRequest): AsyncIterableIterator<responses.ListPipelineRunsResponse>;
    /**
     * Returns a list of Pipelines.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListPipelinesRequest
     * @return ListPipelinesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/datascience/ListPipelines.ts.html |here} to see how to use ListPipelines API.
     */
    listPipelines(listPipelinesRequest: requests.ListPipelinesRequest): Promise<responses.ListPipelinesResponse>;
    /**
     * NOTE: This function is deprecated in favor of listPipelinesRecordIterator function.
     * Creates a new async iterator which will iterate over the models.PipelineSummary objects
     * contained in responses from the listPipelines operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllPipelines(request: requests.ListPipelinesRequest): AsyncIterableIterator<model.PipelineSummary>;
    /**
     * NOTE: This function is deprecated in favor of listPipelinesResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listPipelines operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllPipelinesResponses(request: requests.ListPipelinesRequest): AsyncIterableIterator<responses.ListPipelinesResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.PipelineSummary objects
     * contained in responses from the listPipelines operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listPipelinesRecordIterator(request: requests.ListPipelinesRequest): AsyncIterableIterator<model.PipelineSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listPipelines operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listPipelinesResponseIterator(request: requests.ListPipelinesRequest): AsyncIterableIterator<responses.ListPipelinesResponse>;
    /**
     * Lists projects in the specified compartment.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListProjectsRequest
     * @return ListProjectsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/datascience/ListProjects.ts.html |here} to see how to use ListProjects API.
     */
    listProjects(listProjectsRequest: requests.ListProjectsRequest): Promise<responses.ListProjectsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listProjectsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.ProjectSummary objects
     * contained in responses from the listProjects operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllProjects(request: requests.ListProjectsRequest): AsyncIterableIterator<model.ProjectSummary>;
    /**
     * NOTE: This function is deprecated in favor of listProjectsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listProjects operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllProjectsResponses(request: requests.ListProjectsRequest): AsyncIterableIterator<responses.ListProjectsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.ProjectSummary objects
     * contained in responses from the listProjects operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listProjectsRecordIterator(request: requests.ListProjectsRequest): AsyncIterableIterator<model.ProjectSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listProjects operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listProjectsResponseIterator(request: requests.ListProjectsRequest): AsyncIterableIterator<responses.ListProjectsResponse>;
    /**
     * Lists work request errors for the specified work request.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListWorkRequestErrorsRequest
     * @return ListWorkRequestErrorsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/datascience/ListWorkRequestErrors.ts.html |here} to see how to use ListWorkRequestErrors API.
     */
    listWorkRequestErrors(listWorkRequestErrorsRequest: requests.ListWorkRequestErrorsRequest): Promise<responses.ListWorkRequestErrorsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listWorkRequestErrorsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.WorkRequestError objects
     * contained in responses from the listWorkRequestErrors operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllWorkRequestErrors(request: requests.ListWorkRequestErrorsRequest): AsyncIterableIterator<model.WorkRequestError>;
    /**
     * NOTE: This function is deprecated in favor of listWorkRequestErrorsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listWorkRequestErrors operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllWorkRequestErrorsResponses(request: requests.ListWorkRequestErrorsRequest): AsyncIterableIterator<responses.ListWorkRequestErrorsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.WorkRequestError objects
     * contained in responses from the listWorkRequestErrors operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listWorkRequestErrorsRecordIterator(request: requests.ListWorkRequestErrorsRequest): AsyncIterableIterator<model.WorkRequestError>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listWorkRequestErrors operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listWorkRequestErrorsResponseIterator(request: requests.ListWorkRequestErrorsRequest): AsyncIterableIterator<responses.ListWorkRequestErrorsResponse>;
    /**
     * Lists work request logs for the specified work request.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListWorkRequestLogsRequest
     * @return ListWorkRequestLogsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/datascience/ListWorkRequestLogs.ts.html |here} to see how to use ListWorkRequestLogs API.
     */
    listWorkRequestLogs(listWorkRequestLogsRequest: requests.ListWorkRequestLogsRequest): Promise<responses.ListWorkRequestLogsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listWorkRequestLogsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.WorkRequestLogEntry objects
     * contained in responses from the listWorkRequestLogs operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllWorkRequestLogs(request: requests.ListWorkRequestLogsRequest): AsyncIterableIterator<model.WorkRequestLogEntry>;
    /**
     * NOTE: This function is deprecated in favor of listWorkRequestLogsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listWorkRequestLogs operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllWorkRequestLogsResponses(request: requests.ListWorkRequestLogsRequest): AsyncIterableIterator<responses.ListWorkRequestLogsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.WorkRequestLogEntry objects
     * contained in responses from the listWorkRequestLogs operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listWorkRequestLogsRecordIterator(request: requests.ListWorkRequestLogsRequest): AsyncIterableIterator<model.WorkRequestLogEntry>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listWorkRequestLogs operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listWorkRequestLogsResponseIterator(request: requests.ListWorkRequestLogsRequest): AsyncIterableIterator<responses.ListWorkRequestLogsResponse>;
    /**
     * Lists work requests in the specified compartment.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListWorkRequestsRequest
     * @return ListWorkRequestsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/datascience/ListWorkRequests.ts.html |here} to see how to use ListWorkRequests API.
     */
    listWorkRequests(listWorkRequestsRequest: requests.ListWorkRequestsRequest): Promise<responses.ListWorkRequestsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listWorkRequestsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.WorkRequestSummary objects
     * contained in responses from the listWorkRequests operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllWorkRequests(request: requests.ListWorkRequestsRequest): AsyncIterableIterator<model.WorkRequestSummary>;
    /**
     * NOTE: This function is deprecated in favor of listWorkRequestsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listWorkRequests operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllWorkRequestsResponses(request: requests.ListWorkRequestsRequest): AsyncIterableIterator<responses.ListWorkRequestsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.WorkRequestSummary objects
     * contained in responses from the listWorkRequests operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listWorkRequestsRecordIterator(request: requests.ListWorkRequestsRequest): AsyncIterableIterator<model.WorkRequestSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listWorkRequests operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listWorkRequestsResponseIterator(request: requests.ListWorkRequestsRequest): AsyncIterableIterator<responses.ListWorkRequestsResponse>;
    /**
     * Updates a private endpoint using a `privateEndpointId`.  If changes to a private endpoint match
     * a previously defined private endpoint, then a 409 status code is returned.  This indicates
     * that a conflict has been detected.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateDataSciencePrivateEndpointRequest
     * @return UpdateDataSciencePrivateEndpointResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/datascience/UpdateDataSciencePrivateEndpoint.ts.html |here} to see how to use UpdateDataSciencePrivateEndpoint API.
     */
    updateDataSciencePrivateEndpoint(updateDataSciencePrivateEndpointRequest: requests.UpdateDataSciencePrivateEndpointRequest): Promise<responses.UpdateDataSciencePrivateEndpointResponse>;
    /**
     * Updates a job.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateJobRequest
     * @return UpdateJobResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/datascience/UpdateJob.ts.html |here} to see how to use UpdateJob API.
     */
    updateJob(updateJobRequest: requests.UpdateJobRequest): Promise<responses.UpdateJobResponse>;
    /**
     * Updates a job run.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateJobRunRequest
     * @return UpdateJobRunResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/datascience/UpdateJobRun.ts.html |here} to see how to use UpdateJobRun API.
     */
    updateJobRun(updateJobRunRequest: requests.UpdateJobRunRequest): Promise<responses.UpdateJobRunResponse>;
    /**
     * Updates the properties of a model. You can update the `displayName`, `description`, `freeformTags`, and `definedTags` properties.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateModelRequest
     * @return UpdateModelResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/datascience/UpdateModel.ts.html |here} to see how to use UpdateModel API.
     */
    updateModel(updateModelRequest: requests.UpdateModelRequest): Promise<responses.UpdateModelResponse>;
    /**
     * Updates the properties of a model deployment. Some of the properties of `modelDeploymentConfigurationDetails` or `CategoryLogDetails` can also be updated with zero down time
     * when the model deployment's lifecycle state is ACTIVE or NEEDS_ATTENTION i.e `instanceShapeName`, `instanceCount` and `modelId`, separately `loadBalancerShape` or `CategoryLogDetails`
     * can also be updated independently. All of the fields can be updated when the deployment is in the INACTIVE lifecycle state. Changes will take effect the next time the model
     * deployment is activated.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateModelDeploymentRequest
     * @return UpdateModelDeploymentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/datascience/UpdateModelDeployment.ts.html |here} to see how to use UpdateModelDeployment API.
     */
    updateModelDeployment(updateModelDeploymentRequest: requests.UpdateModelDeploymentRequest): Promise<responses.UpdateModelDeploymentResponse>;
    /**
     * Updates the provenance information for the specified model.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateModelProvenanceRequest
     * @return UpdateModelProvenanceResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/datascience/UpdateModelProvenance.ts.html |here} to see how to use UpdateModelProvenance API.
     */
    updateModelProvenance(updateModelProvenanceRequest: requests.UpdateModelProvenanceRequest): Promise<responses.UpdateModelProvenanceResponse>;
    /**
     * Updates the properties of a model version set. User can update the `description` property.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateModelVersionSetRequest
     * @return UpdateModelVersionSetResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/datascience/UpdateModelVersionSet.ts.html |here} to see how to use UpdateModelVersionSet API.
     */
    updateModelVersionSet(updateModelVersionSetRequest: requests.UpdateModelVersionSetRequest): Promise<responses.UpdateModelVersionSetResponse>;
    /**
     * Updates the properties of a notebook session. You can update the `displayName`, `freeformTags`, and `definedTags` properties.
     * When the notebook session is in the INACTIVE lifecycle state, you can update `notebookSessionConfigurationDetails` and change `shape`, `subnetId`, and `blockStorageSizeInGBs`.
     * Changes to the `notebookSessionConfigurationDetails` take effect the next time the `ActivateNotebookSession` action is invoked on the notebook session resource.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateNotebookSessionRequest
     * @return UpdateNotebookSessionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/datascience/UpdateNotebookSession.ts.html |here} to see how to use UpdateNotebookSession API.
     */
    updateNotebookSession(updateNotebookSessionRequest: requests.UpdateNotebookSessionRequest): Promise<responses.UpdateNotebookSessionResponse>;
    /**
     * Updates the Pipeline.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdatePipelineRequest
     * @return UpdatePipelineResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/datascience/UpdatePipeline.ts.html |here} to see how to use UpdatePipeline API.
     */
    updatePipeline(updatePipelineRequest: requests.UpdatePipelineRequest): Promise<responses.UpdatePipelineResponse>;
    /**
     * Updates the PipelineRun.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdatePipelineRunRequest
     * @return UpdatePipelineRunResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/datascience/UpdatePipelineRun.ts.html |here} to see how to use UpdatePipelineRun API.
     */
    updatePipelineRun(updatePipelineRunRequest: requests.UpdatePipelineRunRequest): Promise<responses.UpdatePipelineRunResponse>;
    /**
     * Updates the properties of a project. You can update the `displayName`, `description`, `freeformTags`, and `definedTags` properties.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateProjectRequest
     * @return UpdateProjectResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/datascience/UpdateProject.ts.html |here} to see how to use UpdateProject API.
     */
    updateProject(updateProjectRequest: requests.UpdateProjectRequest): Promise<responses.UpdateProjectResponse>;
}
export {};
