/**
 * DevOps API
 * Use the DevOps API to create DevOps projects, configure code repositories,  add artifacts to deploy, build and test software applications, configure  target deployment environments, and deploy software applications.  For more information, see [DevOps](/Content/devops/using/home.htm).
 * OpenAPI spec version: 20210630
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import common = require("oci-common");
import * as requests from "./request";
import * as responses from "./response";
import { DevopsWaiter } from "./devops-waiter";
declare const Breaker: any;
export declare enum DevopsApiKeys {
}
/**
 * This service client uses {@link common.CircuitBreaker.DefaultConfiguration} for all the operations by default if no circuit breaker configuration is defined by the user.
 */
export declare class DevopsClient {
    protected static serviceEndpointTemplate: string;
    protected static endpointServiceName: string;
    protected "_realmSpecificEndpointTemplateEnabled": boolean | undefined;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_waiters": DevopsWaiter;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: typeof Breaker | null;
    protected _httpOptions: any;
    protected _bodyDuplexMode: any;
    targetService: string;
    protected _regionId: string;
    protected "_region": common.Region;
    protected _lastSetRegionOrRegionId: string;
    protected _httpClient: common.HttpClient;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    get endpoint(): string;
    /**
     * Sets the endpoint to call (ex, https://www.example.com).
     * @param endpoint The endpoint of the service.
     */
    set endpoint(endpoint: string);
    get logger(): import("oci-common/lib/log").Logger;
    /**
     * Determines whether realm specific endpoint should be used or not.
     * Set realmSpecificEndpointTemplateEnabled to "true" if the user wants to enable use of realm specific endpoint template, otherwise set it to "false"
     * @param realmSpecificEndpointTemplateEnabled flag to enable the use of realm specific endpoint template
     */
    set useRealmSpecificEndpointTemplate(realmSpecificEndpointTemplateEnabled: boolean);
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    set region(region: common.Region);
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    set regionId(regionId: string);
    /**
     * Creates a new DevopsWaiter for resources for this service.
     *
     * @param config The waiter configuration for termination and delay strategy
     * @return The service waiters.
     */
    createWaiters(config?: common.WaiterConfiguration): DevopsWaiter;
    /**
     * Gets the waiters available for resources for this service.
     *
     * @return The service waiters.
     */
    getWaiters(): DevopsWaiter;
    /**
     * Shutdown the circuit breaker used by the client when it is no longer needed
     */
    shutdownCircuitBreaker(): void;
    /**
     * Close the client once it is no longer needed
     */
    close(): void;
    /**
     * Submit stage approval.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ApproveDeploymentRequest
     * @return ApproveDeploymentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/devops/ApproveDeployment.ts.html |here} to see how to use ApproveDeployment API.
     */
    approveDeployment(approveDeploymentRequest: requests.ApproveDeploymentRequest): Promise<responses.ApproveDeploymentResponse>;
    /**
     * Cancels the build run based on the build run ID provided in the request.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CancelBuildRunRequest
     * @return CancelBuildRunResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/devops/CancelBuildRun.ts.html |here} to see how to use CancelBuildRun API.
     */
    cancelBuildRun(cancelBuildRunRequest: requests.CancelBuildRunRequest): Promise<responses.CancelBuildRunResponse>;
    /**
     * Cancels a deployment resource by identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CancelDeploymentRequest
     * @return CancelDeploymentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/devops/CancelDeployment.ts.html |here} to see how to use CancelDeployment API.
     */
    cancelDeployment(cancelDeploymentRequest: requests.CancelDeploymentRequest): Promise<responses.CancelDeploymentResponse>;
    /**
     * Cascading operation that restores Project and child resources from a DELETING state to an active state
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CancelScheduledCascadingProjectDeletionRequest
     * @return CancelScheduledCascadingProjectDeletionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/devops/CancelScheduledCascadingProjectDeletion.ts.html |here} to see how to use CancelScheduledCascadingProjectDeletion API.
     */
    cancelScheduledCascadingProjectDeletion(cancelScheduledCascadingProjectDeletionRequest: requests.CancelScheduledCascadingProjectDeletionRequest): Promise<responses.CancelScheduledCascadingProjectDeletionResponse>;
    /**
     * Moves a project resource from one compartment OCID to another.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ChangeProjectCompartmentRequest
     * @return ChangeProjectCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/devops/ChangeProjectCompartment.ts.html |here} to see how to use ChangeProjectCompartment API.
     */
    changeProjectCompartment(changeProjectCompartmentRequest: requests.ChangeProjectCompartmentRequest): Promise<responses.ChangeProjectCompartmentResponse>;
    /**
     * Creates a new build pipeline.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateBuildPipelineRequest
     * @return CreateBuildPipelineResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/devops/CreateBuildPipeline.ts.html |here} to see how to use CreateBuildPipeline API.
     */
    createBuildPipeline(createBuildPipelineRequest: requests.CreateBuildPipelineRequest): Promise<responses.CreateBuildPipelineResponse>;
    /**
     * Creates a new stage.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateBuildPipelineStageRequest
     * @return CreateBuildPipelineStageResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/devops/CreateBuildPipelineStage.ts.html |here} to see how to use CreateBuildPipelineStage API.
     */
    createBuildPipelineStage(createBuildPipelineStageRequest: requests.CreateBuildPipelineStageRequest): Promise<responses.CreateBuildPipelineStageResponse>;
    /**
     * Starts a build pipeline run for a predefined build pipeline. Please ensure the completion of any work request for creation/updation of Build Pipeline before starting a Build Run.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateBuildRunRequest
     * @return CreateBuildRunResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/devops/CreateBuildRun.ts.html |here} to see how to use CreateBuildRun API.
     */
    createBuildRun(createBuildRunRequest: requests.CreateBuildRunRequest): Promise<responses.CreateBuildRunResponse>;
    /**
     * Creates a new connection.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateConnectionRequest
     * @return CreateConnectionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/devops/CreateConnection.ts.html |here} to see how to use CreateConnection API.
     */
    createConnection(createConnectionRequest: requests.CreateConnectionRequest): Promise<responses.CreateConnectionResponse>;
    /**
     * Creates a new deployment artifact.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateDeployArtifactRequest
     * @return CreateDeployArtifactResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/devops/CreateDeployArtifact.ts.html |here} to see how to use CreateDeployArtifact API.
     */
    createDeployArtifact(createDeployArtifactRequest: requests.CreateDeployArtifactRequest): Promise<responses.CreateDeployArtifactResponse>;
    /**
     * Creates a new deployment environment.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateDeployEnvironmentRequest
     * @return CreateDeployEnvironmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/devops/CreateDeployEnvironment.ts.html |here} to see how to use CreateDeployEnvironment API.
     */
    createDeployEnvironment(createDeployEnvironmentRequest: requests.CreateDeployEnvironmentRequest): Promise<responses.CreateDeployEnvironmentResponse>;
    /**
     * Creates a new deployment pipeline.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateDeployPipelineRequest
     * @return CreateDeployPipelineResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/devops/CreateDeployPipeline.ts.html |here} to see how to use CreateDeployPipeline API.
     */
    createDeployPipeline(createDeployPipelineRequest: requests.CreateDeployPipelineRequest): Promise<responses.CreateDeployPipelineResponse>;
    /**
     * Creates a new deployment stage.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateDeployStageRequest
     * @return CreateDeployStageResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/devops/CreateDeployStage.ts.html |here} to see how to use CreateDeployStage API.
     */
    createDeployStage(createDeployStageRequest: requests.CreateDeployStageRequest): Promise<responses.CreateDeployStageResponse>;
    /**
     * Creates a new deployment.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateDeploymentRequest
     * @return CreateDeploymentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/devops/CreateDeployment.ts.html |here} to see how to use CreateDeployment API.
     */
    createDeployment(createDeploymentRequest: requests.CreateDeploymentRequest): Promise<responses.CreateDeploymentResponse>;
    /**
     * Creates a new project.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateProjectRequest
     * @return CreateProjectResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/devops/CreateProject.ts.html |here} to see how to use CreateProject API.
     */
    createProject(createProjectRequest: requests.CreateProjectRequest): Promise<responses.CreateProjectResponse>;
    /**
     * Creates a new repository.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateRepositoryRequest
     * @return CreateRepositoryResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/devops/CreateRepository.ts.html |here} to see how to use CreateRepository API.
     */
    createRepository(createRepositoryRequest: requests.CreateRepositoryRequest): Promise<responses.CreateRepositoryResponse>;
    /**
     * Creates a new trigger.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateTriggerRequest
     * @return CreateTriggerResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/devops/CreateTrigger.ts.html |here} to see how to use CreateTrigger API.
     */
    createTrigger(createTriggerRequest: requests.CreateTriggerRequest): Promise<responses.CreateTriggerResponse>;
    /**
     * Deletes a build pipeline resource by identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteBuildPipelineRequest
     * @return DeleteBuildPipelineResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/devops/DeleteBuildPipeline.ts.html |here} to see how to use DeleteBuildPipeline API.
     */
    deleteBuildPipeline(deleteBuildPipelineRequest: requests.DeleteBuildPipelineRequest): Promise<responses.DeleteBuildPipelineResponse>;
    /**
     * Deletes a stage based on the stage ID provided in the request.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteBuildPipelineStageRequest
     * @return DeleteBuildPipelineStageResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/devops/DeleteBuildPipelineStage.ts.html |here} to see how to use DeleteBuildPipelineStage API.
     */
    deleteBuildPipelineStage(deleteBuildPipelineStageRequest: requests.DeleteBuildPipelineStageRequest): Promise<responses.DeleteBuildPipelineStageResponse>;
    /**
     * Deletes a connection resource by identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteConnectionRequest
     * @return DeleteConnectionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/devops/DeleteConnection.ts.html |here} to see how to use DeleteConnection API.
     */
    deleteConnection(deleteConnectionRequest: requests.DeleteConnectionRequest): Promise<responses.DeleteConnectionResponse>;
    /**
     * Deletes a deployment artifact resource by identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteDeployArtifactRequest
     * @return DeleteDeployArtifactResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/devops/DeleteDeployArtifact.ts.html |here} to see how to use DeleteDeployArtifact API.
     */
    deleteDeployArtifact(deleteDeployArtifactRequest: requests.DeleteDeployArtifactRequest): Promise<responses.DeleteDeployArtifactResponse>;
    /**
     * Deletes a deployment environment resource by identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteDeployEnvironmentRequest
     * @return DeleteDeployEnvironmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/devops/DeleteDeployEnvironment.ts.html |here} to see how to use DeleteDeployEnvironment API.
     */
    deleteDeployEnvironment(deleteDeployEnvironmentRequest: requests.DeleteDeployEnvironmentRequest): Promise<responses.DeleteDeployEnvironmentResponse>;
    /**
     * Deletes a deployment pipeline resource by identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteDeployPipelineRequest
     * @return DeleteDeployPipelineResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/devops/DeleteDeployPipeline.ts.html |here} to see how to use DeleteDeployPipeline API.
     */
    deleteDeployPipeline(deleteDeployPipelineRequest: requests.DeleteDeployPipelineRequest): Promise<responses.DeleteDeployPipelineResponse>;
    /**
     * Deletes a deployment stage resource by identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteDeployStageRequest
     * @return DeleteDeployStageResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/devops/DeleteDeployStage.ts.html |here} to see how to use DeleteDeployStage API.
     */
    deleteDeployStage(deleteDeployStageRequest: requests.DeleteDeployStageRequest): Promise<responses.DeleteDeployStageResponse>;
    /**
     * Deletes a project resource by identifier
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteProjectRequest
     * @return DeleteProjectResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/devops/DeleteProject.ts.html |here} to see how to use DeleteProject API.
     */
    deleteProject(deleteProjectRequest: requests.DeleteProjectRequest): Promise<responses.DeleteProjectResponse>;
    /**
     * Deletes a Repository's Ref by its name. Returns an error if the name is ambiguous. Can be disambiguated by using full names like \"heads/<name>\" or \"tags/<name>\". This API will be deprecated on Wed, 12 June 2024 01:00:00 GMT as it does not get recognized when refName has '/'. This will be replaced by \"/repositories/{repositoryId}/actions/deleteGitRef\".
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteRefRequest
     * @return DeleteRefResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/devops/DeleteRef.ts.html |here} to see how to use DeleteRef API.
     */
    deleteRef(deleteRefRequest: requests.DeleteRefRequest): Promise<responses.DeleteRefResponse>;
    /**
     * Deletes a repository resource by identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteRepositoryRequest
     * @return DeleteRepositoryResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/devops/DeleteRepository.ts.html |here} to see how to use DeleteRepository API.
     */
    deleteRepository(deleteRepositoryRequest: requests.DeleteRepositoryRequest): Promise<responses.DeleteRepositoryResponse>;
    /**
     * Deletes a trigger resource by identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteTriggerRequest
     * @return DeleteTriggerResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/devops/DeleteTrigger.ts.html |here} to see how to use DeleteTrigger API.
     */
    deleteTrigger(deleteTriggerRequest: requests.DeleteTriggerRequest): Promise<responses.DeleteTriggerResponse>;
    /**
     * Retrieves a build pipeline by identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetBuildPipelineRequest
     * @return GetBuildPipelineResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/devops/GetBuildPipeline.ts.html |here} to see how to use GetBuildPipeline API.
     */
    getBuildPipeline(getBuildPipelineRequest: requests.GetBuildPipelineRequest): Promise<responses.GetBuildPipelineResponse>;
    /**
     * Retrieves a stage based on the stage ID provided in the request.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetBuildPipelineStageRequest
     * @return GetBuildPipelineStageResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/devops/GetBuildPipelineStage.ts.html |here} to see how to use GetBuildPipelineStage API.
     */
    getBuildPipelineStage(getBuildPipelineStageRequest: requests.GetBuildPipelineStageRequest): Promise<responses.GetBuildPipelineStageResponse>;
    /**
     * Returns the details of a build run for a given build run ID.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetBuildRunRequest
     * @return GetBuildRunResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/devops/GetBuildRun.ts.html |here} to see how to use GetBuildRun API.
     */
    getBuildRun(getBuildRunRequest: requests.GetBuildRunRequest): Promise<responses.GetBuildRunResponse>;
    /**
     * Retrieves a repository's commit by commit ID.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetCommitRequest
     * @return GetCommitResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/devops/GetCommit.ts.html |here} to see how to use GetCommit API.
     */
    getCommit(getCommitRequest: requests.GetCommitRequest): Promise<responses.GetCommitResponse>;
    /**
     * Compares two revisions for their differences. Supports comparison between two references or commits.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetCommitDiffRequest
     * @return GetCommitDiffResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/devops/GetCommitDiff.ts.html |here} to see how to use GetCommitDiff API.
     */
    getCommitDiff(getCommitDiffRequest: requests.GetCommitDiffRequest): Promise<responses.GetCommitDiffResponse>;
    /**
     * Retrieves a connection by identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetConnectionRequest
     * @return GetConnectionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/devops/GetConnection.ts.html |here} to see how to use GetConnection API.
     */
    getConnection(getConnectionRequest: requests.GetConnectionRequest): Promise<responses.GetConnectionResponse>;
    /**
     * Retrieves a deployment artifact by identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetDeployArtifactRequest
     * @return GetDeployArtifactResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/devops/GetDeployArtifact.ts.html |here} to see how to use GetDeployArtifact API.
     */
    getDeployArtifact(getDeployArtifactRequest: requests.GetDeployArtifactRequest): Promise<responses.GetDeployArtifactResponse>;
    /**
     * Retrieves a deployment environment by identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetDeployEnvironmentRequest
     * @return GetDeployEnvironmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/devops/GetDeployEnvironment.ts.html |here} to see how to use GetDeployEnvironment API.
     */
    getDeployEnvironment(getDeployEnvironmentRequest: requests.GetDeployEnvironmentRequest): Promise<responses.GetDeployEnvironmentResponse>;
    /**
     * Retrieves a deployment pipeline by identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetDeployPipelineRequest
     * @return GetDeployPipelineResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/devops/GetDeployPipeline.ts.html |here} to see how to use GetDeployPipeline API.
     */
    getDeployPipeline(getDeployPipelineRequest: requests.GetDeployPipelineRequest): Promise<responses.GetDeployPipelineResponse>;
    /**
     * Retrieves a deployment stage by identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetDeployStageRequest
     * @return GetDeployStageResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/devops/GetDeployStage.ts.html |here} to see how to use GetDeployStage API.
     */
    getDeployStage(getDeployStageRequest: requests.GetDeployStageRequest): Promise<responses.GetDeployStageResponse>;
    /**
     * Retrieves a deployment by identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetDeploymentRequest
     * @return GetDeploymentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/devops/GetDeployment.ts.html |here} to see how to use GetDeployment API.
     */
    getDeployment(getDeploymentRequest: requests.GetDeploymentRequest): Promise<responses.GetDeploymentResponse>;
    /**
     * Gets the line-by-line difference between file on different commits. This API will be deprecated on Wed, 29 Mar 2023 01:00:00 GMT as it does not get recognized when filePath has '/'. This will be replaced by \"/repositories/{repositoryId}/file/diffs\"
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetFileDiffRequest
     * @return GetFileDiffResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/devops/GetFileDiff.ts.html |here} to see how to use GetFileDiff API.
     */
    getFileDiff(getFileDiffRequest: requests.GetFileDiffRequest): Promise<responses.GetFileDiffResponse>;
    /**
     * Returns either current mirror record or last successful mirror record for a specific mirror repository.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetMirrorRecordRequest
     * @return GetMirrorRecordResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/devops/GetMirrorRecord.ts.html |here} to see how to use GetMirrorRecord API.
     */
    getMirrorRecord(getMirrorRecordRequest: requests.GetMirrorRecordRequest): Promise<responses.GetMirrorRecordResponse>;
    /**
     * Retrieves blob of specific branch name/commit ID and file path.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetObjectRequest
     * @return GetObjectResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/devops/GetObject.ts.html |here} to see how to use GetObject API.
     */
    getObject(getObjectRequest: requests.GetObjectRequest): Promise<responses.GetObjectResponse>;
    /**
     * Retrieve contents of a specified object.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetObjectContentRequest
     * @return GetObjectContentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/devops/GetObjectContent.ts.html |here} to see how to use GetObjectContent API.
     */
    getObjectContent(getObjectContentRequest: requests.GetObjectContentRequest): Promise<responses.GetObjectContentResponse>;
    /**
     * Retrieves a project by identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetProjectRequest
     * @return GetProjectResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/devops/GetProject.ts.html |here} to see how to use GetProject API.
     */
    getProject(getProjectRequest: requests.GetProjectRequest): Promise<responses.GetProjectResponse>;
    /**
     * This API will be deprecated on Wed, 12 June 2024 01:00:00 GMT as it does not get recognized when refName has '/'. This will be replaced by \"/repositories/{repositoryId}/refs\". Retrieves a repository's reference by its name with preference for branches over tags if the name is ambiguous. This can be disambiguated by using full names like \"heads/<name>\" or \"tags/<name>\".
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetRefRequest
     * @return GetRefResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/devops/GetRef.ts.html |here} to see how to use GetRef API.
     */
    getRef(getRefRequest: requests.GetRefRequest): Promise<responses.GetRefResponse>;
    /**
     * Gets the line-by-line difference between file on different commits.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetRepoFileDiffRequest
     * @return GetRepoFileDiffResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/devops/GetRepoFileDiff.ts.html |here} to see how to use GetRepoFileDiff API.
     */
    getRepoFileDiff(getRepoFileDiffRequest: requests.GetRepoFileDiffRequest): Promise<responses.GetRepoFileDiffResponse>;
    /**
     * Retrieve lines of a specified file. Supports starting line number and limit.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetRepoFileLinesRequest
     * @return GetRepoFileLinesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/devops/GetRepoFileLines.ts.html |here} to see how to use GetRepoFileLines API.
     */
    getRepoFileLines(getRepoFileLinesRequest: requests.GetRepoFileLinesRequest): Promise<responses.GetRepoFileLinesResponse>;
    /**
     * Retrieves a repository by identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetRepositoryRequest
     * @return GetRepositoryResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/devops/GetRepository.ts.html |here} to see how to use GetRepository API.
     */
    getRepository(getRepositoryRequest: requests.GetRepositoryRequest): Promise<responses.GetRepositoryResponse>;
    /**
     * Returns the archived repository information.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetRepositoryArchiveContentRequest
     * @return GetRepositoryArchiveContentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/devops/GetRepositoryArchiveContent.ts.html |here} to see how to use GetRepositoryArchiveContent API.
     */
    getRepositoryArchiveContent(getRepositoryArchiveContentRequest: requests.GetRepositoryArchiveContentRequest): Promise<responses.GetRepositoryArchiveContentResponse>;
    /**
     * Retrieve lines of a specified file. Supports starting line number and limit. This API will be deprecated on Wed, 29 Mar 2023 01:00:00 GMT as it does not get recognized when filePath has '/'. This will be replaced by \"/repositories/{repositoryId}/file/lines\"
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetRepositoryFileLinesRequest
     * @return GetRepositoryFileLinesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/devops/GetRepositoryFileLines.ts.html |here} to see how to use GetRepositoryFileLines API.
     */
    getRepositoryFileLines(getRepositoryFileLinesRequest: requests.GetRepositoryFileLinesRequest): Promise<responses.GetRepositoryFileLinesResponse>;
    /**
     * Retrieves a trigger by identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetTriggerRequest
     * @return GetTriggerResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/devops/GetTrigger.ts.html |here} to see how to use GetTrigger API.
     */
    getTrigger(getTriggerRequest: requests.GetTriggerRequest): Promise<responses.GetTriggerResponse>;
    /**
     * Retrieves the status of the work request with the given ID.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetWorkRequestRequest
     * @return GetWorkRequestResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/devops/GetWorkRequest.ts.html |here} to see how to use GetWorkRequest API.
     */
    getWorkRequest(getWorkRequestRequest: requests.GetWorkRequestRequest): Promise<responses.GetWorkRequestResponse>;
    /**
     * Retrieve a list of all the authors.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListAuthorsRequest
     * @return ListAuthorsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/devops/ListAuthors.ts.html |here} to see how to use ListAuthors API.
     */
    listAuthors(listAuthorsRequest: requests.ListAuthorsRequest): Promise<responses.ListAuthorsResponse>;
    /**
     * Returns a list of all stages in a compartment or build pipeline.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListBuildPipelineStagesRequest
     * @return ListBuildPipelineStagesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/devops/ListBuildPipelineStages.ts.html |here} to see how to use ListBuildPipelineStages API.
     */
    listBuildPipelineStages(listBuildPipelineStagesRequest: requests.ListBuildPipelineStagesRequest): Promise<responses.ListBuildPipelineStagesResponse>;
    /**
     * Returns a list of build pipelines.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListBuildPipelinesRequest
     * @return ListBuildPipelinesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/devops/ListBuildPipelines.ts.html |here} to see how to use ListBuildPipelines API.
     */
    listBuildPipelines(listBuildPipelinesRequest: requests.ListBuildPipelinesRequest): Promise<responses.ListBuildPipelinesResponse>;
    /**
     * Returns a list of build run summary.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListBuildRunsRequest
     * @return ListBuildRunsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/devops/ListBuildRuns.ts.html |here} to see how to use ListBuildRuns API.
     */
    listBuildRuns(listBuildRunsRequest: requests.ListBuildRunsRequest): Promise<responses.ListBuildRunsResponse>;
    /**
     * Compares two revisions and lists the differences. Supports comparison between two references or commits.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListCommitDiffsRequest
     * @return ListCommitDiffsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/devops/ListCommitDiffs.ts.html |here} to see how to use ListCommitDiffs API.
     */
    listCommitDiffs(listCommitDiffsRequest: requests.ListCommitDiffsRequest): Promise<responses.ListCommitDiffsResponse>;
    /**
     * Returns a list of commits.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListCommitsRequest
     * @return ListCommitsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/devops/ListCommits.ts.html |here} to see how to use ListCommits API.
     */
    listCommits(listCommitsRequest: requests.ListCommitsRequest): Promise<responses.ListCommitsResponse>;
    /**
     * Returns a list of connections.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListConnectionsRequest
     * @return ListConnectionsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/devops/ListConnections.ts.html |here} to see how to use ListConnections API.
     */
    listConnections(listConnectionsRequest: requests.ListConnectionsRequest): Promise<responses.ListConnectionsResponse>;
    /**
     * Returns a list of deployment artifacts.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListDeployArtifactsRequest
     * @return ListDeployArtifactsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/devops/ListDeployArtifacts.ts.html |here} to see how to use ListDeployArtifacts API.
     */
    listDeployArtifacts(listDeployArtifactsRequest: requests.ListDeployArtifactsRequest): Promise<responses.ListDeployArtifactsResponse>;
    /**
     * Returns a list of deployment environments.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListDeployEnvironmentsRequest
     * @return ListDeployEnvironmentsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/devops/ListDeployEnvironments.ts.html |here} to see how to use ListDeployEnvironments API.
     */
    listDeployEnvironments(listDeployEnvironmentsRequest: requests.ListDeployEnvironmentsRequest): Promise<responses.ListDeployEnvironmentsResponse>;
    /**
     * Returns a list of deployment pipelines.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListDeployPipelinesRequest
     * @return ListDeployPipelinesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/devops/ListDeployPipelines.ts.html |here} to see how to use ListDeployPipelines API.
     */
    listDeployPipelines(listDeployPipelinesRequest: requests.ListDeployPipelinesRequest): Promise<responses.ListDeployPipelinesResponse>;
    /**
     * Retrieves a list of deployment stages.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListDeployStagesRequest
     * @return ListDeployStagesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/devops/ListDeployStages.ts.html |here} to see how to use ListDeployStages API.
     */
    listDeployStages(listDeployStagesRequest: requests.ListDeployStagesRequest): Promise<responses.ListDeployStagesResponse>;
    /**
     * Returns a list of deployments.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListDeploymentsRequest
     * @return ListDeploymentsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/devops/ListDeployments.ts.html |here} to see how to use ListDeployments API.
     */
    listDeployments(listDeploymentsRequest: requests.ListDeploymentsRequest): Promise<responses.ListDeploymentsResponse>;
    /**
     * Returns a list of mirror entry in history within 30 days.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListMirrorRecordsRequest
     * @return ListMirrorRecordsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/devops/ListMirrorRecords.ts.html |here} to see how to use ListMirrorRecords API.
     */
    listMirrorRecords(listMirrorRecordsRequest: requests.ListMirrorRecordsRequest): Promise<responses.ListMirrorRecordsResponse>;
    /**
     * Retrieves a list of files and directories in a repository.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListPathsRequest
     * @return ListPathsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/devops/ListPaths.ts.html |here} to see how to use ListPaths API.
     */
    listPaths(listPathsRequest: requests.ListPathsRequest): Promise<responses.ListPathsResponse>;
    /**
     * Returns a list of projects.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListProjectsRequest
     * @return ListProjectsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/devops/ListProjects.ts.html |here} to see how to use ListProjects API.
     */
    listProjects(listProjectsRequest: requests.ListProjectsRequest): Promise<responses.ListProjectsResponse>;
    /**
     * Returns a list of references.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListRefsRequest
     * @return ListRefsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/devops/ListRefs.ts.html |here} to see how to use ListRefs API.
     */
    listRefs(listRefsRequest: requests.ListRefsRequest): Promise<responses.ListRefsResponse>;
    /**
     * Returns a list of repositories given a compartment ID or a project ID.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListRepositoriesRequest
     * @return ListRepositoriesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/devops/ListRepositories.ts.html |here} to see how to use ListRepositories API.
     */
    listRepositories(listRepositoriesRequest: requests.ListRepositoriesRequest): Promise<responses.ListRepositoriesResponse>;
    /**
     * Returns a list of triggers.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListTriggersRequest
     * @return ListTriggersResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/devops/ListTriggers.ts.html |here} to see how to use ListTriggers API.
     */
    listTriggers(listTriggersRequest: requests.ListTriggersRequest): Promise<responses.ListTriggersResponse>;
    /**
     * Returns a list of errors for a given work request.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListWorkRequestErrorsRequest
     * @return ListWorkRequestErrorsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/devops/ListWorkRequestErrors.ts.html |here} to see how to use ListWorkRequestErrors API.
     */
    listWorkRequestErrors(listWorkRequestErrorsRequest: requests.ListWorkRequestErrorsRequest): Promise<responses.ListWorkRequestErrorsResponse>;
    /**
     * Returns a list of logs for a given work request.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListWorkRequestLogsRequest
     * @return ListWorkRequestLogsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/devops/ListWorkRequestLogs.ts.html |here} to see how to use ListWorkRequestLogs API.
     */
    listWorkRequestLogs(listWorkRequestLogsRequest: requests.ListWorkRequestLogsRequest): Promise<responses.ListWorkRequestLogsResponse>;
    /**
     * Lists the work requests in a compartment.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListWorkRequestsRequest
     * @return ListWorkRequestsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/devops/ListWorkRequests.ts.html |here} to see how to use ListWorkRequests API.
     */
    listWorkRequests(listWorkRequestsRequest: requests.ListWorkRequestsRequest): Promise<responses.ListWorkRequestsResponse>;
    /**
     * Synchronize a mirrored repository to the latest version from external providers.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param MirrorRepositoryRequest
     * @return MirrorRepositoryResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/devops/MirrorRepository.ts.html |here} to see how to use MirrorRepository API.
     */
    mirrorRepository(mirrorRepositoryRequest: requests.MirrorRepositoryRequest): Promise<responses.MirrorRepositoryResponse>;
    /**
     * Creates a new reference or updates an existing one. This API will be deprecated on Wed, 12 June 2024 01:00:00 GMT as it does not get recognized when refName has '/'. This will be replaced by \"/repositories/{repositoryId}/actions/createOrUpdateGitRef\".
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param PutRepositoryRefRequest
     * @return PutRepositoryRefResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/devops/PutRepositoryRef.ts.html |here} to see how to use PutRepositoryRef API.
     */
    putRepositoryRef(putRepositoryRefRequest: requests.PutRepositoryRefRequest): Promise<responses.PutRepositoryRefResponse>;
    /**
     * Cascading operation that marks Project and child DevOps resources in a DELETING state for a retention period
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ScheduleCascadingProjectDeletionRequest
     * @return ScheduleCascadingProjectDeletionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/devops/ScheduleCascadingProjectDeletion.ts.html |here} to see how to use ScheduleCascadingProjectDeletion API.
     */
    scheduleCascadingProjectDeletion(scheduleCascadingProjectDeletionRequest: requests.ScheduleCascadingProjectDeletionRequest): Promise<responses.ScheduleCascadingProjectDeletionResponse>;
    /**
     * Updates the build pipeline.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateBuildPipelineRequest
     * @return UpdateBuildPipelineResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/devops/UpdateBuildPipeline.ts.html |here} to see how to use UpdateBuildPipeline API.
     */
    updateBuildPipeline(updateBuildPipelineRequest: requests.UpdateBuildPipelineRequest): Promise<responses.UpdateBuildPipelineResponse>;
    /**
     * Updates the stage based on the stage ID provided in the request.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateBuildPipelineStageRequest
     * @return UpdateBuildPipelineStageResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/devops/UpdateBuildPipelineStage.ts.html |here} to see how to use UpdateBuildPipelineStage API.
     */
    updateBuildPipelineStage(updateBuildPipelineStageRequest: requests.UpdateBuildPipelineStageRequest): Promise<responses.UpdateBuildPipelineStageResponse>;
    /**
     * Updates the build run.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateBuildRunRequest
     * @return UpdateBuildRunResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/devops/UpdateBuildRun.ts.html |here} to see how to use UpdateBuildRun API.
     */
    updateBuildRun(updateBuildRunRequest: requests.UpdateBuildRunRequest): Promise<responses.UpdateBuildRunResponse>;
    /**
     * Updates the connection.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateConnectionRequest
     * @return UpdateConnectionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/devops/UpdateConnection.ts.html |here} to see how to use UpdateConnection API.
     */
    updateConnection(updateConnectionRequest: requests.UpdateConnectionRequest): Promise<responses.UpdateConnectionResponse>;
    /**
     * Updates the deployment artifact.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateDeployArtifactRequest
     * @return UpdateDeployArtifactResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/devops/UpdateDeployArtifact.ts.html |here} to see how to use UpdateDeployArtifact API.
     */
    updateDeployArtifact(updateDeployArtifactRequest: requests.UpdateDeployArtifactRequest): Promise<responses.UpdateDeployArtifactResponse>;
    /**
     * Updates the deployment environment.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateDeployEnvironmentRequest
     * @return UpdateDeployEnvironmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/devops/UpdateDeployEnvironment.ts.html |here} to see how to use UpdateDeployEnvironment API.
     */
    updateDeployEnvironment(updateDeployEnvironmentRequest: requests.UpdateDeployEnvironmentRequest): Promise<responses.UpdateDeployEnvironmentResponse>;
    /**
     * Updates the deployment pipeline.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateDeployPipelineRequest
     * @return UpdateDeployPipelineResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/devops/UpdateDeployPipeline.ts.html |here} to see how to use UpdateDeployPipeline API.
     */
    updateDeployPipeline(updateDeployPipelineRequest: requests.UpdateDeployPipelineRequest): Promise<responses.UpdateDeployPipelineResponse>;
    /**
     * Updates the deployment stage.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateDeployStageRequest
     * @return UpdateDeployStageResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/devops/UpdateDeployStage.ts.html |here} to see how to use UpdateDeployStage API.
     */
    updateDeployStage(updateDeployStageRequest: requests.UpdateDeployStageRequest): Promise<responses.UpdateDeployStageResponse>;
    /**
     * Updates the deployment.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateDeploymentRequest
     * @return UpdateDeploymentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/devops/UpdateDeployment.ts.html |here} to see how to use UpdateDeployment API.
     */
    updateDeployment(updateDeploymentRequest: requests.UpdateDeploymentRequest): Promise<responses.UpdateDeploymentResponse>;
    /**
     * Updates the project.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateProjectRequest
     * @return UpdateProjectResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/devops/UpdateProject.ts.html |here} to see how to use UpdateProject API.
     */
    updateProject(updateProjectRequest: requests.UpdateProjectRequest): Promise<responses.UpdateProjectResponse>;
    /**
     * Updates the repository.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateRepositoryRequest
     * @return UpdateRepositoryResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/devops/UpdateRepository.ts.html |here} to see how to use UpdateRepository API.
     */
    updateRepository(updateRepositoryRequest: requests.UpdateRepositoryRequest): Promise<responses.UpdateRepositoryResponse>;
    /**
     * Updates the trigger.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateTriggerRequest
     * @return UpdateTriggerResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/devops/UpdateTrigger.ts.html |here} to see how to use UpdateTrigger API.
     */
    updateTrigger(updateTriggerRequest: requests.UpdateTriggerRequest): Promise<responses.UpdateTriggerResponse>;
    /**
     * Return whether the credentials of the connection are valid.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ValidateConnectionRequest
     * @return ValidateConnectionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/devops/ValidateConnection.ts.html |here} to see how to use ValidateConnection API.
     */
    validateConnection(validateConnectionRequest: requests.ValidateConnectionRequest): Promise<responses.ValidateConnectionResponse>;
}
export {};
