/**
 * Full Stack Disaster Recovery API
 * Use the Full Stack Disaster Recovery (DR) API to manage disaster recovery for business applications.
Full Stack DR is an OCI disaster recovery orchestration and management service that provides comprehensive disaster
recovery capabilities for all layers of an application stack, including infrastructure, middleware, database,
and application.

 * OpenAPI spec version: 20220125
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * The details of a DR plan execution.
 */
export interface DrPlanExecution {
    /**
      * The OCID of the DR plan execution.
  * <p>
  Example: {@code ocid1.drplanexecution.oc1..uniqueID}
  *
      */
    "id": string;
    /**
      * The OCID of the compartment containing this DR plan execution.
  * <p>
  Example: {@code ocid1.compartment.oc1..uniqueID}
  *
      */
    "compartmentId": string;
    /**
      * The display name of the DR plan execution.
  * <p>
  Example: {@code Execution - EBS Switchover PHX to IAD}
  *
      */
    "displayName": string;
    /**
      * The OCID of the DR plan.
  * <p>
  Example: {@code ocid1.drplan.oc1..uniqueID}
  *
      */
    "planId": string;
    /**
     * The type of the DR plan executed.
     *
     */
    "planExecutionType": model.DrPlanExecutionType;
    "executionOptions": model.StopDrillExecutionOptions | model.SwitchoverExecutionOptions | model.FailoverPrecheckExecutionOptions | model.StartDrillExecutionOptions | model.SwitchoverPrecheckExecutionOptions | model.StartDrillPrecheckExecutionOptions | model.StopDrillPrecheckExecutionOptions | model.FailoverExecutionOptions;
    /**
      * The OCID of the DR protection group to which this DR plan execution belongs.
  * <p>
  Example: {@code ocid1.drprotectiongroup.oc1..uniqueID}
  *
      */
    "drProtectionGroupId": string;
    /**
      * The OCID of peer DR protection group associated with this plan's
  * DR protection group.
  * <p>
  Example: {@code ocid1.drprotectiongroup.oc1..uniqueID}
  *
      */
    "peerDrProtectionGroupId": string;
    /**
      * The region of the peer DR protection group associated with this plan's
  * DR protection group.
  * <p>
  Example: {@code us-ashburn-1}
  *
      */
    "peerRegion": string;
    "logLocation": model.ObjectStorageLogLocation;
    /**
      * The date and time at which DR plan execution was created. An RFC3339 formatted datetime string.
  * <p>
  Example: {@code 2019-03-29T09:36:42Z}
  *
      */
    "timeCreated": Date;
    /**
      * The date and time at which DR plan execution began. An RFC3339 formatted datetime string.
  * <p>
  Example: {@code 2019-03-29T09:36:42Z}
  *
      */
    "timeStarted"?: Date;
    /**
      * The time when DR plan execution was last updated. An RFC3339 formatted datetime string.
  * <p>
  Example: {@code 2019-03-29T09:36:42Z}
  *
      */
    "timeUpdated": Date;
    /**
      * The date and time at which DR plan execution succeeded, failed, was paused, or was canceled.
  * An RFC3339 formatted datetime string.
  * <p>
  Example: {@code 2019-03-29T09:36:42Z}
  *
      */
    "timeEnded"?: Date;
    /**
      * The total duration in seconds taken to complete the DR plan execution.
  * <p>
  Example: {@code 750}
  *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
      */
    "executionDurationInSec"?: number;
    /**
     * A list of groups executed in this DR plan execution.
     *
     */
    "groupExecutions": Array<model.DrPlanGroupExecution>;
    /**
     * The current state of the DR plan execution.
     *
     */
    "lifecycleState": model.DrPlanExecutionLifecycleState;
    /**
     * A message describing the DR plan execution's current state in more detail.
     *
     */
    "lifeCycleDetails"?: string;
    /**
      * Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
  * <p>
  Example: {@code {\"Department\": \"Finance\"}}
  *
      */
    "freeformTags"?: {
        [key: string]: string;
    };
    /**
      * Defined tags for this resource. Each key is predefined and scoped to a namespace.
  * <p>
  Example: {@code {\"Operations\": {\"CostCenter\": \"42\"}}}
  *
      */
    "definedTags"?: {
        [key: string]: {
            [key: string]: any;
        };
    };
    /**
      * Usage of system tag keys. These predefined keys are scoped to namespaces.
  * <p>
  Example: {@code {\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}}
  *
      */
    "systemTags"?: {
        [key: string]: {
            [key: string]: any;
        };
    };
}
export declare namespace DrPlanExecution {
    function getJsonObj(obj: DrPlanExecution): object;
    function getDeserializedJsonObj(obj: DrPlanExecution): object;
}
