/**
 * Full Stack Disaster Recovery API
 * Use the Full Stack Disaster Recovery (DR) API to manage disaster recovery for business applications.
Full Stack DR is an OCI disaster recovery orchestration and management service that provides comprehensive disaster
recovery capabilities for all layers of an application stack, including infrastructure, middleware, database,
and application.

 * OpenAPI spec version: 20220125
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * The details of a group execution in a DR plan execution.
 */
export interface DrPlanGroupExecution {
    /**
      * The unique id of the group. Must not be modified by user.
  * <p>
  Example: {@code sgid1.group..uniqueID}
  *
      */
    "groupId": string;
    /**
      * The group type.
  * <p>
  Example: {@code BUILT_IN}
  *
      */
    "type": model.DrPlanGroupType;
    /**
      * The display name of the group execution.
  * <p>
  Example: {@code DATABASE_SWITCHOVER}
  *
      */
    "displayName": string;
    /**
     * The status of the group execution.
     *
     */
    "status": model.DrPlanGroupExecutionStatus;
    /**
      * Additional details on the group execution status.
  * <p>
  Example: {@code A total of [3] steps failed in the group}
  *
      */
    "statusDetails"?: string;
    /**
      * The time when group execution began. An RFC3339 formatted datetime string.
  * <p>
  Example: {@code 2019-03-29T09:36:42Z}
  *
      */
    "timeStarted"?: Date;
    /**
      * The time when group execution ended. An RFC3339 formatted datetime string.
  * <p>
  Example: {@code 2019-03-29T09:36:42Z}
  *
      */
    "timeEnded"?: Date;
    /**
      * The total duration in seconds taken to complete group execution.
  * <p>
  Example: {@code 120}
  *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
      */
    "executionDurationInSec"?: number;
    /**
     * A list of step executions in the group.
     *
     */
    "stepExecutions": Array<model.DrPlanStepExecution>;
}
export declare namespace DrPlanGroupExecution {
    function getJsonObj(obj: DrPlanGroupExecution): object;
    function getDeserializedJsonObj(obj: DrPlanGroupExecution): object;
}
