/**
 * Full Stack Disaster Recovery API
 * Use the Full Stack Disaster Recovery (DR) API to manage disaster recovery for business applications.
Full Stack DR is an OCI disaster recovery orchestration and management service that provides comprehensive disaster
recovery capabilities for all layers of an application stack, including infrastructure, middleware, database,
and application.

 * OpenAPI spec version: 20220125
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * Details of a step in a DR plan.
 */
export interface DrPlanStep {
    /**
      * The unique id of the step. Must not be modified by the user.
  * <p>
  Example: {@code sgid1.step..uniqueID}
  *
      */
    "id": string;
    /**
      * The unique id of the group to which this step belongs. Must not be modified by user.
  * <p>
  Example: {@code sgid1.group..uniqueID}
  *
      */
    "groupId": string;
    /**
      * The OCID of the member associated with this step.
  * <p>
  Example: {@code ocid1.database.oc1..uniqueID}
  *
      */
    "memberId"?: string;
    /**
     * The plan step type.
     *
     */
    "type": model.DrPlanStepType;
    /**
      * The display name of the group.
  * <p>
  Example: {@code DATABASE_SWITCHOVER}
  *
      */
    "displayName": string;
    /**
     * The error mode for this step.
     *
     */
    "errorMode": model.DrPlanStepErrorMode;
    /**
      * The timeout in seconds for executing this step.
  * <p>
  Example: {@code 600}
  *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
      */
    "timeout": number;
    /**
      * A flag indicating whether this step should be enabled for execution.
  * <p>
  Example: {@code true}
  *
      */
    "isEnabled": boolean;
    "userDefinedStep"?: model.InvokeFunctionStep | model.InvokeFunctionPrecheckStep | model.RunLocalScriptUserDefinedStep | model.LocalScriptPrecheckStep | model.ObjectStoreScriptPrecheckStep | model.RunObjectStoreScriptUserDefinedStep;
}
export declare namespace DrPlanStep {
    function getJsonObj(obj: DrPlanStep): object;
    function getDeserializedJsonObj(obj: DrPlanStep): object;
}
