/**
 * Email Delivery API
 * Use the Email Delivery API to do the necessary set up to send high-volume and application-generated emails through the OCI Email Delivery service.
For more information, see [Overview of the Email Delivery Service](/iaas/Content/Email/Concepts/overview.htm).

 **Note:** Write actions (POST, UPDATE, DELETE) may take several minutes to propagate and be reflected by the API.
 If a subsequent read request fails to reflect your changes, wait a few minutes and try again.

 * OpenAPI spec version: 20170907
 * Contact: email-dev_us_grp@oracle.com
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
/**
 * Properties to create a new DKIM.
 * The new object will be created in the same compartment as the EmailDomain.
 *
 */
export interface CreateDkimDetails {
    /**
      * The DKIM selector. This selector is required to be globally unique for this email domain.
  * If you do not provide the selector, we will generate one for you.
  * If you do provide the selector, we suggest adding a short region indicator
  * to differentiate from your signing of emails in other regions you might be subscribed to.
  * Selectors limited to ASCII characters can use alphanumeric, dash (\"-\"), and dot (\".\") characters.
  * Non-ASCII selector names should adopt IDNA2008 normalization (RFC 5891-5892).
  * <p>
  Avoid entering confidential information.
  * <p>
  Example: {@code mydomain-phx-20210228}
  *
      */
    "name"?: string;
    /**
     * The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the EmailDomain for this DKIM.
     *
     */
    "emailDomainId": string;
    /**
     * A string that describes the details about the DKIM. It does not have to be unique,
     * and you can change it. Avoid entering confidential information.
     *
     */
    "description"?: string;
    /**
      * Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
  * For more information, see [Resource Tags](https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
  * <p>
  Example: {@code {\"Department\": \"Finance\"}}
  *
      */
    "freeformTags"?: {
        [key: string]: string;
    };
    /**
      * Defined tags for this resource. Each key is predefined and scoped to a namespace.
  * For more information, see [Resource Tags](https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
  * <p>
  Example: {@code {\"Operations\": {\"CostCenter\": \"42\"}}}
  *
      */
    "definedTags"?: {
        [key: string]: {
            [key: string]: any;
        };
    };
}
export declare namespace CreateDkimDetails {
    function getJsonObj(obj: CreateDkimDetails): object;
    function getDeserializedJsonObj(obj: CreateDkimDetails): object;
}
