/**
 * File Storage API
 * Use the File Storage service API to manage file systems, mount targets, and snapshots.
For more information, see [Overview of File Storage](/iaas/Content/File/Concepts/filestorageoverview.htm).

 * OpenAPI spec version: 20171215
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
/**
 * A set of file systems to export through one or more mount
 * targets. Composed of zero or more export resources.
 *
 */
export interface ExportSet {
    /**
      * The availability domain the export set is in. May be unset
  * as a blank or NULL value.
  * <p>
  Example: {@code Uocm:PHX-AD-1}
  *
      */
    "availabilityDomain"?: string;
    /**
     * The [OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment that contains the export set.
     */
    "compartmentId": string;
    /**
      * A user-friendly name. It does not have to be unique, and it is changeable.
  * Avoid entering confidential information.
  * <p>
  Example: {@code My export set}
  *
      */
    "displayName": string;
    /**
     * The [OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the export set.
     */
    "id": string;
    /**
     * The current state of the export set.
     */
    "lifecycleState": ExportSet.LifecycleState;
    /**
     * Controls the maximum {@code tbytes}, {@code fbytes}, and {@code abytes},
     * values reported by {@code NFS FSSTAT} calls through any associated
     * mount targets. This is an advanced feature. For most
     * applications, use the default value. The
     * {@code tbytes} value reported by {@code FSSTAT} will be
     * {@code maxFsStatBytes}. The value of {@code fbytes} and {@code abytes} will be
     * {@code maxFsStatBytes} minus the metered size of the file
     * system. If the metered size is larger than {@code maxFsStatBytes},
     * then {@code fbytes} and {@code abytes} will both be '0'.
     *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "maxFsStatBytes"?: number;
    /**
     * Controls the maximum {@code tfiles}, {@code ffiles}, and {@code afiles}
     * values reported by {@code NFS FSSTAT} calls through any associated
     * mount targets. This is an advanced feature. For most
     * applications, use the default value. The
     * {@code tfiles} value reported by {@code FSSTAT} will be
     * {@code maxFsStatFiles}. The value of {@code ffiles} and {@code afiles} will be
     * {@code maxFsStatFiles} minus the metered size of the file
     * system. If the metered size is larger than {@code maxFsStatFiles},
     * then {@code ffiles} and {@code afiles} will both be '0'.
     *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "maxFsStatFiles"?: number;
    /**
      * The date and time the export set was created, expressed
  * in [RFC 3339](https://tools.ietf.org/rfc/rfc3339) timestamp format.
  * <p>
  Example: {@code 2016-08-25T21:10:29.600Z}
  *
      */
    "timeCreated": Date;
    /**
     * The [OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the virtual cloud network (VCN) the export set is in.
     */
    "vcnId": string;
}
export declare namespace ExportSet {
    enum LifecycleState {
        Creating = "CREATING",
        Active = "ACTIVE",
        Deleting = "DELETING",
        Deleted = "DELETED",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    function getJsonObj(obj: ExportSet): object;
    function getDeserializedJsonObj(obj: ExportSet): object;
}
