/**
 * File Storage API
 * Use the File Storage service API to manage file systems, mount targets, and snapshots.
For more information, see [Overview of File Storage](/iaas/Content/File/Concepts/filestorageoverview.htm).

 * OpenAPI spec version: 20171215
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
/**
 * A point-in-time snapshot of a specified file system.
 *
 */
export interface Snapshot {
    /**
     * The [OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the file system from which the snapshot
     * was created.
     *
     */
    "fileSystemId": string;
    /**
     * The [OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the snapshot.
     */
    "id": string;
    /**
     * The current state of the snapshot.
     */
    "lifecycleState": Snapshot.LifecycleState;
    /**
      * Name of the snapshot. This value is immutable.
  * <p>
  Avoid entering confidential information.
  * <p>
  Example: {@code Sunday}
  *
      */
    "name": string;
    /**
      * The date and time the snapshot was created, expressed
  * in [RFC 3339](https://tools.ietf.org/rfc/rfc3339) timestamp format.
  * <p>
  Example: {@code 2016-08-25T21:10:29.600Z}
  *
      */
    "timeCreated": Date;
    /**
     * Specifies generation type of the snapshot.
     *
     */
    "snapshotType"?: Snapshot.SnapshotType;
    /**
      * The date and time the snapshot was taken, expressed
  * in [RFC 3339](https://tools.ietf.org/rfc/rfc3339) timestamp format.
  * This value might be the same or different from {@code timeCreated} depending
  * on the following factors:
  * - If the snapshot is created in the original file system directory.
  * - If the snapshot is cloned from a file system.
  * - If the snapshot is replicated from a file system.
  * <p>
  Example: {@code 2020-08-25T21:10:29.600Z}
  *
      */
    "snapshotTime"?: Date;
    /**
     * An [OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) identifying the parent from which this snapshot was cloned.
     * If this snapshot was not cloned, then the {@code provenanceId} is the same as the snapshot {@code id} value.
     * If this snapshot was cloned, then the {@code provenanceId} value is the parent's {@code provenanceId}.
     * See [Cloning a File System](https://docs.cloud.oracle.com/iaas/Content/File/Tasks/cloningFS.htm).
     *
     */
    "provenanceId"?: string;
    /**
     * Specifies whether the snapshot has been cloned.
     * See [Cloning a File System](https://docs.cloud.oracle.com/iaas/Content/File/Tasks/cloningFS.htm).
     *
     */
    "isCloneSource"?: boolean;
    /**
     * Additional information about the current {@code lifecycleState}.
     */
    "lifecycleDetails"?: string;
    /**
     * Free-form tags for this resource. Each tag is a simple key-value pair
     *  with no predefined name, type, or namespace.
     * For more information, see [Resource Tags](https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
     * Example: {@code {\"Department\": \"Finance\"}}
     *
     */
    "freeformTags"?: {
        [key: string]: string;
    };
    /**
     * Defined tags for this resource. Each key is predefined and scoped to a namespace.
     * For more information, see [Resource Tags](https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
     * Example: {@code {\"Operations\": {\"CostCenter\": \"42\"}}}
     *
     */
    "definedTags"?: {
        [key: string]: {
            [key: string]: any;
        };
    };
    /**
     * The time when this snapshot will be deleted.
     */
    "expirationTime"?: Date;
    /**
     * The [OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the file system snapshot policy that created this snapshot.
     *
     */
    "filesystemSnapshotPolicyId"?: string;
}
export declare namespace Snapshot {
    enum LifecycleState {
        Creating = "CREATING",
        Active = "ACTIVE",
        Deleting = "DELETING",
        Deleted = "DELETED",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    enum SnapshotType {
        User = "USER",
        PolicyBased = "POLICY_BASED",
        Replication = "REPLICATION",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    function getJsonObj(obj: Snapshot): object;
    function getDeserializedJsonObj(obj: Snapshot): object;
}
