/**
 * Exadata Fleet Update service API
 * Use the Exadata Fleet Update service to patch large collections of components directly,
as a single entity, orchestrating the maintenance actions to update all chosen components in the stack in a single cycle.

 * OpenAPI spec version: 20220528
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import common = require("oci-common");
import * as requests from "./request";
import * as responses from "./response";
import { FleetSoftwareUpdateWaiter } from "./fleetsoftwareupdate-waiter";
declare const Breaker: any;
export declare enum FleetSoftwareUpdateApiKeys {
}
/**
 * This service client uses {@link common.CircuitBreaker.DefaultConfiguration} for all the operations by default if no circuit breaker configuration is defined by the user.
 */
export declare class FleetSoftwareUpdateClient {
    protected static serviceEndpointTemplate: string;
    protected static endpointServiceName: string;
    protected "_realmSpecificEndpointTemplateEnabled": boolean | undefined;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_waiters": FleetSoftwareUpdateWaiter;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: typeof Breaker | null;
    protected _httpOptions: any;
    protected _bodyDuplexMode: any;
    targetService: string;
    protected _regionId: string;
    protected "_region": common.Region;
    protected _lastSetRegionOrRegionId: string;
    protected _httpClient: common.HttpClient;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    get endpoint(): string;
    /**
     * Sets the endpoint to call (ex, https://www.example.com).
     * @param endpoint The endpoint of the service.
     */
    set endpoint(endpoint: string);
    get logger(): import("oci-common/lib/log").Logger;
    /**
     * Determines whether realm specific endpoint should be used or not.
     * Set realmSpecificEndpointTemplateEnabled to "true" if the user wants to enable use of realm specific endpoint template, otherwise set it to "false"
     * @param realmSpecificEndpointTemplateEnabled flag to enable the use of realm specific endpoint template
     */
    set useRealmSpecificEndpointTemplate(realmSpecificEndpointTemplateEnabled: boolean);
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    set region(region: common.Region);
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    set regionId(regionId: string);
    /**
     * Creates a new FleetSoftwareUpdateWaiter for resources for this service.
     *
     * @param config The waiter configuration for termination and delay strategy
     * @return The service waiters.
     */
    createWaiters(config?: common.WaiterConfiguration): FleetSoftwareUpdateWaiter;
    /**
     * Gets the waiters available for resources for this service.
     *
     * @return The service waiters.
     */
    getWaiters(): FleetSoftwareUpdateWaiter;
    /**
     * Shutdown the circuit breaker used by the client when it is no longer needed
     */
    shutdownCircuitBreaker(): void;
    /**
     * Close the client once it is no longer needed
     */
    close(): void;
    /**
     * Aborts Exadata Fleet Update Discovery in progress.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param AbortFsuDiscoveryRequest
     * @return AbortFsuDiscoveryResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/fleetsoftwareupdate/AbortFsuDiscovery.ts.html |here} to see how to use AbortFsuDiscovery API.
     */
    abortFsuDiscovery(abortFsuDiscoveryRequest: requests.AbortFsuDiscoveryRequest): Promise<responses.AbortFsuDiscoveryResponse>;
    /**
     * Adds targets to an existing Exadata Fleet Update Collection.
     * Targets that are already part of a different Collection with an active Fleet Software Update Cycle cannot be added.
     * This operation can only be performed on Collections that do not have an Action executing under an active Fleet Software Update Cycle.
     * Additionally, during an active Fleet Software Update Cycle, targets can be added only prior to executing an Apply Action. This will require running a new Stage Action for the active Cycle.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param AddFsuCollectionTargetsRequest
     * @return AddFsuCollectionTargetsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/fleetsoftwareupdate/AddFsuCollectionTargets.ts.html |here} to see how to use AddFsuCollectionTargets API.
     */
    addFsuCollectionTargets(addFsuCollectionTargetsRequest: requests.AddFsuCollectionTargetsRequest): Promise<responses.AddFsuCollectionTargetsResponse>;
    /**
     * Cancels a scheduled Action. Only applicable for Actions that have not started executing.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CancelFsuActionRequest
     * @return CancelFsuActionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/fleetsoftwareupdate/CancelFsuAction.ts.html |here} to see how to use CancelFsuAction API.
     */
    cancelFsuAction(cancelFsuActionRequest: requests.CancelFsuActionRequest): Promise<responses.CancelFsuActionResponse>;
    /**
     * Moves a Exadata Fleet Update Action resource from one compartment identifier to another.
     * When provided, If-Match is checked against ETag values of the resource.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ChangeFsuActionCompartmentRequest
     * @return ChangeFsuActionCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/fleetsoftwareupdate/ChangeFsuActionCompartment.ts.html |here} to see how to use ChangeFsuActionCompartment API.
     */
    changeFsuActionCompartment(changeFsuActionCompartmentRequest: requests.ChangeFsuActionCompartmentRequest): Promise<responses.ChangeFsuActionCompartmentResponse>;
    /**
     * Moves a Exadata Fleet Update Collection resource from one compartment identifier to another.
     * When provided, If-Match is checked against ETag values of the resource.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ChangeFsuCollectionCompartmentRequest
     * @return ChangeFsuCollectionCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/fleetsoftwareupdate/ChangeFsuCollectionCompartment.ts.html |here} to see how to use ChangeFsuCollectionCompartment API.
     */
    changeFsuCollectionCompartment(changeFsuCollectionCompartmentRequest: requests.ChangeFsuCollectionCompartmentRequest): Promise<responses.ChangeFsuCollectionCompartmentResponse>;
    /**
     * Moves a Exadata Fleet Update Cycle resource from one compartment identifier to another.
     * When provided, If-Match is checked against ETag values of the resource.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ChangeFsuCycleCompartmentRequest
     * @return ChangeFsuCycleCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/fleetsoftwareupdate/ChangeFsuCycleCompartment.ts.html |here} to see how to use ChangeFsuCycleCompartment API.
     */
    changeFsuCycleCompartment(changeFsuCycleCompartmentRequest: requests.ChangeFsuCycleCompartmentRequest): Promise<responses.ChangeFsuCycleCompartmentResponse>;
    /**
     * Moves a Exadata Fleet Update Discovery resource from one compartment identifier to another.
     * When provided, If-Match is checked against ETag values of the resource.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ChangeFsuDiscoveryCompartmentRequest
     * @return ChangeFsuDiscoveryCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/fleetsoftwareupdate/ChangeFsuDiscoveryCompartment.ts.html |here} to see how to use ChangeFsuDiscoveryCompartment API.
     */
    changeFsuDiscoveryCompartment(changeFsuDiscoveryCompartmentRequest: requests.ChangeFsuDiscoveryCompartmentRequest): Promise<responses.ChangeFsuDiscoveryCompartmentResponse>;
    /**
     * Clones existing Exadata Fleet Update Cycle details into a new Exadata Fleet Update Cycle resource.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CloneFsuCycleRequest
     * @return CloneFsuCycleResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/fleetsoftwareupdate/CloneFsuCycle.ts.html |here} to see how to use CloneFsuCycle API.
     */
    cloneFsuCycle(cloneFsuCycleRequest: requests.CloneFsuCycleRequest): Promise<responses.CloneFsuCycleResponse>;
    /**
     * Creates a new Exadata Fleet Update Action.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateFsuActionRequest
     * @return CreateFsuActionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/fleetsoftwareupdate/CreateFsuAction.ts.html |here} to see how to use CreateFsuAction API.
     */
    createFsuAction(createFsuActionRequest: requests.CreateFsuActionRequest): Promise<responses.CreateFsuActionResponse>;
    /**
     * Creates a new Exadata Fleet Update Collection.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateFsuCollectionRequest
     * @return CreateFsuCollectionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/fleetsoftwareupdate/CreateFsuCollection.ts.html |here} to see how to use CreateFsuCollection API.
     */
    createFsuCollection(createFsuCollectionRequest: requests.CreateFsuCollectionRequest): Promise<responses.CreateFsuCollectionResponse>;
    /**
     * Creates a new Exadata Fleet Update Cycle.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateFsuCycleRequest
     * @return CreateFsuCycleResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/fleetsoftwareupdate/CreateFsuCycle.ts.html |here} to see how to use CreateFsuCycle API.
     */
    createFsuCycle(createFsuCycleRequest: requests.CreateFsuCycleRequest): Promise<responses.CreateFsuCycleResponse>;
    /**
     * Creates a new Exadata Fleet Update Discovery.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateFsuDiscoveryRequest
     * @return CreateFsuDiscoveryResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/fleetsoftwareupdate/CreateFsuDiscovery.ts.html |here} to see how to use CreateFsuDiscovery API.
     */
    createFsuDiscovery(createFsuDiscoveryRequest: requests.CreateFsuDiscoveryRequest): Promise<responses.CreateFsuDiscoveryResponse>;
    /**
     * Deletes a Exadata Fleet Update Action resource by identifier.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteFsuActionRequest
     * @return DeleteFsuActionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/fleetsoftwareupdate/DeleteFsuAction.ts.html |here} to see how to use DeleteFsuAction API.
     */
    deleteFsuAction(deleteFsuActionRequest: requests.DeleteFsuActionRequest): Promise<responses.DeleteFsuActionResponse>;
    /**
     * Deletes a Exadata Fleet Update Collection resource by identifier.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteFsuCollectionRequest
     * @return DeleteFsuCollectionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/fleetsoftwareupdate/DeleteFsuCollection.ts.html |here} to see how to use DeleteFsuCollection API.
     */
    deleteFsuCollection(deleteFsuCollectionRequest: requests.DeleteFsuCollectionRequest): Promise<responses.DeleteFsuCollectionResponse>;
    /**
     * Deletes a Exadata Fleet Update Cycle resource by identifier.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteFsuCycleRequest
     * @return DeleteFsuCycleResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/fleetsoftwareupdate/DeleteFsuCycle.ts.html |here} to see how to use DeleteFsuCycle API.
     */
    deleteFsuCycle(deleteFsuCycleRequest: requests.DeleteFsuCycleRequest): Promise<responses.DeleteFsuCycleResponse>;
    /**
     * Deletes a Exadata Fleet Update Discovery resource by identifier.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteFsuDiscoveryRequest
     * @return DeleteFsuDiscoveryResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/fleetsoftwareupdate/DeleteFsuDiscovery.ts.html |here} to see how to use DeleteFsuDiscovery API.
     */
    deleteFsuDiscovery(deleteFsuDiscoveryRequest: requests.DeleteFsuDiscoveryRequest): Promise<responses.DeleteFsuDiscoveryResponse>;
    /**
     * Deletes the Exadata Fleet Update Job resource by identifier.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteFsuJobRequest
     * @return DeleteFsuJobResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/fleetsoftwareupdate/DeleteFsuJob.ts.html |here} to see how to use DeleteFsuJob API.
     */
    deleteFsuJob(deleteFsuJobRequest: requests.DeleteFsuJobRequest): Promise<responses.DeleteFsuJobResponse>;
    /**
     * Gets a Exadata Fleet Update Action by identifier.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetFsuActionRequest
     * @return GetFsuActionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/fleetsoftwareupdate/GetFsuAction.ts.html |here} to see how to use GetFsuAction API.
     */
    getFsuAction(getFsuActionRequest: requests.GetFsuActionRequest): Promise<responses.GetFsuActionResponse>;
    /**
     * Gets the Exadata Fleet Update Action Output content as a binary file (string).
     * This will only include the output from FAILED Exadata Fleet Update Jobs. No content in case there are no FAILED jobs.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetFsuActionOutputContentRequest
     * @return GetFsuActionOutputContentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/fleetsoftwareupdate/GetFsuActionOutputContent.ts.html |here} to see how to use GetFsuActionOutputContent API.
     */
    getFsuActionOutputContent(getFsuActionOutputContentRequest: requests.GetFsuActionOutputContentRequest): Promise<responses.GetFsuActionOutputContentResponse>;
    /**
     * Gets a Exadata Fleet Update Collection by identifier.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetFsuCollectionRequest
     * @return GetFsuCollectionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/fleetsoftwareupdate/GetFsuCollection.ts.html |here} to see how to use GetFsuCollection API.
     */
    getFsuCollection(getFsuCollectionRequest: requests.GetFsuCollectionRequest): Promise<responses.GetFsuCollectionResponse>;
    /**
     * Gets a Exadata Fleet Update Cycle by identifier.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetFsuCycleRequest
     * @return GetFsuCycleResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/fleetsoftwareupdate/GetFsuCycle.ts.html |here} to see how to use GetFsuCycle API.
     */
    getFsuCycle(getFsuCycleRequest: requests.GetFsuCycleRequest): Promise<responses.GetFsuCycleResponse>;
    /**
     * Gets a Exadata Fleet Update Discovery by identifier.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetFsuDiscoveryRequest
     * @return GetFsuDiscoveryResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/fleetsoftwareupdate/GetFsuDiscovery.ts.html |here} to see how to use GetFsuDiscovery API.
     */
    getFsuDiscovery(getFsuDiscoveryRequest: requests.GetFsuDiscoveryRequest): Promise<responses.GetFsuDiscoveryResponse>;
    /**
     * Gets a Exadata Fleet Update Job by identifier.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetFsuJobRequest
     * @return GetFsuJobResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/fleetsoftwareupdate/GetFsuJob.ts.html |here} to see how to use GetFsuJob API.
     */
    getFsuJob(getFsuJobRequest: requests.GetFsuJobRequest): Promise<responses.GetFsuJobResponse>;
    /**
     * Get the Exadata Fleet Update Job Output content as a binary file (string).
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetFsuJobOutputContentRequest
     * @return GetFsuJobOutputContentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/fleetsoftwareupdate/GetFsuJobOutputContent.ts.html |here} to see how to use GetFsuJobOutputContent API.
     */
    getFsuJobOutputContent(getFsuJobOutputContentRequest: requests.GetFsuJobOutputContentRequest): Promise<responses.GetFsuJobOutputContentResponse>;
    /**
     * Gets the status of the work request with the specified ID.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetWorkRequestRequest
     * @return GetWorkRequestResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/fleetsoftwareupdate/GetWorkRequest.ts.html |here} to see how to use GetWorkRequest API.
     */
    getWorkRequest(getWorkRequestRequest: requests.GetWorkRequestRequest): Promise<responses.GetWorkRequestResponse>;
    /**
     * Gets a list of all Exadata Fleet Update Actions in a compartment.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListFsuActionsRequest
     * @return ListFsuActionsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/fleetsoftwareupdate/ListFsuActions.ts.html |here} to see how to use ListFsuActions API.
     */
    listFsuActions(listFsuActionsRequest: requests.ListFsuActionsRequest): Promise<responses.ListFsuActionsResponse>;
    /**
     * Gets a list of all Targets that are members of a specific Exadata Fleet Update Collection.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListFsuCollectionTargetsRequest
     * @return ListFsuCollectionTargetsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/fleetsoftwareupdate/ListFsuCollectionTargets.ts.html |here} to see how to use ListFsuCollectionTargets API.
     */
    listFsuCollectionTargets(listFsuCollectionTargetsRequest: requests.ListFsuCollectionTargetsRequest): Promise<responses.ListFsuCollectionTargetsResponse>;
    /**
     * Gets a list of all Exadata Fleet Update Collections in a compartment.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListFsuCollectionsRequest
     * @return ListFsuCollectionsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/fleetsoftwareupdate/ListFsuCollections.ts.html |here} to see how to use ListFsuCollections API.
     */
    listFsuCollections(listFsuCollectionsRequest: requests.ListFsuCollectionsRequest): Promise<responses.ListFsuCollectionsResponse>;
    /**
     * Gets a list of all Exadata Fleet Update Cycles in a compartment.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListFsuCyclesRequest
     * @return ListFsuCyclesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/fleetsoftwareupdate/ListFsuCycles.ts.html |here} to see how to use ListFsuCycles API.
     */
    listFsuCycles(listFsuCyclesRequest: requests.ListFsuCyclesRequest): Promise<responses.ListFsuCyclesResponse>;
    /**
     * Returns a list of Exadata Fleet Update Discoveries resources in the specified compartment.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListFsuDiscoveriesRequest
     * @return ListFsuDiscoveriesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/fleetsoftwareupdate/ListFsuDiscoveries.ts.html |here} to see how to use ListFsuDiscoveries API.
     */
    listFsuDiscoveries(listFsuDiscoveriesRequest: requests.ListFsuDiscoveriesRequest): Promise<responses.ListFsuDiscoveriesResponse>;
    /**
     * Gets a list of all Targets in the results of a Exadata Fleet Update Discovery.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListFsuDiscoveryTargetsRequest
     * @return ListFsuDiscoveryTargetsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/fleetsoftwareupdate/ListFsuDiscoveryTargets.ts.html |here} to see how to use ListFsuDiscoveryTargets API.
     */
    listFsuDiscoveryTargets(listFsuDiscoveryTargetsRequest: requests.ListFsuDiscoveryTargetsRequest): Promise<responses.ListFsuDiscoveryTargetsResponse>;
    /**
     * Lists the Exadata Fleet Update Job Output messages, if any.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListFsuJobOutputsRequest
     * @return ListFsuJobOutputsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/fleetsoftwareupdate/ListFsuJobOutputs.ts.html |here} to see how to use ListFsuJobOutputs API.
     */
    listFsuJobOutputs(listFsuJobOutputsRequest: requests.ListFsuJobOutputsRequest): Promise<responses.ListFsuJobOutputsResponse>;
    /**
     * Lists all the Exadata Fleet Update Jobs associated to the specified Exadata Fleet Update Action.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListFsuJobsRequest
     * @return ListFsuJobsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/fleetsoftwareupdate/ListFsuJobs.ts.html |here} to see how to use ListFsuJobs API.
     */
    listFsuJobs(listFsuJobsRequest: requests.ListFsuJobsRequest): Promise<responses.ListFsuJobsResponse>;
    /**
     * Returns a paginated list of errors for a specified Work Request..
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListWorkRequestErrorsRequest
     * @return ListWorkRequestErrorsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/fleetsoftwareupdate/ListWorkRequestErrors.ts.html |here} to see how to use ListWorkRequestErrors API.
     */
    listWorkRequestErrors(listWorkRequestErrorsRequest: requests.ListWorkRequestErrorsRequest): Promise<responses.ListWorkRequestErrorsResponse>;
    /**
     * Returns a paginated list of logs for a specified Work Request.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListWorkRequestLogsRequest
     * @return ListWorkRequestLogsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/fleetsoftwareupdate/ListWorkRequestLogs.ts.html |here} to see how to use ListWorkRequestLogs API.
     */
    listWorkRequestLogs(listWorkRequestLogsRequest: requests.ListWorkRequestLogsRequest): Promise<responses.ListWorkRequestLogsResponse>;
    /**
     * Lists the work requests in a compartment.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListWorkRequestsRequest
     * @return ListWorkRequestsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/fleetsoftwareupdate/ListWorkRequests.ts.html |here} to see how to use ListWorkRequests API.
     */
    listWorkRequests(listWorkRequestsRequest: requests.ListWorkRequestsRequest): Promise<responses.ListWorkRequestsResponse>;
    /**
     * Removes targets from an existing Exadata Fleet Update Collection.
     * This operation can only be performed on Collections that do not have an Action executing under an active Fleet Software Update Cycle.
     * Additionally, during an active Fleet Software Update Cycle, targets can be removed only prior to executing an Apply Action.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param RemoveFsuCollectionTargetsRequest
     * @return RemoveFsuCollectionTargetsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/fleetsoftwareupdate/RemoveFsuCollectionTargets.ts.html |here} to see how to use RemoveFsuCollectionTargets API.
     */
    removeFsuCollectionTargets(removeFsuCollectionTargetsRequest: requests.RemoveFsuCollectionTargetsRequest): Promise<responses.RemoveFsuCollectionTargetsResponse>;
    /**
     * Resumes an Action that has batches of targets waiting to execute.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ResumeFsuActionRequest
     * @return ResumeFsuActionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/fleetsoftwareupdate/ResumeFsuAction.ts.html |here} to see how to use ResumeFsuAction API.
     */
    resumeFsuAction(resumeFsuActionRequest: requests.ResumeFsuActionRequest): Promise<responses.ResumeFsuActionResponse>;
    /**
     * Retry a failed Job, only while the current Action is being executed.
     * After the Action reaches a terminal state, a new Action of the same kind is required to retry on failed targets.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param RetryFsuJobRequest
     * @return RetryFsuJobResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/fleetsoftwareupdate/RetryFsuJob.ts.html |here} to see how to use RetryFsuJob API.
     */
    retryFsuJob(retryFsuJobRequest: requests.RetryFsuJobRequest): Promise<responses.RetryFsuJobResponse>;
    /**
     * Updates the Exadata Fleet Update Action identified by the ID.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateFsuActionRequest
     * @return UpdateFsuActionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/fleetsoftwareupdate/UpdateFsuAction.ts.html |here} to see how to use UpdateFsuAction API.
     */
    updateFsuAction(updateFsuActionRequest: requests.UpdateFsuActionRequest): Promise<responses.UpdateFsuActionResponse>;
    /**
     * Updates the Exadata Fleet Update Collection identified by the ID.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateFsuCollectionRequest
     * @return UpdateFsuCollectionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/fleetsoftwareupdate/UpdateFsuCollection.ts.html |here} to see how to use UpdateFsuCollection API.
     */
    updateFsuCollection(updateFsuCollectionRequest: requests.UpdateFsuCollectionRequest): Promise<responses.UpdateFsuCollectionResponse>;
    /**
     * Updates the Exadata Fleet Update Cycle identified by the ID.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateFsuCycleRequest
     * @return UpdateFsuCycleResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/fleetsoftwareupdate/UpdateFsuCycle.ts.html |here} to see how to use UpdateFsuCycle API.
     */
    updateFsuCycle(updateFsuCycleRequest: requests.UpdateFsuCycleRequest): Promise<responses.UpdateFsuCycleResponse>;
    /**
     * Updates the Exadata Fleet Update Discovery identified by the ID.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateFsuDiscoveryRequest
     * @return UpdateFsuDiscoveryResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/fleetsoftwareupdate/UpdateFsuDiscovery.ts.html |here} to see how to use UpdateFsuDiscovery API.
     */
    updateFsuDiscovery(updateFsuDiscoveryRequest: requests.UpdateFsuDiscoveryRequest): Promise<responses.UpdateFsuDiscoveryResponse>;
    /**
     * Updates Exadata Fleet Update Job resource details.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateFsuJobRequest
     * @return UpdateFsuJobResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/fleetsoftwareupdate/UpdateFsuJob.ts.html |here} to see how to use UpdateFsuJob API.
     */
    updateFsuJob(updateFsuJobRequest: requests.UpdateFsuJobRequest): Promise<responses.UpdateFsuJobResponse>;
}
export {};
