/**
 * Fusion Applications Environment Management API
 * Use the Fusion Applications Environment Management API to manage the environments where your Fusion Applications run. For more information, see the [Fusion Applications Environment Management documentation](/iaas/Content/fusion-applications/home.htm).
 * OpenAPI spec version: 20211201
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * Description of FusionEnvironment.
 */
export interface FusionEnvironment {
    /**
     * Unique identifier that is immutable on creation
     */
    "id": string;
    /**
     * FusionEnvironment Identifier, can be renamed
     */
    "displayName": string;
    "maintenancePolicy"?: model.GetMaintenancePolicyDetails;
    /**
     * The next maintenance for this environment
     */
    "timeUpcomingMaintenance"?: Date;
    /**
     * Compartment Identifier
     */
    "compartmentId": string;
    /**
     * FusionEnvironmentFamily Identifier
     */
    "fusionEnvironmentFamilyId"?: string;
    /**
     * List of subscription IDs.
     */
    "subscriptionIds"?: Array<string>;
    /**
     * Type of the FusionEnvironment.
     */
    "fusionEnvironmentType": FusionEnvironment.FusionEnvironmentType;
    /**
     * BYOK key id
     */
    "kmsKeyId"?: string;
    /**
     * BYOK key info
     */
    "kmsKeyInfo"?: any;
    /**
     * The IDCS domain created for the fusion instance
     */
    "domainId"?: string;
    /**
     * The IDCS Domain URL
     */
    "idcsDomainUrl"?: string;
    /**
     * Patch bundle names
     */
    "appliedPatchBundles"?: Array<string>;
    /**
     * Version of Fusion Apps used by this environment
     */
    "version"?: string;
    /**
     * Public URL
     */
    "publicUrl"?: string;
    /**
     * DNS prefix
     */
    "dnsPrefix"?: string;
    /**
     * Language packs
     */
    "additionalLanguagePacks"?: Array<string>;
    /**
     * The lockbox Id of this fusion environment. If there's no lockbox id, this field will be null
     */
    "lockboxId"?: string;
    /**
     * If it's true, then the Break Glass feature is enabled
     */
    "isBreakGlassEnabled"?: boolean;
    "refresh"?: model.RefreshDetails;
    /**
     * Network Access Control Rules
     */
    "rules"?: Array<model.Rule>;
    /**
     * The time the the FusionEnvironment was created. An RFC3339 formatted datetime string
     */
    "timeCreated"?: Date;
    /**
     * The time the FusionEnvironment was updated. An RFC3339 formatted datetime string
     */
    "timeUpdated"?: Date;
    /**
     * The current state of the ServiceInstance.
     */
    "lifecycleState": FusionEnvironment.LifecycleState;
    /**
     * A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.
     */
    "lifecycleDetails"?: string;
    /**
     * Environment Specific Guid/ System Name
     */
    "systemName"?: string;
    "environmentRole"?: model.EnvironmentRole;
    /**
     * Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
     * Example: {@code {\"bar-key\": \"value\"}}
     *
     */
    "freeformTags"?: {
        [key: string]: string;
    };
    /**
     * Defined tags for this resource. Each key is predefined and scoped to a namespace.
     * Example: {@code {\"foo-namespace\": {\"bar-key\": \"value\"}}}
     *
     */
    "definedTags"?: {
        [key: string]: {
            [key: string]: any;
        };
    };
    /**
     * Environment suspended status
     */
    "isSuspended"?: boolean;
}
export declare namespace FusionEnvironment {
    enum FusionEnvironmentType {
        Production = "PRODUCTION",
        Test = "TEST",
        Development = "DEVELOPMENT",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    enum LifecycleState {
        Creating = "CREATING",
        Updating = "UPDATING",
        Active = "ACTIVE",
        Inactive = "INACTIVE",
        Deleting = "DELETING",
        Deleted = "DELETED",
        Failed = "FAILED",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    function getJsonObj(obj: FusionEnvironment): object;
    function getDeserializedJsonObj(obj: FusionEnvironment): object;
}
