/**
 * Fusion Applications Environment Management API
 * Use the Fusion Applications Environment Management API to manage the environments where your Fusion Applications run. For more information, see the [Fusion Applications Environment Management documentation](/iaas/Content/fusion-applications/home.htm).
 * OpenAPI spec version: 20211201
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * An environment refresh copies data from a source environment to a target environment, making a copy of the source environment onto the target environment. For more information, see [Refreshing an Environment](https://docs.cloud.oracle.com/iaas/Content/fusion-applications/refresh-environment.htm).
 */
export interface RefreshActivity {
    /**
     * The unique identifier (OCID) of the refresh activity. Can't be changed after creation.
     */
    "id": string;
    /**
     * A friendly name for the refresh activity. Can be changed later.
     */
    "displayName": string;
    /**
     * The OCID of the Fusion environment that is the source environment for the refresh.
     */
    "sourceFusionEnvironmentId": string;
    /**
     * The date and time of the most recent source environment backup used for the environment refresh.
     */
    "timeOfRestorationPoint"?: Date;
    /**
     * The current state of the refreshActivity.
     */
    "lifecycleState": RefreshActivity.LifecycleState;
    /**
     * Service availability / impact during refresh activity execution up down
     */
    "serviceAvailability": RefreshActivity.ServiceAvailability;
    /**
     * The time the refresh activity is scheduled to start. An RFC3339 formatted datetime string.
     */
    "timeScheduledStart": Date;
    /**
     * The time the refresh activity is scheduled to end. An RFC3339 formatted datetime string.
     */
    "timeExpectedFinish": Date;
    /**
     * The time the refresh activity actually completed / cancelled / failed. An RFC3339 formatted datetime string.
     */
    "timeFinished"?: Date;
    /**
     * The time the refresh activity record was created. An RFC3339 formatted datetime string.
     */
    "timeAccepted"?: Date;
    /**
     * The time the refresh activity record was updated. An RFC3339 formatted datetime string.
     */
    "timeUpdated"?: Date;
    /**
     * Details of refresh investigation information, each item represents a different issue.
     */
    "refreshIssueDetailsList"?: Array<model.RefreshIssueDetails>;
    /**
     * A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.
     */
    "lifecycleDetails"?: RefreshActivity.LifecycleDetails;
}
export declare namespace RefreshActivity {
    enum LifecycleState {
        Accepted = "ACCEPTED",
        InProgress = "IN_PROGRESS",
        NeedsAttention = "NEEDS_ATTENTION",
        Failed = "FAILED",
        Succeeded = "SUCCEEDED",
        Canceled = "CANCELED",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    enum ServiceAvailability {
        Available = "AVAILABLE",
        Unavailable = "UNAVAILABLE",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    enum LifecycleDetails {
        None = "NONE",
        Rollbackaccepted = "ROLLBACKACCEPTED",
        Rollbackinprogress = "ROLLBACKINPROGRESS",
        Rollbacksucceeded = "ROLLBACKSUCCEEDED",
        Rollbackfailed = "ROLLBACKFAILED",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    function getJsonObj(obj: RefreshActivity): object;
    function getDeserializedJsonObj(obj: RefreshActivity): object;
}
