/**
 * Generative AI Service Management API
 * OCI Generative AI is a fully managed service that provides a set of state-of-the-art, customizable large language models (LLMs) that cover a wide range of use cases for text generation, summarization, and text embeddings.

Use the Generative AI service management API to create and manage [dedicated AI clusters](#/en/generative-ai/latest/DedicatedAiCluster/), [endpoints](#/en/generative-ai/latest/Endpoint/), [custom models](#/en/generative-ai/latest/Model/), and [work requests](#/en/generative-ai/latest/WorkRequest/) in the Generative AI service. For example, create a custom model by fine-tuning an out-of-the-box model using your own data, on a fine-tuning dedicated AI cluster. Then, create a hosting dedicated AI cluster with an endpoint to host your custom model.

To access your custom model endpoints, or to try the out-of-the-box models to generate text, summarize, and create text embeddings see the [Generative AI Inference API](/#/en/generative-ai-inference/latest/).

To learn more about the service, see the [Generative AI documentation](/iaas/Content/generative-ai/home.htm).

 * OpenAPI spec version: 20231130
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
/**
 * The data to create a dedicated AI cluster.
 */
export interface CreateDedicatedAiClusterDetails {
    /**
     * A user-friendly name. Does not have to be unique, and it's changeable.
     */
    "displayName"?: string;
    /**
     * An optional description of the dedicated AI cluster.
     */
    "description"?: string;
    /**
      * The dedicated AI cluster type indicating whether this is a fine-tuning/training processor or hosting/inference processor.
  * <p>
  Allowed values are:
  * - HOSTING
  * - FINE_TUNING
  *
      */
    "type": string;
    /**
     * The compartment OCID to create the dedicated AI cluster in.
     */
    "compartmentId": string;
    /**
     * The number of dedicated units in this AI cluster. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "unitCount": number;
    /**
      * The shape of dedicated unit in this AI cluster. The underlying hardware configuration is hidden from customers.
  * <p>
  Allowed values are:
  * - LARGE_COHERE
  * - LARGE_COHERE_V2
  * - SMALL_COHERE
  * - SMALL_COHERE_V2
  * - EMBED_COHERE
  * - LLAMA2_70
  * - LARGE_GENERIC
  * - LARGE_COHERE_V2_2
  *
      */
    "unitShape": string;
    /**
      * Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
  * For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
  * <p>
  Example: {@code {\"Department\": \"Finance\"}}
  *
      */
    "freeformTags"?: {
        [key: string]: string;
    };
    /**
      * Defined tags for this resource. Each key is predefined and scoped to a namespace.
  * For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
  * <p>
  Example: {@code {\"Operations\": {\"CostCenter\": \"42\"}}}
  *
      */
    "definedTags"?: {
        [key: string]: {
            [key: string]: any;
        };
    };
}
export declare namespace CreateDedicatedAiClusterDetails {
    function getJsonObj(obj: CreateDedicatedAiClusterDetails): object;
    function getDeserializedJsonObj(obj: CreateDedicatedAiClusterDetails): object;
}
