/**
 * Globally Distributed Database
 * Use the Globally Distributed Database service APIs to create and manage distributed databases.
 * OpenAPI spec version: 20230301
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
/**
 * PrivateEndpoint resource.
 */
export interface PrivateEndpoint {
    /**
     * The identifier of the Private Endpoint.
     */
    "id": string;
    /**
     * Identifier of the compartment in which private endpoint exists.
     */
    "compartmentId": string;
    /**
     * Identifier of the subnet in which private endpoint exists.
     */
    "subnetId": string;
    /**
     * Identifier of the VCN in which subnet exists.
     */
    "vcnId": string;
    /**
     * PrivateEndpoint display name.
     */
    "displayName": string;
    /**
     * PrivateEndpoint description.
     */
    "description"?: string;
    /**
     * IP address of the Private Endpoint.
     */
    "privateIp"?: string;
    /**
     * The OCIDs of the network security groups that the private endpoint belongs to.
     *
     */
    "nsgIds"?: Array<string>;
    /**
     * The OCIDs of sharded databases that consumes the given private endpoint.
     */
    "shardedDatabases"?: Array<string>;
    /**
     * The time the PrivateEndpoint was first created. An RFC3339 formatted datetime string
     */
    "timeCreated": Date;
    /**
     * The time the Private Endpoint was last updated. An RFC3339 formatted datetime string
     */
    "timeUpdated": Date;
    /**
     * Lifecycle states for private endpoint.
     */
    "lifecycleState": PrivateEndpoint.LifecycleState;
    /**
     * Detailed message for the lifecycle state.
     */
    "lifecycleStateDetails"?: string;
    /**
     * The identifier of the proxy compute instance.
     */
    "proxyComputeInstanceId"?: string;
    /**
     * Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
     * Example: {@code {\"bar-key\": \"value\"}}
     *
     */
    "freeformTags"?: {
        [key: string]: string;
    };
    /**
     * Defined tags for this resource. Each key is predefined and scoped to a namespace.
     * Example: {@code {\"foo-namespace\": {\"bar-key\": \"value\"}}}
     *
     */
    "definedTags"?: {
        [key: string]: {
            [key: string]: any;
        };
    };
    /**
     * Usage of system tag keys. These predefined keys are scoped to namespaces.
     * Example: {@code {\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}}
     *
     */
    "systemTags"?: {
        [key: string]: {
            [key: string]: any;
        };
    };
}
export declare namespace PrivateEndpoint {
    enum LifecycleState {
        Active = "ACTIVE",
        Failed = "FAILED",
        Inactive = "INACTIVE",
        Deleting = "DELETING",
        Deleted = "DELETED",
        Updating = "UPDATING",
        Creating = "CREATING",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    function getJsonObj(obj: PrivateEndpoint): object;
    function getDeserializedJsonObj(obj: PrivateEndpoint): object;
}
