/**
 * GoldenGate API
 * Use the Oracle Cloud Infrastructure GoldenGate APIs to perform data replication operations.

 * OpenAPI spec version: 20200407
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import common = require("oci-common");
import * as requests from "./request";
import * as model from "./model";
import * as responses from "./response";
import { GoldenGateWaiter } from "./goldengate-waiter";
declare const Breaker: any;
export declare enum GoldenGateApiKeys {
}
/**
 * This service client uses {@link common.CircuitBreaker.DefaultConfiguration} for all the operations by default if no circuit breaker configuration is defined by the user.
 */
export declare class GoldenGateClient {
    protected static serviceEndpointTemplate: string;
    protected static endpointServiceName: string;
    protected "_realmSpecificEndpointTemplateEnabled": boolean | undefined;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_waiters": GoldenGateWaiter;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: typeof Breaker | null;
    protected _httpOptions: any;
    protected _bodyDuplexMode: any;
    targetService: string;
    protected _regionId: string;
    protected "_region": common.Region;
    protected _lastSetRegionOrRegionId: string;
    protected _httpClient: common.HttpClient;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    get endpoint(): string;
    /**
     * Sets the endpoint to call (ex, https://www.example.com).
     * @param endpoint The endpoint of the service.
     */
    set endpoint(endpoint: string);
    get logger(): import("oci-common/lib/log").Logger;
    /**
     * Determines whether realm specific endpoint should be used or not.
     * Set realmSpecificEndpointTemplateEnabled to "true" if the user wants to enable use of realm specific endpoint template, otherwise set it to "false"
     * @param realmSpecificEndpointTemplateEnabled flag to enable the use of realm specific endpoint template
     */
    set useRealmSpecificEndpointTemplate(realmSpecificEndpointTemplateEnabled: boolean);
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    set region(region: common.Region);
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    set regionId(regionId: string);
    /**
     * Creates a new GoldenGateWaiter for resources for this service.
     *
     * @param config The waiter configuration for termination and delay strategy
     * @return The service waiters.
     */
    createWaiters(config?: common.WaiterConfiguration): GoldenGateWaiter;
    /**
     * Gets the waiters available for resources for this service.
     *
     * @return The service waiters.
     */
    getWaiters(): GoldenGateWaiter;
    /**
     * Shutdown the circuit breaker used by the client when it is no longer needed
     */
    shutdownCircuitBreaker(): void;
    /**
     * Close the client once it is no longer needed
     */
    close(): void;
    /**
     * Adds a lock to a Connection resource.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param AddConnectionLockRequest
     * @return AddConnectionLockResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/goldengate/AddConnectionLock.ts.html |here} to see how to use AddConnectionLock API.
     */
    addConnectionLock(addConnectionLockRequest: requests.AddConnectionLockRequest): Promise<responses.AddConnectionLockResponse>;
    /**
     * Adds a lock to a DeploymentBackup resource.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param AddDeploymentBackupLockRequest
     * @return AddDeploymentBackupLockResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/goldengate/AddDeploymentBackupLock.ts.html |here} to see how to use AddDeploymentBackupLock API.
     */
    addDeploymentBackupLock(addDeploymentBackupLockRequest: requests.AddDeploymentBackupLockRequest): Promise<responses.AddDeploymentBackupLockResponse>;
    /**
     * Adds a lock to a Deployment resource.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param AddDeploymentLockRequest
     * @return AddDeploymentLockResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/goldengate/AddDeploymentLock.ts.html |here} to see how to use AddDeploymentLock API.
     */
    addDeploymentLock(addDeploymentLockRequest: requests.AddDeploymentLockRequest): Promise<responses.AddDeploymentLockResponse>;
    /**
     * Cancels a Deployment Backup creation process.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CancelDeploymentBackupRequest
     * @return CancelDeploymentBackupResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/goldengate/CancelDeploymentBackup.ts.html |here} to see how to use CancelDeploymentBackup API.
     */
    cancelDeploymentBackup(cancelDeploymentBackupRequest: requests.CancelDeploymentBackupRequest): Promise<responses.CancelDeploymentBackupResponse>;
    /**
     * Cancels a DeploymentUpgrade, applicable only for DeploymentUpgrade in Waiting state. When provided, If-Match is checked against ETag values of the resource.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CancelDeploymentUpgradeRequest
     * @return CancelDeploymentUpgradeResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/goldengate/CancelDeploymentUpgrade.ts.html |here} to see how to use CancelDeploymentUpgrade API.
     */
    cancelDeploymentUpgrade(cancelDeploymentUpgradeRequest: requests.CancelDeploymentUpgradeRequest): Promise<responses.CancelDeploymentUpgradeResponse>;
    /**
     * Cancel snooze of a DeploymentUpgrade. When provided, If-Match is checked against ETag values of the resource.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CancelSnoozeDeploymentUpgradeRequest
     * @return CancelSnoozeDeploymentUpgradeResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/goldengate/CancelSnoozeDeploymentUpgrade.ts.html |here} to see how to use CancelSnoozeDeploymentUpgrade API.
     */
    cancelSnoozeDeploymentUpgrade(cancelSnoozeDeploymentUpgradeRequest: requests.CancelSnoozeDeploymentUpgradeRequest): Promise<responses.CancelSnoozeDeploymentUpgradeResponse>;
    /**
     * Moves the Connection into a different compartment within the same tenancy. When
     * provided, If-Match is checked against ETag values of the resource.  For information about
     * moving resources between compartments, see [Moving Resources Between
     * Compartments](https://docs.cloud.oracle.com/iaas/Content/Identity/Tasks/managingcompartments.htm#moveRes).
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ChangeConnectionCompartmentRequest
     * @return ChangeConnectionCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/goldengate/ChangeConnectionCompartment.ts.html |here} to see how to use ChangeConnectionCompartment API.
     */
    changeConnectionCompartment(changeConnectionCompartmentRequest: requests.ChangeConnectionCompartmentRequest): Promise<responses.ChangeConnectionCompartmentResponse>;
    /**
     * Note: Deprecated. Use the /connections API instead.
     * Moves the DatabaseRegistration into a different compartment within the same tenancy. When
     * provided, If-Match is checked against ETag values of the resource.  For information about
     * moving resources between compartments, see [Moving Resources Between
     * Compartments](https://docs.cloud.oracle.com/iaas/Content/Identity/Tasks/managingcompartments.htm#moveRes).
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ChangeDatabaseRegistrationCompartmentRequest
     * @return ChangeDatabaseRegistrationCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/goldengate/ChangeDatabaseRegistrationCompartment.ts.html |here} to see how to use ChangeDatabaseRegistrationCompartment API.
     */
    changeDatabaseRegistrationCompartment(changeDatabaseRegistrationCompartmentRequest: requests.ChangeDatabaseRegistrationCompartmentRequest): Promise<responses.ChangeDatabaseRegistrationCompartmentResponse>;
    /**
     * Moves a DeploymentBackup into a different compartment within the same tenancy.  When provided,
     * If-Match is checked against ETag values of the resource.  For information about moving
     * resources between compartments, see [Moving Resources Between
     * Compartments](https://docs.cloud.oracle.com/iaas/Content/Identity/Tasks/managingcompartments.htm#moveRes).
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ChangeDeploymentBackupCompartmentRequest
     * @return ChangeDeploymentBackupCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/goldengate/ChangeDeploymentBackupCompartment.ts.html |here} to see how to use ChangeDeploymentBackupCompartment API.
     */
    changeDeploymentBackupCompartment(changeDeploymentBackupCompartmentRequest: requests.ChangeDeploymentBackupCompartmentRequest): Promise<responses.ChangeDeploymentBackupCompartmentResponse>;
    /**
     * Moves the Deployment into a different compartment within the same tenancy.  When provided,
     * If-Match is checked against ETag values of the resource.  For information about moving
     * resources between compartments, see [Moving Resources Between
     * Compartments](https://docs.cloud.oracle.com/iaas/Content/Identity/Tasks/managingcompartments.htm#moveRes).
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ChangeDeploymentCompartmentRequest
     * @return ChangeDeploymentCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/goldengate/ChangeDeploymentCompartment.ts.html |here} to see how to use ChangeDeploymentCompartment API.
     */
    changeDeploymentCompartment(changeDeploymentCompartmentRequest: requests.ChangeDeploymentCompartmentRequest): Promise<responses.ChangeDeploymentCompartmentResponse>;
    /**
     * Collects the diagnostic of a Deployment. When provided, If-Match is checked against ETag values of the resource.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CollectDeploymentDiagnosticRequest
     * @return CollectDeploymentDiagnosticResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/goldengate/CollectDeploymentDiagnostic.ts.html |here} to see how to use CollectDeploymentDiagnostic API.
     */
    collectDeploymentDiagnostic(collectDeploymentDiagnosticRequest: requests.CollectDeploymentDiagnosticRequest): Promise<responses.CollectDeploymentDiagnosticResponse>;
    /**
     * Creates a copy of a Deployment Backup.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CopyDeploymentBackupRequest
     * @return CopyDeploymentBackupResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/goldengate/CopyDeploymentBackup.ts.html |here} to see how to use CopyDeploymentBackup API.
     */
    copyDeploymentBackup(copyDeploymentBackupRequest: requests.CopyDeploymentBackupRequest): Promise<responses.CopyDeploymentBackupResponse>;
    /**
     * Creates a new certificate to truststore.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateCertificateRequest
     * @return CreateCertificateResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/goldengate/CreateCertificate.ts.html |here} to see how to use CreateCertificate API.
     */
    createCertificate(createCertificateRequest: requests.CreateCertificateRequest): Promise<responses.CreateCertificateResponse>;
    /**
     * Creates a new Connection.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateConnectionRequest
     * @return CreateConnectionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/goldengate/CreateConnection.ts.html |here} to see how to use CreateConnection API.
     */
    createConnection(createConnectionRequest: requests.CreateConnectionRequest): Promise<responses.CreateConnectionResponse>;
    /**
     * Creates a new Connection Assignment.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateConnectionAssignmentRequest
     * @return CreateConnectionAssignmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/goldengate/CreateConnectionAssignment.ts.html |here} to see how to use CreateConnectionAssignment API.
     */
    createConnectionAssignment(createConnectionAssignmentRequest: requests.CreateConnectionAssignmentRequest): Promise<responses.CreateConnectionAssignmentResponse>;
    /**
     * Note: Deprecated. Use the /connections API instead.
     * Creates a new DatabaseRegistration.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateDatabaseRegistrationRequest
     * @return CreateDatabaseRegistrationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/goldengate/CreateDatabaseRegistration.ts.html |here} to see how to use CreateDatabaseRegistration API.
     */
    createDatabaseRegistration(createDatabaseRegistrationRequest: requests.CreateDatabaseRegistrationRequest): Promise<responses.CreateDatabaseRegistrationResponse>;
    /**
     * Creates a new Deployment.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateDeploymentRequest
     * @return CreateDeploymentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/goldengate/CreateDeployment.ts.html |here} to see how to use CreateDeployment API.
     */
    createDeployment(createDeploymentRequest: requests.CreateDeploymentRequest): Promise<responses.CreateDeploymentResponse>;
    /**
     * Creates a new DeploymentBackup.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateDeploymentBackupRequest
     * @return CreateDeploymentBackupResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/goldengate/CreateDeploymentBackup.ts.html |here} to see how to use CreateDeploymentBackup API.
     */
    createDeploymentBackup(createDeploymentBackupRequest: requests.CreateDeploymentBackupRequest): Promise<responses.CreateDeploymentBackupResponse>;
    /**
     * Deletes the certificate from truststore.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteCertificateRequest
     * @return DeleteCertificateResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/goldengate/DeleteCertificate.ts.html |here} to see how to use DeleteCertificate API.
     */
    deleteCertificate(deleteCertificateRequest: requests.DeleteCertificateRequest): Promise<responses.DeleteCertificateResponse>;
    /**
     * Deletes a Connection.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteConnectionRequest
     * @return DeleteConnectionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/goldengate/DeleteConnection.ts.html |here} to see how to use DeleteConnection API.
     */
    deleteConnection(deleteConnectionRequest: requests.DeleteConnectionRequest): Promise<responses.DeleteConnectionResponse>;
    /**
     * Deletes a Connection Assignment.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteConnectionAssignmentRequest
     * @return DeleteConnectionAssignmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/goldengate/DeleteConnectionAssignment.ts.html |here} to see how to use DeleteConnectionAssignment API.
     */
    deleteConnectionAssignment(deleteConnectionAssignmentRequest: requests.DeleteConnectionAssignmentRequest): Promise<responses.DeleteConnectionAssignmentResponse>;
    /**
     * Note: Deprecated. Use the /connections API instead.
     * Deletes a DatabaseRegistration.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteDatabaseRegistrationRequest
     * @return DeleteDatabaseRegistrationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/goldengate/DeleteDatabaseRegistration.ts.html |here} to see how to use DeleteDatabaseRegistration API.
     */
    deleteDatabaseRegistration(deleteDatabaseRegistrationRequest: requests.DeleteDatabaseRegistrationRequest): Promise<responses.DeleteDatabaseRegistrationResponse>;
    /**
     * Deletes the Deployment.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteDeploymentRequest
     * @return DeleteDeploymentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/goldengate/DeleteDeployment.ts.html |here} to see how to use DeleteDeployment API.
     */
    deleteDeployment(deleteDeploymentRequest: requests.DeleteDeploymentRequest): Promise<responses.DeleteDeploymentResponse>;
    /**
     * Deletes a DeploymentBackup.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteDeploymentBackupRequest
     * @return DeleteDeploymentBackupResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/goldengate/DeleteDeploymentBackup.ts.html |here} to see how to use DeleteDeploymentBackup API.
     */
    deleteDeploymentBackup(deleteDeploymentBackupRequest: requests.DeleteDeploymentBackupRequest): Promise<responses.DeleteDeploymentBackupResponse>;
    /**
     * Checks if a wallet is already present in the deployment. When provided, If-Match is checked against ETag values of the resource.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeploymentWalletExistsRequest
     * @return DeploymentWalletExistsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/goldengate/DeploymentWalletExists.ts.html |here} to see how to use DeploymentWalletExists API.
     */
    deploymentWalletExists(deploymentWalletExistsRequest: requests.DeploymentWalletExistsRequest): Promise<responses.DeploymentWalletExistsResponse>;
    /**
     * Export the OGG wallet from the deployment to OCI vault. When provided, If-Match is checked against ETag values of the resource.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ExportDeploymentWalletRequest
     * @return ExportDeploymentWalletResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/goldengate/ExportDeploymentWallet.ts.html |here} to see how to use ExportDeploymentWallet API.
     */
    exportDeploymentWallet(exportDeploymentWalletRequest: requests.ExportDeploymentWalletRequest): Promise<responses.ExportDeploymentWalletResponse>;
    /**
     * Generates a Pre-Authenticated Request Object URL to a DB2 for z/OS library that needs to be uploaded to your DB2 for z/OS server in order to establish GoldenGate connections to it. For licensing reasons, the URL is accessible for 10 minutes only.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GenerateLibraryUrlRequest
     * @return GenerateLibraryUrlResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/goldengate/GenerateLibraryUrl.ts.html |here} to see how to use GenerateLibraryUrl API.
     */
    generateLibraryUrl(generateLibraryUrlRequest: requests.GenerateLibraryUrlRequest): Promise<responses.GenerateLibraryUrlResponse>;
    /**
     * Retrieves a Certificate.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetCertificateRequest
     * @return GetCertificateResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/goldengate/GetCertificate.ts.html |here} to see how to use GetCertificate API.
     */
    getCertificate(getCertificateRequest: requests.GetCertificateRequest): Promise<responses.GetCertificateResponse>;
    /**
     * Retrieves a Connection.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetConnectionRequest
     * @return GetConnectionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/goldengate/GetConnection.ts.html |here} to see how to use GetConnection API.
     */
    getConnection(getConnectionRequest: requests.GetConnectionRequest): Promise<responses.GetConnectionResponse>;
    /**
     * Retrieves a Connection Assignment.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetConnectionAssignmentRequest
     * @return GetConnectionAssignmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/goldengate/GetConnectionAssignment.ts.html |here} to see how to use GetConnectionAssignment API.
     */
    getConnectionAssignment(getConnectionAssignmentRequest: requests.GetConnectionAssignmentRequest): Promise<responses.GetConnectionAssignmentResponse>;
    /**
     * Note: Deprecated. Use the /connections API instead.
     * Retrieves a DatabaseRegistration.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetDatabaseRegistrationRequest
     * @return GetDatabaseRegistrationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/goldengate/GetDatabaseRegistration.ts.html |here} to see how to use GetDatabaseRegistration API.
     */
    getDatabaseRegistration(getDatabaseRegistrationRequest: requests.GetDatabaseRegistrationRequest): Promise<responses.GetDatabaseRegistrationResponse>;
    /**
     * Retrieves a deployment.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetDeploymentRequest
     * @return GetDeploymentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/goldengate/GetDeployment.ts.html |here} to see how to use GetDeployment API.
     */
    getDeployment(getDeploymentRequest: requests.GetDeploymentRequest): Promise<responses.GetDeploymentResponse>;
    /**
     * Retrieves a DeploymentBackup.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetDeploymentBackupRequest
     * @return GetDeploymentBackupResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/goldengate/GetDeploymentBackup.ts.html |here} to see how to use GetDeploymentBackup API.
     */
    getDeploymentBackup(getDeploymentBackupRequest: requests.GetDeploymentBackupRequest): Promise<responses.GetDeploymentBackupResponse>;
    /**
     * Retrieves a deployment upgrade.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetDeploymentUpgradeRequest
     * @return GetDeploymentUpgradeResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/goldengate/GetDeploymentUpgrade.ts.html |here} to see how to use GetDeploymentUpgrade API.
     */
    getDeploymentUpgrade(getDeploymentUpgradeRequest: requests.GetDeploymentUpgradeRequest): Promise<responses.GetDeploymentUpgradeResponse>;
    /**
     * Retrieve the WorkRequest identified by the given OCID.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetWorkRequestRequest
     * @return GetWorkRequestResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/goldengate/GetWorkRequest.ts.html |here} to see how to use GetWorkRequest API.
     */
    getWorkRequest(getWorkRequestRequest: requests.GetWorkRequestRequest): Promise<responses.GetWorkRequestResponse>;
    /**
     * Imports an OGG wallet from the OCI Vault to the Deployment. When provided, If-Match is checked against ETag values of the resource.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ImportDeploymentWalletRequest
     * @return ImportDeploymentWalletResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/goldengate/ImportDeploymentWallet.ts.html |here} to see how to use ImportDeploymentWallet API.
     */
    importDeploymentWallet(importDeploymentWalletRequest: requests.ImportDeploymentWalletRequest): Promise<responses.ImportDeploymentWalletResponse>;
    /**
     * Returns a list of certificates from truststore.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListCertificatesRequest
     * @return ListCertificatesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/goldengate/ListCertificates.ts.html |here} to see how to use ListCertificates API.
     */
    listCertificates(listCertificatesRequest: requests.ListCertificatesRequest): Promise<responses.ListCertificatesResponse>;
    /**
     * Lists the Connection Assignments in the compartment.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListConnectionAssignmentsRequest
     * @return ListConnectionAssignmentsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/goldengate/ListConnectionAssignments.ts.html |here} to see how to use ListConnectionAssignments API.
     */
    listConnectionAssignments(listConnectionAssignmentsRequest: requests.ListConnectionAssignmentsRequest): Promise<responses.ListConnectionAssignmentsResponse>;
    /**
     * Lists the Connections in the compartment.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListConnectionsRequest
     * @return ListConnectionsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/goldengate/ListConnections.ts.html |here} to see how to use ListConnections API.
     */
    listConnections(listConnectionsRequest: requests.ListConnectionsRequest): Promise<responses.ListConnectionsResponse>;
    /**
     * Note: Deprecated. Use the /connections API instead.
     * Lists the DatabaseRegistrations in the compartment.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListDatabaseRegistrationsRequest
     * @return ListDatabaseRegistrationsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/goldengate/ListDatabaseRegistrations.ts.html |here} to see how to use ListDatabaseRegistrations API.
     */
    listDatabaseRegistrations(listDatabaseRegistrationsRequest: requests.ListDatabaseRegistrationsRequest): Promise<responses.ListDatabaseRegistrationsResponse>;
    /**
     * Lists the Backups in a compartment.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListDeploymentBackupsRequest
     * @return ListDeploymentBackupsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/goldengate/ListDeploymentBackups.ts.html |here} to see how to use ListDeploymentBackups API.
     */
    listDeploymentBackups(listDeploymentBackupsRequest: requests.ListDeploymentBackupsRequest): Promise<responses.ListDeploymentBackupsResponse>;
    /**
     * Returns an array of DeploymentTypeDescriptor
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListDeploymentTypesRequest
     * @return ListDeploymentTypesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/goldengate/ListDeploymentTypes.ts.html |here} to see how to use ListDeploymentTypes API.
     */
    listDeploymentTypes(listDeploymentTypesRequest: requests.ListDeploymentTypesRequest): Promise<responses.ListDeploymentTypesResponse>;
    /**
     * Lists the Deployment Upgrades in a compartment.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListDeploymentUpgradesRequest
     * @return ListDeploymentUpgradesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/goldengate/ListDeploymentUpgrades.ts.html |here} to see how to use ListDeploymentUpgrades API.
     */
    listDeploymentUpgrades(listDeploymentUpgradesRequest: requests.ListDeploymentUpgradesRequest): Promise<responses.ListDeploymentUpgradesResponse>;
    /**
     * Returns the list of available deployment versions.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListDeploymentVersionsRequest
     * @return ListDeploymentVersionsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/goldengate/ListDeploymentVersions.ts.html |here} to see how to use ListDeploymentVersions API.
     */
    listDeploymentVersions(listDeploymentVersionsRequest: requests.ListDeploymentVersionsRequest): Promise<responses.ListDeploymentVersionsResponse>;
    /**
     * Lists the wallets export/import operations to/from a deployment.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListDeploymentWalletsOperationsRequest
     * @return ListDeploymentWalletsOperationsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/goldengate/ListDeploymentWalletsOperations.ts.html |here} to see how to use ListDeploymentWalletsOperations API.
     */
    listDeploymentWalletsOperations(listDeploymentWalletsOperationsRequest: requests.ListDeploymentWalletsOperationsRequest): Promise<responses.ListDeploymentWalletsOperationsResponse>;
    /**
     * Lists the Deployments in a compartment.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListDeploymentsRequest
     * @return ListDeploymentsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/goldengate/ListDeployments.ts.html |here} to see how to use ListDeployments API.
     */
    listDeployments(listDeploymentsRequest: requests.ListDeploymentsRequest): Promise<responses.ListDeploymentsResponse>;
    /**
     * Lists the DeploymentMessages for a deployment. The sorting order is not important. By default first will be Upgrade message, next Exception message and then Storage Utilization message.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListMessagesRequest
     * @return ListMessagesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/goldengate/ListMessages.ts.html |here} to see how to use ListMessages API.
     */
    listMessages(listMessagesRequest: requests.ListMessagesRequest): Promise<responses.ListMessagesResponse>;
    /**
     * Lists the TrailFiles for a deployment. Deprecated: Please access trail file management functions directly on OGG console which are available since version Oracle GoldenGate 23c.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListTrailFilesRequest
     * @return ListTrailFilesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/goldengate/ListTrailFiles.ts.html |here} to see how to use ListTrailFiles API.
     */
    listTrailFiles(listTrailFilesRequest: requests.ListTrailFilesRequest): Promise<responses.ListTrailFilesResponse>;
    /**
     * Lists the Trail Sequences for a TrailFile in a given deployment. Deprecated: Please access trail file management functions directly on OGG console which are available since version Oracle GoldenGate 23c.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListTrailSequencesRequest
     * @return ListTrailSequencesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/goldengate/ListTrailSequences.ts.html |here} to see how to use ListTrailSequences API.
     */
    listTrailSequences(listTrailSequencesRequest: requests.ListTrailSequencesRequest): Promise<responses.ListTrailSequencesResponse>;
    /**
     * Lists work request errors.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListWorkRequestErrorsRequest
     * @return ListWorkRequestErrorsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/goldengate/ListWorkRequestErrors.ts.html |here} to see how to use ListWorkRequestErrors API.
     */
    listWorkRequestErrors(listWorkRequestErrorsRequest: requests.ListWorkRequestErrorsRequest): Promise<responses.ListWorkRequestErrorsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listWorkRequestErrorsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.WorkRequestError objects
     * contained in responses from the listWorkRequestErrors operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllWorkRequestErrors(request: requests.ListWorkRequestErrorsRequest): AsyncIterableIterator<model.WorkRequestError>;
    /**
     * NOTE: This function is deprecated in favor of listWorkRequestErrorsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listWorkRequestErrors operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllWorkRequestErrorsResponses(request: requests.ListWorkRequestErrorsRequest): AsyncIterableIterator<responses.ListWorkRequestErrorsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.WorkRequestError objects
     * contained in responses from the listWorkRequestErrors operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listWorkRequestErrorsRecordIterator(request: requests.ListWorkRequestErrorsRequest): AsyncIterableIterator<model.WorkRequestError>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listWorkRequestErrors operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listWorkRequestErrorsResponseIterator(request: requests.ListWorkRequestErrorsRequest): AsyncIterableIterator<responses.ListWorkRequestErrorsResponse>;
    /**
     * Lists work request logs.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListWorkRequestLogsRequest
     * @return ListWorkRequestLogsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/goldengate/ListWorkRequestLogs.ts.html |here} to see how to use ListWorkRequestLogs API.
     */
    listWorkRequestLogs(listWorkRequestLogsRequest: requests.ListWorkRequestLogsRequest): Promise<responses.ListWorkRequestLogsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listWorkRequestLogsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.WorkRequestLogEntry objects
     * contained in responses from the listWorkRequestLogs operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllWorkRequestLogs(request: requests.ListWorkRequestLogsRequest): AsyncIterableIterator<model.WorkRequestLogEntry>;
    /**
     * NOTE: This function is deprecated in favor of listWorkRequestLogsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listWorkRequestLogs operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllWorkRequestLogsResponses(request: requests.ListWorkRequestLogsRequest): AsyncIterableIterator<responses.ListWorkRequestLogsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.WorkRequestLogEntry objects
     * contained in responses from the listWorkRequestLogs operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listWorkRequestLogsRecordIterator(request: requests.ListWorkRequestLogsRequest): AsyncIterableIterator<model.WorkRequestLogEntry>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listWorkRequestLogs operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listWorkRequestLogsResponseIterator(request: requests.ListWorkRequestLogsRequest): AsyncIterableIterator<responses.ListWorkRequestLogsResponse>;
    /**
     * Lists the work requests in the compartment.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListWorkRequestsRequest
     * @return ListWorkRequestsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/goldengate/ListWorkRequests.ts.html |here} to see how to use ListWorkRequests API.
     */
    listWorkRequests(listWorkRequestsRequest: requests.ListWorkRequestsRequest): Promise<responses.ListWorkRequestsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listWorkRequestsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.WorkRequest objects
     * contained in responses from the listWorkRequests operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllWorkRequests(request: requests.ListWorkRequestsRequest): AsyncIterableIterator<model.WorkRequest>;
    /**
     * NOTE: This function is deprecated in favor of listWorkRequestsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listWorkRequests operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllWorkRequestsResponses(request: requests.ListWorkRequestsRequest): AsyncIterableIterator<responses.ListWorkRequestsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.WorkRequest objects
     * contained in responses from the listWorkRequests operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listWorkRequestsRecordIterator(request: requests.ListWorkRequestsRequest): AsyncIterableIterator<model.WorkRequest>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listWorkRequests operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listWorkRequestsResponseIterator(request: requests.ListWorkRequestsRequest): AsyncIterableIterator<responses.ListWorkRequestsResponse>;
    /**
     * Removes a lock from a Connection resource.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param RemoveConnectionLockRequest
     * @return RemoveConnectionLockResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/goldengate/RemoveConnectionLock.ts.html |here} to see how to use RemoveConnectionLock API.
     */
    removeConnectionLock(removeConnectionLockRequest: requests.RemoveConnectionLockRequest): Promise<responses.RemoveConnectionLockResponse>;
    /**
     * Removes a lock from a DeploymentBackup resource.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param RemoveDeploymentBackupLockRequest
     * @return RemoveDeploymentBackupLockResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/goldengate/RemoveDeploymentBackupLock.ts.html |here} to see how to use RemoveDeploymentBackupLock API.
     */
    removeDeploymentBackupLock(removeDeploymentBackupLockRequest: requests.RemoveDeploymentBackupLockRequest): Promise<responses.RemoveDeploymentBackupLockResponse>;
    /**
     * Removes a lock from a Deployment resource.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param RemoveDeploymentLockRequest
     * @return RemoveDeploymentLockResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/goldengate/RemoveDeploymentLock.ts.html |here} to see how to use RemoveDeploymentLock API.
     */
    removeDeploymentLock(removeDeploymentLockRequest: requests.RemoveDeploymentLockRequest): Promise<responses.RemoveDeploymentLockResponse>;
    /**
     * Reschedules a DeploymentUpgrade, applicable only for DeploymentUpgrade in Waiting state. When provided, If-Match is checked against ETag values of the resource.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param RescheduleDeploymentUpgradeRequest
     * @return RescheduleDeploymentUpgradeResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/goldengate/RescheduleDeploymentUpgrade.ts.html |here} to see how to use RescheduleDeploymentUpgrade API.
     */
    rescheduleDeploymentUpgrade(rescheduleDeploymentUpgradeRequest: requests.RescheduleDeploymentUpgradeRequest): Promise<responses.RescheduleDeploymentUpgradeResponse>;
    /**
     * Restores a Deployment from a Deployment Backup created from the same Deployment.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param RestoreDeploymentRequest
     * @return RestoreDeploymentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/goldengate/RestoreDeployment.ts.html |here} to see how to use RestoreDeployment API.
     */
    restoreDeployment(restoreDeploymentRequest: requests.RestoreDeploymentRequest): Promise<responses.RestoreDeploymentResponse>;
    /**
     * Rollback a deployment to it's previous version. When provided, If-Match is checked against ETag values of the resource.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param RollbackDeploymentUpgradeRequest
     * @return RollbackDeploymentUpgradeResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/goldengate/RollbackDeploymentUpgrade.ts.html |here} to see how to use RollbackDeploymentUpgrade API.
     */
    rollbackDeploymentUpgrade(rollbackDeploymentUpgradeRequest: requests.RollbackDeploymentUpgradeRequest): Promise<responses.RollbackDeploymentUpgradeResponse>;
    /**
     * Snooze a DeploymentUpgrade. When provided, If-Match is checked against ETag values of the resource.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SnoozeDeploymentUpgradeRequest
     * @return SnoozeDeploymentUpgradeResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/goldengate/SnoozeDeploymentUpgrade.ts.html |here} to see how to use SnoozeDeploymentUpgrade API.
     */
    snoozeDeploymentUpgrade(snoozeDeploymentUpgradeRequest: requests.SnoozeDeploymentUpgradeRequest): Promise<responses.SnoozeDeploymentUpgradeResponse>;
    /**
     * Starts a Deployment. When provided, If-Match is checked against ETag values of the resource.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param StartDeploymentRequest
     * @return StartDeploymentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/goldengate/StartDeployment.ts.html |here} to see how to use StartDeployment API.
     */
    startDeployment(startDeploymentRequest: requests.StartDeploymentRequest): Promise<responses.StartDeploymentResponse>;
    /**
     * Stops a Deployment. When provided, If-Match is checked against ETag values of the resource.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param StopDeploymentRequest
     * @return StopDeploymentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/goldengate/StopDeployment.ts.html |here} to see how to use StopDeployment API.
     */
    stopDeployment(stopDeploymentRequest: requests.StopDeploymentRequest): Promise<responses.StopDeploymentResponse>;
    /**
     * Tests the connectivity between given GoldenGate deployment and one of the associated database / service.
     * When provided, If-Match is checked against ETag values of the resource.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param TestConnectionAssignmentRequest
     * @return TestConnectionAssignmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/goldengate/TestConnectionAssignment.ts.html |here} to see how to use TestConnectionAssignment API.
     */
    testConnectionAssignment(testConnectionAssignmentRequest: requests.TestConnectionAssignmentRequest): Promise<responses.TestConnectionAssignmentResponse>;
    /**
     * Updates the Connection.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateConnectionRequest
     * @return UpdateConnectionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/goldengate/UpdateConnection.ts.html |here} to see how to use UpdateConnection API.
     */
    updateConnection(updateConnectionRequest: requests.UpdateConnectionRequest): Promise<responses.UpdateConnectionResponse>;
    /**
     * Note: Deprecated. Use the /connections API instead.
     * Updates the DatabaseRegistration.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateDatabaseRegistrationRequest
     * @return UpdateDatabaseRegistrationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/goldengate/UpdateDatabaseRegistration.ts.html |here} to see how to use UpdateDatabaseRegistration API.
     */
    updateDatabaseRegistration(updateDatabaseRegistrationRequest: requests.UpdateDatabaseRegistrationRequest): Promise<responses.UpdateDatabaseRegistrationResponse>;
    /**
     * Modifies a Deployment.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateDeploymentRequest
     * @return UpdateDeploymentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/goldengate/UpdateDeployment.ts.html |here} to see how to use UpdateDeployment API.
     */
    updateDeployment(updateDeploymentRequest: requests.UpdateDeploymentRequest): Promise<responses.UpdateDeploymentResponse>;
    /**
     * Modifies a Deployment Backup.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateDeploymentBackupRequest
     * @return UpdateDeploymentBackupResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/goldengate/UpdateDeploymentBackup.ts.html |here} to see how to use UpdateDeploymentBackup API.
     */
    updateDeploymentBackup(updateDeploymentBackupRequest: requests.UpdateDeploymentBackupRequest): Promise<responses.UpdateDeploymentBackupResponse>;
    /**
     * Upgrade a Deployment. When provided, If-Match is checked against ETag values of the resource.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpgradeDeploymentRequest
     * @return UpgradeDeploymentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/goldengate/UpgradeDeployment.ts.html |here} to see how to use UpgradeDeployment API.
     */
    upgradeDeployment(upgradeDeploymentRequest: requests.UpgradeDeploymentRequest): Promise<responses.UpgradeDeploymentResponse>;
    /**
     * Upgrade a deployment. When provided, If-Match is checked against ETag values of the resource.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpgradeDeploymentUpgradeRequest
     * @return UpgradeDeploymentUpgradeResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/goldengate/UpgradeDeploymentUpgrade.ts.html |here} to see how to use UpgradeDeploymentUpgrade API.
     */
    upgradeDeploymentUpgrade(upgradeDeploymentUpgradeRequest: requests.UpgradeDeploymentUpgradeRequest): Promise<responses.UpgradeDeploymentUpgradeResponse>;
}
export {};
