/**
 * GoldenGate API
 * Use the Oracle Cloud Infrastructure GoldenGate APIs to perform data replication operations.

 * OpenAPI spec version: 20200407
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
/**
 * The information about a new DatabaseRegistration.
 *
 */
export interface CreateDatabaseRegistrationDetails {
    /**
     * An object's Display Name.
     *
     */
    "displayName": string;
    /**
     * Metadata about this specific object.
     *
     */
    "description"?: string;
    /**
     * The [OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment being referenced.
     *
     */
    "compartmentId": string;
    /**
      * A simple key-value pair that is applied without any predefined name, type, or scope. Exists
  * for cross-compatibility only.
  * <p>
  Example: {@code {\"bar-key\": \"value\"}}
  *
      */
    "freeformTags"?: {
        [key: string]: string;
    };
    /**
      * Tags defined for this resource. Each key is predefined and scoped to a namespace.
  * <p>
  Example: {@code {\"foo-namespace\": {\"bar-key\": \"value\"}}}
  *
      */
    "definedTags"?: {
        [key: string]: {
            [key: string]: any;
        };
    };
    /**
     * A three-label Fully Qualified Domain Name (FQDN) for a resource.
     *
     */
    "fqdn": string;
    /**
     * The private IP address in the customer's VCN of the customer's endpoint, typically a
     * database.
     *
     */
    "ipAddress"?: string;
    /**
     * The [OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the target subnet of the dedicated connection.
     *
     */
    "subnetId"?: string;
    /**
     * The [OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the database being referenced.
     *
     */
    "databaseId"?: string;
    /**
     * The username Oracle GoldenGate uses to connect the associated system of the given technology.
     * This username must already exist and be available by the system/application to be connected to
     * and must conform to the case sensitivty requirments defined in it.
     *
     */
    "username": string;
    /**
     * The password Oracle GoldenGate uses to connect the associated system of the given technology.
     * It must conform to the specific security requirements including length, case sensitivity, and so on.
     *
     */
    "password": string;
    /**
     * Connect descriptor or Easy Connect Naming method used to connect to a database.
     *
     */
    "connectionString"?: string;
    /**
     * The mode of the database connection session to be established by the data client.
     * 'REDIRECT' - for a RAC database, 'DIRECT' - for a non-RAC database.
     * Connection to a RAC database involves a redirection received from the SCAN listeners
     * to the database node to connect to. By default the mode would be DIRECT.
     *
     */
    "sessionMode"?: CreateDatabaseRegistrationDetails.SessionMode;
    /**
     * The wallet contents Oracle GoldenGate uses to make connections to a database.  This
     * attribute is expected to be base64 encoded.
     *
     */
    "wallet"?: string;
    /**
     * Credential store alias.
     *
     */
    "aliasName": string;
    /**
     * Refers to the customer's vault OCID.
     * If provided, it references a vault where GoldenGate can manage secrets. Customers must add policies to permit GoldenGate
     * to manage secrets contained within this vault.
     *
     */
    "vaultId"?: string;
    /**
     * Refers to the customer's master key OCID.
     * If provided, it references a key to manage secrets. Customers must add policies to permit GoldenGate to use this key.
     *
     */
    "keyId"?: string;
    /**
     * The OCID of the compartment where the GoldenGate Secret will be created.
     * If provided, it references a key to manage secrets. Customers must add policies to permit GoldenGate to use this key.
     *
     */
    "secretCompartmentId"?: string;
}
export declare namespace CreateDatabaseRegistrationDetails {
    enum SessionMode {
        Direct = "DIRECT",
        Redirect = "REDIRECT"
    }
    function getJsonObj(obj: CreateDatabaseRegistrationDetails): object;
    function getDeserializedJsonObj(obj: CreateDatabaseRegistrationDetails): object;
}
