/**
 * GoldenGate API
 * Use the Oracle Cloud Infrastructure GoldenGate APIs to perform data replication operations.

 * OpenAPI spec version: 20200407
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * Represents the metadata of an Oracle Database Connection.
 *
 */
export interface OracleConnection extends model.Connection {
    /**
     * The Oracle technology type.
     */
    "technologyType": OracleConnection.TechnologyType;
    /**
     * The username Oracle GoldenGate uses to connect the associated system of the given technology.
     * This username must already exist and be available by the system/application to be connected to
     * and must conform to the case sensitivty requirments defined in it.
     *
     */
    "username": string;
    /**
     * Connect descriptor or Easy Connect Naming method used to connect to a database.
     *
     */
    "connectionString"?: string;
    /**
     * Authentication mode. It can be provided at creation of Oracle Autonomous Database Serverless connections,
     * when a databaseId is provided. The default value is MTLS.
     *
     */
    "authenticationMode"?: OracleConnection.AuthenticationMode;
    /**
     * The mode of the database connection session to be established by the data client.
     * 'REDIRECT' - for a RAC database, 'DIRECT' - for a non-RAC database.
     * Connection to a RAC database involves a redirection received from the SCAN listeners
     * to the database node to connect to. By default the mode would be DIRECT.
     *
     */
    "sessionMode"?: OracleConnection.SessionMode;
    /**
      * Deprecated: this field will be removed in future versions. Either specify the private IP in the connectionString or host
  * field, or make sure the host name is resolvable in the target VCN.
  * <p>
  The private IP address of the connection's endpoint in the customer's VCN, typically a
  * database endpoint or a big data endpoint (e.g. Kafka bootstrap server).
  * In case the privateIp is provided, the subnetId must also be provided.
  * In case the privateIp (and the subnetId) is not provided it is assumed the datasource is publicly accessible.
  * In case the connection is accessible only privately, the lack of privateIp will result in not being able to access the connection.
  *
      */
    "privateIp"?: string;
    /**
     * The [OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the database being referenced.
     *
     */
    "databaseId"?: string;
    "connectionType": string;
}
export declare namespace OracleConnection {
    enum TechnologyType {
        AmazonRdsOracle = "AMAZON_RDS_ORACLE",
        OciAutonomousDatabase = "OCI_AUTONOMOUS_DATABASE",
        OracleDatabase = "ORACLE_DATABASE",
        OracleExadata = "ORACLE_EXADATA",
        OracleExadataDatabaseAtAzure = "ORACLE_EXADATA_DATABASE_AT_AZURE",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    enum AuthenticationMode {
        Tls = "TLS",
        Mtls = "MTLS",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    enum SessionMode {
        Direct = "DIRECT",
        Redirect = "REDIRECT",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    function getJsonObj(obj: OracleConnection, isParentJsonObj?: boolean): object;
    const connectionType = "ORACLE";
    function getDeserializedJsonObj(obj: OracleConnection, isParentJsonObj?: boolean): object;
}
