/**
 * GoldenGate API
 * Use the Oracle Cloud Infrastructure GoldenGate APIs to perform data replication operations.

 * OpenAPI spec version: 20200407
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * Represents the metadata of a Redis Database Connection.
 *
 */
export interface RedisConnection extends model.Connection {
    /**
     * The Redis technology type.
     */
    "technologyType": RedisConnection.TechnologyType;
    /**
     * Comma separated list of Redis server addresses, specified as host:port entries, where :port is optional.
     * If port is not specified, it defaults to 6379.
     * Used for establishing the initial connection to the Redis cluster.
     * Example: {@code \"server1.example.com:6379,server2.example.com:6379\"}
     *
     */
    "servers": string;
    /**
     * Security protocol for Redis
     */
    "securityProtocol": RedisConnection.SecurityProtocol;
    /**
     * Authentication type for Redis.
     */
    "authenticationType": RedisConnection.AuthenticationType;
    /**
     * The username Oracle GoldenGate uses to connect the associated system of the given technology.
     * This username must already exist and be available by the system/application to be connected to
     * and must conform to the case sensitivty requirments defined in it.
     *
     */
    "username"?: string;
    /**
     * The [OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Redis cluster.
     *
     */
    "redisClusterId"?: string;
    "connectionType": string;
}
export declare namespace RedisConnection {
    enum TechnologyType {
        Redis = "REDIS",
        OciCacheWithRedis = "OCI_CACHE_WITH_REDIS",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    enum SecurityProtocol {
        Plain = "PLAIN",
        Tls = "TLS",
        Mtls = "MTLS",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    enum AuthenticationType {
        None = "NONE",
        Basic = "BASIC",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    function getJsonObj(obj: RedisConnection, isParentJsonObj?: boolean): object;
    const connectionType = "REDIS";
    function getDeserializedJsonObj(obj: RedisConnection, isParentJsonObj?: boolean): object;
}
