/**
 * Identity and Access Management Service API
 * Use the Identity and Access Management Service API to manage users, groups, identity domains, compartments, policies, tagging, and limits. For information about managing users, groups, compartments, and policies, see [Identity and Access Management (without identity domains)](/iaas/Content/Identity/Concepts/overview.htm). For information about tagging and service limits, see [Tagging](/iaas/Content/Tagging/Concepts/taggingoverview.htm) and [Service Limits](/iaas/Content/General/Concepts/servicelimits.htm). For information about creating, modifying, and deleting identity domains, see [Identity and Access Management (with identity domains)](/iaas/Content/Identity/home.htm).
 * OpenAPI spec version: 20160918
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
/**
* An {@code AuthToken} is an Oracle-generated token string that you can use to authenticate with third-party APIs
* that do not support Oracle Cloud Infrastructure's signature-based authentication. For example, use an {@code AuthToken}
* to authenticate with a Swift client with the Object Storage Service.
* <p>
The auth token is associated with the user's Console login. Auth tokens never expire. A user can have up to two
* auth tokens at a time.
* <p>
**Note:** The token is always an Oracle-generated string; you can't change it to a string of your choice.
* <p>
For more information, see [Managing User Credentials](https://docs.cloud.oracle.com/Content/Identity/access/managing-user-credentials.htm).
*
*/
export interface AuthToken {
    /**
     * The auth token. The value is available only in the response for {@code CreateAuthToken}, and not
     * for {@code ListAuthTokens} or {@code UpdateAuthToken}.
     *
     */
    "token"?: string;
    /**
     * The OCID of the auth token.
     */
    "id"?: string;
    /**
     * The OCID of the user the auth token belongs to.
     */
    "userId"?: string;
    /**
      * The description you assign to the auth token. Does not have to be unique, and it's changeable.
  * <p>
  (For tenancies that support identity domains) You can have an empty description.
  *
      */
    "description"?: string;
    /**
      * Date and time the {@code AuthToken} object was created, in the format defined by RFC3339.
  * <p>
  Example: {@code 2016-08-25T21:10:29.600Z}
  *
      */
    "timeCreated"?: Date;
    /**
      * Date and time when this auth token will expire, in the format defined by RFC3339.
  * Null if it never expires.
  * <p>
  Example: {@code 2016-08-25T21:10:29.600Z}
  *
      */
    "timeExpires"?: Date;
    /**
     * The token's current state. After creating an auth token, make sure its {@code lifecycleState} changes from
     * CREATING to ACTIVE before using it.
     *
     */
    "lifecycleState"?: AuthToken.LifecycleState;
    /**
     * The detailed status of INACTIVE lifecycleState. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "inactiveStatus"?: number;
}
export declare namespace AuthToken {
    enum LifecycleState {
        Creating = "CREATING",
        Active = "ACTIVE",
        Inactive = "INACTIVE",
        Deleting = "DELETING",
        Deleted = "DELETED",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    function getJsonObj(obj: AuthToken): object;
    function getDeserializedJsonObj(obj: AuthToken): object;
}
