/**
 * Identity and Access Management Service API
 * Use the Identity and Access Management Service API to manage users, groups, identity domains, compartments, policies, tagging, and limits. For information about managing users, groups, compartments, and policies, see [Identity and Access Management (without identity domains)](/iaas/Content/Identity/Concepts/overview.htm). For information about tagging and service limits, see [Tagging](/iaas/Content/Tagging/Concepts/taggingoverview.htm) and [Service Limits](/iaas/Content/General/Concepts/servicelimits.htm). For information about creating, modifying, and deleting identity domains, see [Identity and Access Management (with identity domains)](/iaas/Content/Identity/home.htm).
 * OpenAPI spec version: 20160918
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
/**
 * As the name suggests, a {@code MfaTotpDeviceSummary} object contains information about a {@code MfaTotpDevice}.
 *
 */
export interface MfaTotpDeviceSummary {
    /**
     * The OCID of the MFA TOTP Device.
     */
    "id": string;
    /**
     * The OCID of the user the MFA TOTP device belongs to.
     */
    "userId": string;
    /**
      * Date and time the {@code MfaTotpDevice} object was created, in the format defined by RFC3339.
  * <p>
  Example: {@code 2016-08-25T21:10:29.600Z}
  *
      */
    "timeCreated": Date;
    /**
      * Date and time when this MFA TOTP device will expire, in the format defined by RFC3339.
  * Null if it never expires.
  * <p>
  Example: {@code 2016-08-25T21:10:29.600Z}
  *
      */
    "timeExpires"?: Date;
    /**
     * The MFA TOTP device's current state.
     *
     */
    "lifecycleState": MfaTotpDeviceSummary.LifecycleState;
    /**
     * The detailed status of INACTIVE lifecycleState.
     * Allowed values are:
     *  - 1 - SUSPENDED
     *  - 2 - DISABLED
     *  - 4 - BLOCKED
     *  - 8 - LOCKED
     *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "inactiveStatus"?: number;
    /**
     * Flag to indicate if the MFA TOTP device has been activated
     */
    "isActivated": boolean;
}
export declare namespace MfaTotpDeviceSummary {
    enum LifecycleState {
        Creating = "CREATING",
        Active = "ACTIVE",
        Inactive = "INACTIVE",
        Deleting = "DELETING",
        Deleted = "DELETED",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    function getJsonObj(obj: MfaTotpDeviceSummary): object;
    function getDeserializedJsonObj(obj: MfaTotpDeviceSummary): object;
}
