/**
 * Identity and Access Management Service API
 * Use the Identity and Access Management Service API to manage users, groups, identity domains, compartments, policies, tagging, and limits. For information about managing users, groups, compartments, and policies, see [Identity and Access Management (without identity domains)](/iaas/Content/Identity/Concepts/overview.htm). For information about tagging and service limits, see [Tagging](/iaas/Content/Tagging/Concepts/taggingoverview.htm) and [Service Limits](/iaas/Content/General/Concepts/servicelimits.htm). For information about creating, modifying, and deleting identity domains, see [Identity and Access Management (with identity domains)](/iaas/Content/Identity/home.htm).
 * OpenAPI spec version: 20160918
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
/**
 * As the name suggests, an {@code SmtpCredentialSummary} object contains information about an {@code SmtpCredential}.
 * The SMTP credential is used for SMTP authentication with
 * the [Email Delivery Service](https://docs.cloud.oracle.com/Content/Email/Concepts/overview.htm).
 *
 */
export interface SmtpCredentialSummary {
    /**
     * The SMTP user name.
     *
     */
    "username"?: string;
    /**
     * The OCID of the SMTP credential.
     */
    "id"?: string;
    /**
     * The OCID of the user the SMTP credential belongs to.
     */
    "userId"?: string;
    /**
      * The description you assign to the SMTP credential. Does not have to be unique, and it's changeable.
  * <p>
  (For tenancies that support identity domains) You can have an empty description.
  *
      */
    "description"?: string;
    /**
      * Date and time the {@code SmtpCredential} object was created, in the format defined by RFC3339.
  * <p>
  Example: {@code 2016-08-25T21:10:29.600Z}
  *
      */
    "timeCreated"?: Date;
    /**
      * Date and time when this credential will expire, in the format defined by RFC3339.
  * Null if it never expires.
  * <p>
  Example: {@code 2016-08-25T21:10:29.600Z}
  *
      */
    "timeExpires"?: Date;
    /**
     * The credential's current state. After creating a SMTP credential, make sure its {@code lifecycleState} changes from
     * CREATING to ACTIVE before using it.
     *
     */
    "lifecycleState"?: SmtpCredentialSummary.LifecycleState;
    /**
     * The detailed status of INACTIVE lifecycleState. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "inactiveStatus"?: number;
}
export declare namespace SmtpCredentialSummary {
    enum LifecycleState {
        Creating = "CREATING",
        Active = "ACTIVE",
        Inactive = "INACTIVE",
        Deleting = "DELETING",
        Deleted = "DELETED",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    function getJsonObj(obj: SmtpCredentialSummary): object;
    function getDeserializedJsonObj(obj: SmtpCredentialSummary): object;
}
