/**
 * Identity and Access Management Service API
 * Use the Identity and Access Management Service API to manage users, groups, identity domains, compartments, policies, tagging, and limits. For information about managing users, groups, compartments, and policies, see [Identity and Access Management (without identity domains)](/iaas/Content/Identity/Concepts/overview.htm). For information about tagging and service limits, see [Tagging](/iaas/Content/Tagging/Concepts/taggingoverview.htm) and [Service Limits](/iaas/Content/General/Concepts/servicelimits.htm). For information about creating, modifying, and deleting identity domains, see [Identity and Access Management (with identity domains)](/iaas/Content/Identity/home.htm).
 * OpenAPI spec version: 20160918
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
/**
 * An object that represents the membership of a user in a group. When you add a user to a group, the result is a
 * {@code UserGroupMembership} with its own OCID. To remove a user from a group, you delete the {@code UserGroupMembership} object.
 *
 */
export interface UserGroupMembership {
    /**
     * The OCID of the membership.
     */
    "id": string;
    /**
     * The OCID of the tenancy containing the user, group, and membership object.
     */
    "compartmentId": string;
    /**
     * The OCID of the group.
     */
    "groupId": string;
    /**
     * The OCID of the user.
     */
    "userId": string;
    /**
      * Date and time the membership was created, in the format defined by RFC3339.
  * <p>
  Example: {@code 2016-08-25T21:10:29.600Z}
  *
      */
    "timeCreated": Date;
    /**
     * The membership's current state.  After creating a membership object, make sure its {@code lifecycleState} changes
     * from CREATING to ACTIVE before using it.
     *
     */
    "lifecycleState": UserGroupMembership.LifecycleState;
    /**
     * The detailed status of INACTIVE lifecycleState. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "inactiveStatus"?: number;
}
export declare namespace UserGroupMembership {
    enum LifecycleState {
        Creating = "CREATING",
        Active = "ACTIVE",
        Inactive = "INACTIVE",
        Deleting = "DELETING",
        Deleted = "DELETED",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    function getJsonObj(obj: UserGroupMembership): object;
    function getDeserializedJsonObj(obj: UserGroupMembership): object;
}
