/**
 * Identity and Access Management Service API
 * Use the Identity and Access Management Service API to manage users, groups, identity domains, compartments, policies, tagging, and limits. For information about managing users, groups, compartments, and policies, see [Identity and Access Management (without identity domains)](/iaas/Content/Identity/Concepts/overview.htm). For information about tagging and service limits, see [Tagging](/iaas/Content/Tagging/Concepts/taggingoverview.htm) and [Service Limits](/iaas/Content/General/Concepts/servicelimits.htm). For information about creating, modifying, and deleting identity domains, see [Identity and Access Management (with identity domains)](/iaas/Content/Identity/home.htm).
 * OpenAPI spec version: 20160918
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * The work request summary. Tracks the status of the asynchronous operation.
 *
 */
export interface WorkRequestSummary {
    /**
     * The OCID of the work request.
     */
    "id": string;
    /**
     * An enum-like description of the type of work the work request is doing.
     */
    "operationType": WorkRequestSummary.OperationType;
    /**
     * The OCID of the compartment that contains the work request.
     */
    "compartmentId"?: string;
    /**
     * The current status of the work request.
     */
    "status": WorkRequestSummary.Status;
    /**
     * The resources this work request affects.
     *
     */
    "resources"?: Array<model.WorkRequestResource>;
    /**
     * The errors for work request.
     *
     */
    "errors"?: Array<model.WorkRequestError>;
    /**
     * Date and time the work was accepted, in the format defined by RFC3339.
     * Example: {@code 2016-08-25T21:10:29.600Z}
     *
     */
    "timeAccepted"?: Date;
    /**
     * Date and time the work started, in the format defined by RFC3339.
     * Example: {@code 2016-08-25T21:10:29.600Z}
     *
     */
    "timeStarted"?: Date;
    /**
     * Date and time the work completed, in the format defined by RFC3339.
     * Example: {@code 2016-08-25T21:10:29.600Z}
     *
     */
    "timeFinished"?: Date;
    /**
     * How much progress the operation has made.
     *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "percentComplete"?: number;
}
export declare namespace WorkRequestSummary {
    enum OperationType {
        DeleteCompartment = "DELETE_COMPARTMENT",
        DeleteTagDefinition = "DELETE_TAG_DEFINITION",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    enum Status {
        Accepted = "ACCEPTED",
        InProgress = "IN_PROGRESS",
        Failed = "FAILED",
        Succeeded = "SUCCEEDED",
        Canceling = "CANCELING",
        Canceled = "CANCELED",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    function getJsonObj(obj: WorkRequestSummary): object;
    function getDeserializedJsonObj(obj: WorkRequestSummary): object;
}
