/**
 * Identity Domains API
 * Use the Identity Domains API to manage resources within an identity domain, for example, users, dynamic resource groups, groups, and identity providers. For information about managing resources within identity domains, see [Identity and Access Management (with identity domains)](https://docs.oracle.com/iaas/Content/Identity/home.htm). This REST API is SCIM compliant.
Use the table of contents and search tool to explore the Identity Domains API.
 * OpenAPI spec version: v1
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * Schema for App resource.
 */
export interface App {
    /**
     * Unique identifier for the SCIM Resource as defined by the Service Provider. Each representation of the Resource MUST include a non-empty id value. This identifier MUST be unique across the Service Provider's entire set of Resources. It MUST be a stable, non-reassignable identifier that does not change when the same Resource is returned in subsequent requests. The value of the id attribute is always issued by the Service Provider and MUST never be specified by the Service Consumer. bulkId: is a reserved keyword and MUST NOT be used in the unique identifier.
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: false
     *  - idcsSearchable: true
     *  - multiValued: false
     *  - mutability: readOnly
     *  - required: false
     *  - returned: always
     *  - type: string
     *  - uniqueness: global
     */
    "id"?: string;
    /**
     * Unique OCI identifier for the SCIM Resource.
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: true
     *  - idcsSearchable: true
     *  - multiValued: false
     *  - mutability: immutable
     *  - required: false
     *  - returned: default
     *  - type: string
     *  - uniqueness: global
     */
    "ocid"?: string;
    /**
     * REQUIRED. The schemas attribute is an array of Strings which allows introspection of the supported schema version for a SCIM representation as well any schema extensions supported by that representation. Each String value must be a unique URI. This specification defines URIs for User, Group, and a standard \\\"enterprise\\\" extension. All representations of SCIM schema MUST include a non-zero value array with value(s) of the URIs supported by that representation. Duplicate values MUST NOT be included. Value order is not specified and MUST not impact behavior.
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: false
     *  - idcsSearchable: false
     *  - multiValued: true
     *  - mutability: readWrite
     *  - required: true
     *  - returned: default
     *  - type: string
     *  - uniqueness: none
     */
    "schemas": Array<string>;
    "meta"?: model.Meta;
    "idcsCreatedBy"?: model.IdcsCreatedBy;
    "idcsLastModifiedBy"?: model.IdcsLastModifiedBy;
    /**
     * Each value of this attribute specifies an operation that only an internal client may perform on this particular resource.
     * <p>
     **SCIM++ Properties:**
     *  - idcsSearchable: false
     *  - multiValued: true
     *  - mutability: readOnly
     *  - required: false
     *  - returned: request
     *  - type: string
     *  - uniqueness: none
     */
    "idcsPreventedOperations"?: Array<App.IdcsPreventedOperations>;
    /**
     * A list of tags on this resource.
     * <p>
     **SCIM++ Properties:**
     *  - idcsCompositeKey: [key, value]
     *  - idcsSearchable: true
     *  - multiValued: true
     *  - mutability: readWrite
     *  - required: false
     *  - returned: request
     *  - type: complex
     *  - uniqueness: none
     */
    "tags"?: Array<model.Tags>;
    /**
     * A boolean flag indicating this resource in the process of being deleted. Usually set to true when synchronous deletion of the resource would take too long.
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: false
     *  - idcsSearchable: true
     *  - multiValued: false
     *  - mutability: readOnly
     *  - required: false
     *  - returned: default
     *  - type: boolean
     *  - uniqueness: none
     */
    "deleteInProgress"?: boolean;
    /**
     * The release number when the resource was upgraded.
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: false
     *  - idcsSearchable: false
     *  - multiValued: false
     *  - mutability: readOnly
     *  - required: false
     *  - returned: request
     *  - type: string
     *  - uniqueness: none
     */
    "idcsLastUpgradedInRelease"?: string;
    /**
     * OCI Domain Id (ocid) in which the resource lives.
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: false
     *  - idcsSearchable: false
     *  - multiValued: false
     *  - mutability: readOnly
     *  - required: false
     *  - returned: default
     *  - type: string
     *  - uniqueness: none
     */
    "domainOcid"?: string;
    /**
     * OCI Compartment Id (ocid) in which the resource lives.
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: false
     *  - idcsSearchable: false
     *  - multiValued: false
     *  - mutability: readOnly
     *  - required: false
     *  - returned: default
     *  - type: string
     *  - uniqueness: none
     */
    "compartmentOcid"?: string;
    /**
     * OCI Tenant Id (ocid) in which the resource lives.
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: false
     *  - idcsSearchable: false
     *  - multiValued: false
     *  - mutability: readOnly
     *  - required: false
     *  - returned: default
     *  - type: string
     *  - uniqueness: none
     */
    "tenancyOcid"?: string;
    /**
     * Indicates whether the application is billed as an OPCService. If true, customer is not billed for runtime operations of the app.
     * <p>
     **Added In:** 18.4.2
     * <p>
     **SCIM++ Properties:**
     *  - idcsSearchable: false
     *  - multiValued: false
     *  - mutability: readOnly
     *  - required: false
     *  - returned: always
     *  - type: boolean
     *  - uniqueness: none
     */
    "meterAsOPCService"?: boolean;
    /**
     * Name of the application. Also serves as username if the application authenticates to Oracle Public Cloud infrastructure. This name may not be user-friendly and cannot be changed once an App is created.
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: false
     *  - idcsSearchable: true
     *  - multiValued: false
     *  - mutability: immutable
     *  - required: false
     *  - returned: default
     *  - type: string
     *  - uniqueness: server
     */
    "name"?: string;
    /**
     * This value is the credential of this App, which this App supplies as a password when this App authenticates to the Oracle Public Cloud infrastructure. This value is also the client secret of this App when it acts as an OAuthClient.
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: false
     *  - idcsSearchable: false
     *  - idcsSensitive: none
     *  - multiValued: false
     *  - mutability: readOnly
     *  - required: false
     *  - returned: default
     *  - type: string
     *  - uniqueness: none
     */
    "clientSecret"?: string;
    /**
     * Hashed Client Secret. This hash-value is used to verify the 'clientSecret' credential of this App
     * <p>
     **Added In:** 2106240046
     * <p>
     **SCIM++ Properties:**
     *  - idcsSearchable: false
     *  - idcsSensitive: hash_sc
     *  - multiValued: false
     *  - mutability: readOnly
     *  - required: false
     *  - returned: request
     *  - type: string
     *  - uniqueness: none
     */
    "hashedClientSecret"?: string;
    /**
     * Display name of the application. Display name is intended to be user-friendly, and an administrator can change the value at any time.
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: false
     *  - idcsSearchable: true
     *  - multiValued: false
     *  - mutability: readWrite
     *  - required: true
     *  - returned: always
     *  - type: string
     *  - uniqueness: server
     */
    "displayName": string;
    /**
     * Description of the application.
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: false
     *  - idcsSearchable: true
     *  - multiValued: false
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: string
     *  - uniqueness: none
     */
    "description"?: string;
    /**
     * Encryption Alogrithm to use for encrypting ID token.
     * <p>
     **Added In:** 2010242156
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: false
     *  - idcsSearchable: false
     *  - multiValued: false
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: string
     *  - uniqueness: none
     */
    "idTokenEncAlgo"?: string;
    /**
     * Service Names allow to use OCI signature for client authentication instead of client credentials
     * <p>
     **Added In:** 2207040824
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: true
     *  - idcsSearchable: false
     *  - multiValued: true
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: string
     *  - uniqueness: none
     */
    "delegatedServiceNames"?: Array<string>;
    /**
     * If true, this App is able to participate in runtime services, such as automatic-login, OAuth, and SAML. If false, all runtime services are disabled for this App, and only administrative operations can be performed.
     * <p>
     **SCIM++ Properties:**
     *  - idcsSearchable: true
     *  - multiValued: false
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: boolean
     *  - uniqueness: none
     */
    "active"?: boolean;
    /**
     * Application icon.
     * <p>
     **SCIM++ Properties:**
     *  - idcsSearchable: false
     *  - multiValued: false
     *  - mutability: readWrite
     *  - required: false
     *  - returned: request
     *  - type: string
     *  - uniqueness: none
     */
    "appIcon"?: string;
    /**
     * Application thumbnail.
     * <p>
     **SCIM++ Properties:**
     *  - idcsSearchable: false
     *  - multiValued: false
     *  - mutability: readWrite
     *  - required: false
     *  - returned: request
     *  - type: string
     *  - uniqueness: none
     */
    "appThumbnail"?: string;
    /**
     * If true, this App was migrated from an earlier version of Oracle Public Cloud infrastructure (and may therefore require special handling from runtime services such as OAuth or SAML). If false, this App requires no special handling from runtime services.
     * <p>
     **SCIM++ Properties:**
     *  - idcsSearchable: true
     *  - multiValued: false
     *  - mutability: readOnly
     *  - required: false
     *  - returned: default
     *  - type: boolean
     *  - uniqueness: none
     */
    "migrated"?: boolean;
    /**
     * If true, this App is an internal infrastructure App.
     * <p>
     **SCIM++ Properties:**
     *  - idcsSearchable: true
     *  - multiValued: false
     *  - mutability: readOnly
     *  - required: false
     *  - returned: default
     *  - type: boolean
     *  - uniqueness: none
     */
    "infrastructure"?: boolean;
    /**
     * If true, this App allows runtime services to log end users into this App automatically.
     * <p>
     **SCIM++ Properties:**
     *  - idcsSearchable: true
     *  - multiValued: false
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: boolean
     *  - uniqueness: none
     */
    "isLoginTarget"?: boolean;
    /**
     * If true, this app will be displayed in the MyApps page of each end-user who has access to the App.
     * <p>
     **Added In:** 18.1.2
     * <p>
     **SCIM++ Properties:**
     *  - idcsSearchable: true
     *  - multiValued: false
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: boolean
     *  - uniqueness: none
     */
    "showInMyApps"?: boolean;
    /**
     * The protocol that runtime services will use to log end users in to this App automatically. If 'OIDC', then runtime services use the OpenID Connect protocol. If 'SAML', then runtime services use Security Assertion Markup Language protocol.
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: true
     *  - idcsSearchable: true
     *  - multiValued: false
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: string
     *  - uniqueness: none
     */
    "loginMechanism"?: App.LoginMechanism;
    /**
     * The URL of the landing page for this App, which is the first page that an end user should see if runtime services log that end user in to this App automatically.
     * <p>
     **SCIM++ Properties:**
     *  - idcsSearchable: false
     *  - multiValued: false
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: string
     *  - uniqueness: none
     */
    "landingPageUrl"?: string;
    /**
     * Application Logo URL
     * <p>
     **Added In:** 19.2.1
     * <p>
     **SCIM++ Properties:**
     *  - idcsSearchable: false
     *  - multiValued: false
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: string
     *  - uniqueness: none
     */
    "productLogoUrl"?: string;
    /**
     * Privacy Policy URL
     * <p>
     **Added In:** 19.2.1
     * <p>
     **SCIM++ Properties:**
     *  - idcsSearchable: false
     *  - multiValued: false
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: string
     *  - uniqueness: none
     */
    "privacyPolicyUrl"?: string;
    /**
     * Terms of Service URL
     * <p>
     **Added In:** 19.2.1
     * <p>
     **SCIM++ Properties:**
     *  - idcsSearchable: false
     *  - multiValued: false
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: string
     *  - uniqueness: none
     */
    "termsOfServiceUrl"?: string;
    /**
     * Contact Email Address
     * <p>
     **Added In:** 19.2.1
     * <p>
     **SCIM++ Properties:**
     *  - idcsSearchable: false
     *  - multiValued: false
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: string
     *  - uniqueness: none
     */
    "contactEmailAddress"?: string;
    /**
     * Product Name
     * <p>
     **Added In:** 19.2.1
     * <p>
     **SCIM++ Properties:**
     *  - idcsSearchable: false
     *  - multiValued: false
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: string
     *  - uniqueness: none
     */
    "productName"?: string;
    /**
     * Home Page URL
     * <p>
     **Added In:** 19.2.1
     * <p>
     **SCIM++ Properties:**
     *  - idcsSearchable: false
     *  - multiValued: false
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: string
     *  - uniqueness: none
     */
    "homePageUrl"?: string;
    /**
     * If true, this application acts as FormFill Application
     * <p>
     **SCIM++ Properties:**
     *  - idcsSearchable: true
     *  - multiValued: false
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: boolean
     *  - uniqueness: none
     */
    "isFormFill"?: boolean;
    /**
     * If true, this application acts as an OAuth Client
     * <p>
     **SCIM++ Properties:**
     *  - idcsSearchable: true
     *  - multiValued: false
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: boolean
     *  - uniqueness: none
     */
    "isOAuthClient"?: boolean;
    /**
     * If true, this application acts as an Radius App
     * <p>
     **Added In:** 20.1.3
     * <p>
     **SCIM++ Properties:**
     *  - idcsSearchable: true
     *  - multiValued: false
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: boolean
     *  - uniqueness: none
     */
    "isRadiusApp"?: boolean;
    /**
     * Specifies the type of access that this App has when it acts as an OAuthClient.
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: false
     *  - idcsSearchable: false
     *  - multiValued: false
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: string
     *  - uniqueness: none
     */
    "clientType"?: App.ClientType;
    /**
     * OPTIONAL. Each value is a URI within this App. This attribute is required when this App acts as an OAuthClient and is involved in three-legged flows (authorization-code flows).
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: false
     *  - idcsSearchable: false
     *  - multiValued: true
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: string
     *  - uniqueness: none
     */
    "redirectUris"?: Array<string>;
    /**
     * If true, indicates that the system should allow all URL-schemes within each value of the 'redirectUris' attribute.  Also indicates that the system should not attempt to confirm that each value of the 'redirectUris' attribute is a valid URI.  In particular, the system should not confirm that the domain component of the URI is a top-level domain and the system should not confirm that the hostname portion is a valid system that is reachable over the network.
     * <p>
     **SCIM++ Properties:**
     *  - idcsSearchable: true
     *  - multiValued: false
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: boolean
     *  - uniqueness: none
     */
    "allUrlSchemesAllowed"?: boolean;
    /**
     * OAuth will use this URI to logout if this App wants to participate in SSO, and if this App's session gets cleared as part of global logout. Note: This attribute is used only if this App acts as an OAuthClient.
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: false
     *  - idcsSearchable: false
     *  - multiValued: false
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: string
     *  - uniqueness: none
     */
    "logoutUri"?: string;
    /**
     * Each value of this attribute is the URI of a landing page within this App. It is used only when this App, acting as an OAuthClient, initiates the logout flow and wants to be redirected back to one of its landing pages.
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: false
     *  - idcsSearchable: false
     *  - multiValued: true
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: string
     *  - uniqueness: none
     */
    "postLogoutRedirectUris"?: Array<string>;
    /**
     * List of grant-types that this App is allowed to use when it acts as an OAuthClient.
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: true
     *  - idcsSearchable: true
     *  - multiValued: true
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: string
     *  - uniqueness: none
     */
    "allowedGrants"?: Array<string>;
    /**
     * OPTIONAL. Required only when this App acts as an OAuthClient. Supported values are 'introspect' and 'onBehalfOfUser'. The value 'introspect' allows the client to look inside the access-token. The value 'onBehalfOfUser' overrides how the client's privileges are combined with the privileges of the Subject User. Ordinarily, authorization calculates the set of effective privileges as the intersection of the client's privileges and the user's privileges. The value 'onBehalfOf' indicates that authorization should ignore the privileges of the client and use only the user's privileges to calculate the effective privileges.
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: true
     *  - idcsSearchable: true
     *  - multiValued: true
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: string
     *  - uniqueness: none
     */
    "allowedOperations"?: Array<App.AllowedOperations>;
    /**
     * Network Perimeters checking mode
     * <p>
     **Added In:** 2010242156
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: true
     *  - idcsSearchable: false
     *  - multiValued: false
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: string
     *  - uniqueness: none
     */
    "clientIPChecking"?: App.ClientIPChecking;
    /**
     * If true, this application is an Oracle Public Cloud service-instance.
     * <p>
     **SCIM++ Properties:**
     *  - idcsSearchable: true
     *  - multiValued: false
     *  - mutability: readOnly
     *  - required: false
     *  - returned: default
     *  - type: boolean
     *  - uniqueness: none
     */
    "isOPCService"?: boolean;
    /**
     * If true, indicates that this application accepts an Oracle Cloud Identity Service User as a login-identity (does not require an account) and relies for authorization on the User's memberships in AppRoles.
     * <p>
     **SCIM++ Properties:**
     *  - idcsSearchable: true
     *  - multiValued: false
     *  - mutability: immutable
     *  - required: false
     *  - returned: default
     *  - type: boolean
     *  - uniqueness: none
     */
    "isUnmanagedApp"?: boolean;
    /**
     * If true, any managed App that is based on this template is checked for access control that is, access to this app is subject to successful authorization at SSO service, viz. app grants to start with.
     * <p>
     **SCIM++ Properties:**
     *  - idcsSearchable: true
     *  - multiValued: false
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: boolean
     *  - uniqueness: none
     */
    "allowAccessControl"?: boolean;
    /**
     * If true, indicates that this application acts as an OAuth Resource.
     * <p>
     **SCIM++ Properties:**
     *  - idcsSearchable: true
     *  - multiValued: false
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: boolean
     *  - uniqueness: none
     */
    "isOAuthResource"?: boolean;
    /**
     * Expiry-time in seconds for an Access Token. Any token that allows access to this App will expire after the specified duration.
     * <p>
     **SCIM++ Properties:**
     *  - idcsSearchable: false
     *  - multiValued: false
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: integer
     *  - uniqueness: none Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "accessTokenExpiry"?: number;
    /**
     * Expiry-time in seconds for a Refresh Token.  Any token that allows access to this App, once refreshed, will expire after the specified duration.
     * <p>
     **SCIM++ Properties:**
     *  - idcsSearchable: false
     *  - multiValued: false
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: integer
     *  - uniqueness: none Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "refreshTokenExpiry"?: number;
    /**
     * If true, indicates that the Refresh Token is allowed when this App acts as an OAuth Resource.
     * <p>
     **SCIM++ Properties:**
     *  - idcsSearchable: true
     *  - multiValued: false
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: boolean
     *  - uniqueness: none
     */
    "allowOffline"?: boolean;
    /**
     * Callback Service URL
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: false
     *  - idcsSearchable: false
     *  - multiValued: false
     *  - mutability: readOnly
     *  - required: false
     *  - returned: default
     *  - type: string
     *  - uniqueness: none
     */
    "callbackServiceUrl"?: string;
    /**
     * The base URI for all of the scopes defined in this App. The value of 'audience' is combined with the 'value' of each scope to form an 'fqs' or fully qualified scope.
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: false
     *  - idcsSearchable: false
     *  - multiValued: false
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: string
     *  - uniqueness: none
     */
    "audience"?: string;
    /**
     * If true, indicates that the App should be visible in each end-user's mobile application.
     * <p>
     **SCIM++ Properties:**
     *  - idcsSearchable: true
     *  - multiValued: false
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: boolean
     *  - uniqueness: none
     */
    "isMobileTarget"?: boolean;
    /**
     * This attribute specifies the URL of the page that the App uses when an end-user signs in to that App.
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: false
     *  - idcsSearchable: false
     *  - multiValued: false
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: string
     *  - uniqueness: none
     */
    "loginPageUrl"?: string;
    /**
     * This attribute specifies the callback URL for the social linking operation.
     * <p>
     **Added In:** 18.2.4
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: false
     *  - idcsSearchable: false
     *  - multiValued: false
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: string
     *  - uniqueness: none
     */
    "linkingCallbackUrl"?: string;
    /**
     * This attribute specifies the URL of the page that the App uses when an end-user signs out.
     * <p>
     **Added In:** 17.4.2
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: false
     *  - idcsSearchable: false
     *  - multiValued: false
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: string
     *  - uniqueness: none
     */
    "logoutPageUrl"?: string;
    /**
     * This attribute specifies the URL of the page to which an application will redirect an end-user in case of error.
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: false
     *  - idcsSearchable: false
     *  - multiValued: false
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: string
     *  - uniqueness: none
     */
    "errorPageUrl"?: string;
    /**
     * If true, then this App acts as a SAML Service Provider.
     * <p>
     **SCIM++ Properties:**
     *  - idcsSearchable: true
     *  - multiValued: false
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: boolean
     *  - uniqueness: none
     */
    "isSamlServiceProvider"?: boolean;
    /**
     * If true, the webtier policy is active
     * <p>
     **SCIM++ Properties:**
     *  - idcsSearchable: true
     *  - multiValued: false
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: boolean
     *  - uniqueness: none
     */
    "isWebTierPolicy"?: boolean;
    /**
     * If true, indicates that this App supports Kerberos Authentication
     * <p>
     **SCIM++ Properties:**
     *  - idcsSearchable: true
     *  - multiValued: false
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: boolean
     *  - uniqueness: none
     */
    "isKerberosRealm"?: boolean;
    /**
     * URL of application icon.
     * <p>
     **SCIM++ Properties:**
     *  - idcsSearchable: false
     *  - multiValued: false
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: reference
     *  - uniqueness: none
     */
    "icon"?: string;
    /**
     * If true, this App is an AliasApp and it cannot be granted to an end-user directly.
     * <p>
     **SCIM++ Properties:**
     *  - idcsSearchable: true
     *  - multiValued: false
     *  - mutability: immutable
     *  - required: false
     *  - returned: always
     *  - type: boolean
     *  - uniqueness: none
     */
    "isAliasApp"?: boolean;
    /**
     * If true, indicates that access to this App requires an account. That is, in order to log in to the App, a User must use an application-specific identity that is maintained in the remote identity-repository of that App.
     * <p>
     **SCIM++ Properties:**
     *  - idcsSearchable: true
     *  - multiValued: false
     *  - mutability: readOnly
     *  - required: false
     *  - returned: default
     *  - type: boolean
     *  - uniqueness: none
     */
    "isManagedApp"?: boolean;
    /**
     * This Uniform Resource Name (URN) value identifies the type of Oracle Public Cloud service of which this app is an instance.
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: false
     *  - idcsSearchable: true
     *  - multiValued: false
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: string
     *  - uniqueness: none
     */
    "serviceTypeURN"?: string;
    /**
     * This value specifies the version of the Oracle Public Cloud service of which this App is an instance
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: false
     *  - idcsSearchable: true
     *  - multiValued: false
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: string
     *  - uniqueness: none
     */
    "serviceTypeVersion"?: string;
    /**
     * This flag indicates if the App is capable of validating obligations with the token for allowing access to the App.
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: false
     *  - idcsSearchable: true
     *  - multiValued: false
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: boolean
     *  - uniqueness: none
     */
    "isObligationCapable"?: boolean;
    /**
     * If true, this App requires an upgrade and mandates attention from application administrator. The flag is used by UI to indicate this app is ready to upgrade.
     * <p>
     **SCIM++ Properties:**
     *  - idcsSearchable: true
     *  - multiValued: false
     *  - mutability: readOnly
     *  - required: false
     *  - returned: default
     *  - type: boolean
     *  - uniqueness: none
     */
    "readyToUpgrade"?: boolean;
    /**
     * Indicates the scope of trust for this App when acting as an OAuthClient. A value of 'Explicit' indicates that the App is allowed to access only the scopes of OAuthResources that are explicitly specified as 'allowedScopes'. A value of 'Account' indicates that the App is allowed implicitly to access any scope of any OAuthResource within the same Oracle Cloud Account. A value of 'Tags' indicates that the App is allowed to access any scope of any OAuthResource with a matching tag within the same Oracle Cloud Account. A value of 'Default' indicates that the Tenant default trust scope configured in the Tenant Settings is used.
     * <p>
     **Added In:** 17.4.2
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: true
     *  - idcsSearchable: false
     *  - multiValued: false
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: string
     *  - uniqueness: none
     */
    "trustScope"?: App.TrustScope;
    /**
     * If true, this application acts as database service Application
     * <p>
     **Added In:** 18.2.2
     * <p>
     **SCIM++ Properties:**
     *  - idcsSearchable: true
     *  - multiValued: false
     *  - mutability: readOnly
     *  - required: false
     *  - type: boolean
     */
    "isDatabaseService"?: boolean;
    /**
     * A list of secondary audiences--additional URIs to be added automatically to any OAuth token that allows access to this App. Note: This attribute is used mainly for backward compatibility in certain Oracle Public Cloud Apps.
     * <p>
     **Deprecated Since: 18.2.6**
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: false
     *  - idcsSearchable: false
     *  - multiValued: true
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: string
     *  - uniqueness: none
     */
    "secondaryAudiences"?: Array<string>;
    /**
     * If true, this app acts as Enterprise app with Authentication and URL Authz policy.
     * <p>
     **Added In:** 19.2.1
     * <p>
     **SCIM++ Properties:**
     *  - idcsSearchable: true
     *  - multiValued: false
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: boolean
     *  - uniqueness: none
     */
    "isEnterpriseApp"?: boolean;
    /**
     * If true, indicates that consent should be skipped for all scopes
     * <p>
     **Added In:** 19.2.1
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: false
     *  - idcsSearchable: false
     *  - multiValued: false
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: boolean
     *  - uniqueness: none
     */
    "bypassConsent"?: boolean;
    /**
     * Indicates whether the application is allowed to be access using kmsi token.
     * <p>
     **Added In:** 2111190457
     * <p>
     **SCIM++ Properties:**
     *  - idcsSearchable: false
     *  - multiValued: false
     *  - mutability: readWrite
     *  - required: false
     *  - returned: always
     *  - type: boolean
     *  - uniqueness: none
     */
    "disableKmsiTokenAuthentication"?: boolean;
    /**
     * If true, indicates the app is used for multicloud service integration.
     * <p>
     **Added In:** 2301202328
     * <p>
     **SCIM++ Properties:**
     *  - idcsSearchable: true
     *  - multiValued: false
     *  - mutability: immutable
     *  - required: false
     *  - returned: default
     *  - type: boolean
     *  - uniqueness: none
     */
    "isMulticloudServiceApp"?: boolean;
    "radiusPolicy"?: model.AppRadiusPolicy;
    /**
     * Network Perimeter
     * <p>
     **Added In:** 2010242156
     * <p>
     **SCIM++ Properties:**
     *  - idcsCompositeKey: [value]
     *  - multiValued: true
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: complex
     */
    "appsNetworkPerimeters"?: Array<model.AppAppsNetworkPerimeters>;
    /**
     * A collection of arbitrary properties that scope the privileges of a cloud-control App.
     * <p>
     **Added In:** 18.4.2
     * <p>
     **SCIM++ Properties:**
     *  - idcsCompositeKey: [name]
     *  - idcsSearchable: false
     *  - multiValued: true
     *  - mutability: readOnly
     *  - required: false
     *  - returned: request
     *  - type: complex
     *  - uniqueness: none
     */
    "cloudControlProperties"?: Array<model.AppCloudControlProperties>;
    /**
     * App attributes editable by subject
     * <p>
     **Added In:** 18.2.6
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: false
     *  - idcsCompositeKey: [name]
     *  - idcsSearchable: false
     *  - multiValued: true
     *  - mutability: readOnly
     *  - required: false
     *  - returned: request
     *  - type: complex
     *  - uniqueness: none
     */
    "editableAttributes"?: Array<model.AppEditableAttributes>;
    "termsOfUse"?: model.AppTermsOfUse;
    /**
     * A list of secondary audiences--additional URIs to be added automatically to any OAuth token that allows access to this App. Note: This attribute is used mainly for backward compatibility in certain Oracle Public Cloud Apps.
     * <p>
     **Added In:** 18.2.2
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: false
     *  - idcsCompositeKey: [value]
     *  - idcsSearchable: false
     *  - multiValued: true
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: complex
     *  - uniqueness: none
     */
    "protectableSecondaryAudiences"?: Array<model.AppProtectableSecondaryAudiences>;
    "idpPolicy"?: model.AppIdpPolicy;
    /**
     * A list of tags, acting as an OAuthClient, this App is allowed to access.
     * <p>
     **Added In:** 17.4.6
     * <p>
     **SCIM++ Properties:**
     *  - idcsCompositeKey: [key, value]
     *  - idcsSearchable: true
     *  - multiValued: true
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: complex
     *  - uniqueness: none
     */
    "allowedTags"?: Array<model.AppAllowedTags>;
    "appSignonPolicy"?: model.AppAppSignonPolicy;
    /**
     * Trust Policies.
     * <p>
     **SCIM++ Properties:**
     *  - idcsCompositeKey: [value]
     *  - idcsSearchable: true
     *  - multiValued: true
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: complex
     */
    "trustPolicies"?: Array<model.AppTrustPolicies>;
    "signonPolicy"?: model.AppSignonPolicy;
    /**
     * A list of IdentityProvider assigned to app. A user trying to access this app will be automatically redirected to configured IdP during the authentication phase, before being able to access App.
     * <p>
     **SCIM++ Properties:**
     *  - idcsCompositeKey: [value]
     *  - idcsSearchable: false
     *  - multiValued: true
     *  - mutability: readWrite
     *  - required: false
     *  - returned: request
     *  - type: complex
     */
    "identityProviders"?: Array<model.AppIdentityProviders>;
    /**
     * Accounts of App
     * <p>
     **SCIM++ Properties:**
     *  - idcsCompositeKey: [value]
     *  - idcsSearchable: true
     *  - multiValued: true
     *  - mutability: readOnly
     *  - required: false
     *  - returned: request
     *  - type: complex
     *  - uniqueness: none
     */
    "accounts"?: Array<model.AppAccounts>;
    /**
     * Grants assigned to the app
     * <p>
     **SCIM++ Properties:**
     *  - idcsCompositeKey: [value]
     *  - idcsSearchable: true
     *  - multiValued: true
     *  - mutability: readOnly
     *  - required: false
     *  - returned: request
     *  - type: complex
     *  - uniqueness: none
     */
    "grants"?: Array<model.AppGrants>;
    /**
     * Custom attribute that is required to compute other attribute values during app creation.
     * <p>
     **SCIM++ Properties:**
     *  - idcsCompositeKey: [name]
     *  - idcsSearchable: false
     *  - multiValued: true
     *  - mutability: readWrite
     *  - required: false
     *  - returned: always
     *  - type: complex
     *  - uniqueness: none
     */
    "serviceParams"?: Array<model.AppServiceParams>;
    /**
     * Label for the attribute to be shown in the UI.
     * <p>
     **SCIM++ Properties:**
     *  - idcsCompositeKey: [name]
     *  - idcsSearchable: false
     *  - multiValued: true
     *  - mutability: immutable
     *  - required: false
     *  - returned: default
     *  - type: complex
     *  - uniqueness: none
     */
    "attrRenderingMetadata"?: Array<model.AppAttrRenderingMetadata>;
    "basedOnTemplate": model.AppBasedOnTemplate;
    /**
     * A list of AppRoles that are granted to this App (and that are defined by other Apps). Within the Oracle Public Cloud infrastructure, this allows AppID-based association. Such an association allows this App to act as a consumer and thus to access resources of another App that acts as a producer.
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: true
     *  - idcsCompositeKey: [value]
     *  - idcsSearchable: true
     *  - multiValued: true
     *  - mutability: readOnly
     *  - required: false
     *  - returned: default
     *  - type: complex
     *  - uniqueness: none
     */
    "grantedAppRoles"?: Array<model.AppGrantedAppRoles>;
    "samlServiceProvider"?: model.AppSamlServiceProvider;
    /**
     * A list of scopes (exposed by this App or by other Apps) that this App is allowed to access when it acts as an OAuthClient.
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: true
     *  - idcsCompositeKey: [fqs]
     *  - idcsSearchable: true
     *  - multiValued: true
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: complex
     *  - uniqueness: none
     */
    "allowedScopes"?: Array<model.AppAllowedScopes>;
    /**
     * Each value of this attribute represent a certificate that this App uses when it acts as an OAuthClient.
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: false
     *  - idcsCompositeKey: [certAlias]
     *  - idcsSearchable: false
     *  - multiValued: true
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: complex
     *  - uniqueness: none
     */
    "certificates"?: Array<model.AppCertificates>;
    /**
     * Each value of this internal attribute refers to an Oracle Public Cloud infrastructure App on which this App depends.
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: true
     *  - idcsCompositeKey: [value]
     *  - idcsSearchable: true
     *  - multiValued: true
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: complex
     *  - uniqueness: none
     */
    "aliasApps"?: Array<model.AppAliasApps>;
    "asOPCService"?: model.AppAsOPCService;
    /**
     * A list of AppRoles defined by this UnmanagedApp. Membership in each of these AppRoles confers administrative privilege within this App.
     * <p>
     **SCIM++ Properties:**
     *  - idcsCompositeKey: [value]
     *  - idcsSearchable: false
     *  - multiValued: true
     *  - mutability: readOnly
     *  - required: false
     *  - returned: request
     *  - type: complex
     */
    "adminRoles"?: Array<model.AppAdminRoles>;
    /**
     * A list of AppRoles defined by this UnmanagedApp. Membership in each of these AppRoles confers end-user privilege within this App.
     * <p>
     **SCIM++ Properties:**
     *  - idcsCompositeKey: [value]
     *  - idcsSearchable: false
     *  - multiValued: true
     *  - mutability: readOnly
     *  - required: false
     *  - returned: request
     *  - type: complex
     */
    "userRoles"?: Array<model.AppUserRoles>;
    /**
     * Scopes defined by this App. Used when this App acts as an OAuth Resource.
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: true
     *  - idcsCompositeKey: [value]
     *  - idcsSearchable: true
     *  - multiValued: true
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: complex
     *  - uniqueness: none
     */
    "scopes"?: Array<model.AppScopes>;
    "urnIetfParamsScimSchemasOracleIdcsExtensionRadiusAppApp"?: model.AppExtensionRadiusAppApp;
    "urnIetfParamsScimSchemasOracleIdcsExtensionSamlServiceProviderApp"?: model.AppExtensionSamlServiceProviderApp;
    "urnIetfParamsScimSchemasOracleIdcsExtensionWebTierPolicyApp"?: model.AppExtensionWebTierPolicyApp;
    "urnIetfParamsScimSchemasOracleIdcsExtensionManagedappApp"?: model.AppExtensionManagedappApp;
    "urnIetfParamsScimSchemasOracleIdcsExtensionFormFillAppTemplateAppTemplate"?: model.AppExtensionFormFillAppTemplateAppTemplate;
    "urnIetfParamsScimSchemasOracleIdcsExtensionOpcServiceApp"?: model.AppExtensionOpcServiceApp;
    "urnIetfParamsScimSchemasOracleIdcsExtensionKerberosRealmApp"?: model.AppExtensionKerberosRealmApp;
    "urnIetfParamsScimSchemasOracleIdcsExtensionRequestableApp"?: model.AppExtensionRequestableApp;
    "urnIetfParamsScimSchemasOracleIdcsExtensionFormFillAppApp"?: model.AppExtensionFormFillAppApp;
    "urnIetfParamsScimSchemasOracleIdcsExtensionDbcsApp"?: model.AppExtensionDbcsApp;
    "urnIetfParamsScimSchemasOracleIdcsExtensionEnterpriseAppApp"?: model.AppExtensionEnterpriseAppApp;
    "urnIetfParamsScimSchemasOracleIdcsExtensionOciTags"?: model.ExtensionOCITags;
    "urnIetfParamsScimSchemasOracleIdcsExtensionMulticloudServiceAppApp"?: model.AppExtensionMulticloudServiceAppApp;
}
export declare namespace App {
    enum IdcsPreventedOperations {
        Replace = "replace",
        Update = "update",
        Delete = "delete",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    enum LoginMechanism {
        Oidc = "OIDC",
        Saml = "SAML",
        Formfill = "FORMFILL",
        Radius = "RADIUS",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    enum ClientType {
        Confidential = "confidential",
        Public = "public",
        Trusted = "trusted",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    enum AllowedOperations {
        Introspect = "introspect",
        OnBehalfOfUser = "onBehalfOfUser",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    enum ClientIPChecking {
        Anywhere = "anywhere",
        Whitelisted = "whitelisted",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    enum TrustScope {
        Explicit = "Explicit",
        Account = "Account",
        Tags = "Tags",
        Default = "Default",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    function getJsonObj(obj: App): object;
    function getDeserializedJsonObj(obj: App): object;
}
