/**
 * Identity Domains API
 * Use the Identity Domains API to manage resources within an identity domain, for example, users, dynamic resource groups, groups, and identity providers. For information about managing resources within identity domains, see [Identity and Access Management (with identity domains)](https://docs.oracle.com/iaas/Content/Identity/home.htm). This REST API is SCIM compliant.
Use the table of contents and search tool to explore the Identity Domains API.
 * OpenAPI spec version: v1
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
/**
 * POSIX User extension
 */
export interface ExtensionPosixUser {
    /**
     * Integer uniquely identifying a user in a POSIX administrative domain
     * <p>
     **SCIM++ Properties:**
     *  - idcsSearchable: true
     *  - multiValued: false
     *  - mutability: readWrite
     *  - required: false
     *  - returned: request
     *  - type: integer
     *  - uniqueness: server Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "uidNumber"?: number;
    /**
     * Primary Group identifier of the POSIX user
     * <p>
     **SCIM++ Properties:**
     *  - idcsSearchable: true
     *  - multiValued: false
     *  - mutability: readWrite
     *  - required: false
     *  - returned: request
     *  - type: integer
     *  - uniqueness: none Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "gidNumber"?: number;
    /**
     * General information about the POSIX account such as their real name and phone number
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: false
     *  - multiValued: false
     *  - mutability: readWrite
     *  - required: false
     *  - returned: request
     *  - type: string
     *  - uniqueness: none
     */
    "gecos"?: string;
    /**
     * The absolute path to the home directory of the POSIX account
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: true
     *  - multiValued: false
     *  - mutability: readWrite
     *  - required: false
     *  - returned: request
     *  - type: string
     *  - uniqueness: none
     */
    "homeDirectory"?: string;
    /**
     * The path to the login shell of the POSIX account
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: true
     *  - multiValued: false
     *  - mutability: readWrite
     *  - required: false
     *  - returned: request
     *  - type: string
     *  - uniqueness: none
     */
    "loginShell"?: string;
}
export declare namespace ExtensionPosixUser {
    function getJsonObj(obj: ExtensionPosixUser): object;
    function getDeserializedJsonObj(obj: ExtensionPosixUser): object;
}
