/**
 * Identity Domains API
 * Use the Identity Domains API to manage resources within an identity domain, for example, users, dynamic resource groups, groups, and identity providers. For information about managing resources within identity domains, see [Identity and Access Management (with identity domains)](https://docs.oracle.com/iaas/Content/Identity/home.htm). This REST API is SCIM compliant.
Use the table of contents and search tool to explore the Identity Domains API.
 * OpenAPI spec version: v1
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * User's credentials
 */
export interface ExtensionUserCredentialsUser {
    /**
     * A list of database credentials corresponding to user.
     * <p>
     **Added In:** 2102181953
     * <p>
     **SCIM++ Properties:**
     *  - idcsCompositeKey: [value]
     *  - idcsSearchable: true
     *  - multiValued: true
     *  - mutability: readOnly
     *  - required: false
     *  - returned: request
     *  - type: complex
     *  - uniqueness: none
     */
    "dbCredentials"?: Array<model.UserExtDbCredentials>;
    /**
     * A list of customer secret keys corresponding to user.
     * <p>
     **Added In:** 2102181953
     * <p>
     **SCIM++ Properties:**
     *  - idcsCompositeKey: [value]
     *  - idcsSearchable: true
     *  - multiValued: true
     *  - mutability: readOnly
     *  - required: false
     *  - returned: request
     *  - type: complex
     *  - uniqueness: none
     */
    "customerSecretKeys"?: Array<model.UserExtCustomerSecretKeys>;
    /**
     * A list of Auth tokens corresponding to user.
     * <p>
     **Added In:** 2012271618
     * <p>
     **SCIM++ Properties:**
     *  - idcsCompositeKey: [value]
     *  - idcsSearchable: true
     *  - multiValued: true
     *  - mutability: readOnly
     *  - required: false
     *  - returned: request
     *  - type: complex
     *  - uniqueness: none
     */
    "authTokens"?: Array<model.UserExtAuthTokens>;
    /**
     * A list of SMTP credentials corresponding to user.
     * <p>
     **Added In:** 2012271618
     * <p>
     **SCIM++ Properties:**
     *  - idcsCompositeKey: [value]
     *  - idcsSearchable: true
     *  - multiValued: true
     *  - mutability: readOnly
     *  - required: false
     *  - returned: request
     *  - type: complex
     *  - uniqueness: none
     */
    "smtpCredentials"?: Array<model.UserExtSmtpCredentials>;
    /**
     * A list of API keys corresponding to user.
     * <p>
     **Added In:** 2012271618
     * <p>
     **SCIM++ Properties:**
     *  - idcsCompositeKey: [value]
     *  - idcsSearchable: true
     *  - multiValued: true
     *  - mutability: readOnly
     *  - required: false
     *  - returned: request
     *  - type: complex
     *  - uniqueness: none
     */
    "apiKeys"?: Array<model.UserExtApiKeys>;
    /**
     * A list of OAuth2 client credentials corresponding to a user.
     * <p>
     **Added In:** 2012271618
     * <p>
     **SCIM++ Properties:**
     *  - idcsCompositeKey: [value]
     *  - idcsSearchable: true
     *  - multiValued: true
     *  - mutability: readOnly
     *  - required: false
     *  - returned: request
     *  - type: complex
     *  - uniqueness: none
     */
    "oAuth2ClientCredentials"?: Array<model.UserExtOAuth2ClientCredentials>;
}
export declare namespace ExtensionUserCredentialsUser {
    function getJsonObj(obj: ExtensionUserCredentialsUser): object;
    function getDeserializedJsonObj(obj: ExtensionUserCredentialsUser): object;
}
