/**
 * Identity Domains API
 * Use the Identity Domains API to manage resources within an identity domain, for example, users, dynamic resource groups, groups, and identity providers. For information about managing resources within identity domains, see [Identity and Access Management (with identity domains)](https://docs.oracle.com/iaas/Content/Identity/home.htm). This REST API is SCIM compliant.
Use the table of contents and search tool to explore the Identity Domains API.
 * OpenAPI spec version: v1
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
/**
 * Grantee beneficiary. The grantee may be a User, Group, App or DynamicResourceGroup.
 * <p>
 **SCIM++ Properties:**
 *  - idcsCsvAttributeNameMappings: [[columnHeaderName:Grantee Name, csvColumnForResolvingResourceType:Grantee Type, mapsTo:grantee.value], [columnHeaderName:Grantee Type, mapsTo:grantee.type]]
 *  - idcsSearchable: true
 *  - multiValued: false
 *  - mutability: immutable
 *  - required: true
 *  - returned: default
 *  - type: complex
 *  - uniqueness: none
 */
export interface GrantGrantee {
    /**
     * Grantee identifier
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: true
     *  - idcsCsvAttributeName: Member
     *  - idcsSearchable: true
     *  - multiValued: false
     *  - mutability: immutable
     *  - required: true
     *  - returned: default
     *  - type: string
     *  - uniqueness: none
     */
    "value": string;
    /**
     * Grantee URI
     * <p>
     **SCIM++ Properties:**
     *  - idcsSearchable: false
     *  - multiValued: false
     *  - mutability: readOnly
     *  - required: false
     *  - returned: default
     *  - type: reference
     *  - uniqueness: none
     */
    "ref"?: string;
    /**
     * Grantee resource type. Allowed values are User, Group, App and DynamicResourceGroup.
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: true
     *  - idcsCsvAttributeName: Member Type
     *  - idcsDefaultValue: User
     *  - idcsSearchable: true
     *  - multiValued: false
     *  - mutability: immutable
     *  - required: true
     *  - returned: default
     *  - type: string
     *  - uniqueness: none
     */
    "type": GrantGrantee.Type;
    /**
     * Grantee display name
     * <p>
     **SCIM++ Properties:**
     *  - idcsSearchable: false
     *  - multiValued: false
     *  - mutability: readOnly
     *  - required: false
     *  - returned: request
     *  - type: string
     *  - uniqueness: none
     */
    "display"?: string;
}
export declare namespace GrantGrantee {
    enum Type {
        User = "User",
        Group = "Group",
        App = "App",
        DynamicResourceGroup = "DynamicResourceGroup",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    function getJsonObj(obj: GrantGrantee): object;
    function getDeserializedJsonObj(obj: GrantGrantee): object;
}
