/**
 * Identity Domains API
 * Use the Identity Domains API to manage resources within an identity domain, for example, users, dynamic resource groups, groups, and identity providers. For information about managing resources within identity domains, see [Identity and Access Management (with identity domains)](https://docs.oracle.com/iaas/Content/Identity/home.htm). This REST API is SCIM compliant.
Use the table of contents and search tool to explore the Identity Domains API.
 * OpenAPI spec version: v1
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
/**
 * Grants assigned to group
 * <p>
 **SCIM++ Properties:**
 *  - idcsSearchable: true
 *  - multiValued: true
 *  - mutability: readOnly
 *  - required: false
 *  - returned: request
 *  - type: complex
 *  - uniqueness: none
 */
export interface GroupExtGrants {
    /**
     * Grant identifier
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: true
     *  - idcsSearchable: true
     *  - multiValued: false
     *  - mutability: readOnly
     *  - required: false
     *  - returned: default
     *  - type: string
     *  - uniqueness: none
     */
    "value"?: string;
    /**
     * Grant URI
     * <p>
     **SCIM++ Properties:**
     *  - idcsSearchable: false
     *  - multiValued: false
     *  - mutability: readOnly
     *  - required: false
     *  - returned: default
     *  - type: reference
     *  - uniqueness: none
     */
    "ref"?: string;
    /**
     * App identifier
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: true
     *  - idcsSearchable: true
     *  - multiValued: false
     *  - mutability: readOnly
     *  - required: false
     *  - returned: default
     *  - type: string
     *  - uniqueness: none
     */
    "appId"?: string;
    /**
     * Each value of grantMechanism indicates how (or by what component) some App (or App-Entitlement) was granted.
     * A customer or the UI should use only grantMechanism values that start with 'ADMINISTRATOR':
     *   - 'ADMINISTRATOR_TO_USER' is for a direct grant to a specific User.
     *   - 'ADMINISTRATOR_TO_GROUP' is for a grant to a specific Group, which results in indirect grants to Users who are members of that Group.
     *   - 'ADMINISTRATOR_TO_APP' is for a grant to a specific App.  The grantee (client) App gains access to the granted (server) App.
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: true
     *  - idcsSearchable: true
     *  - multiValued: false
     *  - mutability: readOnly
     *  - required: false
     *  - returned: default
     *  - type: string
     *  - uniqueness: none
     */
    "grantMechanism"?: GroupExtGrants.GrantMechanism;
}
export declare namespace GroupExtGrants {
    enum GrantMechanism {
        ImportApproleMembers = "IMPORT_APPROLE_MEMBERS",
        AdministratorToUser = "ADMINISTRATOR_TO_USER",
        AdministratorToGroup = "ADMINISTRATOR_TO_GROUP",
        ServiceManagerToUser = "SERVICE_MANAGER_TO_USER",
        AdministratorToApp = "ADMINISTRATOR_TO_APP",
        ServiceManagerToApp = "SERVICE_MANAGER_TO_APP",
        OpcInfraToApp = "OPC_INFRA_TO_APP",
        GroupMembership = "GROUP_MEMBERSHIP",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    function getJsonObj(obj: GroupExtGrants): object;
    function getDeserializedJsonObj(obj: GroupExtGrants): object;
}
