/**
 * Identity Domains API
 * Use the Identity Domains API to manage resources within an identity domain, for example, users, dynamic resource groups, groups, and identity providers. For information about managing resources within identity domains, see [Identity and Access Management (with identity domains)](https://docs.oracle.com/iaas/Content/Identity/home.htm). This REST API is SCIM compliant.
Use the table of contents and search tool to explore the Identity Domains API.
 * OpenAPI spec version: v1
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
/**
 * From email address to be used in the notification emails
 * <p>
 **SCIM++ Properties:**
 *  - caseExact: false
 *  - multiValued: false
 *  - mutability: readWrite
 *  - required: true
 *  - returned: always
 *  - type: complex
 *  - uniqueness: none
 */
export interface NotificationSettingsFromEmailAddress {
    /**
     * Value of the From email address
     * <p>
     **SCIM++ Properties:**
     *  - multiValued: false
     *  - mutability: readWrite
     *  - required: true
     *  - returned: default
     *  - type: string
     */
    "value": string;
    /**
     * Validation status for the From email address
     * <p>
     **SCIM++ Properties:**
     *  - multiValued: false
     *  - mutability: readOnly
     *  - required: false
     *  - returned: default
     *  - type: string
     */
    "validationStatus"?: NotificationSettingsFromEmailAddress.ValidationStatus;
    /**
     * From address verification mode. If postmaster account is available then 'domain' mode is used or entire valid email can be verified using 'email' mode
     * <p>
     **Added In:** 18.2.6
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: false
     *  - idcsSearchable: false
     *  - multiValued: false
     *  - mutability: readWrite
     *  - required: true
     *  - returned: default
     *  - type: string
     *  - uniqueness: none
     */
    "validate": NotificationSettingsFromEmailAddress.Validate;
    /**
     * Display name for the From email address
     * <p>
     **Added In:** 19.2.1
     * <p>
     **SCIM++ Properties:**
     *  - idcsSearchable: false
     *  - multiValued: false
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: string
     */
    "displayName"?: string;
}
export declare namespace NotificationSettingsFromEmailAddress {
    enum ValidationStatus {
        Verified = "VERIFIED",
        Pending = "PENDING",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    enum Validate {
        Email = "email",
        Domain = "domain",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    function getJsonObj(obj: NotificationSettingsFromEmailAddress): object;
    function getDeserializedJsonObj(obj: NotificationSettingsFromEmailAddress): object;
}
