/**
 * Identity Domains API
 * Use the Identity Domains API to manage resources within an identity domain, for example, users, dynamic resource groups, groups, and identity providers. For information about managing resources within identity domains, see [Identity and Access Management (with identity domains)](https://docs.oracle.com/iaas/Content/Identity/home.htm). This REST API is SCIM compliant.
Use the table of contents and search tool to explore the Identity Domains API.
 * OpenAPI spec version: v1
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * Self Registration Profile
 */
export interface SelfRegistrationProfile {
    /**
     * Unique identifier for the SCIM Resource as defined by the Service Provider. Each representation of the Resource MUST include a non-empty id value. This identifier MUST be unique across the Service Provider's entire set of Resources. It MUST be a stable, non-reassignable identifier that does not change when the same Resource is returned in subsequent requests. The value of the id attribute is always issued by the Service Provider and MUST never be specified by the Service Consumer. bulkId: is a reserved keyword and MUST NOT be used in the unique identifier.
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: false
     *  - idcsSearchable: true
     *  - multiValued: false
     *  - mutability: readOnly
     *  - required: false
     *  - returned: always
     *  - type: string
     *  - uniqueness: global
     */
    "id"?: string;
    /**
     * Unique OCI identifier for the SCIM Resource.
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: true
     *  - idcsSearchable: true
     *  - multiValued: false
     *  - mutability: immutable
     *  - required: false
     *  - returned: default
     *  - type: string
     *  - uniqueness: global
     */
    "ocid"?: string;
    /**
     * REQUIRED. The schemas attribute is an array of Strings which allows introspection of the supported schema version for a SCIM representation as well any schema extensions supported by that representation. Each String value must be a unique URI. This specification defines URIs for User, Group, and a standard \\\"enterprise\\\" extension. All representations of SCIM schema MUST include a non-zero value array with value(s) of the URIs supported by that representation. Duplicate values MUST NOT be included. Value order is not specified and MUST not impact behavior.
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: false
     *  - idcsSearchable: false
     *  - multiValued: true
     *  - mutability: readWrite
     *  - required: true
     *  - returned: default
     *  - type: string
     *  - uniqueness: none
     */
    "schemas": Array<string>;
    "meta"?: model.Meta;
    "idcsCreatedBy"?: model.IdcsCreatedBy;
    "idcsLastModifiedBy"?: model.IdcsLastModifiedBy;
    /**
     * Each value of this attribute specifies an operation that only an internal client may perform on this particular resource.
     * <p>
     **SCIM++ Properties:**
     *  - idcsSearchable: false
     *  - multiValued: true
     *  - mutability: readOnly
     *  - required: false
     *  - returned: request
     *  - type: string
     *  - uniqueness: none
     */
    "idcsPreventedOperations"?: Array<SelfRegistrationProfile.IdcsPreventedOperations>;
    /**
     * A list of tags on this resource.
     * <p>
     **SCIM++ Properties:**
     *  - idcsCompositeKey: [key, value]
     *  - idcsSearchable: true
     *  - multiValued: true
     *  - mutability: readWrite
     *  - required: false
     *  - returned: request
     *  - type: complex
     *  - uniqueness: none
     */
    "tags"?: Array<model.Tags>;
    /**
     * A boolean flag indicating this resource in the process of being deleted. Usually set to true when synchronous deletion of the resource would take too long.
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: false
     *  - idcsSearchable: true
     *  - multiValued: false
     *  - mutability: readOnly
     *  - required: false
     *  - returned: default
     *  - type: boolean
     *  - uniqueness: none
     */
    "deleteInProgress"?: boolean;
    /**
     * The release number when the resource was upgraded.
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: false
     *  - idcsSearchable: false
     *  - multiValued: false
     *  - mutability: readOnly
     *  - required: false
     *  - returned: request
     *  - type: string
     *  - uniqueness: none
     */
    "idcsLastUpgradedInRelease"?: string;
    /**
     * OCI Domain Id (ocid) in which the resource lives.
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: false
     *  - idcsSearchable: false
     *  - multiValued: false
     *  - mutability: readOnly
     *  - required: false
     *  - returned: default
     *  - type: string
     *  - uniqueness: none
     */
    "domainOcid"?: string;
    /**
     * OCI Compartment Id (ocid) in which the resource lives.
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: false
     *  - idcsSearchable: false
     *  - multiValued: false
     *  - mutability: readOnly
     *  - required: false
     *  - returned: default
     *  - type: string
     *  - uniqueness: none
     */
    "compartmentOcid"?: string;
    /**
     * OCI Tenant Id (ocid) in which the resource lives.
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: false
     *  - idcsSearchable: false
     *  - multiValued: false
     *  - mutability: readOnly
     *  - required: false
     *  - returned: default
     *  - type: string
     *  - uniqueness: none
     */
    "tenancyOcid"?: string;
    /**
     * An identifier for the Resource as defined by the Service Consumer. The externalId may simplify identification of the Resource between Service Consumer and Service Provider by allowing the Consumer to refer to the Resource with its own identifier, obviating the need to store a local mapping between the local identifier of the Resource and the identifier used by the Service Provider. Each Resource MAY include a non-empty externalId value. The value of the externalId attribute is always issued by the Service Consumer and can never be specified by the Service Provider. The Service Provider MUST always interpret the externalId as scoped to the Service Consumer's tenant.
     * <p>
     **SCIM++ Properties:**
     *  - multiValued: false
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: string
     *  - uniqueness: none
     */
    "externalId"?: string;
    /**
     * Name of the profile
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: false
     *  - idcsSearchable: true
     *  - multiValued: false
     *  - mutability: readWrite
     *  - required: true
     *  - returned: always
     *  - type: string
     *  - uniqueness: global
     */
    "name": string;
    /**
     * **SCIM++ Properties:**
     * - caseExact: false
     * - idcsSearchable: true
     * - multiValued: false
     * - mutability: readWrite
     * - required: true
     * - returned: default
     * - type: boolean
     * - uniqueness: none
     * A Boolean value that indicates whether Account verification email is required to be sent before login or not
     */
    "activationEmailRequired": boolean;
    /**
     * Number of days redirect URL is valid
     * <p>
     **SCIM++ Properties:**
     *  - idcsSearchable: true
     *  - multiValued: false
     *  - mutability: readWrite
     *  - required: true
     *  - returned: default
     *  - type: integer
     *  - uniqueness: none Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "numberOfDaysRedirectUrlIsValid": number;
    /**
     * A Boolean value that indicates whether the profile is enabled or not
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: false
     *  - idcsSearchable: true
     *  - multiValued: false
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: boolean
     *  - uniqueness: none
     */
    "active"?: boolean;
    /**
     * A Boolean value that indicates whether the profile should be displayed on login page
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: false
     *  - idcsSearchable: true
     *  - multiValued: false
     *  - mutability: readWrite
     *  - required: true
     *  - returned: default
     *  - type: boolean
     *  - uniqueness: none
     */
    "showOnLoginPage": boolean;
    /**
     * A Multivalue String value for Email domains which are valid for this profile
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: false
     *  - idcsSearchable: true
     *  - multiValued: true
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: string
     *  - uniqueness: none
     */
    "allowedEmailDomains"?: Array<string>;
    /**
     * A Multivalue String Value for Email domains to be handled as exceptions
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: false
     *  - idcsSearchable: true
     *  - multiValued: true
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: string
     *  - uniqueness: none
     */
    "disallowedEmailDomains"?: Array<string>;
    /**
     * Reference to header logo
     * <p>
     **SCIM++ Properties:**
     *  - idcsSearchable: true
     *  - multiValued: false
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: reference
     */
    "headerLogo"?: string;
    /**
     * References to footer logo
     * <p>
     **SCIM++ Properties:**
     *  - idcsSearchable: true
     *  - multiValued: false
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: reference
     */
    "footerLogo"?: string;
    /**
     * This URL will be replaced in email notification sent to user. When activation email required is set to true, user is created in \\\"pending verification\\\" state, upon clicking this link user will be able to activate himself. When activation email required is set to false, user is created in \\\"verified\\\" state, this link will be used to verify user's email.
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: false
     *  - idcsSearchable: true
     *  - multiValued: false
     *  - mutability: readWrite
     *  - required: true
     *  - returned: default
     *  - type: string
     *  - uniqueness: none
     */
    "redirectUrl": string;
    /**
     * A boolean value that indicates whether the consent text is present.
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: false
     *  - idcsSearchable: true
     *  - multiValued: false
     *  - mutability: readWrite
     *  - required: true
     *  - returned: default
     *  - type: boolean
     *  - uniqueness: none
     */
    "consentTextPresent": boolean;
    /**
     * Registration page name
     * <p>
     **SCIM++ Properties:**
     *  - idcsCompositeKey: [locale]
     *  - idcsMultiLanguage: true
     *  - idcsSearchable: true
     *  - multiValued: true
     *  - mutability: readWrite
     *  - required: true
     *  - returned: default
     *  - type: complex
     *  - uniqueness: none
     */
    "displayName": Array<model.SelfRegistrationProfileDisplayName>;
    /**
     * Text to be displayed on UI after doing self registration
     * <p>
     **SCIM++ Properties:**
     *  - idcsCompositeKey: [locale]
     *  - idcsMultiLanguage: true
     *  - idcsSearchable: true
     *  - multiValued: true
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: complex
     *  - uniqueness: none
     */
    "afterSubmitText"?: Array<model.SelfRegistrationProfileAfterSubmitText>;
    /**
     * **SCIM++ Properties:**
     * - idcsCompositeKey: [value]
     * - idcsSearchable: true
     * - multiValued: true
     * - mutability: readWrite
     * - required: false
     * - returned: default
     * - type: complex
     * - uniqueness: none
     * User Attributes
     */
    "userAttributes"?: Array<model.SelfRegistrationProfileUserAttributes>;
    "emailTemplate": model.SelfRegistrationProfileEmailTemplate;
    /**
     * Default groups assigned to the user
     * <p>
     **SCIM++ Properties:**
     *  - idcsCompositeKey: [value]
     *  - idcsSearchable: true
     *  - multiValued: true
     *  - mutability: readWrite
     *  - required: false
     *  - returned: request
     *  - type: complex
     */
    "defaultGroups"?: Array<model.SelfRegistrationProfileDefaultGroups>;
    /**
     * Header text
     * <p>
     **SCIM++ Properties:**
     *  - idcsCompositeKey: [locale]
     *  - idcsMultiLanguage: true
     *  - idcsSearchable: true
     *  - multiValued: true
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: complex
     *  - uniqueness: none
     */
    "headerText"?: Array<model.SelfRegistrationProfileHeaderText>;
    /**
     * Footer text
     * <p>
     **SCIM++ Properties:**
     *  - idcsCompositeKey: [locale]
     *  - idcsMultiLanguage: true
     *  - idcsSearchable: true
     *  - multiValued: true
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: complex
     *  - uniqueness: none
     */
    "footerText"?: Array<model.SelfRegistrationProfileFooterText>;
    /**
     * Consent text
     * <p>
     **SCIM++ Properties:**
     *  - idcsCompositeKey: [locale]
     *  - idcsMultiLanguage: true
     *  - idcsSearchable: true
     *  - multiValued: true
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: complex
     *  - uniqueness: none
     */
    "consentText"?: Array<model.SelfRegistrationProfileConsentText>;
}
export declare namespace SelfRegistrationProfile {
    enum IdcsPreventedOperations {
        Replace = "replace",
        Update = "update",
        Delete = "delete",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    function getJsonObj(obj: SelfRegistrationProfile): object;
    function getDeserializedJsonObj(obj: SelfRegistrationProfile): object;
}
