/**
 * Identity Domains API
 * Use the Identity Domains API to manage resources within an identity domain, for example, users, dynamic resource groups, groups, and identity providers. For information about managing resources within identity domains, see [Identity and Access Management (with identity domains)](https://docs.oracle.com/iaas/Content/Identity/home.htm). This REST API is SCIM compliant.
Use the table of contents and search tool to explore the Identity Domains API.
 * OpenAPI spec version: v1
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
/**
 * Certificate Validation Config
 * <p>
 **Added In:** 2010242156
 * <p>
 **SCIM++ Properties:**
 *  - caseExact: false
 *  - multiValued: false
 *  - mutability: readWrite
 *  - required: false
 *  - returned: default
 *  - type: complex
 *  - uniqueness: none
 */
export interface SettingsCertificateValidation {
    /**
     * CRL is enabled Configuration
     * <p>
     **Added In:** 2010242156
     * <p>
     **SCIM++ Properties:**
     *  - multiValued: false
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: boolean
     *  - uniqueness: none
     */
    "crlEnabled"?: boolean;
    /**
     * Use CRL as Fallback.
     * <p>
     **Added In:** 2010242156
     * <p>
     **SCIM++ Properties:**
     *  - multiValued: false
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: boolean
     *  - uniqueness: none
     */
    "crlCheckOnOCSPFailureEnabled"?: boolean;
    /**
     * CRL Location.
     * <p>
     **Added In:** 2010242156
     * <p>
     **SCIM++ Properties:**
     *  - multiValued: false
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: string
     *  - uniqueness: none
     */
    "crlLocation"?: string;
    /**
     * The CRL refresh interval in minutes
     * <p>
     **Added In:** 2010242156
     * <p>
     **SCIM++ Properties:**
     *  - multiValued: false
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: integer
     *  - uniqueness: none Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "crlRefreshInterval"?: number;
    /**
     * OCSP is enabled Configuration
     * <p>
     **Added In:** 2010242156
     * <p>
     **SCIM++ Properties:**
     *  - multiValued: false
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: boolean
     *  - uniqueness: none
     */
    "ocspEnabled"?: boolean;
    /**
     * OCSP Accept unknown response status from ocsp responder.
     * <p>
     **Added In:** 2010242156
     * <p>
     **SCIM++ Properties:**
     *  - multiValued: false
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: boolean
     *  - uniqueness: none
     */
    "ocspUnknownResponseStatusAllowed"?: boolean;
    /**
     * OCSP Responder URL
     * <p>
     **Added In:** 2010242156
     * <p>
     **SCIM++ Properties:**
     *  - multiValued: false
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: string
     *  - uniqueness: none
     */
    "ocspResponderURL"?: string;
    /**
     * This setting says, OCSP Responder URL present in the issued certificate must be used. Otherwise, OCSP Responder URL from IDP or Settings.
     * <p>
     **Added In:** 2010242156
     * <p>
     **SCIM++ Properties:**
     *  - multiValued: false
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: boolean
     *  - uniqueness: none
     */
    "ocspSettingsResponderURLPreferred"?: boolean;
    /**
     * The OCSP Timeout duration in minutes
     * <p>
     **Added In:** 2010242156
     * <p>
     **SCIM++ Properties:**
     *  - idcsMaxValue: 10
     *  - idcsMinValue: 1
     *  - multiValued: false
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: integer
     *  - uniqueness: none Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "ocspTimeoutDuration"?: number;
    /**
     * OCSP Signing Certificate Alias
     * <p>
     **Added In:** 2010242156
     * <p>
     **SCIM++ Properties:**
     *  - multiValued: false
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: string
     *  - uniqueness: none
     */
    "ocspSigningCertificateAlias"?: string;
}
export declare namespace SettingsCertificateValidation {
    function getJsonObj(obj: SettingsCertificateValidation): object;
    function getDeserializedJsonObj(obj: SettingsCertificateValidation): object;
}
