/**
 * Identity Domains API
 * Use the Identity Domains API to manage resources within an identity domain, for example, users, dynamic resource groups, groups, and identity providers. For information about managing resources within identity domains, see [Identity and Access Management (with identity domains)](https://docs.oracle.com/iaas/Content/Identity/home.htm). This REST API is SCIM compliant.
Use the table of contents and search tool to explore the Identity Domains API.
 * OpenAPI spec version: v1
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
/**
 * A complex attribute that specifies the Cloud Gate cross origin resource sharing settings.
 * <p>
 **Added In:** 2011192329
 * <p>
 **SCIM++ Properties:**
 *  - caseExact: false
 *  - idcsSearchable: false
 *  - multiValued: false
 *  - mutability: readWrite
 *  - required: false
 *  - returned: default
 *  - type: complex
 *  - uniqueness: none
 */
export interface SettingsCloudGateCorsSettings {
    /**
     * Allow Null Origin (CORS) for this tenant.
     * <p>
     **Added In:** 2011192329
     * <p>
     **SCIM++ Properties:**
     *  - idcsSearchable: false
     *  - multiValued: false
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: boolean
     *  - uniqueness: none
     */
    "cloudGateCorsAllowNullOrigin"?: boolean;
    /**
     * Enable Cloud Gate Cross-Origin Resource Sharing (CORS) for this tenant.
     * <p>
     **Added In:** 2011192329
     * <p>
     **SCIM++ Properties:**
     *  - idcsSearchable: false
     *  - multiValued: false
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: boolean
     *  - uniqueness: none
     */
    "cloudGateCorsEnabled"?: boolean;
    /**
     * Cloud Gate Allowed Cross-Origin Resource Sharing (CORS) Origins for this tenant.
     * <p>
     **Added In:** 2011192329
     * <p>
     **SCIM++ Properties:**
     *  - idcsSearchable: false
     *  - multiValued: true
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: string
     *  - uniqueness: none
     */
    "cloudGateCorsAllowedOrigins"?: Array<string>;
    /**
     * Maximum number of seconds a CORS Pre-flight Response may be cached by client.
     * <p>
     **Added In:** 2205182039
     * <p>
     **SCIM++ Properties:**
     *  - idcsSearchable: false
     *  - multiValued: false
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: integer
     *  - uniqueness: none Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "cloudGateCorsMaxAge"?: number;
    /**
     * List of Response Headers Cloud Gate is allowed to expose in the CORS Response Header: Access-Control-Expose-Headers.
     * <p>
     **Added In:** 2205182039
     * <p>
     **SCIM++ Properties:**
     *  - idcsSearchable: false
     *  - multiValued: true
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: string
     *  - uniqueness: none
     */
    "cloudGateCorsExposedHeaders"?: Array<string>;
}
export declare namespace SettingsCloudGateCorsSettings {
    function getJsonObj(obj: SettingsCloudGateCorsSettings): object;
    function getDeserializedJsonObj(obj: SettingsCloudGateCorsSettings): object;
}
