/**
 * Identity Domains API
 * Use the Identity Domains API to manage resources within an identity domain, for example, users, dynamic resource groups, groups, and identity providers. For information about managing resources within identity domains, see [Identity and Access Management (with identity domains)](https://docs.oracle.com/iaas/Content/Identity/home.htm). This REST API is SCIM compliant.
Use the table of contents and search tool to explore the Identity Domains API.
 * OpenAPI spec version: v1
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * User's Database Credential
 */
export interface UserDbCredential {
    /**
     * Unique identifier for the SCIM Resource as defined by the Service Provider. Each representation of the Resource MUST include a non-empty id value. This identifier MUST be unique across the Service Provider's entire set of Resources. It MUST be a stable, non-reassignable identifier that does not change when the same Resource is returned in subsequent requests. The value of the id attribute is always issued by the Service Provider and MUST never be specified by the Service Consumer. bulkId: is a reserved keyword and MUST NOT be used in the unique identifier.
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: false
     *  - idcsSearchable: true
     *  - multiValued: false
     *  - mutability: readOnly
     *  - required: false
     *  - returned: always
     *  - type: string
     *  - uniqueness: global
     */
    "id"?: string;
    /**
     * Unique OCI identifier for the SCIM Resource.
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: true
     *  - idcsSearchable: true
     *  - multiValued: false
     *  - mutability: immutable
     *  - required: false
     *  - returned: default
     *  - type: string
     *  - uniqueness: global
     */
    "ocid"?: string;
    /**
     * REQUIRED. The schemas attribute is an array of Strings which allows introspection of the supported schema version for a SCIM representation as well any schema extensions supported by that representation. Each String value must be a unique URI. This specification defines URIs for User, Group, and a standard \\\"enterprise\\\" extension. All representations of SCIM schema MUST include a non-zero value array with value(s) of the URIs supported by that representation. Duplicate values MUST NOT be included. Value order is not specified and MUST not impact behavior.
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: false
     *  - idcsSearchable: false
     *  - multiValued: true
     *  - mutability: readWrite
     *  - required: true
     *  - returned: default
     *  - type: string
     *  - uniqueness: none
     */
    "schemas": Array<string>;
    "meta"?: model.Meta;
    "idcsCreatedBy"?: model.IdcsCreatedBy;
    "idcsLastModifiedBy"?: model.IdcsLastModifiedBy;
    /**
     * Each value of this attribute specifies an operation that only an internal client may perform on this particular resource.
     * <p>
     **SCIM++ Properties:**
     *  - idcsSearchable: false
     *  - multiValued: true
     *  - mutability: readOnly
     *  - required: false
     *  - returned: request
     *  - type: string
     *  - uniqueness: none
     */
    "idcsPreventedOperations"?: Array<UserDbCredential.IdcsPreventedOperations>;
    /**
     * A list of tags on this resource.
     * <p>
     **SCIM++ Properties:**
     *  - idcsCompositeKey: [key, value]
     *  - idcsSearchable: true
     *  - multiValued: true
     *  - mutability: readWrite
     *  - required: false
     *  - returned: request
     *  - type: complex
     *  - uniqueness: none
     */
    "tags"?: Array<model.Tags>;
    /**
     * A boolean flag indicating this resource in the process of being deleted. Usually set to true when synchronous deletion of the resource would take too long.
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: false
     *  - idcsSearchable: true
     *  - multiValued: false
     *  - mutability: readOnly
     *  - required: false
     *  - returned: default
     *  - type: boolean
     *  - uniqueness: none
     */
    "deleteInProgress"?: boolean;
    /**
     * The release number when the resource was upgraded.
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: false
     *  - idcsSearchable: false
     *  - multiValued: false
     *  - mutability: readOnly
     *  - required: false
     *  - returned: request
     *  - type: string
     *  - uniqueness: none
     */
    "idcsLastUpgradedInRelease"?: string;
    /**
     * OCI Domain Id (ocid) in which the resource lives.
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: false
     *  - idcsSearchable: false
     *  - multiValued: false
     *  - mutability: readOnly
     *  - required: false
     *  - returned: default
     *  - type: string
     *  - uniqueness: none
     */
    "domainOcid"?: string;
    /**
     * OCI Compartment Id (ocid) in which the resource lives.
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: false
     *  - idcsSearchable: false
     *  - multiValued: false
     *  - mutability: readOnly
     *  - required: false
     *  - returned: default
     *  - type: string
     *  - uniqueness: none
     */
    "compartmentOcid"?: string;
    /**
     * OCI Tenant Id (ocid) in which the resource lives.
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: false
     *  - idcsSearchable: false
     *  - multiValued: false
     *  - mutability: readOnly
     *  - required: false
     *  - returned: default
     *  - type: string
     *  - uniqueness: none
     */
    "tenancyOcid"?: string;
    /**
     * Name
     * <p>
     **Added In:** 2109090424
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: false
     *  - type: string
     *  - mutability: readOnly
     *  - required: false
     *  - returned: default
     */
    "name"?: string;
    /**
     * The user's database password.
     * <p>
     **SCIM++ Properties:**
     *  - type: string
     *  - mutability: immutable
     *  - returned: default
     *  - required: true
     */
    "dbPassword": string;
    /**
     * Description
     * <p>
     **Added In:** 2109020413
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: false
     *  - type: string
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     */
    "description"?: string;
    /**
     * The user's database password with mixed salt.
     * <p>
     **SCIM++ Properties:**
     *  - type: string
     *  - mutability: readOnly
     *  - returned: default
     *  - required: false
     */
    "mixedDbPassword"?: string;
    /**
     * The salt of the password.
     * <p>
     **SCIM++ Properties:**
     *  - type: string
     *  - mutability: readOnly
     *  - returned: default
     *  - required: false
     */
    "salt"?: string;
    /**
     * The mixed salt of the password.
     * <p>
     **SCIM++ Properties:**
     *  - type: string
     *  - mutability: readOnly
     *  - returned: default
     *  - required: false
     */
    "mixedSalt"?: string;
    /**
     * A DateTime that specifies the date and time when the current database password was set.
     * <p>
     **SCIM++ Properties:**
     *  - type: dateTime
     *  - mutability: readOnly
     *  - returned: default
     */
    "lastSetDate"?: string;
    /**
     * Indicates that the database password has expired.
     * <p>
     **SCIM++ Properties:**
     *  - type: boolean
     *  - mutability: readOnly
     *  - returned: default
     */
    "expired"?: boolean;
    /**
     * User credential status
     * <p>
     **Added In:** 2109090424
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: false
     *  - idcsSearchable: false
     *  - multiValued: false
     *  - mutability: readWrite
     *  - required: false
     *  - returned: never
     *  - type: string
     *  - uniqueness: none
     */
    "status"?: UserDbCredential.Status;
    /**
     * When the user credential expires.
     * <p>
     **Added In:** 2109090424
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: false
     *  - idcsSearchable: false
     *  - multiValued: false
     *  - mutability: immutable
     *  - required: false
     *  - returned: default
     *  - type: dateTime
     *  - uniqueness: none
     */
    "expiresOn"?: string;
    "user"?: model.UserDbCredentialsUser;
    "urnIetfParamsScimSchemasOracleIdcsExtensionSelfChangeUser"?: model.ExtensionSelfChangeUser;
}
export declare namespace UserDbCredential {
    enum IdcsPreventedOperations {
        Replace = "replace",
        Update = "update",
        Delete = "delete",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    enum Status {
        Active = "ACTIVE",
        Inactive = "INACTIVE",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    function getJsonObj(obj: UserDbCredential): object;
    function getDeserializedJsonObj(obj: UserDbCredential): object;
}
