/**
 * Identity Domains API
 * Use the Identity Domains API to manage resources within an identity domain, for example, users, dynamic resource groups, groups, and identity providers. For information about managing resources within identity domains, see [Identity and Access Management (with identity domains)](https://docs.oracle.com/iaas/Content/Identity/home.htm). This REST API is SCIM compliant.
Use the table of contents and search tool to explore the Identity Domains API.
 * OpenAPI spec version: v1
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
/**
 * A complex attribute that indicates an account is locked (blocking any new sessions).
 * <p>
 **SCIM++ Properties:**
 *  - idcsCsvAttributeNameMappings: [[columnHeaderName:Locked, mapsTo:locked.on], [columnHeaderName:Locked Reason, mapsTo:locked.reason], [columnHeaderName:Locked Date, mapsTo:locked.lockDate]]
 *  - idcsSearchable: false
 *  - idcsAllowUpdatesInReadOnlyMode: true
 *  - multiValued: false
 *  - mutability: readWrite
 *  - required: false
 *  - returned: default
 *  - type: complex
 *  - uniqueness: none
 */
export interface UserExtLocked {
    /**
     * Indicates the reason for locking the account. Valid values are: 0 - failed password login attempts, 1 - admin lock, 2 - failed reset password attempts, 3 - failed MFA login attempts, 4 - failed MFA login attempts for federated user, 5 - failed Database login attempts
     * <p>
     **SCIM++ Properties:**
     *  - idcsSearchable: false
     *  - multiValued: false
     *  - mutability: readWrite
     *  - idcsRequiresWriteForAccessFlows: true
     *  - idcsRequiresImmediateReadAfterWriteForAccessFlows: true
     *  - required: false
     *  - returned: default
     *  - type: integer
     *  - uniqueness: none Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "reason"?: number;
    /**
     * Indicates that the account is locked.
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: false
     *  - idcsSearchable: true
     *  - multiValued: false
     *  - mutability: readWrite
     *  - idcsRequiresWriteForAccessFlows: true
     *  - idcsRequiresImmediateReadAfterWriteForAccessFlows: true
     *  - required: false
     *  - returned: default
     *  - type: boolean
     *  - uniqueness: none
     */
    "on"?: boolean;
    /**
     * The date and time that the current resource was locked.
     * <p>
     **SCIM++ Properties:**
     *  - idcsSearchable: false
     *  - multiValued: false
     *  - mutability: readWrite
     *  - idcsRequiresWriteForAccessFlows: true
     *  - required: false
     *  - returned: default
     *  - type: dateTime
     *  - uniqueness: none
     */
    "lockDate"?: string;
    /**
     * Indicates whether the user password is expired. If this value is false, password expiry is still evaluated during user login.
     * <p>
     **Added In:** 20.1.3
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: false
     *  - idcsSearchable: false
     *  - multiValued: false
     *  - mutability: readWrite
     *  - required: false
     *  - returned: request
     *  - type: boolean
     *  - uniqueness: none
     */
    "expired"?: boolean;
}
export declare namespace UserExtLocked {
    function getJsonObj(obj: UserExtLocked): object;
    function getDeserializedJsonObj(obj: UserExtLocked): object;
}
