/**
 * Identity Domains API
 * Use the Identity Domains API to manage resources within an identity domain, for example, users, dynamic resource groups, groups, and identity providers. For information about managing resources within identity domains, see [Identity and Access Management (with identity domains)](https://docs.oracle.com/iaas/Content/Identity/home.htm). This REST API is SCIM compliant.
Use the table of contents and search tool to explore the Identity Domains API.
 * OpenAPI spec version: v1
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
/**
 * The risk score pertaining to the user.
 * <p>
 **Added In:** 18.1.6
 * <p>
 **SCIM++ Properties:**
 *  - caseExact: false
 *  - idcsCompositeKey: [value]
 *  - multiValued: true
 *  - mutability: readWrite
 *  - required: false
 *  - returned: request
 *  - type: complex
 *  - uniqueness: none
 */
export interface UserExtRiskScores {
    /**
     * Risk Provider Profile: Identifier for the provider service from which the risk score was received.
     * <p>
     **Added In:** 18.1.6
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: true
     *  - idcsSearchable: true
     *  - multiValued: false
     *  - mutability: readWrite
     *  - required: true
     *  - returned: always
     *  - type: string
     *  - uniqueness: none
     */
    "value": string;
    /**
     * Risk Provider Profile URI: URI that corresponds to risk source identifier.
     * <p>
     **Added In:** 18.1.6
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: true
     *  - idcsSearchable: false
     *  - multiValued: false
     *  - mutability: readOnly
     *  - required: false
     *  - returned: always
     *  - type: reference
     *  - uniqueness: none
     */
    "ref"?: string;
    /**
     * Risk Provider Profile Source
     * <p>
     **Added In:** 18.1.6
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: false
     *  - idcsSearchable: true
     *  - multiValued: false
     *  - mutability: readOnly
     *  - required: false
     *  - returned: always
     *  - type: string
     *  - uniqueness: none
     */
    "source"?: string;
    /**
     * Risk Provider Profile status
     * <p>
     **Added In:** 18.1.6
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: false
     *  - idcsSearchable: true
     *  - multiValued: false
     *  - mutability: readOnly
     *  - required: false
     *  - returned: always
     *  - type: string
     *  - uniqueness: none
     */
    "status"?: string;
    /**
     * Risk Score value
     * <p>
     **Added In:** 18.1.6
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: false
     *  - idcsSearchable: true
     *  - multiValued: false
     *  - mutability: readWrite
     *  - required: true
     *  - returned: always
     *  - type: integer
     *  - uniqueness: none
     *  - idcsMaxValue: 100
     *  - idcsMinValue: 0 Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "score": number;
    /**
     * Risk Level
     * <p>
     **Added In:** 18.1.6
     * <p>
     **SCIM++ Properties:**
     *  - idcsSearchable: true
     *  - multiValued: false
     *  - mutability: readWrite
     *  - required: true
     *  - returned: always
     *  - type: string
     *  - uniqueness: none
     */
    "riskLevel": UserExtRiskScores.RiskLevel;
    /**
     * Last update timestamp for the risk score
     * <p>
     **Added In:** 18.1.6
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: false
     *  - idcsSearchable: false
     *  - multiValued: false
     *  - mutability: readWrite
     *  - required: true
     *  - returned: always
     *  - type: dateTime
     *  - uniqueness: none
     */
    "lastUpdateTimestamp": string;
}
export declare namespace UserExtRiskScores {
    enum RiskLevel {
        Low = "LOW",
        Medium = "MEDIUM",
        High = "HIGH",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    function getJsonObj(obj: UserExtRiskScores): object;
    function getDeserializedJsonObj(obj: UserExtRiskScores): object;
}
