/**
 * Identity Domains API
 * Use the Identity Domains API to manage resources within an identity domain, for example, users, dynamic resource groups, groups, and identity providers. For information about managing resources within identity domains, see [Identity and Access Management (with identity domains)](https://docs.oracle.com/iaas/Content/Identity/home.htm). This REST API is SCIM compliant.
Use the table of contents and search tool to explore the Identity Domains API.
 * OpenAPI spec version: v1
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * User Account
 */
export interface User {
    /**
     * Unique identifier for the SCIM Resource as defined by the Service Provider. Each representation of the Resource MUST include a non-empty id value. This identifier MUST be unique across the Service Provider's entire set of Resources. It MUST be a stable, non-reassignable identifier that does not change when the same Resource is returned in subsequent requests. The value of the id attribute is always issued by the Service Provider and MUST never be specified by the Service Consumer. bulkId: is a reserved keyword and MUST NOT be used in the unique identifier.
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: false
     *  - idcsSearchable: true
     *  - multiValued: false
     *  - mutability: readOnly
     *  - required: false
     *  - returned: always
     *  - type: string
     *  - uniqueness: global
     */
    "id"?: string;
    /**
     * Unique OCI identifier for the SCIM Resource.
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: true
     *  - idcsSearchable: true
     *  - multiValued: false
     *  - mutability: immutable
     *  - required: false
     *  - returned: default
     *  - type: string
     *  - uniqueness: global
     */
    "ocid"?: string;
    /**
     * REQUIRED. The schemas attribute is an array of Strings which allows introspection of the supported schema version for a SCIM representation as well any schema extensions supported by that representation. Each String value must be a unique URI. This specification defines URIs for User, Group, and a standard \\\"enterprise\\\" extension. All representations of SCIM schema MUST include a non-zero value array with value(s) of the URIs supported by that representation. Duplicate values MUST NOT be included. Value order is not specified and MUST not impact behavior.
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: false
     *  - idcsSearchable: false
     *  - multiValued: true
     *  - mutability: readWrite
     *  - required: true
     *  - returned: default
     *  - type: string
     *  - uniqueness: none
     */
    "schemas": Array<string>;
    "meta"?: model.Meta;
    "idcsCreatedBy"?: model.IdcsCreatedBy;
    "idcsLastModifiedBy"?: model.IdcsLastModifiedBy;
    /**
     * Each value of this attribute specifies an operation that only an internal client may perform on this particular resource.
     * <p>
     **SCIM++ Properties:**
     *  - idcsSearchable: false
     *  - multiValued: true
     *  - mutability: readOnly
     *  - required: false
     *  - returned: request
     *  - type: string
     *  - uniqueness: none
     */
    "idcsPreventedOperations"?: Array<User.IdcsPreventedOperations>;
    /**
     * A list of tags on this resource.
     * <p>
     **SCIM++ Properties:**
     *  - idcsCompositeKey: [key, value]
     *  - idcsSearchable: true
     *  - multiValued: true
     *  - mutability: readWrite
     *  - required: false
     *  - returned: request
     *  - type: complex
     *  - uniqueness: none
     */
    "tags"?: Array<model.Tags>;
    /**
     * A boolean flag indicating this resource in the process of being deleted. Usually set to true when synchronous deletion of the resource would take too long.
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: false
     *  - idcsSearchable: true
     *  - multiValued: false
     *  - mutability: readOnly
     *  - required: false
     *  - returned: default
     *  - type: boolean
     *  - uniqueness: none
     */
    "deleteInProgress"?: boolean;
    /**
     * The release number when the resource was upgraded.
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: false
     *  - idcsSearchable: false
     *  - multiValued: false
     *  - mutability: readOnly
     *  - required: false
     *  - returned: request
     *  - type: string
     *  - uniqueness: none
     */
    "idcsLastUpgradedInRelease"?: string;
    /**
     * OCI Domain Id (ocid) in which the resource lives.
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: false
     *  - idcsSearchable: false
     *  - multiValued: false
     *  - mutability: readOnly
     *  - required: false
     *  - returned: default
     *  - type: string
     *  - uniqueness: none
     */
    "domainOcid"?: string;
    /**
     * OCI Compartment Id (ocid) in which the resource lives.
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: false
     *  - idcsSearchable: false
     *  - multiValued: false
     *  - mutability: readOnly
     *  - required: false
     *  - returned: default
     *  - type: string
     *  - uniqueness: none
     */
    "compartmentOcid"?: string;
    /**
     * OCI Tenant Id (ocid) in which the resource lives.
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: false
     *  - idcsSearchable: false
     *  - multiValued: false
     *  - mutability: readOnly
     *  - required: false
     *  - returned: default
     *  - type: string
     *  - uniqueness: none
     */
    "tenancyOcid"?: string;
    /**
     * An identifier for the Resource as defined by the Service Consumer. The externalId may simplify identification of the Resource between Service Consumer and Service Provider by allowing the Consumer to refer to the Resource with its own identifier, obviating the need to store a local mapping between the local identifier of the Resource and the identifier used by the Service Provider. Each Resource MAY include a non-empty externalId value. The value of the externalId attribute is always issued by the Service Consumer and can never be specified by the Service Provider. The Service Provider MUST always interpret the externalId as scoped to the Service Consumer's tenant.
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: false
     *  - idcsCsvAttributeNameMappings: [[columnHeaderName:External Id]]
     *  - idcsPii: true
     *  - idcsSearchable: true
     *  - multiValued: false
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: string
     *  - uniqueness: none
     */
    "externalId"?: string;
    /**
     * User name
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: false
     *  - idcsCsvAttributeName: User ID
     *  - idcsCsvAttributeNameMappings: [[columnHeaderName:User Name, deprecatedColumnHeaderName:User ID]]
     *  - idcsPii: true
     *  - idcsSearchable: true
     *  - multiValued: false
     *  - mutability: readWrite
     *  - required: true
     *  - returned: always
     *  - type: string
     *  - uniqueness: global
     */
    "userName": string;
    /**
     * Description of the user
     * <p>
     **Added In:** 2012271618
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: false
     *  - idcsPii: true
     *  - idcsSearchable: false
     *  - multiValued: false
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: string
     *  - uniqueness: none
     */
    "description"?: string;
    /**
     * Display name
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: false
     *  - idcsCsvAttributeName: Display Name
     *  - idcsCsvAttributeNameMappings: [[columnHeaderName:Display Name]]
     *  - idcsPii: true
     *  - idcsSearchable: true
     *  - multiValued: false
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: string
     *  - uniqueness: none
     */
    "displayName"?: string;
    /**
     * Nick name
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: false
     *  - idcsCsvAttributeName: Nick Name
     *  - idcsCsvAttributeNameMappings: [[columnHeaderName:Nick Name]]
     *  - idcsPii: true
     *  - idcsSearchable: true
     *  - multiValued: false
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: string
     *  - uniqueness: none
     */
    "nickName"?: string;
    /**
     * A fully-qualified URL to a page representing the User's online profile
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: false
     *  - idcsCsvAttributeName: Profile URL
     *  - idcsCsvAttributeNameMappings: [[columnHeaderName:Profile Url]]
     *  - idcsPii: true
     *  - idcsSearchable: true
     *  - multiValued: false
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: reference
     *  - uniqueness: none
     */
    "profileUrl"?: string;
    /**
     * Title
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: false
     *  - idcsCsvAttributeName: Title
     *  - idcsCsvAttributeNameMappings: [[columnHeaderName:Title]]
     *  - idcsPii: true
     *  - idcsSearchable: true
     *  - multiValued: false
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: string
     *  - uniqueness: none
     */
    "title"?: string;
    /**
     * Used to identify the organization-to-user relationship
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: false
     *  - idcsCsvAttributeName: User Type
     *  - idcsCsvAttributeNameMappings: [[columnHeaderName:User Type]]
     *  - idcsPii: true
     *  - idcsSearchable: true
     *  - multiValued: false
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: string
     *  - uniqueness: none
     */
    "userType"?: User.UserType;
    /**
     * Used to indicate the User's default location for purposes of localizing items such as currency, date and time format, numerical representations, and so on.
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: false
     *  - idcsCsvAttributeName: Locale
     *  - idcsCsvAttributeNameMappings: [[columnHeaderName:Locale]]
     *  - idcsSearchable: true
     *  - multiValued: false
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: string
     *  - uniqueness: none
     */
    "locale"?: string;
    /**
     * User's preferred written or spoken language used for localized user interfaces
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: false
     *  - idcsCsvAttributeName: Preferred Language
     *  - idcsCsvAttributeNameMappings: [[columnHeaderName:Preferred Language]]
     *  - idcsSearchable: true
     *  - multiValued: false
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: string
     *  - uniqueness: none
     */
    "preferredLanguage"?: string;
    /**
     * User's timezone
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: false
     *  - idcsCanonicalValueSourceFilter: attrName eq \"timezones\" and attrValues.value eq \"$(timezone)\"
     *  - idcsCanonicalValueSourceResourceType: AllowedValue
     *  - idcsCsvAttributeName: TimeZone
     *  - idcsCsvAttributeNameMappings: [[columnHeaderName:Time Zone, deprecatedColumnHeaderName:TimeZone]]
     *  - idcsSearchable: true
     *  - multiValued: false
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: string
     *  - uniqueness: none
     */
    "timezone"?: string;
    /**
     * User status
     * <p>
     **SCIM++ Properties:**
     *  - caseExact: false
     *  - idcsCsvAttributeName: Active
     *  - idcsCsvAttributeNameMappings: [[columnHeaderName:Active]]
     *  - idcsSearchable: true
     *  - multiValued: false
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: boolean
     *  - uniqueness: none
     */
    "active"?: boolean;
    /**
     * Password attribute. Max length for password is controlled via Password Policy.
     * <p>
     **SCIM++ Properties:**
     *  - idcsCsvAttributeName: Password
     *  - idcsCsvAttributeNameMappings: [[columnHeaderName:Password]]
     *  - idcsPii: true
     *  - idcsSearchable: false
     *  - idcsSensitive: hash
     *  - multiValued: false
     *  - mutability: writeOnly
     *  - required: false
     *  - returned: never
     *  - type: string
     *  - uniqueness: none
     */
    "password"?: string;
    "name"?: model.UserName;
    /**
     * A complex attribute representing emails
     * <p>
     **SCIM++ Properties:**
     *  - idcsCompositeKey: [value, type]
     *  - idcsCsvAttributeNameMappings: [[columnHeaderName:Work Email, mapsTo:emails[work].value], [columnHeaderName:Home Email, mapsTo:emails[home].value], [columnHeaderName:Primary Email Type, mapsTo:emails[$(type)].primary], [columnHeaderName:Other Email, mapsTo:emails[other].value], [columnHeaderName:Recovery Email, mapsTo:emails[recovery].value], [columnHeaderName:Work Email Verified, mapsTo:emails[work].verified], [columnHeaderName:Home Email Verified, mapsTo:emails[home].verified], [columnHeaderName:Other Email Verified, mapsTo:emails[other].verified], [columnHeaderName:Recovery Email Verified, mapsTo:emails[recovery].verified]]
     *  - idcsPii: true
     *  - multiValued: true
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: complex
     *  - uniqueness: none
     */
    "emails"?: Array<model.UserEmails>;
    /**
     * Phone numbers
     * <p>
     **SCIM++ Properties:**
     *  - idcsCompositeKey: [value, type]
     *  - idcsCsvAttributeNameMappings: [[columnHeaderName:Work Phone, mapsTo:phoneNumbers[work].value], [columnHeaderName:Mobile No, mapsTo:phoneNumbers[mobile].value], [columnHeaderName:Home Phone, mapsTo:phoneNumbers[home].value], [columnHeaderName:Fax, mapsTo:phoneNumbers[fax].value], [columnHeaderName:Pager, mapsTo:phoneNumbers[pager].value], [columnHeaderName:Other Phone, mapsTo:phoneNumbers[other].value], [columnHeaderName:Recovery Phone, mapsTo:phoneNumbers[recovery].value], [columnHeaderName:Primary Phone Type, mapsTo:phoneNumbers[$(type)].primary]]
     *  - idcsPii: true
     *  - multiValued: true
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: complex
     *  - uniqueness: none
     */
    "phoneNumbers"?: Array<model.UserPhoneNumbers>;
    /**
     * User's instant messaging addresses
     * <p>
     **SCIM++ Properties:**
     *  - idcsCompositeKey: [value, type]
     *  - idcsPii: true
     *  - multiValued: true
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: complex
     *  - uniqueness: none
     */
    "ims"?: Array<model.UserIms>;
    /**
     * URLs of photos for the User
     * <p>
     **SCIM++ Properties:**
     *  - idcsCompositeKey: [value, type]
     *  - idcsPii: true
     *  - multiValued: true
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: complex
     *  - uniqueness: none
     */
    "photos"?: Array<model.UserPhotos>;
    /**
     * A physical mailing address for this User, as described in (address Element). Canonical Type Values of work, home, and other. The value attribute is a complex type with the following sub-attributes.
     * <p>
     **SCIM++ Properties:**
     *  - idcsCompositeKey: [type]
     *  - idcsCsvAttributeNameMappings: [[columnHeaderName:Work Address Street, deprecatedColumnHeaderName:Work Street Address, mapsTo:addresses[work].streetAddress], [columnHeaderName:Work Address Locality, deprecatedColumnHeaderName:Work City, mapsTo:addresses[work].locality], [columnHeaderName:Work Address Region, deprecatedColumnHeaderName:Work State, mapsTo:addresses[work].region], [columnHeaderName:Work Address Postal Code, deprecatedColumnHeaderName:Work Postal Code, mapsTo:addresses[work].postalCode], [columnHeaderName:Work Address Country, deprecatedColumnHeaderName:Work Country, mapsTo:addresses[work].country], [columnHeaderName:Work Address Formatted, mapsTo:addresses[work].formatted], [columnHeaderName:Home Address Formatted, mapsTo:addresses[home].formatted], [columnHeaderName:Other Address Formatted, mapsTo:addresses[other].formatted], [columnHeaderName:Home Address Street, mapsTo:addresses[home].streetAddress], [columnHeaderName:Other Address Street, mapsTo:addresses[other].streetAddress], [columnHeaderName:Home Address Locality, mapsTo:addresses[home].locality], [columnHeaderName:Other Address Locality, mapsTo:addresses[other].locality], [columnHeaderName:Home Address Region, mapsTo:addresses[home].region], [columnHeaderName:Other Address Region, mapsTo:addresses[other].region], [columnHeaderName:Home Address Country, mapsTo:addresses[home].country], [columnHeaderName:Other Address Country, mapsTo:addresses[other].country], [columnHeaderName:Home Address Postal Code, mapsTo:addresses[home].postalCode], [columnHeaderName:Other Address Postal Code, mapsTo:addresses[other].postalCode], [columnHeaderName:Primary Address Type, mapsTo:addresses[$(type)].primary]]
     *  - idcsPii: true
     *  - multiValued: true
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: complex
     *  - uniqueness: none
     */
    "addresses"?: Array<model.Addresses>;
    /**
     * A list of groups that the user belongs to, either thorough direct membership, nested groups, or dynamically calculated
     * <p>
     **SCIM++ Properties:**
     *  - idcsCompositeKey: [value]
     *  - idcsSearchable: true
     *  - multiValued: true
     *  - mutability: readOnly
     *  - required: false
     *  - returned: request
     *  - type: complex
     *  - uniqueness: none
     */
    "groups"?: Array<model.UserGroups>;
    /**
     * A list of entitlements for the User that represent a thing the User has.
     * <p>
     **SCIM++ Properties:**
     *  - idcsCompositeKey: [value, type]
     *  - multiValued: true
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: complex
     *  - uniqueness: none
     */
    "entitlements"?: Array<model.UserEntitlements>;
    /**
     * A list of roles for the User that collectively represent who the User is; e.g., 'Student', 'Faculty'.
     * <p>
     **SCIM++ Properties:**
     *  - idcsCompositeKey: [value, type]
     *  - multiValued: true
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: complex
     *  - uniqueness: none
     */
    "roles"?: Array<model.UserRoles>;
    /**
     * A list of certificates issued to the User.
     * <p>
     **SCIM++ Properties:**
     *  - idcsCompositeKey: [value]
     *  - multiValued: true
     *  - mutability: readWrite
     *  - required: false
     *  - returned: default
     *  - type: complex
     *  - uniqueness: none
     */
    "x509Certificates"?: Array<model.UserX509Certificates>;
    "urnIetfParamsScimSchemasExtensionEnterprise2_0User"?: model.ExtensionEnterprise20User;
    "urnIetfParamsScimSchemasOracleIdcsExtensionUserUser"?: model.ExtensionUserUser;
    "urnIetfParamsScimSchemasOracleIdcsExtensionPasswordStateUser"?: model.ExtensionPasswordStateUser;
    "urnIetfParamsScimSchemasOracleIdcsExtensionUserStateUser"?: model.ExtensionUserStateUser;
    "urnIetfParamsScimSchemasOracleIdcsExtensionPosixUser"?: model.ExtensionPosixUser;
    "urnIetfParamsScimSchemasOracleIdcsExtensionKerberosUserUser"?: model.ExtensionKerberosUserUser;
    "urnIetfParamsScimSchemasOracleIdcsExtensionMfaUser"?: model.ExtensionMfaUser;
    "urnIetfParamsScimSchemasOracleIdcsExtensionAdaptiveUser"?: model.ExtensionAdaptiveUser;
    "urnIetfParamsScimSchemasOracleIdcsExtensionSffUser"?: model.ExtensionSffUser;
    "urnIetfParamsScimSchemasOracleIdcsExtensionSecurityQuestionsUser"?: model.ExtensionSecurityQuestionsUser;
    "urnIetfParamsScimSchemasOracleIdcsExtensionSelfRegistrationUser"?: model.ExtensionSelfRegistrationUser;
    "urnIetfParamsScimSchemasOracleIdcsExtensionSocialAccountUser"?: model.ExtensionSocialAccountUser;
    "urnIetfParamsScimSchemasOracleIdcsExtensionDbUserUser"?: model.ExtensionDbUserUser;
    "urnIetfParamsScimSchemasOracleIdcsExtensionTermsOfUseUser"?: model.ExtensionTermsOfUseUser;
    "urnIetfParamsScimSchemasOracleIdcsExtensionPasswordlessUser"?: model.ExtensionPasswordlessUser;
    "urnIetfParamsScimSchemasOracleIdcsExtensionOciTags"?: model.ExtensionOCITags;
    "urnIetfParamsScimSchemasOracleIdcsExtensionUserCredentialsUser"?: model.ExtensionUserCredentialsUser;
    "urnIetfParamsScimSchemasOracleIdcsExtensionCapabilitiesUser"?: model.ExtensionCapabilitiesUser;
    "urnIetfParamsScimSchemasOracleIdcsExtensionDbCredentialsUser"?: model.ExtensionDbCredentialsUser;
    "urnIetfParamsScimSchemasOracleIdcsExtensionSelfChangeUser"?: model.ExtensionSelfChangeUser;
}
export declare namespace User {
    enum IdcsPreventedOperations {
        Replace = "replace",
        Update = "update",
        Delete = "delete",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    enum UserType {
        Contractor = "Contractor",
        Employee = "Employee",
        Intern = "Intern",
        Temp = "Temp",
        External = "External",
        Service = "Service",
        Generic = "Generic",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    function getJsonObj(obj: User): object;
    function getDeserializedJsonObj(obj: User): object;
}
