/**
 * Java Management Service API
 * API for the Java Management Service. Use this API to view, create, and manage Fleets.
 * OpenAPI spec version: 20210610
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * Information about a binary artifact of Java.
 */
export interface JavaArtifact {
    /**
     * Unique identifier for the artifact. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "artifactId": number;
    /**
     * Description of the binary artifact. Typically includes the OS, architecture, and installer type.
     */
    "artifactDescription": string;
    /**
     * Product content type of this artifact.
     */
    "artifactContentType": model.ArtifactContentType;
    /**
     * Approximate compressed file size in bytes. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "approximateFileSizeInBytes": number;
    /**
     * SHA256 checksum of the artifact.
     */
    "sha256": string;
    /**
     * The file name of the artifact.
     */
    "artifactFileName"?: string;
    /**
     * The target Operating System family for the artifact.
     */
    "osFamily": string;
    /**
     * The target Operating System architecture for the artifact.
     */
    "architecture": string;
    /**
     * The package type(typically the file extension) of the artifact.
     */
    "packageType": string;
    /**
     * Additional information about the package type.
     */
    "packageTypeDetail"?: string;
    /**
     * The endpoint that returns a short-lived artifact download URL in the response payload.
     * This download url can then be used for downloading the artifact.
     * See this [API](https://docs.oracle.com/en-us/iaas/api/#/en/jms/20230601/JavaArtifact/GenerateArtifactDownloadUrl) for more details.
     *
     */
    "downloadUrl": string;
    /**
     * The endpoint for downloading this artifact from command line, automatically in scripts and dockerfiles.
     * Depending on the context, this can point to the archive or latest update release version artifact in the specified family.
     *
     */
    "scriptDownloadUrl": string;
    /**
     * The URL for retrieving the checksum for the artifact.
     * Depending on the context, this can point to the checksum of the archive or latest update release version artifact.
     *
     */
    "scriptChecksumUrl": string;
}
export declare namespace JavaArtifact {
    function getJsonObj(obj: JavaArtifact): object;
    function getDeserializedJsonObj(obj: JavaArtifact): object;
}
