/**
 * Java Management Service API
 * API for the Java Management Service. Use this API to view, create, and manage Fleets.
 * OpenAPI spec version: 20210610
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * Java Runtime usage during a specified time period. A Java Runtime is identified by its vendor and version.
 */
export interface JreUsage {
    /**
     * The internal identifier of the Java Runtime.
     */
    "id"?: string;
    /**
     * The [OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the related fleet.
     */
    "fleetId"?: string;
    /**
     * The [OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the related managed instance. This property value is present only for /listJreUsage.
     */
    "managedInstanceId"?: string;
    /**
     * The security status of the Java Runtime.
     */
    "securityStatus"?: model.JreSecurityStatus;
    /**
     * The release date of the Java Runtime (formatted according to [RFC3339](https://datatracker.ietf.org/doc/html/rfc3339)).
     */
    "releaseDate"?: Date;
    /**
     * The End of Support Life (EOSL) date of the Java Runtime (formatted according to [RFC3339](https://datatracker.ietf.org/doc/html/rfc3339)).
     */
    "endOfSupportLifeDate"?: Date;
    /**
     * The vendor of the Java Runtime.
     */
    "vendor": string;
    /**
     * The distribution of a Java Runtime is the name of the lineage of product to which it belongs, for example _Java(TM) SE Runtime Environment_.
     */
    "distribution": string;
    /**
     * The version of the Java Runtime.
     */
    "version": string;
    /**
     * The number of days since this release has been under the security baseline. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "daysUnderSecurityBaseline"?: number;
    /**
     * The operating systems that have this Java Runtime installed.
     */
    "operatingSystems"?: Array<model.OperatingSystem>;
    /**
     * The approximate count of installations that are installations of this Java Runtime. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "approximateInstallationCount"?: number;
    /**
     * The approximate count of the applications running on this Java Runtime. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "approximateApplicationCount"?: number;
    /**
     * The approximate count of the managed instances that report this Java Runtime. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "approximateManagedInstanceCount"?: number;
    /**
     * The approximate count of work requests working on this Java Runtime. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "approximatePendingWorkRequestCount"?: number;
    /**
     * Lower bound of the specified time period filter. JMS provides a view of the data that is _per day_. The query uses only the date element of the parameter.
     */
    "timeStart"?: Date;
    /**
     * Upper bound of the specified time period filter. JMS provides a view of the data that is _per day_. The query uses only the date element of the parameter.
     */
    "timeEnd"?: Date;
    /**
     * The date and time the resource was _first_ reported to JMS.
     * This is potentially _before_ the specified time period provided by the filters.
     * For example, a resource can be first reported to JMS before the start of a specified time period,
     * if it is also reported during the time period.
     *
     */
    "timeFirstSeen"?: Date;
    /**
     * The date and time the resource was _last_ reported to JMS.
     * This is potentially _after_ the specified time period provided by the filters.
     * For example, a resource can be last reported to JMS before the start of a specified time period,
     * if it is also reported during the time period.
     *
     */
    "timeLastSeen"?: Date;
}
export declare namespace JreUsage {
    function getJsonObj(obj: JreUsage): object;
    function getDeserializedJsonObj(obj: JreUsage): object;
}
