/**
 * Java Management Service API
 * API for the Java Management Service. Use this API to view, create, and manage Fleets.
 * OpenAPI spec version: 20210610
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * Managed instance usage during a specified time period.
 * An entity that emits usage events to Java Management Service (JMS) is represented as a managed instance.
 * A managed instance has a unique identity which is used by JMS to distinguish it from other managed instances.
 * Currently, JMS supports only one kind of managed instance, a Management Agent.
 *
 */
export interface ManagedInstanceUsage {
    /**
     * The [OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the related managed instance.
     *
     */
    "managedInstanceId": string;
    /**
     * The type of the source of events.
     */
    "managedInstanceType": model.ManagedInstanceType;
    /**
     * The hostname of the managed instance (if applicable).
     */
    "hostname"?: string;
    /**
     * The host [OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the related managed instance.
     *
     */
    "hostId"?: string;
    "operatingSystem"?: model.OperatingSystem;
    "agent"?: model.Agent;
    /**
     * The approximate count of applications reported by this managed instance. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "approximateApplicationCount"?: number;
    /**
     * The approximate count of installations reported by this managed instance. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "approximateInstallationCount"?: number;
    /**
     * The approximate count of Java Runtimes reported by this managed instance. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "approximateJreCount"?: number;
    /**
     * DRS file status
     */
    "drsFileStatus"?: model.DrsFileStatus;
    /**
     * Lower bound of the specified time period filter. JMS provides a view of the data that is _per day_. The query uses only the date element of the parameter.
     */
    "timeStart"?: Date;
    /**
     * Upper bound of the specified time period filter. JMS provides a view of the data that is _per day_. The query uses only the date element of the parameter.
     */
    "timeEnd"?: Date;
    /**
     * The date and time the resource was _first_ reported to JMS.
     * This is potentially _before_ the specified time period provided by the filters.
     * For example, a resource can be first reported to JMS before the start of a specified time period,
     * if it is also reported during the time period.
     *
     */
    "timeFirstSeen"?: Date;
    /**
     * The date and time the resource was _last_ reported to JMS.
     * This is potentially _after_ the specified time period provided by the filters.
     * For example, a resource can be last reported to JMS before the start of a specified time period,
     * if it is also reported during the time period.
     *
     */
    "timeLastSeen"?: Date;
}
export declare namespace ManagedInstanceUsage {
    function getJsonObj(obj: ManagedInstanceUsage): object;
    function getDeserializedJsonObj(obj: ManagedInstanceUsage): object;
}
