/**
 * Java Management Service Download API
 * The APIs for the <a href="https://docs.oracle.com/en-us/iaas/jms/doc/java-download.html">Java Download</a> feature of Java Management Service.
 * OpenAPI spec version: 20230601
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import common = require("oci-common");
import * as requests from "./request";
import * as responses from "./response";
import { JavaDownloadWaiter } from "./javadownload-waiter";
declare const Breaker: any;
export declare enum JavaDownloadApiKeys {
}
/**
 * This service client uses {@link common.CircuitBreaker.DefaultConfiguration} for all the operations by default if no circuit breaker configuration is defined by the user.
 */
export declare class JavaDownloadClient {
    protected static serviceEndpointTemplate: string;
    protected static endpointServiceName: string;
    protected "_realmSpecificEndpointTemplateEnabled": boolean | undefined;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_waiters": JavaDownloadWaiter;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: typeof Breaker | null;
    protected _httpOptions: any;
    protected _bodyDuplexMode: any;
    targetService: string;
    protected _regionId: string;
    protected "_region": common.Region;
    protected _lastSetRegionOrRegionId: string;
    protected _httpClient: common.HttpClient;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    get endpoint(): string;
    /**
     * Sets the endpoint to call (ex, https://www.example.com).
     * @param endpoint The endpoint of the service.
     */
    set endpoint(endpoint: string);
    get logger(): import("oci-common/lib/log").Logger;
    /**
     * Determines whether realm specific endpoint should be used or not.
     * Set realmSpecificEndpointTemplateEnabled to "true" if the user wants to enable use of realm specific endpoint template, otherwise set it to "false"
     * @param realmSpecificEndpointTemplateEnabled flag to enable the use of realm specific endpoint template
     */
    set useRealmSpecificEndpointTemplate(realmSpecificEndpointTemplateEnabled: boolean);
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    set region(region: common.Region);
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    set regionId(regionId: string);
    /**
     * Creates a new JavaDownloadWaiter for resources for this service.
     *
     * @param config The waiter configuration for termination and delay strategy
     * @return The service waiters.
     */
    createWaiters(config?: common.WaiterConfiguration): JavaDownloadWaiter;
    /**
     * Gets the waiters available for resources for this service.
     *
     * @return The service waiters.
     */
    getWaiters(): JavaDownloadWaiter;
    /**
     * Shutdown the circuit breaker used by the client when it is no longer needed
     */
    shutdownCircuitBreaker(): void;
    /**
     * Close the client once it is no longer needed
     */
    close(): void;
    /**
     * Cancels the work request with the given ID.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CancelWorkRequestRequest
     * @return CancelWorkRequestResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/jmsjavadownloads/CancelWorkRequest.ts.html |here} to see how to use CancelWorkRequest API.
     */
    cancelWorkRequest(cancelWorkRequestRequest: requests.CancelWorkRequestRequest): Promise<responses.CancelWorkRequestResponse>;
    /**
     * Create a new report in the specified format containing the download details
     * for the tenancy.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateJavaDownloadReportRequest
     * @return CreateJavaDownloadReportResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/jmsjavadownloads/CreateJavaDownloadReport.ts.html |here} to see how to use CreateJavaDownloadReport API.
     */
    createJavaDownloadReport(createJavaDownloadReportRequest: requests.CreateJavaDownloadReportRequest): Promise<responses.CreateJavaDownloadReportResponse>;
    /**
     * Creates a new JavaDownloadToken in the tenancy with specified attributes.
     * Ensure that you review the license terms before token generation. Visit the <a href=\"https://www.oracle.com/java/technologies/downloads\"/>Oracle Java Downloads</a> page to understand the license terms of the Java version for which you are generating a token. By generating a token, you agree to the associated license terms. See <a href=\"https://www.oracle.com/cis/java/technologies/javase/jdk-faqs.html\">Oracle JDK Licensing - FAQs</a> for detailed information.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateJavaDownloadTokenRequest
     * @return CreateJavaDownloadTokenResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/jmsjavadownloads/CreateJavaDownloadToken.ts.html |here} to see how to use CreateJavaDownloadToken API.
     */
    createJavaDownloadToken(createJavaDownloadTokenRequest: requests.CreateJavaDownloadTokenRequest): Promise<responses.CreateJavaDownloadTokenResponse>;
    /**
     * Creates a Java license acceptance record for the specified license type in a tenancy.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateJavaLicenseAcceptanceRecordRequest
     * @return CreateJavaLicenseAcceptanceRecordResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/jmsjavadownloads/CreateJavaLicenseAcceptanceRecord.ts.html |here} to see how to use CreateJavaLicenseAcceptanceRecord API.
     */
    createJavaLicenseAcceptanceRecord(createJavaLicenseAcceptanceRecordRequest: requests.CreateJavaLicenseAcceptanceRecordRequest): Promise<responses.CreateJavaLicenseAcceptanceRecordResponse>;
    /**
     * Deletes a JavaDownloadReport resource by identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteJavaDownloadReportRequest
     * @return DeleteJavaDownloadReportResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/jmsjavadownloads/DeleteJavaDownloadReport.ts.html |here} to see how to use DeleteJavaDownloadReport API.
     */
    deleteJavaDownloadReport(deleteJavaDownloadReportRequest: requests.DeleteJavaDownloadReportRequest): Promise<responses.DeleteJavaDownloadReportResponse>;
    /**
     * Deletes a JavaDownloadToken resource by identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteJavaDownloadTokenRequest
     * @return DeleteJavaDownloadTokenResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/jmsjavadownloads/DeleteJavaDownloadToken.ts.html |here} to see how to use DeleteJavaDownloadToken API.
     */
    deleteJavaDownloadToken(deleteJavaDownloadTokenRequest: requests.DeleteJavaDownloadTokenRequest): Promise<responses.DeleteJavaDownloadTokenResponse>;
    /**
     * Deletes a Java license acceptance record with the specified identifier.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteJavaLicenseAcceptanceRecordRequest
     * @return DeleteJavaLicenseAcceptanceRecordResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/jmsjavadownloads/DeleteJavaLicenseAcceptanceRecord.ts.html |here} to see how to use DeleteJavaLicenseAcceptanceRecord API.
     */
    deleteJavaLicenseAcceptanceRecord(deleteJavaLicenseAcceptanceRecordRequest: requests.DeleteJavaLicenseAcceptanceRecordRequest): Promise<responses.DeleteJavaLicenseAcceptanceRecordResponse>;
    /**
       * Generates a short-lived download URL and returns it in the response payload.
  * The returned URL can then be used for downloading the specific Java runtime artifact.
  * <p>
  Use the {@link #getJavaRelease(GetJavaReleaseRequest) getJavaRelease} API
  * to get information about available artifacts for a specific release. Each such artifact is uniquely identified by an `artifactId`.
  * Refer {@link #javaArtifact(JavaArtifactRequest) javaArtifact} for more details.
  *
       * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
       * @param GenerateArtifactDownloadUrlRequest
       * @return GenerateArtifactDownloadUrlResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/jmsjavadownloads/GenerateArtifactDownloadUrl.ts.html |here} to see how to use GenerateArtifactDownloadUrl API.
       */
    generateArtifactDownloadUrl(generateArtifactDownloadUrlRequest: requests.GenerateArtifactDownloadUrlRequest): Promise<responses.GenerateArtifactDownloadUrlResponse>;
    /**
     * Gets a JavaDownloadReport by the specified identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetJavaDownloadReportRequest
     * @return GetJavaDownloadReportResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/jmsjavadownloads/GetJavaDownloadReport.ts.html |here} to see how to use GetJavaDownloadReport API.
     */
    getJavaDownloadReport(getJavaDownloadReportRequest: requests.GetJavaDownloadReportRequest): Promise<responses.GetJavaDownloadReportResponse>;
    /**
     * Retrieve a Java download report with the specified identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetJavaDownloadReportContentRequest
     * @return GetJavaDownloadReportContentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/jmsjavadownloads/GetJavaDownloadReportContent.ts.html |here} to see how to use GetJavaDownloadReportContent API.
     */
    getJavaDownloadReportContent(getJavaDownloadReportContentRequest: requests.GetJavaDownloadReportContentRequest): Promise<responses.GetJavaDownloadReportContentResponse>;
    /**
     * Gets a JavaDownloadToken by identifier
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetJavaDownloadTokenRequest
     * @return GetJavaDownloadTokenResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/jmsjavadownloads/GetJavaDownloadToken.ts.html |here} to see how to use GetJavaDownloadToken API.
     */
    getJavaDownloadToken(getJavaDownloadTokenRequest: requests.GetJavaDownloadTokenRequest): Promise<responses.GetJavaDownloadTokenResponse>;
    /**
     * Return details of the specified Java license type.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetJavaLicenseRequest
     * @return GetJavaLicenseResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/jmsjavadownloads/GetJavaLicense.ts.html |here} to see how to use GetJavaLicense API.
     */
    getJavaLicense(getJavaLicenseRequest: requests.GetJavaLicenseRequest): Promise<responses.GetJavaLicenseResponse>;
    /**
     * Returns a specific Java license acceptance record in a tenancy.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetJavaLicenseAcceptanceRecordRequest
     * @return GetJavaLicenseAcceptanceRecordResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/jmsjavadownloads/GetJavaLicenseAcceptanceRecord.ts.html |here} to see how to use GetJavaLicenseAcceptanceRecord API.
     */
    getJavaLicenseAcceptanceRecord(getJavaLicenseAcceptanceRecordRequest: requests.GetJavaLicenseAcceptanceRecordRequest): Promise<responses.GetJavaLicenseAcceptanceRecordResponse>;
    /**
     * Gets details of the work request with the given ID.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetWorkRequestRequest
     * @return GetWorkRequestResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/jmsjavadownloads/GetWorkRequest.ts.html |here} to see how to use GetWorkRequest API.
     */
    getWorkRequest(getWorkRequestRequest: requests.GetWorkRequestRequest): Promise<responses.GetWorkRequestResponse>;
    /**
     * Returns a list of Java download records in a tenancy based on specified parameters.
     * See {@link #listJavaReleases(ListJavaReleasesRequest) listJavaReleases}
     * for possible values of `javaFamilyVersion` and `javaReleaseVersion` parameters.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListJavaDownloadRecordsRequest
     * @return ListJavaDownloadRecordsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/jmsjavadownloads/ListJavaDownloadRecords.ts.html |here} to see how to use ListJavaDownloadRecords API.
     */
    listJavaDownloadRecords(listJavaDownloadRecordsRequest: requests.ListJavaDownloadRecordsRequest): Promise<responses.ListJavaDownloadRecordsResponse>;
    /**
     * Returns a list of JavaDownloadReports.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListJavaDownloadReportsRequest
     * @return ListJavaDownloadReportsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/jmsjavadownloads/ListJavaDownloadReports.ts.html |here} to see how to use ListJavaDownloadReports API.
     */
    listJavaDownloadReports(listJavaDownloadReportsRequest: requests.ListJavaDownloadReportsRequest): Promise<responses.ListJavaDownloadReportsResponse>;
    /**
     * Returns a list of JavaDownloadTokens.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListJavaDownloadTokensRequest
     * @return ListJavaDownloadTokensResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/jmsjavadownloads/ListJavaDownloadTokens.ts.html |here} to see how to use ListJavaDownloadTokens API.
     */
    listJavaDownloadTokens(listJavaDownloadTokensRequest: requests.ListJavaDownloadTokensRequest): Promise<responses.ListJavaDownloadTokensResponse>;
    /**
     * Returns a list of all the Java license acceptance records in a tenancy.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListJavaLicenseAcceptanceRecordsRequest
     * @return ListJavaLicenseAcceptanceRecordsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/jmsjavadownloads/ListJavaLicenseAcceptanceRecords.ts.html |here} to see how to use ListJavaLicenseAcceptanceRecords API.
     */
    listJavaLicenseAcceptanceRecords(listJavaLicenseAcceptanceRecordsRequest: requests.ListJavaLicenseAcceptanceRecordsRequest): Promise<responses.ListJavaLicenseAcceptanceRecordsResponse>;
    /**
     * Return a list with details of all Java licenses.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListJavaLicensesRequest
     * @return ListJavaLicensesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/jmsjavadownloads/ListJavaLicenses.ts.html |here} to see how to use ListJavaLicenses API.
     */
    listJavaLicenses(listJavaLicensesRequest: requests.ListJavaLicensesRequest): Promise<responses.ListJavaLicensesResponse>;
    /**
     * Returns a (paginated) list of errors for the work request with the given ID.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListWorkRequestErrorsRequest
     * @return ListWorkRequestErrorsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/jmsjavadownloads/ListWorkRequestErrors.ts.html |here} to see how to use ListWorkRequestErrors API.
     */
    listWorkRequestErrors(listWorkRequestErrorsRequest: requests.ListWorkRequestErrorsRequest): Promise<responses.ListWorkRequestErrorsResponse>;
    /**
     * Returns a (paginated) list of logs for the work request with the given ID.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListWorkRequestLogsRequest
     * @return ListWorkRequestLogsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/jmsjavadownloads/ListWorkRequestLogs.ts.html |here} to see how to use ListWorkRequestLogs API.
     */
    listWorkRequestLogs(listWorkRequestLogsRequest: requests.ListWorkRequestLogsRequest): Promise<responses.ListWorkRequestLogsResponse>;
    /**
     * Lists the work requests in a tenancy.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListWorkRequestsRequest
     * @return ListWorkRequestsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/jmsjavadownloads/ListWorkRequests.ts.html |here} to see how to use ListWorkRequests API.
     */
    listWorkRequests(listWorkRequestsRequest: requests.ListWorkRequestsRequest): Promise<responses.ListWorkRequestsResponse>;
    /**
     * Returns list of download counts grouped by the specified property.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param RequestSummarizedJavaDownloadCountsRequest
     * @return RequestSummarizedJavaDownloadCountsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/jmsjavadownloads/RequestSummarizedJavaDownloadCounts.ts.html |here} to see how to use RequestSummarizedJavaDownloadCounts API.
     */
    requestSummarizedJavaDownloadCounts(requestSummarizedJavaDownloadCountsRequest: requests.RequestSummarizedJavaDownloadCountsRequest): Promise<responses.RequestSummarizedJavaDownloadCountsResponse>;
    /**
     * Updates the JavaDownloadToken specified by the identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateJavaDownloadTokenRequest
     * @return UpdateJavaDownloadTokenResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/jmsjavadownloads/UpdateJavaDownloadToken.ts.html |here} to see how to use UpdateJavaDownloadToken API.
     */
    updateJavaDownloadToken(updateJavaDownloadTokenRequest: requests.UpdateJavaDownloadTokenRequest): Promise<responses.UpdateJavaDownloadTokenResponse>;
    /**
     * Updates a specific Java license acceptance record in a tenancy.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateJavaLicenseAcceptanceRecordRequest
     * @return UpdateJavaLicenseAcceptanceRecordResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/jmsjavadownloads/UpdateJavaLicenseAcceptanceRecord.ts.html |here} to see how to use UpdateJavaLicenseAcceptanceRecord API.
     */
    updateJavaLicenseAcceptanceRecord(updateJavaLicenseAcceptanceRecordRequest: requests.UpdateJavaLicenseAcceptanceRecordRequest): Promise<responses.UpdateJavaLicenseAcceptanceRecordResponse>;
}
export {};
