/**
 * Java Management Service Download API
 * The APIs for the <a href="https://docs.oracle.com/en-us/iaas/jms/doc/java-download.html">Java Download</a> feature of Java Management Service.
 * OpenAPI spec version: 20230601
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * A summary of the Java download report in a tenancy.
 *
 */
export interface JavaDownloadReportSummary {
    /**
     * The [OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Java download report.
     *
     */
    "id": string;
    /**
     * Display name for the Java download report.
     */
    "displayName": string;
    /**
     * The file format of the Java download report.
     */
    "format": model.JavaDownloadReportFormat;
    /**
     * Approximate size of the Java download report file in bytes. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "fileSizeInBytes": number;
    /**
     * The algorithm used for calculating the checksum.
     */
    "checksumType": model.ChecksumType;
    /**
     * The checksum value of the Java download report file.
     */
    "checksumValue": string;
    /**
     * The [OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the tenancy scoped to the Java download report.
     *
     */
    "compartmentId": string;
    "createdBy": model.Principal;
    /**
     * The time the Java download report was created, displayed as an [RFC3339](https://datatracker.ietf.org/doc/html/rfc3339) formatted datetime string.
     */
    "timeCreated": Date;
    /**
     * The start time from when the download records are included (formatted according to [RFC3339](https://datatracker.ietf.org/doc/html/rfc3339)).
     *
     */
    "timeStart"?: Date;
    /**
     * The end time until when the download records are included (formatted according to [RFC3339](https://datatracker.ietf.org/doc/html/rfc3339)).
     *
     */
    "timeEnd"?: Date;
    /**
     * The property used for sorting the records.
     */
    "sortBy"?: model.JavaDownloadRecordSortBy;
    /**
     * The sort order for the records.
     */
    "sortOrder"?: model.SortOrder;
    /**
     * The current state of the Java download report.
     */
    "lifecycleState": model.LifecycleState;
    /**
     * Simple key-value pair that is applied without any predefined name, type, or scope. Exists for cross-compatibility only.
     * Example: {@code {\"bar-key\": \"value\"}}. (See [Managing Tags and Tag Namespaces](https://docs.cloud.oracle.com/Content/Tagging/Concepts/understandingfreeformtags.htm).)
     *
     */
    "freeformTags"?: {
        [key: string]: string;
    };
    /**
     * Defined tags for this resource. Each key is predefined and scoped to a namespace.
     * Example: {@code {\"foo-namespace\": {\"bar-key\": \"value\"}}}. (See [Understanding Free-form Tags](https://docs.cloud.oracle.com/Content/Tagging/Tasks/managingtagsandtagnamespaces.htm)).
     *
     */
    "definedTags"?: {
        [key: string]: {
            [key: string]: any;
        };
    };
    /**
      * System tags for this resource. Each key is predefined and scoped to a namespace.
  * For more information, see [Resource Tags](https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
  * System tags can be viewed by users, but can only be created by the system.
  * <p>
  Example: {@code {\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}}
  *
      */
    "systemTags"?: {
        [key: string]: {
            [key: string]: any;
        };
    };
}
export declare namespace JavaDownloadReportSummary {
    function getJsonObj(obj: JavaDownloadReportSummary): object;
    function getDeserializedJsonObj(obj: JavaDownloadReportSummary): object;
}
