/**
 * Load Balancing API
 * API for the Load Balancing service. Use this API to manage load balancers, backend sets, and related items. For more
information, see [Overview of Load Balancing](/iaas/Content/Balance/Concepts/balanceoverview.htm).

 * OpenAPI spec version: 20170115
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * The configuration details for adding a listener to a backend set.
 * For more information on listener configuration, see
 * [Managing Load Balancer Listeners](https://docs.cloud.oracle.com/Content/Balance/Tasks/managinglisteners.htm).
 * <p>
 **Warning:** Oracle recommends that you avoid using any confidential information when you supply string values using the API.
 *
 */
export interface CreateListenerDetails {
    /**
      * The name of the associated backend set.
  * <p>
  Example: {@code example_backend_set}
  *
      */
    "defaultBackendSetName": string;
    /**
      * The communication port for the listener.
  * <p>
  Example: {@code 80}
  *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
      */
    "port": number;
    /**
      * The protocol on which the listener accepts connection requests.
  * To get a list of valid protocols, use the {@link #listProtocols(ListProtocolsRequest) listProtocols}
  * operation.
  * <p>
  Example: {@code HTTP}
  *
      */
    "protocol": string;
    /**
     * An array of hostname resource names.
     */
    "hostnameNames"?: Array<string>;
    /**
      * Deprecated. Please use {@code routingPolicies} instead.
  * <p>
  The name of the set of path-based routing rules, {@link PathRouteSet},
  * applied to this listener's traffic.
  * <p>
  Example: {@code example_path_route_set}
  *
      */
    "pathRouteSetName"?: string;
    "sslConfiguration"?: model.SSLConfigurationDetails;
    "connectionConfiguration"?: model.ConnectionConfiguration;
    /**
      * A friendly name for the listener. It must be unique and it cannot be changed.
  * Avoid entering confidential information.
  * <p>
  Example: {@code example_listener}
  *
      */
    "name": string;
    /**
      * The name of the routing policy applied to this listener's traffic.
  * <p>
  Example: {@code example_routing_policy}
  *
      */
    "routingPolicyName"?: string;
    /**
      * The names of the {@link RuleSet} to apply to the listener.
  * <p>
  Example: [\"example_rule_set\"]
  *
      */
    "ruleSetNames"?: Array<string>;
}
export declare namespace CreateListenerDetails {
    function getJsonObj(obj: CreateListenerDetails): object;
    function getDeserializedJsonObj(obj: CreateListenerDetails): object;
}
