/**
 * Load Balancing API
 * API for the Load Balancing service. Use this API to manage load balancers, backend sets, and related items. For more
information, see [Overview of Load Balancing](/iaas/Content/Balance/Concepts/balanceoverview.htm).

 * OpenAPI spec version: 20170115
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
/**
* The configuration details for implementing load balancer cookie session persistence (LB cookie stickiness).
* <p>
Session persistence enables the Load Balancing service to direct all requests that originate from a single logical
* client to a single backend web server. For more information, see
* [Session Persistence](https://docs.cloud.oracle.com/Content/Balance/Reference/sessionpersistence.htm).
* <p>
When you configure LB cookie stickiness, the load balancer inserts a cookie into the response. The parameters configured
* in the cookie enable session stickiness. This method is useful when you have applications and Web backend services
* that cannot generate their own cookies.
* <p>
Path route rules take precedence to determine the target backend server. The load balancer verifies that session stickiness
* is enabled for the backend server and that the cookie configuration (domain, path, and cookie hash) is valid for the
* target. The system ignores invalid cookies.
* <p>
To disable LB cookie stickiness on a running load balancer, use the
* {@link #updateBackendSet(UpdateBackendSetRequest) updateBackendSet} operation and specify {@code null} for the
* {@code LBCookieSessionPersistenceConfigurationDetails} object.
* <p>
Example: {@code LBCookieSessionPersistenceConfigurationDetails: null}
* <p>
**Note:** {@code SessionPersistenceConfigurationDetails} (application cookie stickiness) and {@code LBCookieSessionPersistenceConfigurationDetails}
* (LB cookie stickiness) are mutually exclusive. An error results if you try to enable both types of session persistence.
* <p>
**Warning:** Oracle recommends that you avoid using any confidential information when you supply string values using the API.
*
*/
export interface LBCookieSessionPersistenceConfigurationDetails {
    /**
      * The name of the cookie inserted by the load balancer. If this field is not configured, the cookie name defaults
  * to \"X-Oracle-BMC-LBS-Route\".
  * <p>
  Example: {@code example_cookie}
  * <p>
  **Notes:**
  * <p>
  *  Ensure that the cookie name used at the backend application servers is different from the cookie name used
  *    at the load balancer. To minimize the chance of name collision, Oracle recommends that you use a prefix
  *    such as \"X-Oracle-OCI-\" for this field.
  * <p>
  *  If a backend server and the load balancer both insert cookies with the same name, the client or browser
  *    behavior can vary depending on the domain and path values associated with the cookie. If the name, domain,
  *    and path values of the {@code Set-cookie} generated by a backend server and the {@code Set-cookie} generated by the
  *    load balancer are all the same, the client or browser treats them as one cookie and returns only one of
  *    the cookie values in subsequent requests. If both {@code Set-cookie} names are the same, but the domain and path
  *    names are different, the client or browser treats them as two different cookies.
  *
      */
    "cookieName"?: string;
    /**
      * Whether the load balancer is prevented from directing traffic from a persistent session client to
  * a different backend server if the original server is unavailable. Defaults to false.
  * <p>
  Example: {@code false}
  *
      */
    "disableFallback"?: boolean;
    /**
      * The domain in which the cookie is valid. The {@code Set-cookie} header inserted by the load balancer contains a
  * domain attribute with the specified value.
  * <p>
  This attribute has no default value. If you do not specify a value, the load balancer does not insert the domain
  * attribute into the {@code Set-cookie} header.
  * <p>
  **Notes:**
  * <p>
  *  [RFC 6265 - HTTP State Management Mechanism](https://www.ietf.org/rfc/rfc6265.txt) describes client and
  *    browser behavior when the domain attribute is present or not present in the {@code Set-cookie} header.
  * <p>
     If the value of the {@code Domain} attribute is {@code example.com} in the {@code Set-cookie} header, the client includes
  *    the same cookie in the {@code Cookie} header when making HTTP requests to {@code example.com}, {@code www.example.com}, and
  *    {@code www.abc.example.com}. If the {@code Domain} attribute is not present, the client returns the cookie only for
  *    the domain to which the original request was made.
  * <p>
  *  Ensure that this attribute specifies the correct domain value. If the {@code Domain} attribute in the {@code Set-cookie}
  *    header does not include the domain to which the original request was made, the client or browser might reject
  *    the cookie. As specified in RFC 6265, the client accepts a cookie with the {@code Domain} attribute value {@code example.com}
  *    or {@code www.example.com} sent from {@code www.example.com}. It does not accept a cookie with the {@code Domain} attribute
  *    {@code abc.example.com} or {@code www.abc.example.com} sent from {@code www.example.com}.
  * <p>
  Example: {@code example.com}
  *
      */
    "domain"?: string;
    /**
      * The path in which the cookie is valid. The {@code Set-cookie header} inserted by the load balancer contains a {@code Path}
  * attribute with the specified value.
  * <p>
  Clients include the cookie in an HTTP request only if the path portion of the request-uri matches, or is a
  * subdirectory of, the cookie's {@code Path} attribute.
  * <p>
  The default value is {@code /}.
  * <p>
  Example: {@code /example}
  *
      */
    "path"?: string;
    /**
      * The amount of time the cookie remains valid. The {@code Set-cookie} header inserted by the load balancer contains
  * a {@code Max-Age} attribute with the specified value.
  * <p>
  The specified value must be at least one second. There is no default value for this attribute. If you do not
  * specify a value, the load balancer does not include the {@code Max-Age} attribute in the {@code Set-cookie} header. In
  * most cases, the client or browser retains the cookie until the current session ends, as defined by the client.
  * <p>
  Example: {@code 3600}
  *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
      */
    "maxAgeInSeconds"?: number;
    /**
      * Whether the {@code Set-cookie} header should contain the {@code Secure} attribute. If {@code true}, the {@code Set-cookie} header
  * inserted by the load balancer contains the {@code Secure} attribute, which directs the client or browser to send the
  * cookie only using a secure protocol.
  * <p>
  **Note:** If you set this field to {@code true}, you cannot associate the corresponding backend set with an HTTP
  * listener.
  * <p>
  Example: {@code true}
  *
      */
    "isSecure"?: boolean;
    /**
      * Whether the {@code Set-cookie} header should contain the {@code HttpOnly} attribute. If {@code true}, the {@code Set-cookie} header
  * inserted by the load balancer contains the {@code HttpOnly} attribute, which limits the scope of the cookie to HTTP
  * requests. This attribute directs the client or browser to omit the cookie when providing access to cookies
  * through non-HTTP APIs. For example, it restricts the cookie from JavaScript channels.
  * <p>
  Example: {@code true}
  *
      */
    "isHttpOnly"?: boolean;
}
export declare namespace LBCookieSessionPersistenceConfigurationDetails {
    function getJsonObj(obj: LBCookieSessionPersistenceConfigurationDetails): object;
    function getDeserializedJsonObj(obj: LBCookieSessionPersistenceConfigurationDetails): object;
}
