/**
 * Managed Access API
 * Use the Managed Access API to approve access requests, create and manage templates, and manage resource approval settings. For more information, see [Managed Access Overview](https://docs.oracle.com/iaas/Content/managed-access/home.htm).

Use the table of contents and search tool to explore the Managed Access API.

 * OpenAPI spec version: 20220126
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
/**
 * Summary information for an access request.
 */
export interface AccessRequestSummary {
    /**
     * The unique identifier (OCID) of the access request, which can't be changed after creation.
     */
    "id": string;
    /**
     * The unique identifier (OCID) of the lockbox box that the access request is associated with, which can't be changed after creation.
     */
    "lockboxId": string;
    /**
     * The name of the access request.
     */
    "displayName": string;
    /**
     * The rationale for requesting the access request.
     */
    "description": string;
    /**
     * The unique identifier of the requestor.
     */
    "requestorId": string;
    /**
     * The two-char country code of the requestor while creating the access request
     * Example: {@code US}
     *
     */
    "requestorLocation"?: string;
    /**
     * The current state of the access request.
     */
    "lifecycleState": string;
    /**
     * The maximum amount of time operator has access to associated resources.
     */
    "accessDuration"?: string;
    /**
     * The time the access request was created. Format is defined by [RFC3339](https://tools.ietf.org/html/rfc3339).
     * Example: {@code 2020-01-25T21:10:29.600Z}
     *
     */
    "timeCreated": Date;
    /**
     * The time the access request was last updated. Format is defined by [RFC3339](https://tools.ietf.org/html/rfc3339).
     * Example: {@code 2020-01-25T21:10:29.600Z}
     *
     */
    "timeUpdated": Date;
    /**
     * The time the access request expired. Format is defined by [RFC3339](https://tools.ietf.org/html/rfc3339).
     * Example: {@code 2020-01-25T21:10:29.600Z}
     *
     */
    "timeExpired": Date;
    /**
     * Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
     * Example: {@code {\"bar-key\": \"value\"}}
     *
     */
    "freeformTags"?: {
        [key: string]: string;
    };
    /**
     * Defined tags for this resource. Each key is predefined and scoped to a namespace.
     * Example: {@code {\"foo-namespace\": {\"bar-key\": \"value\"}}}
     *
     */
    "definedTags"?: {
        [key: string]: {
            [key: string]: any;
        };
    };
    /**
     * Usage of system tag keys. These predefined keys are scoped to namespaces.
     * Example: {@code {\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}}
     *
     */
    "systemTags"?: {
        [key: string]: {
            [key: string]: any;
        };
    };
}
export declare namespace AccessRequestSummary {
    function getJsonObj(obj: AccessRequestSummary): object;
    function getDeserializedJsonObj(obj: AccessRequestSummary): object;
}
