/**
 * MarketplacePrivateOffer API
 * Use the Marketplace Publisher API to manage the publishing of applications in Oracle Cloud Infrastructure Marketplace.
 * OpenAPI spec version: 20220901
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * Description of Offer.
 */
export interface Offer {
    /**
     * Unique identifier that is immutable on creation
     */
    "id": string;
    /**
     * Offer Identifier, can be renamed
     */
    "displayName": string;
    /**
     * OCID of the seller's tenancy (root compartment).
     */
    "sellerCompartmentId": string;
    /**
     * OCID of the buyer's tenancy (root compartment).
     */
    "buyerCompartmentId"?: string;
    /**
     * The description of the offer
     */
    "description"?: string;
    /**
     * The time the Offer will become active after it has been accepted by the Buyer. An RFC3339 formatted datetime string
     */
    "timeStartDate"?: Date;
    /**
     * Duration the Offer will be active after its start date. An ISO8601 extended formatted string.
     */
    "duration"?: string;
    /**
     * The time the the Offer was created. An RFC3339 formatted datetime string
     */
    "timeCreated": Date;
    /**
     * The time the Offer was updated. An RFC3339 formatted datetime string
     */
    "timeUpdated"?: Date;
    /**
     * The time the Offer must be accepted by the Buyer before the Offer becomes invalid. An RFC3339 formatted datetime string
     */
    "timeAcceptBy"?: Date;
    /**
     * The time the Offer was accepted by the Buyer of the Offer. An RFC3339 formatted datetime string
     */
    "timeAccepted"?: Date;
    /**
     * The time the accepted Offer will end. An RFC3339 formatted datetime string
     */
    "timeOfferEnd"?: Date;
    /**
     * The current state of the Offer.
     */
    "lifecycleState": Offer.LifecycleState;
    /**
     * A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.
     */
    "lifecycleDetails"?: string;
    /**
     * A substate for lifeCycleStatus to give a more human readable version of the offer
     */
    "offerStatus"?: Offer.OfferStatus;
    "publisherSummary"?: model.PublisherSummary;
    "pricing"?: model.Pricing;
    "buyerInformation"?: model.BuyerInformation;
    "sellerInformation"?: model.SellerInformation;
    /**
     * A list of Resource Bundles associated with an Offer.
     */
    "resourceBundles"?: Array<model.ResourceBundle>;
    /**
     * Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
     * Example: {@code {\"bar-key\": \"value\"}}
     *
     */
    "freeformTags": {
        [key: string]: string;
    };
    /**
     * Defined tags for this resource. Each key is predefined and scoped to a namespace.
     * Example: {@code {\"foo-namespace\": {\"bar-key\": \"value\"}}}
     *
     */
    "definedTags": {
        [key: string]: {
            [key: string]: any;
        };
    };
}
export declare namespace Offer {
    enum LifecycleState {
        Creating = "CREATING",
        Updating = "UPDATING",
        Active = "ACTIVE",
        Deleting = "DELETING",
        Deleted = "DELETED",
        Failed = "FAILED",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    enum OfferStatus {
        Draft = "DRAFT",
        PendingMarketplace = "PENDING_MARKETPLACE",
        PendingBuyer = "PENDING_BUYER",
        Expired = "EXPIRED",
        Accepted = "ACCEPTED",
        Active = "ACTIVE",
        Ended = "ENDED",
        FailedSend = "FAILED_SEND",
        FailedAccept = "FAILED_ACCEPT",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    function getJsonObj(obj: Offer): object;
    function getDeserializedJsonObj(obj: Offer): object;
}
