/**
 * Media Services API
 * Media Services (includes Media Flow and Media Streams) is a fully managed service for processing media (video) source content. Use Media Flow and Media Streams to transcode and package digital video using configurable workflows and stream video outputs.

Use the Media Services API to configure media workflows and run Media Flow jobs, create distribution channels, ingest assets, create Preview URLs and play assets. For more information, see [Media Flow](/iaas/Content/dms-mediaflow/home.htm) and [Media Streams](/iaas/Content/dms-mediastream/home.htm).

 * OpenAPI spec version: 20211101
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import common = require("oci-common");
import * as requests from "./request";
import * as responses from "./response";
import { MediaServicesWaiter } from "./mediaservices-waiter";
declare const Breaker: any;
export declare enum MediaServicesApiKeys {
}
/**
 * This service client uses {@link common.CircuitBreaker.DefaultConfiguration} for all the operations by default if no circuit breaker configuration is defined by the user.
 */
export declare class MediaServicesClient {
    protected static serviceEndpointTemplate: string;
    protected static endpointServiceName: string;
    protected "_realmSpecificEndpointTemplateEnabled": boolean | undefined;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_waiters": MediaServicesWaiter;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: typeof Breaker | null;
    protected _httpOptions: any;
    protected _bodyDuplexMode: any;
    targetService: string;
    protected _regionId: string;
    protected "_region": common.Region;
    protected _lastSetRegionOrRegionId: string;
    protected _httpClient: common.HttpClient;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    get endpoint(): string;
    /**
     * Sets the endpoint to call (ex, https://www.example.com).
     * @param endpoint The endpoint of the service.
     */
    set endpoint(endpoint: string);
    get logger(): import("oci-common/lib/log").Logger;
    /**
     * Determines whether realm specific endpoint should be used or not.
     * Set realmSpecificEndpointTemplateEnabled to "true" if the user wants to enable use of realm specific endpoint template, otherwise set it to "false"
     * @param realmSpecificEndpointTemplateEnabled flag to enable the use of realm specific endpoint template
     */
    set useRealmSpecificEndpointTemplate(realmSpecificEndpointTemplateEnabled: boolean);
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    set region(region: common.Region);
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    set regionId(regionId: string);
    /**
     * Creates a new MediaServicesWaiter for resources for this service.
     *
     * @param config The waiter configuration for termination and delay strategy
     * @return The service waiters.
     */
    createWaiters(config?: common.WaiterConfiguration): MediaServicesWaiter;
    /**
     * Gets the waiters available for resources for this service.
     *
     * @return The service waiters.
     */
    getWaiters(): MediaServicesWaiter;
    /**
     * Shutdown the circuit breaker used by the client when it is no longer needed
     */
    shutdownCircuitBreaker(): void;
    /**
     * Close the client once it is no longer needed
     */
    close(): void;
    /**
     * Add a lock to an MediaAsset.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param AddMediaAssetLockRequest
     * @return AddMediaAssetLockResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/mediaservices/AddMediaAssetLock.ts.html |here} to see how to use AddMediaAssetLock API.
     */
    addMediaAssetLock(addMediaAssetLockRequest: requests.AddMediaAssetLockRequest): Promise<responses.AddMediaAssetLockResponse>;
    /**
     * Add a lock to a MediaWorkflowConfiguration.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param AddMediaWorkflowConfigurationLockRequest
     * @return AddMediaWorkflowConfigurationLockResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/mediaservices/AddMediaWorkflowConfigurationLock.ts.html |here} to see how to use AddMediaWorkflowConfigurationLock API.
     */
    addMediaWorkflowConfigurationLock(addMediaWorkflowConfigurationLockRequest: requests.AddMediaWorkflowConfigurationLockRequest): Promise<responses.AddMediaWorkflowConfigurationLockResponse>;
    /**
     * Add a lock to a MediaWorkflowJob.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param AddMediaWorkflowJobLockRequest
     * @return AddMediaWorkflowJobLockResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/mediaservices/AddMediaWorkflowJobLock.ts.html |here} to see how to use AddMediaWorkflowJobLock API.
     */
    addMediaWorkflowJobLock(addMediaWorkflowJobLockRequest: requests.AddMediaWorkflowJobLockRequest): Promise<responses.AddMediaWorkflowJobLockResponse>;
    /**
     * Add a lock to a MediaWorkflow.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param AddMediaWorkflowLockRequest
     * @return AddMediaWorkflowLockResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/mediaservices/AddMediaWorkflowLock.ts.html |here} to see how to use AddMediaWorkflowLock API.
     */
    addMediaWorkflowLock(addMediaWorkflowLockRequest: requests.AddMediaWorkflowLockRequest): Promise<responses.AddMediaWorkflowLockResponse>;
    /**
     * Add a lock to a StreamCdnConfig.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param AddStreamCdnConfigLockRequest
     * @return AddStreamCdnConfigLockResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/mediaservices/AddStreamCdnConfigLock.ts.html |here} to see how to use AddStreamCdnConfigLock API.
     */
    addStreamCdnConfigLock(addStreamCdnConfigLockRequest: requests.AddStreamCdnConfigLockRequest): Promise<responses.AddStreamCdnConfigLockResponse>;
    /**
     * Add a lock to a StreamDistributionChannel.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param AddStreamDistributionChannelLockRequest
     * @return AddStreamDistributionChannelLockResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/mediaservices/AddStreamDistributionChannelLock.ts.html |here} to see how to use AddStreamDistributionChannelLock API.
     */
    addStreamDistributionChannelLock(addStreamDistributionChannelLockRequest: requests.AddStreamDistributionChannelLockRequest): Promise<responses.AddStreamDistributionChannelLockResponse>;
    /**
     * Add a lock to a StreamPackagingConfig.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param AddStreamPackagingConfigLockRequest
     * @return AddStreamPackagingConfigLockResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/mediaservices/AddStreamPackagingConfigLock.ts.html |here} to see how to use AddStreamPackagingConfigLock API.
     */
    addStreamPackagingConfigLock(addStreamPackagingConfigLockRequest: requests.AddStreamPackagingConfigLockRequest): Promise<responses.AddStreamPackagingConfigLockResponse>;
    /**
     * Moves a MediaAsset resource from one compartment identifier to another.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ChangeMediaAssetCompartmentRequest
     * @return ChangeMediaAssetCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/mediaservices/ChangeMediaAssetCompartment.ts.html |here} to see how to use ChangeMediaAssetCompartment API.
     */
    changeMediaAssetCompartment(changeMediaAssetCompartmentRequest: requests.ChangeMediaAssetCompartmentRequest): Promise<responses.ChangeMediaAssetCompartmentResponse>;
    /**
     * Moves a MediaWorkflow resource from one compartment identifier to another.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ChangeMediaWorkflowCompartmentRequest
     * @return ChangeMediaWorkflowCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/mediaservices/ChangeMediaWorkflowCompartment.ts.html |here} to see how to use ChangeMediaWorkflowCompartment API.
     */
    changeMediaWorkflowCompartment(changeMediaWorkflowCompartmentRequest: requests.ChangeMediaWorkflowCompartmentRequest): Promise<responses.ChangeMediaWorkflowCompartmentResponse>;
    /**
     * Moves a MediaWorkflowConfiguration resource from one compartment identifier to another. When provided, If-Match is checked against ETag values of the resource.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ChangeMediaWorkflowConfigurationCompartmentRequest
     * @return ChangeMediaWorkflowConfigurationCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/mediaservices/ChangeMediaWorkflowConfigurationCompartment.ts.html |here} to see how to use ChangeMediaWorkflowConfigurationCompartment API.
     */
    changeMediaWorkflowConfigurationCompartment(changeMediaWorkflowConfigurationCompartmentRequest: requests.ChangeMediaWorkflowConfigurationCompartmentRequest): Promise<responses.ChangeMediaWorkflowConfigurationCompartmentResponse>;
    /**
     * Moves a MediaWorkflowJob resource from one compartment identifier to another.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ChangeMediaWorkflowJobCompartmentRequest
     * @return ChangeMediaWorkflowJobCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/mediaservices/ChangeMediaWorkflowJobCompartment.ts.html |here} to see how to use ChangeMediaWorkflowJobCompartment API.
     */
    changeMediaWorkflowJobCompartment(changeMediaWorkflowJobCompartmentRequest: requests.ChangeMediaWorkflowJobCompartmentRequest): Promise<responses.ChangeMediaWorkflowJobCompartmentResponse>;
    /**
     * Moves a Stream Distribution Channel resource from one compartment identifier to another.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ChangeStreamDistributionChannelCompartmentRequest
     * @return ChangeStreamDistributionChannelCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/mediaservices/ChangeStreamDistributionChannelCompartment.ts.html |here} to see how to use ChangeStreamDistributionChannelCompartment API.
     */
    changeStreamDistributionChannelCompartment(changeStreamDistributionChannelCompartmentRequest: requests.ChangeStreamDistributionChannelCompartmentRequest): Promise<responses.ChangeStreamDistributionChannelCompartmentResponse>;
    /**
     * Creates a new MediaAsset.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateMediaAssetRequest
     * @return CreateMediaAssetResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/mediaservices/CreateMediaAsset.ts.html |here} to see how to use CreateMediaAsset API.
     */
    createMediaAsset(createMediaAssetRequest: requests.CreateMediaAssetRequest): Promise<responses.CreateMediaAssetResponse>;
    /**
     * Creates a new MediaWorkflow.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateMediaWorkflowRequest
     * @return CreateMediaWorkflowResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/mediaservices/CreateMediaWorkflow.ts.html |here} to see how to use CreateMediaWorkflow API.
     */
    createMediaWorkflow(createMediaWorkflowRequest: requests.CreateMediaWorkflowRequest): Promise<responses.CreateMediaWorkflowResponse>;
    /**
     * Creates a new MediaWorkflowConfiguration.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateMediaWorkflowConfigurationRequest
     * @return CreateMediaWorkflowConfigurationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/mediaservices/CreateMediaWorkflowConfiguration.ts.html |here} to see how to use CreateMediaWorkflowConfiguration API.
     */
    createMediaWorkflowConfiguration(createMediaWorkflowConfigurationRequest: requests.CreateMediaWorkflowConfigurationRequest): Promise<responses.CreateMediaWorkflowConfigurationResponse>;
    /**
     * Run the MediaWorkflow according to the given mediaWorkflow definition and configuration.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateMediaWorkflowJobRequest
     * @return CreateMediaWorkflowJobResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/mediaservices/CreateMediaWorkflowJob.ts.html |here} to see how to use CreateMediaWorkflowJob API.
     */
    createMediaWorkflowJob(createMediaWorkflowJobRequest: requests.CreateMediaWorkflowJobRequest): Promise<responses.CreateMediaWorkflowJobResponse>;
    /**
     * Creates a new CDN Configuration.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateStreamCdnConfigRequest
     * @return CreateStreamCdnConfigResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/mediaservices/CreateStreamCdnConfig.ts.html |here} to see how to use CreateStreamCdnConfig API.
     */
    createStreamCdnConfig(createStreamCdnConfigRequest: requests.CreateStreamCdnConfigRequest): Promise<responses.CreateStreamCdnConfigResponse>;
    /**
     * Creates a new Stream Distribution Channel.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateStreamDistributionChannelRequest
     * @return CreateStreamDistributionChannelResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/mediaservices/CreateStreamDistributionChannel.ts.html |here} to see how to use CreateStreamDistributionChannel API.
     */
    createStreamDistributionChannel(createStreamDistributionChannelRequest: requests.CreateStreamDistributionChannelRequest): Promise<responses.CreateStreamDistributionChannelResponse>;
    /**
     * Creates a new Packaging Configuration.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateStreamPackagingConfigRequest
     * @return CreateStreamPackagingConfigResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/mediaservices/CreateStreamPackagingConfig.ts.html |here} to see how to use CreateStreamPackagingConfig API.
     */
    createStreamPackagingConfig(createStreamPackagingConfigRequest: requests.CreateStreamPackagingConfigRequest): Promise<responses.CreateStreamPackagingConfigResponse>;
    /**
     * Deletes a MediaAsset resource by identifier. If DeleteChildren is passed in as the mode, all the assets with the parentMediaAssetId matching the ID will be deleted. If DeleteDerivatives is set as the mode, all the assets with the masterMediaAssetId matching the ID will be deleted.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteMediaAssetRequest
     * @return DeleteMediaAssetResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/mediaservices/DeleteMediaAsset.ts.html |here} to see how to use DeleteMediaAsset API.
     */
    deleteMediaAsset(deleteMediaAssetRequest: requests.DeleteMediaAssetRequest): Promise<responses.DeleteMediaAssetResponse>;
    /**
     * Deletes a MediaAsset from the DistributionChannel by identifiers.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteMediaAssetDistributionChannelAttachmentRequest
     * @return DeleteMediaAssetDistributionChannelAttachmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/mediaservices/DeleteMediaAssetDistributionChannelAttachment.ts.html |here} to see how to use DeleteMediaAssetDistributionChannelAttachment API.
     */
    deleteMediaAssetDistributionChannelAttachment(deleteMediaAssetDistributionChannelAttachmentRequest: requests.DeleteMediaAssetDistributionChannelAttachmentRequest): Promise<responses.DeleteMediaAssetDistributionChannelAttachmentResponse>;
    /**
     * The MediaWorkflow lifecycleState will change to DELETED.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteMediaWorkflowRequest
     * @return DeleteMediaWorkflowResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/mediaservices/DeleteMediaWorkflow.ts.html |here} to see how to use DeleteMediaWorkflow API.
     */
    deleteMediaWorkflow(deleteMediaWorkflowRequest: requests.DeleteMediaWorkflowRequest): Promise<responses.DeleteMediaWorkflowResponse>;
    /**
     * Deletes a MediaWorkflowConfiguration resource by identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteMediaWorkflowConfigurationRequest
     * @return DeleteMediaWorkflowConfigurationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/mediaservices/DeleteMediaWorkflowConfiguration.ts.html |here} to see how to use DeleteMediaWorkflowConfiguration API.
     */
    deleteMediaWorkflowConfiguration(deleteMediaWorkflowConfigurationRequest: requests.DeleteMediaWorkflowConfigurationRequest): Promise<responses.DeleteMediaWorkflowConfigurationResponse>;
    /**
     * This is an asynchronous operation. The MediaWorkflowJob lifecycleState will change to CANCELING temporarily until the job is completely CANCELED.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteMediaWorkflowJobRequest
     * @return DeleteMediaWorkflowJobResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/mediaservices/DeleteMediaWorkflowJob.ts.html |here} to see how to use DeleteMediaWorkflowJob API.
     */
    deleteMediaWorkflowJob(deleteMediaWorkflowJobRequest: requests.DeleteMediaWorkflowJobRequest): Promise<responses.DeleteMediaWorkflowJobResponse>;
    /**
     * The StreamCdnConfig lifecycleState will change to DELETED.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteStreamCdnConfigRequest
     * @return DeleteStreamCdnConfigResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/mediaservices/DeleteStreamCdnConfig.ts.html |here} to see how to use DeleteStreamCdnConfig API.
     */
    deleteStreamCdnConfig(deleteStreamCdnConfigRequest: requests.DeleteStreamCdnConfigRequest): Promise<responses.DeleteStreamCdnConfigResponse>;
    /**
     * The Stream Distribution Channel lifecycleState will change to DELETED.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteStreamDistributionChannelRequest
     * @return DeleteStreamDistributionChannelResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/mediaservices/DeleteStreamDistributionChannel.ts.html |here} to see how to use DeleteStreamDistributionChannel API.
     */
    deleteStreamDistributionChannel(deleteStreamDistributionChannelRequest: requests.DeleteStreamDistributionChannelRequest): Promise<responses.DeleteStreamDistributionChannelResponse>;
    /**
     * The Stream Packaging Configuration lifecycleState will change to DELETED.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteStreamPackagingConfigRequest
     * @return DeleteStreamPackagingConfigResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/mediaservices/DeleteStreamPackagingConfig.ts.html |here} to see how to use DeleteStreamPackagingConfig API.
     */
    deleteStreamPackagingConfig(deleteStreamPackagingConfigRequest: requests.DeleteStreamPackagingConfigRequest): Promise<responses.DeleteStreamPackagingConfigResponse>;
    /**
     * Gets a MediaAsset by identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetMediaAssetRequest
     * @return GetMediaAssetResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/mediaservices/GetMediaAsset.ts.html |here} to see how to use GetMediaAsset API.
     */
    getMediaAsset(getMediaAssetRequest: requests.GetMediaAssetRequest): Promise<responses.GetMediaAssetResponse>;
    /**
     * Gets a MediaAssetDistributionChannelAttachment for a MediaAsset by identifiers.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetMediaAssetDistributionChannelAttachmentRequest
     * @return GetMediaAssetDistributionChannelAttachmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/mediaservices/GetMediaAssetDistributionChannelAttachment.ts.html |here} to see how to use GetMediaAssetDistributionChannelAttachment API.
     */
    getMediaAssetDistributionChannelAttachment(getMediaAssetDistributionChannelAttachmentRequest: requests.GetMediaAssetDistributionChannelAttachmentRequest): Promise<responses.GetMediaAssetDistributionChannelAttachmentResponse>;
    /**
     * Gets a MediaWorkflow by identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetMediaWorkflowRequest
     * @return GetMediaWorkflowResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/mediaservices/GetMediaWorkflow.ts.html |here} to see how to use GetMediaWorkflow API.
     */
    getMediaWorkflow(getMediaWorkflowRequest: requests.GetMediaWorkflowRequest): Promise<responses.GetMediaWorkflowResponse>;
    /**
     * Gets a MediaWorkflowConfiguration by identifier
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetMediaWorkflowConfigurationRequest
     * @return GetMediaWorkflowConfigurationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/mediaservices/GetMediaWorkflowConfiguration.ts.html |here} to see how to use GetMediaWorkflowConfiguration API.
     */
    getMediaWorkflowConfiguration(getMediaWorkflowConfigurationRequest: requests.GetMediaWorkflowConfigurationRequest): Promise<responses.GetMediaWorkflowConfigurationResponse>;
    /**
     * Gets the MediaWorkflowJob.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetMediaWorkflowJobRequest
     * @return GetMediaWorkflowJobResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/mediaservices/GetMediaWorkflowJob.ts.html |here} to see how to use GetMediaWorkflowJob API.
     */
    getMediaWorkflowJob(getMediaWorkflowJobRequest: requests.GetMediaWorkflowJobRequest): Promise<responses.GetMediaWorkflowJobResponse>;
    /**
     * Gets a StreamCdnConfig by identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetStreamCdnConfigRequest
     * @return GetStreamCdnConfigResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/mediaservices/GetStreamCdnConfig.ts.html |here} to see how to use GetStreamCdnConfig API.
     */
    getStreamCdnConfig(getStreamCdnConfigRequest: requests.GetStreamCdnConfigRequest): Promise<responses.GetStreamCdnConfigResponse>;
    /**
     * Gets a Stream Distribution Channel by identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetStreamDistributionChannelRequest
     * @return GetStreamDistributionChannelResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/mediaservices/GetStreamDistributionChannel.ts.html |here} to see how to use GetStreamDistributionChannel API.
     */
    getStreamDistributionChannel(getStreamDistributionChannelRequest: requests.GetStreamDistributionChannelRequest): Promise<responses.GetStreamDistributionChannelResponse>;
    /**
     * Gets a Stream Packaging Configuration by identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetStreamPackagingConfigRequest
     * @return GetStreamPackagingConfigResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/mediaservices/GetStreamPackagingConfig.ts.html |here} to see how to use GetStreamPackagingConfig API.
     */
    getStreamPackagingConfig(getStreamPackagingConfigRequest: requests.GetStreamPackagingConfigRequest): Promise<responses.GetStreamPackagingConfigResponse>;
    /**
     * Ingests an Asset into a Distribution Channel.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param IngestStreamDistributionChannelRequest
     * @return IngestStreamDistributionChannelResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/mediaservices/IngestStreamDistributionChannel.ts.html |here} to see how to use IngestStreamDistributionChannel API.
     */
    ingestStreamDistributionChannel(ingestStreamDistributionChannelRequest: requests.IngestStreamDistributionChannelRequest): Promise<responses.IngestStreamDistributionChannelResponse>;
    /**
     * Lists the MediaAssetDistributionChannelAttachments for a MediaAsset by identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListMediaAssetDistributionChannelAttachmentsRequest
     * @return ListMediaAssetDistributionChannelAttachmentsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/mediaservices/ListMediaAssetDistributionChannelAttachments.ts.html |here} to see how to use ListMediaAssetDistributionChannelAttachments API.
     */
    listMediaAssetDistributionChannelAttachments(listMediaAssetDistributionChannelAttachmentsRequest: requests.ListMediaAssetDistributionChannelAttachmentsRequest): Promise<responses.ListMediaAssetDistributionChannelAttachmentsResponse>;
    /**
     * Returns a list of MediaAssetSummary.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListMediaAssetsRequest
     * @return ListMediaAssetsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/mediaservices/ListMediaAssets.ts.html |here} to see how to use ListMediaAssets API.
     */
    listMediaAssets(listMediaAssetsRequest: requests.ListMediaAssetsRequest): Promise<responses.ListMediaAssetsResponse>;
    /**
     * Returns a list of MediaWorkflowConfigurations.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListMediaWorkflowConfigurationsRequest
     * @return ListMediaWorkflowConfigurationsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/mediaservices/ListMediaWorkflowConfigurations.ts.html |here} to see how to use ListMediaWorkflowConfigurations API.
     */
    listMediaWorkflowConfigurations(listMediaWorkflowConfigurationsRequest: requests.ListMediaWorkflowConfigurationsRequest): Promise<responses.ListMediaWorkflowConfigurationsResponse>;
    /**
     * Lists the MediaWorkflowJobs.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListMediaWorkflowJobsRequest
     * @return ListMediaWorkflowJobsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/mediaservices/ListMediaWorkflowJobs.ts.html |here} to see how to use ListMediaWorkflowJobs API.
     */
    listMediaWorkflowJobs(listMediaWorkflowJobsRequest: requests.ListMediaWorkflowJobsRequest): Promise<responses.ListMediaWorkflowJobsResponse>;
    /**
     * Returns a list of MediaWorkflowTaskDeclarations.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListMediaWorkflowTaskDeclarationsRequest
     * @return ListMediaWorkflowTaskDeclarationsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/mediaservices/ListMediaWorkflowTaskDeclarations.ts.html |here} to see how to use ListMediaWorkflowTaskDeclarations API.
     */
    listMediaWorkflowTaskDeclarations(listMediaWorkflowTaskDeclarationsRequest: requests.ListMediaWorkflowTaskDeclarationsRequest): Promise<responses.ListMediaWorkflowTaskDeclarationsResponse>;
    /**
     * Lists the MediaWorkflows.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListMediaWorkflowsRequest
     * @return ListMediaWorkflowsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/mediaservices/ListMediaWorkflows.ts.html |here} to see how to use ListMediaWorkflows API.
     */
    listMediaWorkflows(listMediaWorkflowsRequest: requests.ListMediaWorkflowsRequest): Promise<responses.ListMediaWorkflowsResponse>;
    /**
     * Lists the StreamCdnConfig.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListStreamCdnConfigsRequest
     * @return ListStreamCdnConfigsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/mediaservices/ListStreamCdnConfigs.ts.html |here} to see how to use ListStreamCdnConfigs API.
     */
    listStreamCdnConfigs(listStreamCdnConfigsRequest: requests.ListStreamCdnConfigsRequest): Promise<responses.ListStreamCdnConfigsResponse>;
    /**
     * Lists the Stream Distribution Channels.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListStreamDistributionChannelsRequest
     * @return ListStreamDistributionChannelsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/mediaservices/ListStreamDistributionChannels.ts.html |here} to see how to use ListStreamDistributionChannels API.
     */
    listStreamDistributionChannels(listStreamDistributionChannelsRequest: requests.ListStreamDistributionChannelsRequest): Promise<responses.ListStreamDistributionChannelsResponse>;
    /**
     * Lists the Stream Packaging Configurations.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListStreamPackagingConfigsRequest
     * @return ListStreamPackagingConfigsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/mediaservices/ListStreamPackagingConfigs.ts.html |here} to see how to use ListStreamPackagingConfigs API.
     */
    listStreamPackagingConfigs(listStreamPackagingConfigsRequest: requests.ListStreamPackagingConfigsRequest): Promise<responses.ListStreamPackagingConfigsResponse>;
    /**
     * Lists the SystemMediaWorkflows that can be used to run a job by name or as a template to create a MediaWorkflow.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListSystemMediaWorkflowsRequest
     * @return ListSystemMediaWorkflowsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/mediaservices/ListSystemMediaWorkflows.ts.html |here} to see how to use ListSystemMediaWorkflows API.
     */
    listSystemMediaWorkflows(listSystemMediaWorkflowsRequest: requests.ListSystemMediaWorkflowsRequest): Promise<responses.ListSystemMediaWorkflowsResponse>;
    /**
     * Remove a lock to an MediaAsset.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param RemoveMediaAssetLockRequest
     * @return RemoveMediaAssetLockResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/mediaservices/RemoveMediaAssetLock.ts.html |here} to see how to use RemoveMediaAssetLock API.
     */
    removeMediaAssetLock(removeMediaAssetLockRequest: requests.RemoveMediaAssetLockRequest): Promise<responses.RemoveMediaAssetLockResponse>;
    /**
     * Remove a lock from a MediaWorkflowConfiguration.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param RemoveMediaWorkflowConfigurationLockRequest
     * @return RemoveMediaWorkflowConfigurationLockResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/mediaservices/RemoveMediaWorkflowConfigurationLock.ts.html |here} to see how to use RemoveMediaWorkflowConfigurationLock API.
     */
    removeMediaWorkflowConfigurationLock(removeMediaWorkflowConfigurationLockRequest: requests.RemoveMediaWorkflowConfigurationLockRequest): Promise<responses.RemoveMediaWorkflowConfigurationLockResponse>;
    /**
     * Remove a lock from a MediaWorkflowJob.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param RemoveMediaWorkflowJobLockRequest
     * @return RemoveMediaWorkflowJobLockResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/mediaservices/RemoveMediaWorkflowJobLock.ts.html |here} to see how to use RemoveMediaWorkflowJobLock API.
     */
    removeMediaWorkflowJobLock(removeMediaWorkflowJobLockRequest: requests.RemoveMediaWorkflowJobLockRequest): Promise<responses.RemoveMediaWorkflowJobLockResponse>;
    /**
     * Remove a lock from a MediaWorkflow.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param RemoveMediaWorkflowLockRequest
     * @return RemoveMediaWorkflowLockResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/mediaservices/RemoveMediaWorkflowLock.ts.html |here} to see how to use RemoveMediaWorkflowLock API.
     */
    removeMediaWorkflowLock(removeMediaWorkflowLockRequest: requests.RemoveMediaWorkflowLockRequest): Promise<responses.RemoveMediaWorkflowLockResponse>;
    /**
     * Remove a lock from a StreamCdnConfig.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param RemoveStreamCdnConfigLockRequest
     * @return RemoveStreamCdnConfigLockResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/mediaservices/RemoveStreamCdnConfigLock.ts.html |here} to see how to use RemoveStreamCdnConfigLock API.
     */
    removeStreamCdnConfigLock(removeStreamCdnConfigLockRequest: requests.RemoveStreamCdnConfigLockRequest): Promise<responses.RemoveStreamCdnConfigLockResponse>;
    /**
     * Remove a lock to a StreamDistributionChannel.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param RemoveStreamDistributionChannelLockRequest
     * @return RemoveStreamDistributionChannelLockResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/mediaservices/RemoveStreamDistributionChannelLock.ts.html |here} to see how to use RemoveStreamDistributionChannelLock API.
     */
    removeStreamDistributionChannelLock(removeStreamDistributionChannelLockRequest: requests.RemoveStreamDistributionChannelLockRequest): Promise<responses.RemoveStreamDistributionChannelLockResponse>;
    /**
     * Remove a lock from a StreamPackagingConfig.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param RemoveStreamPackagingConfigLockRequest
     * @return RemoveStreamPackagingConfigLockResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/mediaservices/RemoveStreamPackagingConfigLock.ts.html |here} to see how to use RemoveStreamPackagingConfigLock API.
     */
    removeStreamPackagingConfigLock(removeStreamPackagingConfigLockRequest: requests.RemoveStreamPackagingConfigLockRequest): Promise<responses.RemoveStreamPackagingConfigLockResponse>;
    /**
     * Updates the MediaAsset.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateMediaAssetRequest
     * @return UpdateMediaAssetResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/mediaservices/UpdateMediaAsset.ts.html |here} to see how to use UpdateMediaAsset API.
     */
    updateMediaAsset(updateMediaAssetRequest: requests.UpdateMediaAssetRequest): Promise<responses.UpdateMediaAssetResponse>;
    /**
     * Updates the MediaWorkflow.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateMediaWorkflowRequest
     * @return UpdateMediaWorkflowResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/mediaservices/UpdateMediaWorkflow.ts.html |here} to see how to use UpdateMediaWorkflow API.
     */
    updateMediaWorkflow(updateMediaWorkflowRequest: requests.UpdateMediaWorkflowRequest): Promise<responses.UpdateMediaWorkflowResponse>;
    /**
     * Updates the MediaWorkflowConfiguration.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateMediaWorkflowConfigurationRequest
     * @return UpdateMediaWorkflowConfigurationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/mediaservices/UpdateMediaWorkflowConfiguration.ts.html |here} to see how to use UpdateMediaWorkflowConfiguration API.
     */
    updateMediaWorkflowConfiguration(updateMediaWorkflowConfigurationRequest: requests.UpdateMediaWorkflowConfigurationRequest): Promise<responses.UpdateMediaWorkflowConfigurationResponse>;
    /**
     * Updates the MediaWorkflowJob.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateMediaWorkflowJobRequest
     * @return UpdateMediaWorkflowJobResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/mediaservices/UpdateMediaWorkflowJob.ts.html |here} to see how to use UpdateMediaWorkflowJob API.
     */
    updateMediaWorkflowJob(updateMediaWorkflowJobRequest: requests.UpdateMediaWorkflowJobRequest): Promise<responses.UpdateMediaWorkflowJobResponse>;
    /**
     * Updates the StreamCdnConfig.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateStreamCdnConfigRequest
     * @return UpdateStreamCdnConfigResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/mediaservices/UpdateStreamCdnConfig.ts.html |here} to see how to use UpdateStreamCdnConfig API.
     */
    updateStreamCdnConfig(updateStreamCdnConfigRequest: requests.UpdateStreamCdnConfigRequest): Promise<responses.UpdateStreamCdnConfigResponse>;
    /**
     * Updates the Stream Distribution Channel.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateStreamDistributionChannelRequest
     * @return UpdateStreamDistributionChannelResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/mediaservices/UpdateStreamDistributionChannel.ts.html |here} to see how to use UpdateStreamDistributionChannel API.
     */
    updateStreamDistributionChannel(updateStreamDistributionChannelRequest: requests.UpdateStreamDistributionChannelRequest): Promise<responses.UpdateStreamDistributionChannelResponse>;
    /**
     * Updates the Stream Packaging Configuration.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateStreamPackagingConfigRequest
     * @return UpdateStreamPackagingConfigResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/mediaservices/UpdateStreamPackagingConfig.ts.html |here} to see how to use UpdateStreamPackagingConfig API.
     */
    updateStreamPackagingConfig(updateStreamPackagingConfigRequest: requests.UpdateStreamPackagingConfigRequest): Promise<responses.UpdateStreamPackagingConfigResponse>;
}
export declare enum MediaStreamApiKeys {
}
/**
 * This service client uses {@link common.CircuitBreaker.DefaultConfiguration} for all the operations by default if no circuit breaker configuration is defined by the user.
 */
export declare class MediaStreamClient {
    protected static serviceEndpointTemplate: string;
    protected static endpointServiceName: string;
    protected "_realmSpecificEndpointTemplateEnabled": boolean | undefined;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: typeof Breaker | null;
    protected _httpOptions: any;
    protected _bodyDuplexMode: any;
    targetService: string;
    protected _regionId: string;
    protected "_region": common.Region;
    protected _lastSetRegionOrRegionId: string;
    protected _httpClient: common.HttpClient;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    get endpoint(): string;
    /**
     * Sets the endpoint to call (ex, https://www.example.com).
     * @param endpoint The endpoint of the service.
     */
    set endpoint(endpoint: string);
    get logger(): import("oci-common/lib/log").Logger;
    /**
     * Determines whether realm specific endpoint should be used or not.
     * Set realmSpecificEndpointTemplateEnabled to "true" if the user wants to enable use of realm specific endpoint template, otherwise set it to "false"
     * @param realmSpecificEndpointTemplateEnabled flag to enable the use of realm specific endpoint template
     */
    set useRealmSpecificEndpointTemplate(realmSpecificEndpointTemplateEnabled: boolean);
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    set region(region: common.Region);
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    set regionId(regionId: string);
    /**
     * Shutdown the circuit breaker used by the client when it is no longer needed
     */
    shutdownCircuitBreaker(): void;
    /**
     * Close the client once it is no longer needed
     */
    close(): void;
    /**
     * Gets the playlist content for the specified Packaging Configuration and Media Asset combination. This API call is made using the MediaStreamsClient, which requires the endpoint to be set with the value of the distribution channel domain name (for example, https://example_channel.dc.mediaservices.example_region.oci.oraclecloud.com) to generate a session token or playlist for a media asset registered in this distribution channel.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GeneratePlaylistRequest
     * @return GeneratePlaylistResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/mediaservices/GeneratePlaylist.ts.html |here} to see how to use GeneratePlaylist API.
     */
    generatePlaylist(generatePlaylistRequest: requests.GeneratePlaylistRequest): Promise<responses.GeneratePlaylistResponse>;
    /**
     * Generate a new streaming session token. This API call is made using the MediaStreamsClient, which requires the endpoint to be set with the value of the distribution channel domain name (for example, https://example_channel.dc.mediaservices.example_region.oci.oraclecloud.com) to generate a session token or playlist for a media asset registered in this distribution channel.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GenerateSessionTokenRequest
     * @return GenerateSessionTokenResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/mediaservices/GenerateSessionToken.ts.html |here} to see how to use GenerateSessionToken API.
     */
    generateSessionToken(generateSessionTokenRequest: requests.GenerateSessionTokenRequest): Promise<responses.GenerateSessionTokenResponse>;
}
export {};
