/**
 * Media Services API
 * Media Services (includes Media Flow and Media Streams) is a fully managed service for processing media (video) source content. Use Media Flow and Media Streams to transcode and package digital video using configurable workflows and stream video outputs.

Use the Media Services API to configure media workflows and run Media Flow jobs, create distribution channels, ingest assets, create Preview URLs and play assets. For more information, see [Media Flow](/iaas/Content/dms-mediaflow/home.htm) and [Media Streams](/iaas/Content/dms-mediastream/home.htm).

 * OpenAPI spec version: 20211101
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
/**
 * Defines the type of processing to be run at a given point in the workflow, parameters to configure the
 * processing, and any processing that must be completed before this processing begins.
 *
 */
export interface MediaWorkflowTask {
    /**
     * The type of process to run at this task. Refers to the name of a MediaWorkflowTaskDeclaration.
     *
     */
    "type": string;
    /**
     * The version of the MediaWorkflowTaskDeclaration. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "version": number;
    /**
     * A unique identifier for this task within its workflow. Keys are used to reference a task within workflows
     * and MediaWorkflowJobs. Tasks are referenced as prerequisites and to track output and state.
     *
     */
    "key": string;
    /**
     * Keys to the other tasks in this workflow that must be completed before execution of this task can begin.
     *
     */
    "prerequisites"?: Array<string>;
    /**
     * Allows this task to be conditionally enabled.  If no value or a blank value is given, the task is
     * unconditionally enbled.  Otherwise the given string specifies a parameter of the job created for this task's
     * workflow using the JSON pointer syntax. The JSON pointer is validated when a job is created from the workflow of this task.
     *
     */
    "enableParameterReference"?: string;
    /**
     * Used in conjunction with enableParameterReference to conditionally enable a task.  When a job is created
     * from the workflow of this task, the task will only be enabled if the value of the parameter specified by
     * enableParameterReference is equal to the value of this property. This property must be prenset if and only if
     * a enableParameterReference is given. The value is a JSON node.
     *
     */
    "enableWhenReferencedParameterEquals"?: {
        [key: string]: any;
    };
    /**
     * Data specifiying how this task is to be run. The data is a JSON object that must conform to the JSON Schema
     * specified by the parameters of the MediaWorkflowTaskDeclaration this task references. The parameters may
     * contain values or references to other parameters.
     *
     */
    "parameters": {
        [key: string]: any;
    };
}
export declare namespace MediaWorkflowTask {
    function getJsonObj(obj: MediaWorkflowTask): object;
    function getDeserializedJsonObj(obj: MediaWorkflowTask): object;
}
