/**
 * Monitoring API
 * Use the Monitoring API to manage metric queries and alarms for assessing the health, capacity, and performance of your cloud resources.
Endpoints vary by operation. For PostMetricData, use the `telemetry-ingestion` endpoints; for all other operations, use the `telemetry` endpoints.
For more information, see
[the Monitoring documentation](/iaas/Content/Monitoring/home.htm).

 * OpenAPI spec version: 20180401
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * A summary of properties for the specified dimension-specific alarm suppression.
 *
 */
export interface AlarmSuppressionSummary {
    /**
     * The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the alarm suppression.
     */
    "id": string;
    /**
     * The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment containing the alarm suppression.
     */
    "compartmentId": string;
    "alarmSuppressionTarget": model.AlarmSuppressionAlarmTarget;
    /**
     * A user-friendly name for the alarm suppression. It does not have to be unique, and it's changeable. Avoid entering confidential information.
     */
    "displayName": string;
    /**
      * Human-readable reason for this alarm suppression.
  * It does not have to be unique, and it's changeable.
  * Avoid entering confidential information.
  * <p>
  Oracle recommends including tracking information for the event or associated work,
  * such as a ticket number.
  * <p>
  Example: {@code Planned outage due to change IT-1234.}
  *
      */
    "description"?: string;
    /**
      * Configured dimension filter for suppressing alarm state entries that include the set of specified dimension key-value pairs.
  * <p>
  Example: {@code {\"resourceId\": \"ocid1.instance.region1.phx.exampleuniqueID\"}}
  *
      */
    "dimensions": {
        [key: string]: string;
    };
    /**
      * The start date and time for the suppression to take place, inclusive. Format defined by RFC3339.
  * <p>
  Example: {@code 2023-02-01T01:02:29.600Z}
  *
      */
    "timeSuppressFrom": Date;
    /**
      * The end date and time for the suppression to take place, inclusive. Format defined by RFC3339.
  * <p>
  Example: {@code 2023-02-01T02:02:29.600Z}
  *
      */
    "timeSuppressUntil": Date;
    /**
      * The current lifecycle state of the alarm suppression.
  * <p>
  Example: {@code DELETED}
  *
      */
    "lifecycleState": string;
    /**
      * The date and time the alarm suppression was created. Format defined by RFC3339.
  * <p>
  Example: {@code 2023-02-01T01:02:29.600Z}
  *
      */
    "timeCreated": Date;
    /**
      * The date and time the alarm suppression was last updated (deleted). Format defined by RFC3339.
  * <p>
  Example: {@code 2023-02-03T01:02:29.600Z}
  *
      */
    "timeUpdated": Date;
    /**
     * Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
     * Example: {@code {\"bar-key\": \"value\"}}
     *
     */
    "freeformTags"?: {
        [key: string]: string;
    };
    /**
     * Defined tags for this resource. Each key is predefined and scoped to a namespace.
     * Example: {@code {\"foo-namespace\": {\"bar-key\": \"value\"}}}
     *
     */
    "definedTags"?: {
        [key: string]: {
            [key: string]: any;
        };
    };
}
export declare namespace AlarmSuppressionSummary {
    function getJsonObj(obj: AlarmSuppressionSummary): object;
    function getDeserializedJsonObj(obj: AlarmSuppressionSummary): object;
}
