/**
 * MySQL Database Service API
 * The API for the MySQL Database Service
 * OpenAPI spec version: 20190415
 * Contact: mysql-cloud-dev_ww_grp@oracle.com
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
* A full or incremental copy of a DB System which can be used to create a
* new DB System or recover a DB System.
* <p>
To use any of the API operations, you must be authorized in an IAM
* policy. If you're not authorized, talk to an administrator. If you're an
* administrator who needs to write policies to give users access, see
* [Getting Started with
* Policies](https://docs.cloud.oracle.com/Content/Identity/Concepts/policygetstarted.htm).
*
*/
export interface Backup {
    /**
     * OCID of the backup itself
     */
    "id": string;
    /**
     * A user-supplied display name for the backup.
     */
    "displayName"?: string;
    /**
     * A user-supplied description for the backup.
     */
    "description"?: string;
    /**
     * The OCID of the compartment.
     */
    "compartmentId": string;
    /**
     * The time the backup record was created.
     */
    "timeCreated": Date;
    /**
     * The time at which the backup was updated.
     */
    "timeUpdated": Date;
    /**
     * The state of the backup.
     */
    "lifecycleState": Backup.LifecycleState;
    /**
     * Additional information about the current lifecycleState.
     */
    "lifecycleDetails": string;
    /**
     * The type of backup.
     */
    "backupType": Backup.BackupType;
    /**
     * Indicates how the backup was created: manually, automatic, or by an Operator.
     *
     */
    "creationType": Backup.CreationType;
    /**
     * The OCID of the DB System the backup is associated with.
     */
    "dbSystemId": string;
    "dbSystemSnapshot"?: model.DbSystemSnapshot;
    /**
     * The size of the backup in base-2 (IEC) gibibytes. (GiB). Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "backupSizeInGBs"?: number;
    /**
     * Number of days to retain this backup. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "retentionInDays"?: number;
    /**
     * Initial size of the data volume in GiBs.
     *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "dataStorageSizeInGBs"?: number;
    /**
     * The MySQL server version of the DB System used for backup.
     */
    "mysqlVersion"?: string;
    /**
     * The shape of the DB System used for backup.
     */
    "shapeName"?: string;
    /**
     * Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
     * Example: {@code {\"bar-key\": \"value\"}}
     *
     */
    "freeformTags"?: {
        [key: string]: string;
    };
    /**
     * Defined tags for this resource. Each key is predefined and scoped to a namespace.
     * Example: {@code {\"foo-namespace\": {\"bar-key\": \"value\"}}}
     *
     */
    "definedTags"?: {
        [key: string]: {
            [key: string]: any;
        };
    };
    /**
     * The OCID of the immediate source DB system backup from which this DB system backup was copied.
     *
     */
    "immediateSourceBackupId"?: string;
    /**
     * The OCID of the original source DB system backup from which this DB system backup was copied.
     *
     */
    "originalSourceBackupId"?: string;
    /**
     * The date and time the DB system backup copy was created, as described by [RFC 3339](https://tools.ietf.org/rfc/rfc3339).
     *
     */
    "timeCopyCreated"?: Date;
}
export declare namespace Backup {
    enum LifecycleState {
        Creating = "CREATING",
        Active = "ACTIVE",
        Inactive = "INACTIVE",
        Updating = "UPDATING",
        Deleting = "DELETING",
        Deleted = "DELETED",
        Failed = "FAILED",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    enum BackupType {
        Full = "FULL",
        Incremental = "INCREMENTAL",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    enum CreationType {
        Manual = "MANUAL",
        Automatic = "AUTOMATIC",
        Operator = "OPERATOR",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    function getJsonObj(obj: Backup): object;
    function getDeserializedJsonObj(obj: Backup): object;
}
