/**
 * Network Firewall API
 * Use the Network Firewall API to create network firewalls and configure policies that regulates network traffic in and across VCNs.
 * OpenAPI spec version: 20230501
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import common = require("oci-common");
import * as requests from "./request";
import * as responses from "./response";
import { NetworkFirewallWaiter } from "./networkfirewall-waiter";
declare const Breaker: any;
export declare enum NetworkFirewallApiKeys {
}
/**
 * This service client uses {@link common.CircuitBreaker.DefaultConfiguration} for all the operations by default if no circuit breaker configuration is defined by the user.
 */
export declare class NetworkFirewallClient {
    protected static serviceEndpointTemplate: string;
    protected static endpointServiceName: string;
    protected "_realmSpecificEndpointTemplateEnabled": boolean | undefined;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_waiters": NetworkFirewallWaiter;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: typeof Breaker | null;
    protected _httpOptions: any;
    protected _bodyDuplexMode: any;
    targetService: string;
    protected _regionId: string;
    protected "_region": common.Region;
    protected _lastSetRegionOrRegionId: string;
    protected _httpClient: common.HttpClient;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    get endpoint(): string;
    /**
     * Sets the endpoint to call (ex, https://www.example.com).
     * @param endpoint The endpoint of the service.
     */
    set endpoint(endpoint: string);
    get logger(): import("oci-common/lib/log").Logger;
    /**
     * Determines whether realm specific endpoint should be used or not.
     * Set realmSpecificEndpointTemplateEnabled to "true" if the user wants to enable use of realm specific endpoint template, otherwise set it to "false"
     * @param realmSpecificEndpointTemplateEnabled flag to enable the use of realm specific endpoint template
     */
    set useRealmSpecificEndpointTemplate(realmSpecificEndpointTemplateEnabled: boolean);
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    set region(region: common.Region);
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    set regionId(regionId: string);
    /**
     * Creates a new NetworkFirewallWaiter for resources for this service.
     *
     * @param config The waiter configuration for termination and delay strategy
     * @return The service waiters.
     */
    createWaiters(config?: common.WaiterConfiguration): NetworkFirewallWaiter;
    /**
     * Gets the waiters available for resources for this service.
     *
     * @return The service waiters.
     */
    getWaiters(): NetworkFirewallWaiter;
    /**
     * Shutdown the circuit breaker used by the client when it is no longer needed
     */
    shutdownCircuitBreaker(): void;
    /**
     * Close the client once it is no longer needed
     */
    close(): void;
    /**
     * Applies the candidate version of the NetworkFirewallPolicy resource. When provided, If-Match is checked against ETag values of the resource.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ApplyNetworkFirewallPolicyRequest
     * @return ApplyNetworkFirewallPolicyResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/networkfirewall/ApplyNetworkFirewallPolicy.ts.html |here} to see how to use ApplyNetworkFirewallPolicy API.
     */
    applyNetworkFirewallPolicy(applyNetworkFirewallPolicyRequest: requests.ApplyNetworkFirewallPolicyRequest): Promise<responses.ApplyNetworkFirewallPolicyResponse>;
    /**
     * Creates a new Address Lists at bulk for the Network Firewall Policy.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param BulkUploadAddressListsRequest
     * @return BulkUploadAddressListsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/networkfirewall/BulkUploadAddressLists.ts.html |here} to see how to use BulkUploadAddressLists API.
     */
    bulkUploadAddressLists(bulkUploadAddressListsRequest: requests.BulkUploadAddressListsRequest): Promise<responses.BulkUploadAddressListsResponse>;
    /**
     * Creates a new Application Group at bulk for the Network Firewall Policy.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param BulkUploadApplicationGroupsRequest
     * @return BulkUploadApplicationGroupsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/networkfirewall/BulkUploadApplicationGroups.ts.html |here} to see how to use BulkUploadApplicationGroups API.
     */
    bulkUploadApplicationGroups(bulkUploadApplicationGroupsRequest: requests.BulkUploadApplicationGroupsRequest): Promise<responses.BulkUploadApplicationGroupsResponse>;
    /**
     * Creates new Applications at bulk for the Network Firewall Policy.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param BulkUploadApplicationsRequest
     * @return BulkUploadApplicationsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/networkfirewall/BulkUploadApplications.ts.html |here} to see how to use BulkUploadApplications API.
     */
    bulkUploadApplications(bulkUploadApplicationsRequest: requests.BulkUploadApplicationsRequest): Promise<responses.BulkUploadApplicationsResponse>;
    /**
     * Creates new Decryption Profiles at bulk for the Network Firewall Policy.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param BulkUploadDecryptionProfilesRequest
     * @return BulkUploadDecryptionProfilesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/networkfirewall/BulkUploadDecryptionProfiles.ts.html |here} to see how to use BulkUploadDecryptionProfiles API.
     */
    bulkUploadDecryptionProfiles(bulkUploadDecryptionProfilesRequest: requests.BulkUploadDecryptionProfilesRequest): Promise<responses.BulkUploadDecryptionProfilesResponse>;
    /**
     * Creates Decryption Rules at bulk for the Network Firewall Policy.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param BulkUploadDecryptionRulesRequest
     * @return BulkUploadDecryptionRulesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/networkfirewall/BulkUploadDecryptionRules.ts.html |here} to see how to use BulkUploadDecryptionRules API.
     */
    bulkUploadDecryptionRules(bulkUploadDecryptionRulesRequest: requests.BulkUploadDecryptionRulesRequest): Promise<responses.BulkUploadDecryptionRulesResponse>;
    /**
     * Creates new Mapped Secrets at bulk for the Network Firewall Policy.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param BulkUploadMappedSecretsRequest
     * @return BulkUploadMappedSecretsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/networkfirewall/BulkUploadMappedSecrets.ts.html |here} to see how to use BulkUploadMappedSecrets API.
     */
    bulkUploadMappedSecrets(bulkUploadMappedSecretsRequest: requests.BulkUploadMappedSecretsRequest): Promise<responses.BulkUploadMappedSecretsResponse>;
    /**
     * Creates a new Security Rule at bulk for the Network Firewall Policy.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param BulkUploadSecurityRulesRequest
     * @return BulkUploadSecurityRulesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/networkfirewall/BulkUploadSecurityRules.ts.html |here} to see how to use BulkUploadSecurityRules API.
     */
    bulkUploadSecurityRules(bulkUploadSecurityRulesRequest: requests.BulkUploadSecurityRulesRequest): Promise<responses.BulkUploadSecurityRulesResponse>;
    /**
     * Creates a new Service List at bulk for the Network Firewall Policy.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param BulkUploadServiceListsRequest
     * @return BulkUploadServiceListsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/networkfirewall/BulkUploadServiceLists.ts.html |here} to see how to use BulkUploadServiceLists API.
     */
    bulkUploadServiceLists(bulkUploadServiceListsRequest: requests.BulkUploadServiceListsRequest): Promise<responses.BulkUploadServiceListsResponse>;
    /**
     * Creates new Services at bulk for the Network Firewall Policy.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param BulkUploadServicesRequest
     * @return BulkUploadServicesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/networkfirewall/BulkUploadServices.ts.html |here} to see how to use BulkUploadServices API.
     */
    bulkUploadServices(bulkUploadServicesRequest: requests.BulkUploadServicesRequest): Promise<responses.BulkUploadServicesResponse>;
    /**
     * Creates a new Url Lists at bulk for the Network Firewall Policy.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param BulkUploadUrlListsRequest
     * @return BulkUploadUrlListsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/networkfirewall/BulkUploadUrlLists.ts.html |here} to see how to use BulkUploadUrlLists API.
     */
    bulkUploadUrlLists(bulkUploadUrlListsRequest: requests.BulkUploadUrlListsRequest): Promise<responses.BulkUploadUrlListsResponse>;
    /**
     * Cancel work request with the given ID.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CancelWorkRequestRequest
     * @return CancelWorkRequestResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/networkfirewall/CancelWorkRequest.ts.html |here} to see how to use CancelWorkRequest API.
     */
    cancelWorkRequest(cancelWorkRequestRequest: requests.CancelWorkRequestRequest): Promise<responses.CancelWorkRequestResponse>;
    /**
     * Moves a NetworkFirewall resource from one compartment identifier to another. When provided, If-Match is checked against ETag values of the resource.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ChangeNetworkFirewallCompartmentRequest
     * @return ChangeNetworkFirewallCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/networkfirewall/ChangeNetworkFirewallCompartment.ts.html |here} to see how to use ChangeNetworkFirewallCompartment API.
     */
    changeNetworkFirewallCompartment(changeNetworkFirewallCompartmentRequest: requests.ChangeNetworkFirewallCompartmentRequest): Promise<responses.ChangeNetworkFirewallCompartmentResponse>;
    /**
     * Moves a NetworkFirewallPolicy resource from one compartment identifier to another. When provided, If-Match is checked against ETag values of the resource.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ChangeNetworkFirewallPolicyCompartmentRequest
     * @return ChangeNetworkFirewallPolicyCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/networkfirewall/ChangeNetworkFirewallPolicyCompartment.ts.html |here} to see how to use ChangeNetworkFirewallPolicyCompartment API.
     */
    changeNetworkFirewallPolicyCompartment(changeNetworkFirewallPolicyCompartmentRequest: requests.ChangeNetworkFirewallPolicyCompartmentRequest): Promise<responses.ChangeNetworkFirewallPolicyCompartmentResponse>;
    /**
     * Moves a NetworkFirewallPolicy resource from one compartment identifier to another. When provided, If-Match is checked against ETag values of the resource.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CloneNetworkFirewallPolicyRequest
     * @return CloneNetworkFirewallPolicyResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/networkfirewall/CloneNetworkFirewallPolicy.ts.html |here} to see how to use CloneNetworkFirewallPolicy API.
     */
    cloneNetworkFirewallPolicy(cloneNetworkFirewallPolicyRequest: requests.CloneNetworkFirewallPolicyRequest): Promise<responses.CloneNetworkFirewallPolicyResponse>;
    /**
     * Creates a new Address List for the Network Firewall Policy.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateAddressListRequest
     * @return CreateAddressListResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/networkfirewall/CreateAddressList.ts.html |here} to see how to use CreateAddressList API.
     */
    createAddressList(createAddressListRequest: requests.CreateAddressListRequest): Promise<responses.CreateAddressListResponse>;
    /**
     * Creates a new Application for the Network Firewall Policy.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateApplicationRequest
     * @return CreateApplicationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/networkfirewall/CreateApplication.ts.html |here} to see how to use CreateApplication API.
     */
    createApplication(createApplicationRequest: requests.CreateApplicationRequest): Promise<responses.CreateApplicationResponse>;
    /**
     * Creates a new ApplicationGroup for the Network Firewall Policy.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateApplicationGroupRequest
     * @return CreateApplicationGroupResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/networkfirewall/CreateApplicationGroup.ts.html |here} to see how to use CreateApplicationGroup API.
     */
    createApplicationGroup(createApplicationGroupRequest: requests.CreateApplicationGroupRequest): Promise<responses.CreateApplicationGroupResponse>;
    /**
     * Creates a new Decryption Profile for the Network Firewall Policy.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateDecryptionProfileRequest
     * @return CreateDecryptionProfileResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/networkfirewall/CreateDecryptionProfile.ts.html |here} to see how to use CreateDecryptionProfile API.
     */
    createDecryptionProfile(createDecryptionProfileRequest: requests.CreateDecryptionProfileRequest): Promise<responses.CreateDecryptionProfileResponse>;
    /**
     * Creates a new Decryption Rule for the Network Firewall Policy.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateDecryptionRuleRequest
     * @return CreateDecryptionRuleResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/networkfirewall/CreateDecryptionRule.ts.html |here} to see how to use CreateDecryptionRule API.
     */
    createDecryptionRule(createDecryptionRuleRequest: requests.CreateDecryptionRuleRequest): Promise<responses.CreateDecryptionRuleResponse>;
    /**
     * Creates a new Mapped Secret for the Network Firewall Policy.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateMappedSecretRequest
     * @return CreateMappedSecretResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/networkfirewall/CreateMappedSecret.ts.html |here} to see how to use CreateMappedSecret API.
     */
    createMappedSecret(createMappedSecretRequest: requests.CreateMappedSecretRequest): Promise<responses.CreateMappedSecretResponse>;
    /**
     * Creates a new NetworkFirewall.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateNetworkFirewallRequest
     * @return CreateNetworkFirewallResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/networkfirewall/CreateNetworkFirewall.ts.html |here} to see how to use CreateNetworkFirewall API.
     */
    createNetworkFirewall(createNetworkFirewallRequest: requests.CreateNetworkFirewallRequest): Promise<responses.CreateNetworkFirewallResponse>;
    /**
     * Creates a new Network Firewall Policy.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateNetworkFirewallPolicyRequest
     * @return CreateNetworkFirewallPolicyResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/networkfirewall/CreateNetworkFirewallPolicy.ts.html |here} to see how to use CreateNetworkFirewallPolicy API.
     */
    createNetworkFirewallPolicy(createNetworkFirewallPolicyRequest: requests.CreateNetworkFirewallPolicyRequest): Promise<responses.CreateNetworkFirewallPolicyResponse>;
    /**
     * Creates a new Security Rule for the Network Firewall Policy.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateSecurityRuleRequest
     * @return CreateSecurityRuleResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/networkfirewall/CreateSecurityRule.ts.html |here} to see how to use CreateSecurityRule API.
     */
    createSecurityRule(createSecurityRuleRequest: requests.CreateSecurityRuleRequest): Promise<responses.CreateSecurityRuleResponse>;
    /**
     * Creates a new Service for the Network Firewall Policy.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateServiceRequest
     * @return CreateServiceResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/networkfirewall/CreateService.ts.html |here} to see how to use CreateService API.
     */
    createService(createServiceRequest: requests.CreateServiceRequest): Promise<responses.CreateServiceResponse>;
    /**
     * Creates a new ServiceList for the Network Firewall Policy.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateServiceListRequest
     * @return CreateServiceListResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/networkfirewall/CreateServiceList.ts.html |here} to see how to use CreateServiceList API.
     */
    createServiceList(createServiceListRequest: requests.CreateServiceListRequest): Promise<responses.CreateServiceListResponse>;
    /**
     * Creates a new Url List for the Network Firewall Policy.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateUrlListRequest
     * @return CreateUrlListResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/networkfirewall/CreateUrlList.ts.html |here} to see how to use CreateUrlList API.
     */
    createUrlList(createUrlListRequest: requests.CreateUrlListRequest): Promise<responses.CreateUrlListResponse>;
    /**
     * Deletes a Address List resource with the given identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteAddressListRequest
     * @return DeleteAddressListResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/networkfirewall/DeleteAddressList.ts.html |here} to see how to use DeleteAddressList API.
     */
    deleteAddressList(deleteAddressListRequest: requests.DeleteAddressListRequest): Promise<responses.DeleteAddressListResponse>;
    /**
     * Deletes a Application resource with the given identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteApplicationRequest
     * @return DeleteApplicationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/networkfirewall/DeleteApplication.ts.html |here} to see how to use DeleteApplication API.
     */
    deleteApplication(deleteApplicationRequest: requests.DeleteApplicationRequest): Promise<responses.DeleteApplicationResponse>;
    /**
     * Deletes a ApplicationGroup resource with the given identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteApplicationGroupRequest
     * @return DeleteApplicationGroupResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/networkfirewall/DeleteApplicationGroup.ts.html |here} to see how to use DeleteApplicationGroup API.
     */
    deleteApplicationGroup(deleteApplicationGroupRequest: requests.DeleteApplicationGroupRequest): Promise<responses.DeleteApplicationGroupResponse>;
    /**
     * Deletes a Decryption Profile resource with the given identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteDecryptionProfileRequest
     * @return DeleteDecryptionProfileResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/networkfirewall/DeleteDecryptionProfile.ts.html |here} to see how to use DeleteDecryptionProfile API.
     */
    deleteDecryptionProfile(deleteDecryptionProfileRequest: requests.DeleteDecryptionProfileRequest): Promise<responses.DeleteDecryptionProfileResponse>;
    /**
     * Deletes a Decryption Rule resource with the given identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteDecryptionRuleRequest
     * @return DeleteDecryptionRuleResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/networkfirewall/DeleteDecryptionRule.ts.html |here} to see how to use DeleteDecryptionRule API.
     */
    deleteDecryptionRule(deleteDecryptionRuleRequest: requests.DeleteDecryptionRuleRequest): Promise<responses.DeleteDecryptionRuleResponse>;
    /**
     * Deletes a Mapped Secret resource with the given identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteMappedSecretRequest
     * @return DeleteMappedSecretResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/networkfirewall/DeleteMappedSecret.ts.html |here} to see how to use DeleteMappedSecret API.
     */
    deleteMappedSecret(deleteMappedSecretRequest: requests.DeleteMappedSecretRequest): Promise<responses.DeleteMappedSecretResponse>;
    /**
     * Deletes a NetworkFirewall resource by identifier
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteNetworkFirewallRequest
     * @return DeleteNetworkFirewallResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/networkfirewall/DeleteNetworkFirewall.ts.html |here} to see how to use DeleteNetworkFirewall API.
     */
    deleteNetworkFirewall(deleteNetworkFirewallRequest: requests.DeleteNetworkFirewallRequest): Promise<responses.DeleteNetworkFirewallResponse>;
    /**
     * Deletes a NetworkFirewallPolicy resource with the given identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteNetworkFirewallPolicyRequest
     * @return DeleteNetworkFirewallPolicyResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/networkfirewall/DeleteNetworkFirewallPolicy.ts.html |here} to see how to use DeleteNetworkFirewallPolicy API.
     */
    deleteNetworkFirewallPolicy(deleteNetworkFirewallPolicyRequest: requests.DeleteNetworkFirewallPolicyRequest): Promise<responses.DeleteNetworkFirewallPolicyResponse>;
    /**
     * Deletes a Security Rule resource with the given identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteSecurityRuleRequest
     * @return DeleteSecurityRuleResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/networkfirewall/DeleteSecurityRule.ts.html |here} to see how to use DeleteSecurityRule API.
     */
    deleteSecurityRule(deleteSecurityRuleRequest: requests.DeleteSecurityRuleRequest): Promise<responses.DeleteSecurityRuleResponse>;
    /**
     * Deletes a Service resource with the given identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteServiceRequest
     * @return DeleteServiceResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/networkfirewall/DeleteService.ts.html |here} to see how to use DeleteService API.
     */
    deleteService(deleteServiceRequest: requests.DeleteServiceRequest): Promise<responses.DeleteServiceResponse>;
    /**
     * Deletes a ServiceList resource with the given identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteServiceListRequest
     * @return DeleteServiceListResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/networkfirewall/DeleteServiceList.ts.html |here} to see how to use DeleteServiceList API.
     */
    deleteServiceList(deleteServiceListRequest: requests.DeleteServiceListRequest): Promise<responses.DeleteServiceListResponse>;
    /**
     * Deletes a Url List resource with the given identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteUrlListRequest
     * @return DeleteUrlListResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/networkfirewall/DeleteUrlList.ts.html |here} to see how to use DeleteUrlList API.
     */
    deleteUrlList(deleteUrlListRequest: requests.DeleteUrlListRequest): Promise<responses.DeleteUrlListResponse>;
    /**
     * Get Address List by the given name in the context of network firewall policy.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetAddressListRequest
     * @return GetAddressListResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/networkfirewall/GetAddressList.ts.html |here} to see how to use GetAddressList API.
     */
    getAddressList(getAddressListRequest: requests.GetAddressListRequest): Promise<responses.GetAddressListResponse>;
    /**
     * Get Application by the given name in the context of network firewall policy.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetApplicationRequest
     * @return GetApplicationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/networkfirewall/GetApplication.ts.html |here} to see how to use GetApplication API.
     */
    getApplication(getApplicationRequest: requests.GetApplicationRequest): Promise<responses.GetApplicationResponse>;
    /**
     * Get ApplicationGroup by the given name in the context of network firewall policy.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetApplicationGroupRequest
     * @return GetApplicationGroupResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/networkfirewall/GetApplicationGroup.ts.html |here} to see how to use GetApplicationGroup API.
     */
    getApplicationGroup(getApplicationGroupRequest: requests.GetApplicationGroupRequest): Promise<responses.GetApplicationGroupResponse>;
    /**
     * Get Decryption Profile by the given name in the context of network firewall policy.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetDecryptionProfileRequest
     * @return GetDecryptionProfileResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/networkfirewall/GetDecryptionProfile.ts.html |here} to see how to use GetDecryptionProfile API.
     */
    getDecryptionProfile(getDecryptionProfileRequest: requests.GetDecryptionProfileRequest): Promise<responses.GetDecryptionProfileResponse>;
    /**
     * Get Decryption Rule by the given name in the context of network firewall policy.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetDecryptionRuleRequest
     * @return GetDecryptionRuleResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/networkfirewall/GetDecryptionRule.ts.html |here} to see how to use GetDecryptionRule API.
     */
    getDecryptionRule(getDecryptionRuleRequest: requests.GetDecryptionRuleRequest): Promise<responses.GetDecryptionRuleResponse>;
    /**
     * Get Mapped Secret by the given name in the context of network firewall policy.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetMappedSecretRequest
     * @return GetMappedSecretResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/networkfirewall/GetMappedSecret.ts.html |here} to see how to use GetMappedSecret API.
     */
    getMappedSecret(getMappedSecretRequest: requests.GetMappedSecretRequest): Promise<responses.GetMappedSecretResponse>;
    /**
     * Gets a NetworkFirewall by identifier
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetNetworkFirewallRequest
     * @return GetNetworkFirewallResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/networkfirewall/GetNetworkFirewall.ts.html |here} to see how to use GetNetworkFirewall API.
     */
    getNetworkFirewall(getNetworkFirewallRequest: requests.GetNetworkFirewallRequest): Promise<responses.GetNetworkFirewallResponse>;
    /**
     * Gets a NetworkFirewallPolicy given the network firewall policy identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetNetworkFirewallPolicyRequest
     * @return GetNetworkFirewallPolicyResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/networkfirewall/GetNetworkFirewallPolicy.ts.html |here} to see how to use GetNetworkFirewallPolicy API.
     */
    getNetworkFirewallPolicy(getNetworkFirewallPolicyRequest: requests.GetNetworkFirewallPolicyRequest): Promise<responses.GetNetworkFirewallPolicyResponse>;
    /**
     * Get Security Rule by the given name in the context of network firewall policy.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetSecurityRuleRequest
     * @return GetSecurityRuleResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/networkfirewall/GetSecurityRule.ts.html |here} to see how to use GetSecurityRule API.
     */
    getSecurityRule(getSecurityRuleRequest: requests.GetSecurityRuleRequest): Promise<responses.GetSecurityRuleResponse>;
    /**
     * Get Service by the given name in the context of network firewall policy.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetServiceRequest
     * @return GetServiceResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/networkfirewall/GetService.ts.html |here} to see how to use GetService API.
     */
    getService(getServiceRequest: requests.GetServiceRequest): Promise<responses.GetServiceResponse>;
    /**
     * Get ServiceList by the given name in the context of network firewall policy.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetServiceListRequest
     * @return GetServiceListResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/networkfirewall/GetServiceList.ts.html |here} to see how to use GetServiceList API.
     */
    getServiceList(getServiceListRequest: requests.GetServiceListRequest): Promise<responses.GetServiceListResponse>;
    /**
     * Get Url List by the given name in the context of network firewall policy.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetUrlListRequest
     * @return GetUrlListResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/networkfirewall/GetUrlList.ts.html |here} to see how to use GetUrlList API.
     */
    getUrlList(getUrlListRequest: requests.GetUrlListRequest): Promise<responses.GetUrlListResponse>;
    /**
     * Gets the status of the work request with the given ID.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetWorkRequestRequest
     * @return GetWorkRequestResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/networkfirewall/GetWorkRequest.ts.html |here} to see how to use GetWorkRequest API.
     */
    getWorkRequest(getWorkRequestRequest: requests.GetWorkRequestRequest): Promise<responses.GetWorkRequestResponse>;
    /**
     * Returns a list of Network Firewall Policies.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListAddressListsRequest
     * @return ListAddressListsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/networkfirewall/ListAddressLists.ts.html |here} to see how to use ListAddressLists API.
     */
    listAddressLists(listAddressListsRequest: requests.ListAddressListsRequest): Promise<responses.ListAddressListsResponse>;
    /**
     * Returns a list of ApplicationGroups for the policy.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListApplicationGroupsRequest
     * @return ListApplicationGroupsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/networkfirewall/ListApplicationGroups.ts.html |here} to see how to use ListApplicationGroups API.
     */
    listApplicationGroups(listApplicationGroupsRequest: requests.ListApplicationGroupsRequest): Promise<responses.ListApplicationGroupsResponse>;
    /**
     * Returns a list of Applications for the policy.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListApplicationsRequest
     * @return ListApplicationsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/networkfirewall/ListApplications.ts.html |here} to see how to use ListApplications API.
     */
    listApplications(listApplicationsRequest: requests.ListApplicationsRequest): Promise<responses.ListApplicationsResponse>;
    /**
     * Returns a list of Decryption Profile for the Network Firewall Policy.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListDecryptionProfilesRequest
     * @return ListDecryptionProfilesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/networkfirewall/ListDecryptionProfiles.ts.html |here} to see how to use ListDecryptionProfiles API.
     */
    listDecryptionProfiles(listDecryptionProfilesRequest: requests.ListDecryptionProfilesRequest): Promise<responses.ListDecryptionProfilesResponse>;
    /**
     * Returns a list of Decryption Rule for the Network Firewall Policy.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListDecryptionRulesRequest
     * @return ListDecryptionRulesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/networkfirewall/ListDecryptionRules.ts.html |here} to see how to use ListDecryptionRules API.
     */
    listDecryptionRules(listDecryptionRulesRequest: requests.ListDecryptionRulesRequest): Promise<responses.ListDecryptionRulesResponse>;
    /**
     * Returns a list of Mapped Secret for the Network Firewall Policy.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListMappedSecretsRequest
     * @return ListMappedSecretsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/networkfirewall/ListMappedSecrets.ts.html |here} to see how to use ListMappedSecrets API.
     */
    listMappedSecrets(listMappedSecretsRequest: requests.ListMappedSecretsRequest): Promise<responses.ListMappedSecretsResponse>;
    /**
     * Returns a list of Network Firewall Policies.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListNetworkFirewallPoliciesRequest
     * @return ListNetworkFirewallPoliciesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/networkfirewall/ListNetworkFirewallPolicies.ts.html |here} to see how to use ListNetworkFirewallPolicies API.
     */
    listNetworkFirewallPolicies(listNetworkFirewallPoliciesRequest: requests.ListNetworkFirewallPoliciesRequest): Promise<responses.ListNetworkFirewallPoliciesResponse>;
    /**
     * Returns a list of NetworkFirewalls.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListNetworkFirewallsRequest
     * @return ListNetworkFirewallsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/networkfirewall/ListNetworkFirewalls.ts.html |here} to see how to use ListNetworkFirewalls API.
     */
    listNetworkFirewalls(listNetworkFirewallsRequest: requests.ListNetworkFirewallsRequest): Promise<responses.ListNetworkFirewallsResponse>;
    /**
     * Returns a list of Security Rule for the Network Firewall Policy.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListSecurityRulesRequest
     * @return ListSecurityRulesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/networkfirewall/ListSecurityRules.ts.html |here} to see how to use ListSecurityRules API.
     */
    listSecurityRules(listSecurityRulesRequest: requests.ListSecurityRulesRequest): Promise<responses.ListSecurityRulesResponse>;
    /**
     * Returns a list of ServiceLists for the policy.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListServiceListsRequest
     * @return ListServiceListsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/networkfirewall/ListServiceLists.ts.html |here} to see how to use ListServiceLists API.
     */
    listServiceLists(listServiceListsRequest: requests.ListServiceListsRequest): Promise<responses.ListServiceListsResponse>;
    /**
     * Returns a list of Services for the policy.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListServicesRequest
     * @return ListServicesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/networkfirewall/ListServices.ts.html |here} to see how to use ListServices API.
     */
    listServices(listServicesRequest: requests.ListServicesRequest): Promise<responses.ListServicesResponse>;
    /**
     * Returns a list of URL lists for the Network Firewall Policy.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListUrlListsRequest
     * @return ListUrlListsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/networkfirewall/ListUrlLists.ts.html |here} to see how to use ListUrlLists API.
     */
    listUrlLists(listUrlListsRequest: requests.ListUrlListsRequest): Promise<responses.ListUrlListsResponse>;
    /**
     * Return a (paginated) list of errors for a given work request.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListWorkRequestErrorsRequest
     * @return ListWorkRequestErrorsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/networkfirewall/ListWorkRequestErrors.ts.html |here} to see how to use ListWorkRequestErrors API.
     */
    listWorkRequestErrors(listWorkRequestErrorsRequest: requests.ListWorkRequestErrorsRequest): Promise<responses.ListWorkRequestErrorsResponse>;
    /**
     * Return a (paginated) list of logs for a given work request.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListWorkRequestLogsRequest
     * @return ListWorkRequestLogsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/networkfirewall/ListWorkRequestLogs.ts.html |here} to see how to use ListWorkRequestLogs API.
     */
    listWorkRequestLogs(listWorkRequestLogsRequest: requests.ListWorkRequestLogsRequest): Promise<responses.ListWorkRequestLogsResponse>;
    /**
     * Lists the work requests in a compartment.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListWorkRequestsRequest
     * @return ListWorkRequestsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/networkfirewall/ListWorkRequests.ts.html |here} to see how to use ListWorkRequests API.
     */
    listWorkRequests(listWorkRequestsRequest: requests.ListWorkRequestsRequest): Promise<responses.ListWorkRequestsResponse>;
    /**
     * Moves a NetworkFirewallPolicy resource from one version to latest version. When provided, If-Match is checked against ETag values of the resource.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param MigrateNetworkFirewallPolicyRequest
     * @return MigrateNetworkFirewallPolicyResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/networkfirewall/MigrateNetworkFirewallPolicy.ts.html |here} to see how to use MigrateNetworkFirewallPolicy API.
     */
    migrateNetworkFirewallPolicy(migrateNetworkFirewallPolicyRequest: requests.MigrateNetworkFirewallPolicyRequest): Promise<responses.MigrateNetworkFirewallPolicyResponse>;
    /**
     * Updates the Address list with the given name in the network firewall policy.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateAddressListRequest
     * @return UpdateAddressListResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/networkfirewall/UpdateAddressList.ts.html |here} to see how to use UpdateAddressList API.
     */
    updateAddressList(updateAddressListRequest: requests.UpdateAddressListRequest): Promise<responses.UpdateAddressListResponse>;
    /**
     * Updates the Application with the given name in the network firewall policy.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateApplicationRequest
     * @return UpdateApplicationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/networkfirewall/UpdateApplication.ts.html |here} to see how to use UpdateApplication API.
     */
    updateApplication(updateApplicationRequest: requests.UpdateApplicationRequest): Promise<responses.UpdateApplicationResponse>;
    /**
     * Updates the ApplicationGroup with the given name in the network firewall policy.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateApplicationGroupRequest
     * @return UpdateApplicationGroupResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/networkfirewall/UpdateApplicationGroup.ts.html |here} to see how to use UpdateApplicationGroup API.
     */
    updateApplicationGroup(updateApplicationGroupRequest: requests.UpdateApplicationGroupRequest): Promise<responses.UpdateApplicationGroupResponse>;
    /**
     * Updates the Decryption Profile with the given name in the network firewall policy.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateDecryptionProfileRequest
     * @return UpdateDecryptionProfileResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/networkfirewall/UpdateDecryptionProfile.ts.html |here} to see how to use UpdateDecryptionProfile API.
     */
    updateDecryptionProfile(updateDecryptionProfileRequest: requests.UpdateDecryptionProfileRequest): Promise<responses.UpdateDecryptionProfileResponse>;
    /**
     * Updates the Decryption Rule with the given name in the network firewall policy.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateDecryptionRuleRequest
     * @return UpdateDecryptionRuleResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/networkfirewall/UpdateDecryptionRule.ts.html |here} to see how to use UpdateDecryptionRule API.
     */
    updateDecryptionRule(updateDecryptionRuleRequest: requests.UpdateDecryptionRuleRequest): Promise<responses.UpdateDecryptionRuleResponse>;
    /**
     * Updates the Mapped Secret with the given name in the network firewall policy.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateMappedSecretRequest
     * @return UpdateMappedSecretResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/networkfirewall/UpdateMappedSecret.ts.html |here} to see how to use UpdateMappedSecret API.
     */
    updateMappedSecret(updateMappedSecretRequest: requests.UpdateMappedSecretRequest): Promise<responses.UpdateMappedSecretResponse>;
    /**
     * Updates the NetworkFirewall
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateNetworkFirewallRequest
     * @return UpdateNetworkFirewallResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/networkfirewall/UpdateNetworkFirewall.ts.html |here} to see how to use UpdateNetworkFirewall API.
     */
    updateNetworkFirewall(updateNetworkFirewallRequest: requests.UpdateNetworkFirewallRequest): Promise<responses.UpdateNetworkFirewallResponse>;
    /**
     * Updates the NetworkFirewallPolicy
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateNetworkFirewallPolicyRequest
     * @return UpdateNetworkFirewallPolicyResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/networkfirewall/UpdateNetworkFirewallPolicy.ts.html |here} to see how to use UpdateNetworkFirewallPolicy API.
     */
    updateNetworkFirewallPolicy(updateNetworkFirewallPolicyRequest: requests.UpdateNetworkFirewallPolicyRequest): Promise<responses.UpdateNetworkFirewallPolicyResponse>;
    /**
     * Updates the Security Rule with the given name in the network firewall policy.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateSecurityRuleRequest
     * @return UpdateSecurityRuleResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/networkfirewall/UpdateSecurityRule.ts.html |here} to see how to use UpdateSecurityRule API.
     */
    updateSecurityRule(updateSecurityRuleRequest: requests.UpdateSecurityRuleRequest): Promise<responses.UpdateSecurityRuleResponse>;
    /**
     * Updates the Service with the given name in the network firewall policy.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateServiceRequest
     * @return UpdateServiceResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/networkfirewall/UpdateService.ts.html |here} to see how to use UpdateService API.
     */
    updateService(updateServiceRequest: requests.UpdateServiceRequest): Promise<responses.UpdateServiceResponse>;
    /**
     * Updates the ServiceList with the given name in the network firewall policy.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateServiceListRequest
     * @return UpdateServiceListResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/networkfirewall/UpdateServiceList.ts.html |here} to see how to use UpdateServiceList API.
     */
    updateServiceList(updateServiceListRequest: requests.UpdateServiceListRequest): Promise<responses.UpdateServiceListResponse>;
    /**
     * Updates the Url list with the given name in the network firewall policy.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateUrlListRequest
     * @return UpdateUrlListResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/networkfirewall/UpdateUrlList.ts.html |here} to see how to use UpdateUrlList API.
     */
    updateUrlList(updateUrlListRequest: requests.UpdateUrlListRequest): Promise<responses.UpdateUrlListResponse>;
}
export {};
