/**
 * Oracle Cloud VMware Solution API
 * Use the Oracle Cloud VMware API to create SDDCs and manage ESXi hosts and software.
For more information, see [Oracle Cloud VMware Solution](/iaas/Content/VMware/Concepts/ocvsoverview.htm).

 * OpenAPI spec version: 20230701
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
/**
 * The SDDC information to be updated.
 * <p>
 **Important:** Only the {@code displayName}, {@code freeFormTags}, and {@code definedTags} attributes
 * affect the existing SDDC. Changing the other attributes affects the {@code Sddc} object, but not
 * the VMware environment currently running on that SDDC. Those other attributes are used
 * by the Oracle Cloud VMware Solution *only* for new ESXi hosts that you add to this
 * SDDC in the future with {@link #createEsxiHost(CreateEsxiHostRequest) createEsxiHost}.
 *
 */
export interface UpdateSddcDetails {
    /**
     * The [OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the SDDC.
     * SDDC name requirements are 1-16 character length limit, Must start with a letter, Must be English letters, numbers, - only, No repeating hyphens, Must be unique within the region.
     *
     */
    "displayName"?: string;
    /**
      * The version of bundled VMware software that the Oracle Cloud VMware Solution will
  * install on any new ESXi hosts that you add to this SDDC in the future unless a specific version is configured on the Cluster level.
  * <p>
  For the list of versions supported by the Oracle Cloud VMware Solution, see
  * {@link #listSupportedVmwareSoftwareVersions(ListSupportedVmwareSoftwareVersionsRequest) listSupportedVmwareSoftwareVersions}).
  *
      */
    "vmwareSoftwareVersion"?: string;
    /**
      * The version of bundled ESXi software that the Oracle Cloud VMware Solution will
  * install on any new ESXi hosts that you add to this SDDC in the future unless a specific version is configured on the Cluster level.
  * <p>
  For the list of versions supported by the Oracle Cloud VMware Solution, see
  * {@link #listSupportedVmwareSoftwareVersions(ListSupportedVmwareSoftwareVersionsRequest) listSupportedVmwareSoftwareVersions}).
  *
      */
    "esxiSoftwareVersion"?: string;
    /**
     * One or more public SSH keys to be included in the {@code ~/.ssh/authorized_keys} file for
     * the default user on each ESXi host, only when adding new ESXi hosts to this SDDC.
     * Use a newline character to separate multiple keys.
     * The SSH keys must be in the format required for the {@code authorized_keys} file.
     *
     */
    "sshAuthorizedKeys"?: string;
    /**
      * Free-form tags for this resource. Each tag is a simple key-value pair with no
  * predefined name, type, or namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
  * <p>
  Example: {@code {\"Department\": \"Finance\"}}
  *
      */
    "freeformTags"?: {
        [key: string]: string;
    };
    /**
      * Defined tags for this resource. Each key is predefined and scoped to a
  * namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
  * <p>
  Example: {@code {\"Operations\": {\"CostCenter\": \"42\"}}}
  *
      */
    "definedTags"?: {
        [key: string]: {
            [key: string]: any;
        };
    };
}
export declare namespace UpdateSddcDetails {
    function getJsonObj(obj: UpdateSddcDetails): object;
    function getDeserializedJsonObj(obj: UpdateSddcDetails): object;
}
