/**
 * Notifications API
 * Use the Notifications API to broadcast messages to distributed components by topic, using a publish-subscribe pattern.
For information about managing topics, subscriptions, and messages, see [Notifications Overview](/iaas/Content/Notification/Concepts/notificationoverview.htm).

 * OpenAPI spec version: 20181201
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * The subscription's configuration summary.
 *
 */
export interface SubscriptionSummary {
    /**
     * The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the subscription.
     *
     */
    "id": string;
    /**
     * The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the associated topic.
     *
     */
    "topicId": string;
    /**
      * The protocol used for the subscription.
  * <p>
  Allowed values:
  *   * {@code CUSTOM_HTTPS}
  *   * {@code EMAIL}
  *   * {@code HTTPS} (deprecated; for PagerDuty endpoints, use {@code PAGERDUTY})
  *   * {@code ORACLE_FUNCTIONS}
  *   * {@code PAGERDUTY}
  *   * {@code SLACK}
  *   * {@code SMS}
  * <p>
  For information about subscription protocols, see
  * [To create a subscription](https://docs.cloud.oracle.com/iaas/Content/Notification/Tasks/managingtopicsandsubscriptions.htm#createSub).
  *
      */
    "protocol": string;
    /**
     * A locator that corresponds to the subscription protocol.
     * For example, an email address for a subscription that uses the {@code EMAIL} protocol, or a URL for a subscription that uses an HTTP-based protocol.
     *
     */
    "endpoint": string;
    /**
     * The lifecycle state of the subscription. The status of a new subscription is PENDING; when confirmed, the subscription status changes to ACTIVE.
     *
     */
    "lifecycleState": SubscriptionSummary.LifecycleState;
    /**
     * The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment for the subscription.
     *
     */
    "compartmentId": string;
    /**
     * The time when this suscription was created. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "createdTime"?: number;
    "deliveryPolicy"?: model.DeliveryPolicy;
    /**
     * For optimistic concurrency control. See {@code if-match}.
     *
     */
    "etag"?: string;
    /**
      * Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
  * <p>
  Example: {@code {\"Department\": \"Finance\"}}
  *
      */
    "freeformTags"?: {
        [key: string]: string;
    };
    /**
      * Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
  * <p>
  Example: {@code {\"Operations\": {\"CostCenter\": \"42\"}}}
  *
      */
    "definedTags"?: {
        [key: string]: {
            [key: string]: any;
        };
    };
}
export declare namespace SubscriptionSummary {
    enum LifecycleState {
        Pending = "PENDING",
        Active = "ACTIVE",
        Deleted = "DELETED",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    function getJsonObj(obj: SubscriptionSummary): object;
    function getDeserializedJsonObj(obj: SubscriptionSummary): object;
}
