/**
 * OpenSearch Service API
 * The OpenSearch service API provides access to OCI Search Service with OpenSearch.
 * OpenAPI spec version: 20180828
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import common = require("oci-common");
import * as requests from "./request";
import * as responses from "./response";
import { OpensearchClusterWaiter } from "./opensearchcluster-waiter";
import { OpensearchClusterBackupWaiter } from "./opensearchclusterbackup-waiter";
declare const Breaker: any;
export declare enum OpensearchClusterApiKeys {
}
/**
 * This service client uses {@link common.CircuitBreaker.DefaultConfiguration} for all the operations by default if no circuit breaker configuration is defined by the user.
 */
export declare class OpensearchClusterClient {
    protected static serviceEndpointTemplate: string;
    protected static endpointServiceName: string;
    protected "_realmSpecificEndpointTemplateEnabled": boolean | undefined;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_waiters": OpensearchClusterWaiter;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: typeof Breaker | null;
    protected _httpOptions: any;
    protected _bodyDuplexMode: any;
    targetService: string;
    protected _regionId: string;
    protected "_region": common.Region;
    protected _lastSetRegionOrRegionId: string;
    protected _httpClient: common.HttpClient;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    get endpoint(): string;
    /**
     * Sets the endpoint to call (ex, https://www.example.com).
     * @param endpoint The endpoint of the service.
     */
    set endpoint(endpoint: string);
    get logger(): import("oci-common/lib/log").Logger;
    /**
     * Determines whether realm specific endpoint should be used or not.
     * Set realmSpecificEndpointTemplateEnabled to "true" if the user wants to enable use of realm specific endpoint template, otherwise set it to "false"
     * @param realmSpecificEndpointTemplateEnabled flag to enable the use of realm specific endpoint template
     */
    set useRealmSpecificEndpointTemplate(realmSpecificEndpointTemplateEnabled: boolean);
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    set region(region: common.Region);
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    set regionId(regionId: string);
    /**
     * Creates a new OpensearchClusterWaiter for resources for this service.
     *
     * @param config The waiter configuration for termination and delay strategy
     * @return The service waiters.
     */
    createWaiters(config?: common.WaiterConfiguration): OpensearchClusterWaiter;
    /**
     * Gets the waiters available for resources for this service.
     *
     * @return The service waiters.
     */
    getWaiters(): OpensearchClusterWaiter;
    /**
     * Shutdown the circuit breaker used by the client when it is no longer needed
     */
    shutdownCircuitBreaker(): void;
    /**
     * Close the client once it is no longer needed
     */
    close(): void;
    /**
     * Backup the opensearch cluster details.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param BackupOpensearchClusterRequest
     * @return BackupOpensearchClusterResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opensearch/BackupOpensearchCluster.ts.html |here} to see how to use BackupOpensearchCluster API.
     */
    backupOpensearchCluster(backupOpensearchClusterRequest: requests.BackupOpensearchClusterRequest): Promise<responses.BackupOpensearchClusterResponse>;
    /**
     * Creates a new OpensearchCluster.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateOpensearchClusterRequest
     * @return CreateOpensearchClusterResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opensearch/CreateOpensearchCluster.ts.html |here} to see how to use CreateOpensearchCluster API.
     */
    createOpensearchCluster(createOpensearchClusterRequest: requests.CreateOpensearchClusterRequest): Promise<responses.CreateOpensearchClusterResponse>;
    /**
     * Deletes a OpensearchCluster resource by identifier
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteOpensearchClusterRequest
     * @return DeleteOpensearchClusterResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opensearch/DeleteOpensearchCluster.ts.html |here} to see how to use DeleteOpensearchCluster API.
     */
    deleteOpensearchCluster(deleteOpensearchClusterRequest: requests.DeleteOpensearchClusterRequest): Promise<responses.DeleteOpensearchClusterResponse>;
    /**
     * Gets a OpensearchCluster by identifier
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetOpensearchClusterRequest
     * @return GetOpensearchClusterResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opensearch/GetOpensearchCluster.ts.html |here} to see how to use GetOpensearchCluster API.
     */
    getOpensearchCluster(getOpensearchClusterRequest: requests.GetOpensearchClusterRequest): Promise<responses.GetOpensearchClusterResponse>;
    /**
     * Gets the status of the work request with the given ID.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetWorkRequestRequest
     * @return GetWorkRequestResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opensearch/GetWorkRequest.ts.html |here} to see how to use GetWorkRequest API.
     */
    getWorkRequest(getWorkRequestRequest: requests.GetWorkRequestRequest): Promise<responses.GetWorkRequestResponse>;
    /**
     * Returns a list of OpensearchClusters.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListOpensearchClustersRequest
     * @return ListOpensearchClustersResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opensearch/ListOpensearchClusters.ts.html |here} to see how to use ListOpensearchClusters API.
     */
    listOpensearchClusters(listOpensearchClustersRequest: requests.ListOpensearchClustersRequest): Promise<responses.ListOpensearchClustersResponse>;
    /**
     * Lists the supported Opensearch versions
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListOpensearchVersionsRequest
     * @return ListOpensearchVersionsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opensearch/ListOpensearchVersions.ts.html |here} to see how to use ListOpensearchVersions API.
     */
    listOpensearchVersions(listOpensearchVersionsRequest: requests.ListOpensearchVersionsRequest): Promise<responses.ListOpensearchVersionsResponse>;
    /**
     * Return a (paginated) list of errors for a given work request.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListWorkRequestErrorsRequest
     * @return ListWorkRequestErrorsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opensearch/ListWorkRequestErrors.ts.html |here} to see how to use ListWorkRequestErrors API.
     */
    listWorkRequestErrors(listWorkRequestErrorsRequest: requests.ListWorkRequestErrorsRequest): Promise<responses.ListWorkRequestErrorsResponse>;
    /**
     * Return a (paginated) list of logs for a given work request.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListWorkRequestLogsRequest
     * @return ListWorkRequestLogsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opensearch/ListWorkRequestLogs.ts.html |here} to see how to use ListWorkRequestLogs API.
     */
    listWorkRequestLogs(listWorkRequestLogsRequest: requests.ListWorkRequestLogsRequest): Promise<responses.ListWorkRequestLogsResponse>;
    /**
     * Lists the work requests in a compartment.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListWorkRequestsRequest
     * @return ListWorkRequestsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opensearch/ListWorkRequests.ts.html |here} to see how to use ListWorkRequests API.
     */
    listWorkRequests(listWorkRequestsRequest: requests.ListWorkRequestsRequest): Promise<responses.ListWorkRequestsResponse>;
    /**
     * Restore the opensearch cluster details.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param OpensearchClusterRestoreRequest
     * @return OpensearchClusterRestoreResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opensearch/OpensearchClusterRestore.ts.html |here} to see how to use OpensearchClusterRestore API.
     */
    opensearchClusterRestore(opensearchClusterRestoreRequest: requests.OpensearchClusterRestoreRequest): Promise<responses.OpensearchClusterRestoreResponse>;
    /**
     * Resize the opensearch cluster horizontal details.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ResizeOpensearchClusterHorizontalRequest
     * @return ResizeOpensearchClusterHorizontalResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opensearch/ResizeOpensearchClusterHorizontal.ts.html |here} to see how to use ResizeOpensearchClusterHorizontal API.
     */
    resizeOpensearchClusterHorizontal(resizeOpensearchClusterHorizontalRequest: requests.ResizeOpensearchClusterHorizontalRequest): Promise<responses.ResizeOpensearchClusterHorizontalResponse>;
    /**
     * Resize the opensearch cluster vertical details.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ResizeOpensearchClusterVerticalRequest
     * @return ResizeOpensearchClusterVerticalResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opensearch/ResizeOpensearchClusterVertical.ts.html |here} to see how to use ResizeOpensearchClusterVertical API.
     */
    resizeOpensearchClusterVertical(resizeOpensearchClusterVerticalRequest: requests.ResizeOpensearchClusterVerticalRequest): Promise<responses.ResizeOpensearchClusterVerticalResponse>;
    /**
     * Updates the OpensearchCluster
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateOpensearchClusterRequest
     * @return UpdateOpensearchClusterResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opensearch/UpdateOpensearchCluster.ts.html |here} to see how to use UpdateOpensearchCluster API.
     */
    updateOpensearchCluster(updateOpensearchClusterRequest: requests.UpdateOpensearchClusterRequest): Promise<responses.UpdateOpensearchClusterResponse>;
}
export declare enum OpensearchClusterBackupApiKeys {
}
/**
 * This service client uses {@link common.CircuitBreaker.DefaultConfiguration} for all the operations by default if no circuit breaker configuration is defined by the user.
 */
export declare class OpensearchClusterBackupClient {
    protected static serviceEndpointTemplate: string;
    protected static endpointServiceName: string;
    protected "_realmSpecificEndpointTemplateEnabled": boolean | undefined;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_waiters": OpensearchClusterBackupWaiter;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: typeof Breaker | null;
    protected _httpOptions: any;
    protected _bodyDuplexMode: any;
    targetService: string;
    protected _regionId: string;
    protected "_region": common.Region;
    protected _lastSetRegionOrRegionId: string;
    protected _httpClient: common.HttpClient;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    get endpoint(): string;
    /**
     * Sets the endpoint to call (ex, https://www.example.com).
     * @param endpoint The endpoint of the service.
     */
    set endpoint(endpoint: string);
    get logger(): import("oci-common/lib/log").Logger;
    /**
     * Determines whether realm specific endpoint should be used or not.
     * Set realmSpecificEndpointTemplateEnabled to "true" if the user wants to enable use of realm specific endpoint template, otherwise set it to "false"
     * @param realmSpecificEndpointTemplateEnabled flag to enable the use of realm specific endpoint template
     */
    set useRealmSpecificEndpointTemplate(realmSpecificEndpointTemplateEnabled: boolean);
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    set region(region: common.Region);
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    set regionId(regionId: string);
    /**
     * Creates a new OpensearchClusterBackupWaiter for resources for this service.
     *
     * @param config The waiter configuration for termination and delay strategy
     * @return The service waiters.
     */
    createWaiters(config?: common.WaiterConfiguration): OpensearchClusterBackupWaiter;
    /**
     * Gets the waiters available for resources for this service.
     *
     * @return The service waiters.
     */
    getWaiters(): OpensearchClusterBackupWaiter;
    /**
     * Shutdown the circuit breaker used by the client when it is no longer needed
     */
    shutdownCircuitBreaker(): void;
    /**
     * Close the client once it is no longer needed
     */
    close(): void;
    /**
     * Deletes a OpensearchClusterBackup resource by identifier
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteOpensearchClusterBackupRequest
     * @return DeleteOpensearchClusterBackupResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opensearch/DeleteOpensearchClusterBackup.ts.html |here} to see how to use DeleteOpensearchClusterBackup API.
     */
    deleteOpensearchClusterBackup(deleteOpensearchClusterBackupRequest: requests.DeleteOpensearchClusterBackupRequest): Promise<responses.DeleteOpensearchClusterBackupResponse>;
    /**
     * Gets a OpensearchClusterBackup by identifier
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetOpensearchClusterBackupRequest
     * @return GetOpensearchClusterBackupResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opensearch/GetOpensearchClusterBackup.ts.html |here} to see how to use GetOpensearchClusterBackup API.
     */
    getOpensearchClusterBackup(getOpensearchClusterBackupRequest: requests.GetOpensearchClusterBackupRequest): Promise<responses.GetOpensearchClusterBackupResponse>;
    /**
     * Returns a list of OpensearchClusterBackups.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListOpensearchClusterBackupsRequest
     * @return ListOpensearchClusterBackupsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opensearch/ListOpensearchClusterBackups.ts.html |here} to see how to use ListOpensearchClusterBackups API.
     */
    listOpensearchClusterBackups(listOpensearchClusterBackupsRequest: requests.ListOpensearchClusterBackupsRequest): Promise<responses.ListOpensearchClusterBackupsResponse>;
    /**
     * Updates the OpensearchClusterBackup
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateOpensearchClusterBackupRequest
     * @return UpdateOpensearchClusterBackupResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opensearch/UpdateOpensearchClusterBackup.ts.html |here} to see how to use UpdateOpensearchClusterBackup API.
     */
    updateOpensearchClusterBackup(updateOpensearchClusterBackupRequest: requests.UpdateOpensearchClusterBackupRequest): Promise<responses.UpdateOpensearchClusterBackupResponse>;
}
export {};
