/**
 * Ops Insights API
 * Use the Ops Insights API to perform data extraction operations to obtain database
resource utilization, performance statistics, and reference information. For more information,
see [About Oracle Cloud Infrastructure Ops Insights](https://docs.cloud.oracle.com/en-us/iaas/operations-insights/doc/operations-insights.html).

 * OpenAPI spec version: 20200630
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import common = require("oci-common");
import * as requests from "./request";
import * as responses from "./response";
import { OperationsInsightsWaiter } from "./operationsinsights-waiter";
declare const Breaker: any;
export declare enum OperationsInsightsApiKeys {
}
/**
 * This service client uses {@link common.CircuitBreaker.DefaultConfiguration} for all the operations by default if no circuit breaker configuration is defined by the user.
 */
export declare class OperationsInsightsClient {
    protected static serviceEndpointTemplate: string;
    protected static endpointServiceName: string;
    protected "_realmSpecificEndpointTemplateEnabled": boolean | undefined;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_waiters": OperationsInsightsWaiter;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: typeof Breaker | null;
    protected _httpOptions: any;
    protected _bodyDuplexMode: any;
    targetService: string;
    protected _regionId: string;
    protected "_region": common.Region;
    protected _lastSetRegionOrRegionId: string;
    protected _httpClient: common.HttpClient;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    get endpoint(): string;
    /**
     * Sets the endpoint to call (ex, https://www.example.com).
     * @param endpoint The endpoint of the service.
     */
    set endpoint(endpoint: string);
    get logger(): import("oci-common/lib/log").Logger;
    /**
     * Determines whether realm specific endpoint should be used or not.
     * Set realmSpecificEndpointTemplateEnabled to "true" if the user wants to enable use of realm specific endpoint template, otherwise set it to "false"
     * @param realmSpecificEndpointTemplateEnabled flag to enable the use of realm specific endpoint template
     */
    set useRealmSpecificEndpointTemplate(realmSpecificEndpointTemplateEnabled: boolean);
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    set region(region: common.Region);
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    set regionId(regionId: string);
    /**
     * Creates a new OperationsInsightsWaiter for resources for this service.
     *
     * @param config The waiter configuration for termination and delay strategy
     * @return The service waiters.
     */
    createWaiters(config?: common.WaiterConfiguration): OperationsInsightsWaiter;
    /**
     * Gets the waiters available for resources for this service.
     *
     * @return The service waiters.
     */
    getWaiters(): OperationsInsightsWaiter;
    /**
     * Shutdown the circuit breaker used by the client when it is no longer needed
     */
    shutdownCircuitBreaker(): void;
    /**
     * Close the client once it is no longer needed
     */
    close(): void;
    /**
     * Add new members (e.g. databases and hosts) to an Exadata system in Operations Insights. Exadata-related metric collection and analysis will be started.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param AddExadataInsightMembersRequest
     * @return AddExadataInsightMembersResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/AddExadataInsightMembers.ts.html |here} to see how to use AddExadataInsightMembers API.
     */
    addExadataInsightMembers(addExadataInsightMembersRequest: requests.AddExadataInsightMembersRequest): Promise<responses.AddExadataInsightMembersResponse>;
    /**
     * Update connection detail for advanced features of Autonomous Database in Operations Insights.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ChangeAutonomousDatabaseInsightAdvancedFeaturesRequest
     * @return ChangeAutonomousDatabaseInsightAdvancedFeaturesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/ChangeAutonomousDatabaseInsightAdvancedFeatures.ts.html |here} to see how to use ChangeAutonomousDatabaseInsightAdvancedFeatures API.
     */
    changeAutonomousDatabaseInsightAdvancedFeatures(changeAutonomousDatabaseInsightAdvancedFeaturesRequest: requests.ChangeAutonomousDatabaseInsightAdvancedFeaturesRequest): Promise<responses.ChangeAutonomousDatabaseInsightAdvancedFeaturesResponse>;
    /**
     * Moves an AwrHubSource resource from one compartment to another. When provided, If-Match is checked against ETag values of the resource.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ChangeAwrHubSourceCompartmentRequest
     * @return ChangeAwrHubSourceCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/ChangeAwrHubSourceCompartment.ts.html |here} to see how to use ChangeAwrHubSourceCompartment API.
     */
    changeAwrHubSourceCompartment(changeAwrHubSourceCompartmentRequest: requests.ChangeAwrHubSourceCompartmentRequest): Promise<responses.ChangeAwrHubSourceCompartmentResponse>;
    /**
     * Moves a DatabaseInsight resource from one compartment identifier to another. When provided, If-Match is checked against ETag values of the resource.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ChangeDatabaseInsightCompartmentRequest
     * @return ChangeDatabaseInsightCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/ChangeDatabaseInsightCompartment.ts.html |here} to see how to use ChangeDatabaseInsightCompartment API.
     */
    changeDatabaseInsightCompartment(changeDatabaseInsightCompartmentRequest: requests.ChangeDatabaseInsightCompartmentRequest): Promise<responses.ChangeDatabaseInsightCompartmentResponse>;
    /**
     * Moves a EnterpriseManagerBridge resource from one compartment to another. When provided, If-Match is checked against ETag values of the resource.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ChangeEnterpriseManagerBridgeCompartmentRequest
     * @return ChangeEnterpriseManagerBridgeCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/ChangeEnterpriseManagerBridgeCompartment.ts.html |here} to see how to use ChangeEnterpriseManagerBridgeCompartment API.
     */
    changeEnterpriseManagerBridgeCompartment(changeEnterpriseManagerBridgeCompartmentRequest: requests.ChangeEnterpriseManagerBridgeCompartmentRequest): Promise<responses.ChangeEnterpriseManagerBridgeCompartmentResponse>;
    /**
     * Moves an Exadata insight resource from one compartment identifier to another. When provided, If-Match is checked against ETag values of the resource.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ChangeExadataInsightCompartmentRequest
     * @return ChangeExadataInsightCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/ChangeExadataInsightCompartment.ts.html |here} to see how to use ChangeExadataInsightCompartment API.
     */
    changeExadataInsightCompartment(changeExadataInsightCompartmentRequest: requests.ChangeExadataInsightCompartmentRequest): Promise<responses.ChangeExadataInsightCompartmentResponse>;
    /**
     * Moves a HostInsight resource from one compartment identifier to another. When provided, If-Match is checked against ETag values of the resource.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ChangeHostInsightCompartmentRequest
     * @return ChangeHostInsightCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/ChangeHostInsightCompartment.ts.html |here} to see how to use ChangeHostInsightCompartment API.
     */
    changeHostInsightCompartment(changeHostInsightCompartmentRequest: requests.ChangeHostInsightCompartmentRequest): Promise<responses.ChangeHostInsightCompartmentResponse>;
    /**
     * Moves a news report resource from one compartment identifier to another. When provided, If-Match is checked against ETag values of the resource.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ChangeNewsReportCompartmentRequest
     * @return ChangeNewsReportCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/ChangeNewsReportCompartment.ts.html |here} to see how to use ChangeNewsReportCompartment API.
     */
    changeNewsReportCompartment(changeNewsReportCompartmentRequest: requests.ChangeNewsReportCompartmentRequest): Promise<responses.ChangeNewsReportCompartmentResponse>;
    /**
     * Moves a private endpoint from one compartment to another. When provided, If-Match is checked against ETag values of the resource.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ChangeOperationsInsightsPrivateEndpointCompartmentRequest
     * @return ChangeOperationsInsightsPrivateEndpointCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/ChangeOperationsInsightsPrivateEndpointCompartment.ts.html |here} to see how to use ChangeOperationsInsightsPrivateEndpointCompartment API.
     */
    changeOperationsInsightsPrivateEndpointCompartment(changeOperationsInsightsPrivateEndpointCompartmentRequest: requests.ChangeOperationsInsightsPrivateEndpointCompartmentRequest): Promise<responses.ChangeOperationsInsightsPrivateEndpointCompartmentResponse>;
    /**
     * Moves a Operations Insights Warehouse resource from one compartment to another. When provided, If-Match is checked against ETag values of the resource.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ChangeOperationsInsightsWarehouseCompartmentRequest
     * @return ChangeOperationsInsightsWarehouseCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/ChangeOperationsInsightsWarehouseCompartment.ts.html |here} to see how to use ChangeOperationsInsightsWarehouseCompartment API.
     */
    changeOperationsInsightsWarehouseCompartment(changeOperationsInsightsWarehouseCompartmentRequest: requests.ChangeOperationsInsightsWarehouseCompartmentRequest): Promise<responses.ChangeOperationsInsightsWarehouseCompartmentResponse>;
    /**
     * Moves an OpsiConfiguration resource from one compartment to another.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ChangeOpsiConfigurationCompartmentRequest
     * @return ChangeOpsiConfigurationCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/ChangeOpsiConfigurationCompartment.ts.html |here} to see how to use ChangeOpsiConfigurationCompartment API.
     */
    changeOpsiConfigurationCompartment(changeOpsiConfigurationCompartmentRequest: requests.ChangeOpsiConfigurationCompartmentRequest): Promise<responses.ChangeOpsiConfigurationCompartmentResponse>;
    /**
     * Change the connection details of a co-managed  database insight. When provided, If-Match is checked against ETag values of the resource.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ChangePeComanagedDatabaseInsightRequest
     * @return ChangePeComanagedDatabaseInsightResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/ChangePeComanagedDatabaseInsight.ts.html |here} to see how to use ChangePeComanagedDatabaseInsight API.
     */
    changePeComanagedDatabaseInsight(changePeComanagedDatabaseInsightRequest: requests.ChangePeComanagedDatabaseInsightRequest): Promise<responses.ChangePeComanagedDatabaseInsightResponse>;
    /**
     * Create a AWR hub resource for the tenant in Operations Insights.
     * This resource will be created in root compartment.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateAwrHubRequest
     * @return CreateAwrHubResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/CreateAwrHub.ts.html |here} to see how to use CreateAwrHub API.
     */
    createAwrHub(createAwrHubRequest: requests.CreateAwrHubRequest): Promise<responses.CreateAwrHubResponse>;
    /**
     * Register Awr Hub source
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateAwrHubSourceRequest
     * @return CreateAwrHubSourceResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/CreateAwrHubSource.ts.html |here} to see how to use CreateAwrHubSource API.
     */
    createAwrHubSource(createAwrHubSourceRequest: requests.CreateAwrHubSourceRequest): Promise<responses.CreateAwrHubSourceResponse>;
    /**
     * Create a Database Insight resource for a database in Operations Insights. The database will be enabled in Operations Insights. Database metric collection and analysis will be started.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateDatabaseInsightRequest
     * @return CreateDatabaseInsightResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/CreateDatabaseInsight.ts.html |here} to see how to use CreateDatabaseInsight API.
     */
    createDatabaseInsight(createDatabaseInsightRequest: requests.CreateDatabaseInsightRequest): Promise<responses.CreateDatabaseInsightResponse>;
    /**
     * Create a Enterprise Manager bridge in Operations Insights.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateEnterpriseManagerBridgeRequest
     * @return CreateEnterpriseManagerBridgeResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/CreateEnterpriseManagerBridge.ts.html |here} to see how to use CreateEnterpriseManagerBridge API.
     */
    createEnterpriseManagerBridge(createEnterpriseManagerBridgeRequest: requests.CreateEnterpriseManagerBridgeRequest): Promise<responses.CreateEnterpriseManagerBridgeResponse>;
    /**
     * Create an Exadata insight resource for an Exadata system in Operations Insights. The Exadata system will be enabled in Operations Insights. Exadata-related metric collection and analysis will be started.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateExadataInsightRequest
     * @return CreateExadataInsightResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/CreateExadataInsight.ts.html |here} to see how to use CreateExadataInsight API.
     */
    createExadataInsight(createExadataInsightRequest: requests.CreateExadataInsightRequest): Promise<responses.CreateExadataInsightResponse>;
    /**
     * Create a Host Insight resource for a host in Ops Insights. The host will be enabled in Ops Insights. Host metric collection and analysis will be started.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateHostInsightRequest
     * @return CreateHostInsightResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/CreateHostInsight.ts.html |here} to see how to use CreateHostInsight API.
     */
    createHostInsight(createHostInsightRequest: requests.CreateHostInsightRequest): Promise<responses.CreateHostInsightResponse>;
    /**
     * Create a news report in Ops Insights. The report will be enabled in Ops Insights. Insights will be emailed as per selected frequency.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateNewsReportRequest
     * @return CreateNewsReportResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/CreateNewsReport.ts.html |here} to see how to use CreateNewsReport API.
     */
    createNewsReport(createNewsReportRequest: requests.CreateNewsReportRequest): Promise<responses.CreateNewsReportResponse>;
    /**
     * Create a private endpoint resource for the tenant in Ops Insights.
     * This resource will be created in customer compartment.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateOperationsInsightsPrivateEndpointRequest
     * @return CreateOperationsInsightsPrivateEndpointResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/CreateOperationsInsightsPrivateEndpoint.ts.html |here} to see how to use CreateOperationsInsightsPrivateEndpoint API.
     */
    createOperationsInsightsPrivateEndpoint(createOperationsInsightsPrivateEndpointRequest: requests.CreateOperationsInsightsPrivateEndpointRequest): Promise<responses.CreateOperationsInsightsPrivateEndpointResponse>;
    /**
     * Create a Ops Insights Warehouse resource for the tenant in Ops Insights. New ADW will be provisioned for this tenant.
     * There is only expected to be 1 warehouse per tenant. The warehouse is expected to be in the root compartment. If the 'opsi-warehouse-type'
     * header is passed to the API, a warehouse resource without ADW or Schema provisioning is created.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateOperationsInsightsWarehouseRequest
     * @return CreateOperationsInsightsWarehouseResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/CreateOperationsInsightsWarehouse.ts.html |here} to see how to use CreateOperationsInsightsWarehouse API.
     */
    createOperationsInsightsWarehouse(createOperationsInsightsWarehouseRequest: requests.CreateOperationsInsightsWarehouseRequest): Promise<responses.CreateOperationsInsightsWarehouseResponse>;
    /**
     * Create a Operations Insights Warehouse user resource for the tenant in Operations Insights.
     * This resource will be created in root compartment.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateOperationsInsightsWarehouseUserRequest
     * @return CreateOperationsInsightsWarehouseUserResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/CreateOperationsInsightsWarehouseUser.ts.html |here} to see how to use CreateOperationsInsightsWarehouseUser API.
     */
    createOperationsInsightsWarehouseUser(createOperationsInsightsWarehouseUserRequest: requests.CreateOperationsInsightsWarehouseUserRequest): Promise<responses.CreateOperationsInsightsWarehouseUserResponse>;
    /**
     * Create an OPSI configuration resource.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateOpsiConfigurationRequest
     * @return CreateOpsiConfigurationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/CreateOpsiConfiguration.ts.html |here} to see how to use CreateOpsiConfiguration API.
     */
    createOpsiConfiguration(createOpsiConfigurationRequest: requests.CreateOpsiConfigurationRequest): Promise<responses.CreateOpsiConfigurationResponse>;
    /**
     * Deletes an AWR hub.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteAwrHubRequest
     * @return DeleteAwrHubResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/DeleteAwrHub.ts.html |here} to see how to use DeleteAwrHub API.
     */
    deleteAwrHub(deleteAwrHubRequest: requests.DeleteAwrHubRequest): Promise<responses.DeleteAwrHubResponse>;
    /**
     * Deletes an Awr Hub object.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteAwrHubObjectRequest
     * @return DeleteAwrHubObjectResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/DeleteAwrHubObject.ts.html |here} to see how to use DeleteAwrHubObject API.
     */
    deleteAwrHubObject(deleteAwrHubObjectRequest: requests.DeleteAwrHubObjectRequest): Promise<responses.DeleteAwrHubObjectResponse>;
    /**
     * Deletes an Awr Hub source object.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteAwrHubSourceRequest
     * @return DeleteAwrHubSourceResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/DeleteAwrHubSource.ts.html |here} to see how to use DeleteAwrHubSource API.
     */
    deleteAwrHubSource(deleteAwrHubSourceRequest: requests.DeleteAwrHubSourceRequest): Promise<responses.DeleteAwrHubSourceResponse>;
    /**
     * Deletes a database insight. The database insight will be deleted and cannot be enabled again.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteDatabaseInsightRequest
     * @return DeleteDatabaseInsightResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/DeleteDatabaseInsight.ts.html |here} to see how to use DeleteDatabaseInsight API.
     */
    deleteDatabaseInsight(deleteDatabaseInsightRequest: requests.DeleteDatabaseInsightRequest): Promise<responses.DeleteDatabaseInsightResponse>;
    /**
     * Deletes an Operations Insights Enterprise Manager bridge. If any database insight is still referencing this bridge, the operation will fail.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteEnterpriseManagerBridgeRequest
     * @return DeleteEnterpriseManagerBridgeResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/DeleteEnterpriseManagerBridge.ts.html |here} to see how to use DeleteEnterpriseManagerBridge API.
     */
    deleteEnterpriseManagerBridge(deleteEnterpriseManagerBridgeRequest: requests.DeleteEnterpriseManagerBridgeRequest): Promise<responses.DeleteEnterpriseManagerBridgeResponse>;
    /**
     * Deletes an Exadata insight. The Exadata insight will be deleted and cannot be enabled again.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteExadataInsightRequest
     * @return DeleteExadataInsightResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/DeleteExadataInsight.ts.html |here} to see how to use DeleteExadataInsight API.
     */
    deleteExadataInsight(deleteExadataInsightRequest: requests.DeleteExadataInsightRequest): Promise<responses.DeleteExadataInsightResponse>;
    /**
     * Deletes a host insight. The host insight will be deleted and cannot be enabled again.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteHostInsightRequest
     * @return DeleteHostInsightResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/DeleteHostInsight.ts.html |here} to see how to use DeleteHostInsight API.
     */
    deleteHostInsight(deleteHostInsightRequest: requests.DeleteHostInsightRequest): Promise<responses.DeleteHostInsightResponse>;
    /**
     * Deletes a news report. The news report will be deleted and cannot be enabled again.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteNewsReportRequest
     * @return DeleteNewsReportResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/DeleteNewsReport.ts.html |here} to see how to use DeleteNewsReport API.
     */
    deleteNewsReport(deleteNewsReportRequest: requests.DeleteNewsReportRequest): Promise<responses.DeleteNewsReportResponse>;
    /**
     * Deletes a private endpoint.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteOperationsInsightsPrivateEndpointRequest
     * @return DeleteOperationsInsightsPrivateEndpointResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/DeleteOperationsInsightsPrivateEndpoint.ts.html |here} to see how to use DeleteOperationsInsightsPrivateEndpoint API.
     */
    deleteOperationsInsightsPrivateEndpoint(deleteOperationsInsightsPrivateEndpointRequest: requests.DeleteOperationsInsightsPrivateEndpointRequest): Promise<responses.DeleteOperationsInsightsPrivateEndpointResponse>;
    /**
     * Deletes an Operations Insights Warehouse. There is only expected to be 1 warehouse per tenant.
     * The warehouse is expected to be in the root compartment.
     * User must delete AWR Hub resource for this warehouse before calling this operation.
     * User must delete the warehouse users before calling this operation.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteOperationsInsightsWarehouseRequest
     * @return DeleteOperationsInsightsWarehouseResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/DeleteOperationsInsightsWarehouse.ts.html |here} to see how to use DeleteOperationsInsightsWarehouse API.
     */
    deleteOperationsInsightsWarehouse(deleteOperationsInsightsWarehouseRequest: requests.DeleteOperationsInsightsWarehouseRequest): Promise<responses.DeleteOperationsInsightsWarehouseResponse>;
    /**
     * Deletes an Operations Insights Warehouse User.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteOperationsInsightsWarehouseUserRequest
     * @return DeleteOperationsInsightsWarehouseUserResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/DeleteOperationsInsightsWarehouseUser.ts.html |here} to see how to use DeleteOperationsInsightsWarehouseUser API.
     */
    deleteOperationsInsightsWarehouseUser(deleteOperationsInsightsWarehouseUserRequest: requests.DeleteOperationsInsightsWarehouseUserRequest): Promise<responses.DeleteOperationsInsightsWarehouseUserResponse>;
    /**
     * Deletes an OPSI configuration resource.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteOpsiConfigurationRequest
     * @return DeleteOpsiConfigurationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/DeleteOpsiConfiguration.ts.html |here} to see how to use DeleteOpsiConfiguration API.
     */
    deleteOpsiConfiguration(deleteOpsiConfigurationRequest: requests.DeleteOpsiConfigurationRequest): Promise<responses.DeleteOpsiConfigurationResponse>;
    /**
     * Disable advanced features for an Autonomous Database in Operations Insights. The connection detail and advanced features will be removed.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DisableAutonomousDatabaseInsightAdvancedFeaturesRequest
     * @return DisableAutonomousDatabaseInsightAdvancedFeaturesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/DisableAutonomousDatabaseInsightAdvancedFeatures.ts.html |here} to see how to use DisableAutonomousDatabaseInsightAdvancedFeatures API.
     */
    disableAutonomousDatabaseInsightAdvancedFeatures(disableAutonomousDatabaseInsightAdvancedFeaturesRequest: requests.DisableAutonomousDatabaseInsightAdvancedFeaturesRequest): Promise<responses.DisableAutonomousDatabaseInsightAdvancedFeaturesResponse>;
    /**
     * Disables a Awr Hub source database in Operations Insights. This will stop the Awr data flow for the given Awr Hub source.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DisableAwrHubSourceRequest
     * @return DisableAwrHubSourceResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/DisableAwrHubSource.ts.html |here} to see how to use DisableAwrHubSource API.
     */
    disableAwrHubSource(disableAwrHubSourceRequest: requests.DisableAwrHubSourceRequest): Promise<responses.DisableAwrHubSourceResponse>;
    /**
     * Disables a database in Operations Insights. Database metric collection and analysis will be stopped.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DisableDatabaseInsightRequest
     * @return DisableDatabaseInsightResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/DisableDatabaseInsight.ts.html |here} to see how to use DisableDatabaseInsight API.
     */
    disableDatabaseInsight(disableDatabaseInsightRequest: requests.DisableDatabaseInsightRequest): Promise<responses.DisableDatabaseInsightResponse>;
    /**
     * Disables an Exadata system in Operations Insights. Exadata-related metric collection and analysis will be stopped.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DisableExadataInsightRequest
     * @return DisableExadataInsightResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/DisableExadataInsight.ts.html |here} to see how to use DisableExadataInsight API.
     */
    disableExadataInsight(disableExadataInsightRequest: requests.DisableExadataInsightRequest): Promise<responses.DisableExadataInsightResponse>;
    /**
     * Disables a host in Ops Insights. Host metric collection and analysis will be stopped.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DisableHostInsightRequest
     * @return DisableHostInsightResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/DisableHostInsight.ts.html |here} to see how to use DisableHostInsight API.
     */
    disableHostInsight(disableHostInsightRequest: requests.DisableHostInsightRequest): Promise<responses.DisableHostInsightResponse>;
    /**
     * Download the ADW wallet for Operations Insights Warehouse using which the Hub data is exposed.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DownloadOperationsInsightsWarehouseWalletRequest
     * @return DownloadOperationsInsightsWarehouseWalletResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/DownloadOperationsInsightsWarehouseWallet.ts.html |here} to see how to use DownloadOperationsInsightsWarehouseWallet API.
     */
    downloadOperationsInsightsWarehouseWallet(downloadOperationsInsightsWarehouseWalletRequest: requests.DownloadOperationsInsightsWarehouseWalletRequest): Promise<responses.DownloadOperationsInsightsWarehouseWalletResponse>;
    /**
     * Enables advanced features for an Autonomous Database in Operations Insights. A direct connection will be available for further collection.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param EnableAutonomousDatabaseInsightAdvancedFeaturesRequest
     * @return EnableAutonomousDatabaseInsightAdvancedFeaturesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/EnableAutonomousDatabaseInsightAdvancedFeatures.ts.html |here} to see how to use EnableAutonomousDatabaseInsightAdvancedFeatures API.
     */
    enableAutonomousDatabaseInsightAdvancedFeatures(enableAutonomousDatabaseInsightAdvancedFeaturesRequest: requests.EnableAutonomousDatabaseInsightAdvancedFeaturesRequest): Promise<responses.EnableAutonomousDatabaseInsightAdvancedFeaturesResponse>;
    /**
     * Enables a Awr Hub source database in Operations Insights. This will resume the Awr data flow for the given Awr Hub source if it was stopped earlier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param EnableAwrHubSourceRequest
     * @return EnableAwrHubSourceResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/EnableAwrHubSource.ts.html |here} to see how to use EnableAwrHubSource API.
     */
    enableAwrHubSource(enableAwrHubSourceRequest: requests.EnableAwrHubSourceRequest): Promise<responses.EnableAwrHubSourceResponse>;
    /**
     * Enables a database in Operations Insights. Database metric collection and analysis will be started.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param EnableDatabaseInsightRequest
     * @return EnableDatabaseInsightResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/EnableDatabaseInsight.ts.html |here} to see how to use EnableDatabaseInsight API.
     */
    enableDatabaseInsight(enableDatabaseInsightRequest: requests.EnableDatabaseInsightRequest): Promise<responses.EnableDatabaseInsightResponse>;
    /**
     * Enables an Exadata system in Operations Insights. Exadata-related metric collection and analysis will be started.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param EnableExadataInsightRequest
     * @return EnableExadataInsightResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/EnableExadataInsight.ts.html |here} to see how to use EnableExadataInsight API.
     */
    enableExadataInsight(enableExadataInsightRequest: requests.EnableExadataInsightRequest): Promise<responses.EnableExadataInsightResponse>;
    /**
     * Enables a host in Ops Insights. Host metric collection and analysis will be started.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param EnableHostInsightRequest
     * @return EnableHostInsightResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/EnableHostInsight.ts.html |here} to see how to use EnableHostInsight API.
     */
    enableHostInsight(enableHostInsightRequest: requests.EnableHostInsightRequest): Promise<responses.EnableHostInsightResponse>;
    /**
     * Gets the AWR report for the specified database.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetAwrDatabaseReportRequest
     * @return GetAwrDatabaseReportResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/GetAwrDatabaseReport.ts.html |here} to see how to use GetAwrDatabaseReport API.
     */
    getAwrDatabaseReport(getAwrDatabaseReportRequest: requests.GetAwrDatabaseReportRequest): Promise<responses.GetAwrDatabaseReportResponse>;
    /**
     * Gets the SQL health check report for one SQL of the specified database.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetAwrDatabaseSqlReportRequest
     * @return GetAwrDatabaseSqlReportResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/GetAwrDatabaseSqlReport.ts.html |here} to see how to use GetAwrDatabaseSqlReport API.
     */
    getAwrDatabaseSqlReport(getAwrDatabaseSqlReportRequest: requests.GetAwrDatabaseSqlReportRequest): Promise<responses.GetAwrDatabaseSqlReportResponse>;
    /**
     * Gets details of an AWR hub.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetAwrHubRequest
     * @return GetAwrHubResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/GetAwrHub.ts.html |here} to see how to use GetAwrHub API.
     */
    getAwrHub(getAwrHubRequest: requests.GetAwrHubRequest): Promise<responses.GetAwrHubResponse>;
    /**
     * Gets the Awr Hub object metadata and body.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetAwrHubObjectRequest
     * @return GetAwrHubObjectResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/GetAwrHubObject.ts.html |here} to see how to use GetAwrHubObject API.
     */
    getAwrHubObject(getAwrHubObjectRequest: requests.GetAwrHubObjectRequest): Promise<responses.GetAwrHubObjectResponse>;
    /**
     * Gets the Awr Hub source object.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetAwrHubSourceRequest
     * @return GetAwrHubSourceResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/GetAwrHubSource.ts.html |here} to see how to use GetAwrHubSource API.
     */
    getAwrHubSource(getAwrHubSourceRequest: requests.GetAwrHubSourceRequest): Promise<responses.GetAwrHubSourceResponse>;
    /**
     * Gets the AWR report for the specified source database in the AWR hub. The difference between the timeGreaterThanOrEqualTo and timeLessThanOrEqualTo should not be greater than 7 days.
     * Either beginSnapshotIdentifierGreaterThanOrEqualTo & endSnapshotIdentifierLessThanOrEqualTo params Or timeGreaterThanOrEqualTo & timeLessThanOrEqualTo params are required.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetAwrReportRequest
     * @return GetAwrReportResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/GetAwrReport.ts.html |here} to see how to use GetAwrReport API.
     */
    getAwrReport(getAwrReportRequest: requests.GetAwrReportRequest): Promise<responses.GetAwrReportResponse>;
    /**
     * Gets details of a database insight.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetDatabaseInsightRequest
     * @return GetDatabaseInsightResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/GetDatabaseInsight.ts.html |here} to see how to use GetDatabaseInsight API.
     */
    getDatabaseInsight(getDatabaseInsightRequest: requests.GetDatabaseInsightRequest): Promise<responses.GetDatabaseInsightResponse>;
    /**
     * Gets details of an Operations Insights Enterprise Manager bridge.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetEnterpriseManagerBridgeRequest
     * @return GetEnterpriseManagerBridgeResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/GetEnterpriseManagerBridge.ts.html |here} to see how to use GetEnterpriseManagerBridge API.
     */
    getEnterpriseManagerBridge(getEnterpriseManagerBridgeRequest: requests.GetEnterpriseManagerBridgeRequest): Promise<responses.GetEnterpriseManagerBridgeResponse>;
    /**
     * Gets details of an Exadata insight.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetExadataInsightRequest
     * @return GetExadataInsightResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/GetExadataInsight.ts.html |here} to see how to use GetExadataInsight API.
     */
    getExadataInsight(getExadataInsightRequest: requests.GetExadataInsightRequest): Promise<responses.GetExadataInsightResponse>;
    /**
     * Gets details of a host insight.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetHostInsightRequest
     * @return GetHostInsightResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/GetHostInsight.ts.html |here} to see how to use GetHostInsight API.
     */
    getHostInsight(getHostInsightRequest: requests.GetHostInsightRequest): Promise<responses.GetHostInsightResponse>;
    /**
     * Gets details of a news report.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetNewsReportRequest
     * @return GetNewsReportResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/GetNewsReport.ts.html |here} to see how to use GetNewsReport API.
     */
    getNewsReport(getNewsReportRequest: requests.GetNewsReportRequest): Promise<responses.GetNewsReportResponse>;
    /**
     * Gets the details of the specified private endpoint.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetOperationsInsightsPrivateEndpointRequest
     * @return GetOperationsInsightsPrivateEndpointResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/GetOperationsInsightsPrivateEndpoint.ts.html |here} to see how to use GetOperationsInsightsPrivateEndpoint API.
     */
    getOperationsInsightsPrivateEndpoint(getOperationsInsightsPrivateEndpointRequest: requests.GetOperationsInsightsPrivateEndpointRequest): Promise<responses.GetOperationsInsightsPrivateEndpointResponse>;
    /**
     * Gets details of an Ops Insights Warehouse.
     * There is only expected to be 1 warehouse per tenant. The warehouse is expected to be in the root compartment.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetOperationsInsightsWarehouseRequest
     * @return GetOperationsInsightsWarehouseResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/GetOperationsInsightsWarehouse.ts.html |here} to see how to use GetOperationsInsightsWarehouse API.
     */
    getOperationsInsightsWarehouse(getOperationsInsightsWarehouseRequest: requests.GetOperationsInsightsWarehouseRequest): Promise<responses.GetOperationsInsightsWarehouseResponse>;
    /**
     * Gets details of an Operations Insights Warehouse User.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetOperationsInsightsWarehouseUserRequest
     * @return GetOperationsInsightsWarehouseUserResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/GetOperationsInsightsWarehouseUser.ts.html |here} to see how to use GetOperationsInsightsWarehouseUser API.
     */
    getOperationsInsightsWarehouseUser(getOperationsInsightsWarehouseUserRequest: requests.GetOperationsInsightsWarehouseUserRequest): Promise<responses.GetOperationsInsightsWarehouseUserResponse>;
    /**
     * Gets details of an OPSI configuration resource.
     * Values specified in configItemField and configItemCustomStatus query params will be considered, only if configItems field is requested as part of opsiConfigField query param.
     * Values specified in configItemCustomStatus will determine whether only customized configuration items or only non-customized configuration items or both have to be returned.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetOpsiConfigurationRequest
     * @return GetOpsiConfigurationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/GetOpsiConfiguration.ts.html |here} to see how to use GetOpsiConfiguration API.
     */
    getOpsiConfiguration(getOpsiConfigurationRequest: requests.GetOpsiConfigurationRequest): Promise<responses.GetOpsiConfigurationResponse>;
    /**
     * Gets details of an OPSI data object.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetOpsiDataObjectRequest
     * @return GetOpsiDataObjectResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/GetOpsiDataObject.ts.html |here} to see how to use GetOpsiDataObject API.
     */
    getOpsiDataObject(getOpsiDataObjectRequest: requests.GetOpsiDataObjectRequest): Promise<responses.GetOpsiDataObjectResponse>;
    /**
     * Gets the status of the work request with the given ID.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetWorkRequestRequest
     * @return GetWorkRequestResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/GetWorkRequest.ts.html |here} to see how to use GetWorkRequest API.
     */
    getWorkRequest(getWorkRequestRequest: requests.GetWorkRequestRequest): Promise<responses.GetWorkRequestResponse>;
    /**
     * Gets the Awr Hub object's user-defined metadata and entity tag (ETag).
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param HeadAwrHubObjectRequest
     * @return HeadAwrHubObjectResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/HeadAwrHubObject.ts.html |here} to see how to use HeadAwrHubObject API.
     */
    headAwrHubObject(headAwrHubObjectRequest: requests.HeadAwrHubObjectRequest): Promise<responses.HeadAwrHubObjectResponse>;
    /**
     * This endpoint takes in a JSON payload, persists it in Operation Insights ingest pipeline.
     * Either databaseId or id must be specified.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param IngestAddmReportsRequest
     * @return IngestAddmReportsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/IngestAddmReports.ts.html |here} to see how to use IngestAddmReports API.
     */
    ingestAddmReports(ingestAddmReportsRequest: requests.IngestAddmReportsRequest): Promise<responses.IngestAddmReportsResponse>;
    /**
     * This is a generic ingest endpoint for all database configuration metrics.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param IngestDatabaseConfigurationRequest
     * @return IngestDatabaseConfigurationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/IngestDatabaseConfiguration.ts.html |here} to see how to use IngestDatabaseConfiguration API.
     */
    ingestDatabaseConfiguration(ingestDatabaseConfigurationRequest: requests.IngestDatabaseConfigurationRequest): Promise<responses.IngestDatabaseConfigurationResponse>;
    /**
     * This is a generic ingest endpoint for all the host configuration metrics
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param IngestHostConfigurationRequest
     * @return IngestHostConfigurationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/IngestHostConfiguration.ts.html |here} to see how to use IngestHostConfiguration API.
     */
    ingestHostConfiguration(ingestHostConfigurationRequest: requests.IngestHostConfigurationRequest): Promise<responses.IngestHostConfigurationResponse>;
    /**
     * This is a generic ingest endpoint for all the host performance metrics
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param IngestHostMetricsRequest
     * @return IngestHostMetricsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/IngestHostMetrics.ts.html |here} to see how to use IngestHostMetrics API.
     */
    ingestHostMetrics(ingestHostMetricsRequest: requests.IngestHostMetricsRequest): Promise<responses.IngestHostMetricsResponse>;
    /**
     * The sqlbucket endpoint takes in a JSON payload, persists it in Ops Insights ingest pipeline.
     * Either databaseId or id must be specified.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param IngestSqlBucketRequest
     * @return IngestSqlBucketResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/IngestSqlBucket.ts.html |here} to see how to use IngestSqlBucket API.
     */
    ingestSqlBucket(ingestSqlBucketRequest: requests.IngestSqlBucketRequest): Promise<responses.IngestSqlBucketResponse>;
    /**
     * The SqlPlanLines endpoint takes in a JSON payload, persists it in Operation Insights ingest pipeline.
     * Either databaseId or id must be specified.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param IngestSqlPlanLinesRequest
     * @return IngestSqlPlanLinesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/IngestSqlPlanLines.ts.html |here} to see how to use IngestSqlPlanLines API.
     */
    ingestSqlPlanLines(ingestSqlPlanLinesRequest: requests.IngestSqlPlanLinesRequest): Promise<responses.IngestSqlPlanLinesResponse>;
    /**
     * The SQL Stats endpoint takes in a JSON payload, persists it in Ops Insights ingest pipeline.
     * Either databaseId or id must be specified.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param IngestSqlStatsRequest
     * @return IngestSqlStatsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/IngestSqlStats.ts.html |here} to see how to use IngestSqlStats API.
     */
    ingestSqlStats(ingestSqlStatsRequest: requests.IngestSqlStatsRequest): Promise<responses.IngestSqlStatsResponse>;
    /**
     * The SqlText endpoint takes in a JSON payload, persists it in Operation Insights ingest pipeline.
     * Either databaseId or id must be specified.
     * Disclaimer: SQL text being uploaded explicitly via APIs is not masked. Any sensitive literals contained in the sqlFullText column should be masked prior to ingestion.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param IngestSqlTextRequest
     * @return IngestSqlTextResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/IngestSqlText.ts.html |here} to see how to use IngestSqlText API.
     */
    ingestSqlText(ingestSqlTextRequest: requests.IngestSqlTextRequest): Promise<responses.IngestSqlTextResponse>;
    /**
     * Gets list of ADDM finding categories.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListAddmDbFindingCategoriesRequest
     * @return ListAddmDbFindingCategoriesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/ListAddmDbFindingCategories.ts.html |here} to see how to use ListAddmDbFindingCategories API.
     */
    listAddmDbFindingCategories(listAddmDbFindingCategoriesRequest: requests.ListAddmDbFindingCategoriesRequest): Promise<responses.ListAddmDbFindingCategoriesResponse>;
    /**
     * Get the ADDM findings time series for the specified databases for a given time period.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListAddmDbFindingsTimeSeriesRequest
     * @return ListAddmDbFindingsTimeSeriesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/ListAddmDbFindingsTimeSeries.ts.html |here} to see how to use ListAddmDbFindingsTimeSeries API.
     */
    listAddmDbFindingsTimeSeries(listAddmDbFindingsTimeSeriesRequest: requests.ListAddmDbFindingsTimeSeriesRequest): Promise<responses.ListAddmDbFindingsTimeSeriesResponse>;
    /**
     * Gets list of ADDM database parameter categories for the specified databases.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListAddmDbParameterCategoriesRequest
     * @return ListAddmDbParameterCategoriesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/ListAddmDbParameterCategories.ts.html |here} to see how to use ListAddmDbParameterCategories API.
     */
    listAddmDbParameterCategories(listAddmDbParameterCategoriesRequest: requests.ListAddmDbParameterCategoriesRequest): Promise<responses.ListAddmDbParameterCategoriesResponse>;
    /**
     * Gets list of ADDM recommendation categories for the specified databases.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListAddmDbRecommendationCategoriesRequest
     * @return ListAddmDbRecommendationCategoriesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/ListAddmDbRecommendationCategories.ts.html |here} to see how to use ListAddmDbRecommendationCategories API.
     */
    listAddmDbRecommendationCategories(listAddmDbRecommendationCategoriesRequest: requests.ListAddmDbRecommendationCategoriesRequest): Promise<responses.ListAddmDbRecommendationCategoriesResponse>;
    /**
     * Gets time series data for ADDM recommendations for the specified databases.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListAddmDbRecommendationsTimeSeriesRequest
     * @return ListAddmDbRecommendationsTimeSeriesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/ListAddmDbRecommendationsTimeSeries.ts.html |here} to see how to use ListAddmDbRecommendationsTimeSeries API.
     */
    listAddmDbRecommendationsTimeSeries(listAddmDbRecommendationsTimeSeriesRequest: requests.ListAddmDbRecommendationsTimeSeriesRequest): Promise<responses.ListAddmDbRecommendationsTimeSeriesResponse>;
    /**
     * Gets a list of ADDM database information
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListAddmDbsRequest
     * @return ListAddmDbsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/ListAddmDbs.ts.html |here} to see how to use ListAddmDbs API.
     */
    listAddmDbs(listAddmDbsRequest: requests.ListAddmDbsRequest): Promise<responses.ListAddmDbsResponse>;
    /**
     * Lists AWR snapshots for the specified database in the AWR.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListAwrDatabaseSnapshotsRequest
     * @return ListAwrDatabaseSnapshotsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/ListAwrDatabaseSnapshots.ts.html |here} to see how to use ListAwrDatabaseSnapshots API.
     */
    listAwrDatabaseSnapshots(listAwrDatabaseSnapshotsRequest: requests.ListAwrDatabaseSnapshotsRequest): Promise<responses.ListAwrDatabaseSnapshotsResponse>;
    /**
     * Gets the list of databases and their snapshot summary details available in the AWRHub.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListAwrDatabasesRequest
     * @return ListAwrDatabasesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/ListAwrDatabases.ts.html |here} to see how to use ListAwrDatabases API.
     */
    listAwrDatabases(listAwrDatabasesRequest: requests.ListAwrDatabasesRequest): Promise<responses.ListAwrDatabasesResponse>;
    /**
     * Gets a list of Awr Hub objects. Awr Hub id needs to specified.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListAwrHubObjectsRequest
     * @return ListAwrHubObjectsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/ListAwrHubObjects.ts.html |here} to see how to use ListAwrHubObjects API.
     */
    listAwrHubObjects(listAwrHubObjectsRequest: requests.ListAwrHubObjectsRequest): Promise<responses.ListAwrHubObjectsResponse>;
    /**
     * Gets a list of Awr Hub source objects.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListAwrHubSourcesRequest
     * @return ListAwrHubSourcesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/ListAwrHubSources.ts.html |here} to see how to use ListAwrHubSources API.
     */
    listAwrHubSources(listAwrHubSourcesRequest: requests.ListAwrHubSourcesRequest): Promise<responses.ListAwrHubSourcesResponse>;
    /**
     * Gets a list of AWR hubs. Either compartmentId or id must be specified. All these resources are expected to be in root compartment.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListAwrHubsRequest
     * @return ListAwrHubsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/ListAwrHubs.ts.html |here} to see how to use ListAwrHubs API.
     */
    listAwrHubs(listAwrHubsRequest: requests.ListAwrHubsRequest): Promise<responses.ListAwrHubsResponse>;
    /**
     * Lists AWR snapshots for the specified source database in the AWR hub. The difference between the timeGreaterThanOrEqualTo and timeLessThanOrEqualTo should not exceed an elapsed range of 1 day.
     * The timeGreaterThanOrEqualTo & timeLessThanOrEqualTo params are optional. If these params are not provided, by default last 1 day snapshots will be returned.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListAwrSnapshotsRequest
     * @return ListAwrSnapshotsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/ListAwrSnapshots.ts.html |here} to see how to use ListAwrSnapshots API.
     */
    listAwrSnapshots(listAwrSnapshotsRequest: requests.ListAwrSnapshotsRequest): Promise<responses.ListAwrSnapshotsResponse>;
    /**
     * Gets a list of database insight configurations based on the query parameters specified. Either compartmentId or databaseInsightId query parameter must be specified.
     * When both compartmentId and compartmentIdInSubtree are specified, a list of database insight configurations in that compartment and in all sub-compartments will be returned.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListDatabaseConfigurationsRequest
     * @return ListDatabaseConfigurationsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/ListDatabaseConfigurations.ts.html |here} to see how to use ListDatabaseConfigurations API.
     */
    listDatabaseConfigurations(listDatabaseConfigurationsRequest: requests.ListDatabaseConfigurationsRequest): Promise<responses.ListDatabaseConfigurationsResponse>;
    /**
     * Gets a list of database insights based on the query parameters specified. Either compartmentId or id query parameter must be specified.
     * When both compartmentId and compartmentIdInSubtree are specified, a list of database insights in that compartment and in all sub-compartments will be returned.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListDatabaseInsightsRequest
     * @return ListDatabaseInsightsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/ListDatabaseInsights.ts.html |here} to see how to use ListDatabaseInsights API.
     */
    listDatabaseInsights(listDatabaseInsightsRequest: requests.ListDatabaseInsightsRequest): Promise<responses.ListDatabaseInsightsResponse>;
    /**
     * Gets a list of Ops Insights Enterprise Manager bridges. Either compartmentId or id must be specified.
     * When both compartmentId and compartmentIdInSubtree are specified, a list of bridges in that compartment and in all sub-compartments will be returned.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListEnterpriseManagerBridgesRequest
     * @return ListEnterpriseManagerBridgesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/ListEnterpriseManagerBridges.ts.html |here} to see how to use ListEnterpriseManagerBridges API.
     */
    listEnterpriseManagerBridges(listEnterpriseManagerBridgesRequest: requests.ListEnterpriseManagerBridgesRequest): Promise<responses.ListEnterpriseManagerBridgesResponse>;
    /**
     * Gets a list of exadata insight configurations. Either compartmentId or exadataInsightsId query parameter must be specified.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListExadataConfigurationsRequest
     * @return ListExadataConfigurationsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/ListExadataConfigurations.ts.html |here} to see how to use ListExadataConfigurations API.
     */
    listExadataConfigurations(listExadataConfigurationsRequest: requests.ListExadataConfigurationsRequest): Promise<responses.ListExadataConfigurationsResponse>;
    /**
     * Gets a list of Exadata insights based on the query parameters specified. Either compartmentId or id query parameter must be specified.
     * When both compartmentId and compartmentIdInSubtree are specified, a list of Exadata insights in that compartment and in all sub-compartments will be returned.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListExadataInsightsRequest
     * @return ListExadataInsightsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/ListExadataInsights.ts.html |here} to see how to use ListExadataInsights API.
     */
    listExadataInsights(listExadataInsightsRequest: requests.ListExadataInsightsRequest): Promise<responses.ListExadataInsightsResponse>;
    /**
     * Gets a list of host insight configurations based on the query parameters specified. Either compartmentId or hostInsightId query parameter must be specified.
     * When both compartmentId and compartmentIdInSubtree are specified, a list of host insight configurations in that compartment and in all sub-compartments will be returned.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListHostConfigurationsRequest
     * @return ListHostConfigurationsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/ListHostConfigurations.ts.html |here} to see how to use ListHostConfigurations API.
     */
    listHostConfigurations(listHostConfigurationsRequest: requests.ListHostConfigurationsRequest): Promise<responses.ListHostConfigurationsResponse>;
    /**
     * Gets a list of host insights based on the query parameters specified. Either compartmentId or id query parameter must be specified.
     * When both compartmentId and compartmentIdInSubtree are specified, a list of host insights in that compartment and in all sub-compartments will be returned.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListHostInsightsRequest
     * @return ListHostInsightsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/ListHostInsights.ts.html |here} to see how to use ListHostInsights API.
     */
    listHostInsights(listHostInsightsRequest: requests.ListHostInsightsRequest): Promise<responses.ListHostInsightsResponse>;
    /**
     * Get a list of hosted entities details.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListHostedEntitiesRequest
     * @return ListHostedEntitiesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/ListHostedEntities.ts.html |here} to see how to use ListHostedEntities API.
     */
    listHostedEntities(listHostedEntitiesRequest: requests.ListHostedEntitiesRequest): Promise<responses.ListHostedEntitiesResponse>;
    /**
     * Gets a list of agent entities available to add a new hostInsight.  An agent entity is \"available\"
     * and will be shown if all the following conditions are true:
     *    1.  The agent OCID is not already being used for an existing hostInsight.
     *    2.  The agent availabilityStatus = 'ACTIVE'
     *    3.  The agent lifecycleState = 'ACTIVE'
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListImportableAgentEntitiesRequest
     * @return ListImportableAgentEntitiesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/ListImportableAgentEntities.ts.html |here} to see how to use ListImportableAgentEntities API.
     */
    listImportableAgentEntities(listImportableAgentEntitiesRequest: requests.ListImportableAgentEntitiesRequest): Promise<responses.ListImportableAgentEntitiesResponse>;
    /**
     * Gets a list of available compute intances running cloud agent to add a new hostInsight.  An Compute entity is \"available\"
     * and will be shown if all the following conditions are true:
     *    1. Compute is running OCA
     *    2. OCI Management Agent is not enabled or If OCI Management Agent is enabled
     *       2.1 The agent OCID is not already being used for an existing hostInsight.
     *       2.2 The agent availabilityStatus = 'ACTIVE'
     *       2.3 The agent lifecycleState = 'ACTIVE'
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListImportableComputeEntitiesRequest
     * @return ListImportableComputeEntitiesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/ListImportableComputeEntities.ts.html |here} to see how to use ListImportableComputeEntities API.
     */
    listImportableComputeEntities(listImportableComputeEntitiesRequest: requests.ListImportableComputeEntitiesRequest): Promise<responses.ListImportableComputeEntitiesResponse>;
    /**
     * Gets a list of importable entities for an Operations Insights Enterprise Manager bridge that have not been imported before.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListImportableEnterpriseManagerEntitiesRequest
     * @return ListImportableEnterpriseManagerEntitiesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/ListImportableEnterpriseManagerEntities.ts.html |here} to see how to use ListImportableEnterpriseManagerEntities API.
     */
    listImportableEnterpriseManagerEntities(listImportableEnterpriseManagerEntitiesRequest: requests.ListImportableEnterpriseManagerEntitiesRequest): Promise<responses.ListImportableEnterpriseManagerEntitiesResponse>;
    /**
     * Gets a list of news reports based on the query parameters specified. Either compartmentId or id query parameter must be specified.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListNewsReportsRequest
     * @return ListNewsReportsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/ListNewsReports.ts.html |here} to see how to use ListNewsReports API.
     */
    listNewsReports(listNewsReportsRequest: requests.ListNewsReportsRequest): Promise<responses.ListNewsReportsResponse>;
    /**
     * Gets a list of Operation Insights private endpoints.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListOperationsInsightsPrivateEndpointsRequest
     * @return ListOperationsInsightsPrivateEndpointsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/ListOperationsInsightsPrivateEndpoints.ts.html |here} to see how to use ListOperationsInsightsPrivateEndpoints API.
     */
    listOperationsInsightsPrivateEndpoints(listOperationsInsightsPrivateEndpointsRequest: requests.ListOperationsInsightsPrivateEndpointsRequest): Promise<responses.ListOperationsInsightsPrivateEndpointsResponse>;
    /**
     * Gets a list of Operations Insights Warehouse users. Either compartmentId or id must be specified. All these resources are expected to be in root compartment.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListOperationsInsightsWarehouseUsersRequest
     * @return ListOperationsInsightsWarehouseUsersResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/ListOperationsInsightsWarehouseUsers.ts.html |here} to see how to use ListOperationsInsightsWarehouseUsers API.
     */
    listOperationsInsightsWarehouseUsers(listOperationsInsightsWarehouseUsersRequest: requests.ListOperationsInsightsWarehouseUsersRequest): Promise<responses.ListOperationsInsightsWarehouseUsersResponse>;
    /**
     * Gets a list of Ops Insights warehouses. Either compartmentId or id must be specified.
     * There is only expected to be 1 warehouse per tenant. The warehouse is expected to be in the root compartment.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListOperationsInsightsWarehousesRequest
     * @return ListOperationsInsightsWarehousesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/ListOperationsInsightsWarehouses.ts.html |here} to see how to use ListOperationsInsightsWarehouses API.
     */
    listOperationsInsightsWarehouses(listOperationsInsightsWarehousesRequest: requests.ListOperationsInsightsWarehousesRequest): Promise<responses.ListOperationsInsightsWarehousesResponse>;
    /**
     * Gets a list of OPSI configuration resources based on the query parameters specified.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListOpsiConfigurationsRequest
     * @return ListOpsiConfigurationsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/ListOpsiConfigurations.ts.html |here} to see how to use ListOpsiConfigurations API.
     */
    listOpsiConfigurations(listOpsiConfigurationsRequest: requests.ListOpsiConfigurationsRequest): Promise<responses.ListOpsiConfigurationsResponse>;
    /**
     * Gets a list of OPSI data objects based on the query parameters specified. CompartmentId id query parameter must be specified.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListOpsiDataObjectsRequest
     * @return ListOpsiDataObjectsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/ListOpsiDataObjects.ts.html |here} to see how to use ListOpsiDataObjects API.
     */
    listOpsiDataObjects(listOpsiDataObjectsRequest: requests.ListOpsiDataObjectsRequest): Promise<responses.ListOpsiDataObjectsResponse>;
    /**
     * Query SQL Warehouse to list the plan xml for a given SQL execution plan. This returns a SqlPlanCollection object, but is currently limited to a single plan.
     * Either databaseId or id must be specified.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListSqlPlansRequest
     * @return ListSqlPlansResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/ListSqlPlans.ts.html |here} to see how to use ListSqlPlans API.
     */
    listSqlPlans(listSqlPlansRequest: requests.ListSqlPlansRequest): Promise<responses.ListSqlPlansResponse>;
    /**
     * Search SQL by SQL Identifier across databases in a compartment and in all sub-compartments if specified.
     * And get the SQL Text and the details of the databases executing the SQL for a given time period.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListSqlSearchesRequest
     * @return ListSqlSearchesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/ListSqlSearches.ts.html |here} to see how to use ListSqlSearches API.
     */
    listSqlSearches(listSqlSearchesRequest: requests.ListSqlSearchesRequest): Promise<responses.ListSqlSearchesResponse>;
    /**
     * Query SQL Warehouse to get the full SQL Text for a SQL in a compartment and in all sub-compartments if specified.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListSqlTextsRequest
     * @return ListSqlTextsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/ListSqlTexts.ts.html |here} to see how to use ListSqlTexts API.
     */
    listSqlTexts(listSqlTextsRequest: requests.ListSqlTextsRequest): Promise<responses.ListSqlTextsResponse>;
    /**
     * Gets a list of Warehouse data objects (e.g: views, tables), based on the query parameters specified.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListWarehouseDataObjectsRequest
     * @return ListWarehouseDataObjectsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/ListWarehouseDataObjects.ts.html |here} to see how to use ListWarehouseDataObjects API.
     */
    listWarehouseDataObjects(listWarehouseDataObjectsRequest: requests.ListWarehouseDataObjectsRequest): Promise<responses.ListWarehouseDataObjectsResponse>;
    /**
     * Return a (paginated) list of errors for a given work request.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListWorkRequestErrorsRequest
     * @return ListWorkRequestErrorsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/ListWorkRequestErrors.ts.html |here} to see how to use ListWorkRequestErrors API.
     */
    listWorkRequestErrors(listWorkRequestErrorsRequest: requests.ListWorkRequestErrorsRequest): Promise<responses.ListWorkRequestErrorsResponse>;
    /**
     * Return a (paginated) list of logs for a given work request.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListWorkRequestLogsRequest
     * @return ListWorkRequestLogsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/ListWorkRequestLogs.ts.html |here} to see how to use ListWorkRequestLogs API.
     */
    listWorkRequestLogs(listWorkRequestLogsRequest: requests.ListWorkRequestLogsRequest): Promise<responses.ListWorkRequestLogsResponse>;
    /**
     * Lists the work requests in a compartment. Either compartmentId or id must be specified. Only one of id, resourceId or relatedResourceId can be specified optionally.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListWorkRequestsRequest
     * @return ListWorkRequestsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/ListWorkRequests.ts.html |here} to see how to use ListWorkRequests API.
     */
    listWorkRequests(listWorkRequestsRequest: requests.ListWorkRequestsRequest): Promise<responses.ListWorkRequestsResponse>;
    /**
     * Creates a new object or overwrites an existing object with the same name to the Awr Hub.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param PutAwrHubObjectRequest
     * @return PutAwrHubObjectResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/PutAwrHubObject.ts.html |here} to see how to use PutAwrHubObject API.
     */
    putAwrHubObject(putAwrHubObjectRequest: requests.PutAwrHubObjectRequest): Promise<responses.PutAwrHubObjectResponse>;
    /**
     * Queries an OPSI data object with the inputs provided and sends the result set back. Either analysisTimeInterval
     * or timeIntervalStart and timeIntervalEnd parameters need to be passed as well.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param QueryOpsiDataObjectDataRequest
     * @return QueryOpsiDataObjectDataResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/QueryOpsiDataObjectData.ts.html |here} to see how to use QueryOpsiDataObjectData API.
     */
    queryOpsiDataObjectData(queryOpsiDataObjectDataRequest: requests.QueryOpsiDataObjectDataRequest): Promise<responses.QueryOpsiDataObjectDataResponse>;
    /**
     * Queries Warehouse data objects (e.g: views, tables) with the inputs provided and sends the result set back.
     * Any data to which an OperationsInsightsWarehouseUser with a permission to the corresponding Warehouse can be queried.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param QueryWarehouseDataObjectDataRequest
     * @return QueryWarehouseDataObjectDataResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/QueryWarehouseDataObjectData.ts.html |here} to see how to use QueryWarehouseDataObjectData API.
     */
    queryWarehouseDataObjectData(queryWarehouseDataObjectDataRequest: requests.QueryWarehouseDataObjectDataRequest): Promise<responses.QueryWarehouseDataObjectDataResponse>;
    /**
     * Rotate the ADW wallet for Operations Insights Warehouse using which the Hub data is exposed.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param RotateOperationsInsightsWarehouseWalletRequest
     * @return RotateOperationsInsightsWarehouseWalletResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/RotateOperationsInsightsWarehouseWallet.ts.html |here} to see how to use RotateOperationsInsightsWarehouseWallet API.
     */
    rotateOperationsInsightsWarehouseWallet(rotateOperationsInsightsWarehouseWalletRequest: requests.RotateOperationsInsightsWarehouseWalletRequest): Promise<responses.RotateOperationsInsightsWarehouseWalletResponse>;
    /**
     * Summarizes ADDM findings for the specified databases.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeAddmDbFindingsRequest
     * @return SummarizeAddmDbFindingsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/SummarizeAddmDbFindings.ts.html |here} to see how to use SummarizeAddmDbFindings API.
     */
    summarizeAddmDbFindings(summarizeAddmDbFindingsRequest: requests.SummarizeAddmDbFindingsRequest): Promise<responses.SummarizeAddmDbFindingsResponse>;
    /**
     * Summarizes the AWR database parameter change history for the specified parameter. There will
     * be one element for each time that parameter changed during the specified time period.
     * This API is limited to only one parameter per request.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeAddmDbParameterChangesRequest
     * @return SummarizeAddmDbParameterChangesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/SummarizeAddmDbParameterChanges.ts.html |here} to see how to use SummarizeAddmDbParameterChanges API.
     */
    summarizeAddmDbParameterChanges(summarizeAddmDbParameterChangesRequest: requests.SummarizeAddmDbParameterChangesRequest): Promise<responses.SummarizeAddmDbParameterChangesResponse>;
    /**
     * Summarizes database parameter history information for the specified databases. Return a list of parameters
     * with information on whether the parameter values were changed or not within the specified
     * time period. The response does not include the individual parameter changes within the time
     * period.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeAddmDbParametersRequest
     * @return SummarizeAddmDbParametersResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/SummarizeAddmDbParameters.ts.html |here} to see how to use SummarizeAddmDbParameters API.
     */
    summarizeAddmDbParameters(summarizeAddmDbParametersRequest: requests.SummarizeAddmDbParametersRequest): Promise<responses.SummarizeAddmDbParametersResponse>;
    /**
     * Summarizes ADDM recommendations for the specified databases.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeAddmDbRecommendationsRequest
     * @return SummarizeAddmDbRecommendationsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/SummarizeAddmDbRecommendations.ts.html |here} to see how to use SummarizeAddmDbRecommendations API.
     */
    summarizeAddmDbRecommendations(summarizeAddmDbRecommendationsRequest: requests.SummarizeAddmDbRecommendationsRequest): Promise<responses.SummarizeAddmDbRecommendationsResponse>;
    /**
     * Summarizes Schema objects for the specified databases for the specified objectIdentifiers
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeAddmDbSchemaObjectsRequest
     * @return SummarizeAddmDbSchemaObjectsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/SummarizeAddmDbSchemaObjects.ts.html |here} to see how to use SummarizeAddmDbSchemaObjects API.
     */
    summarizeAddmDbSchemaObjects(summarizeAddmDbSchemaObjectsRequest: requests.SummarizeAddmDbSchemaObjectsRequest): Promise<responses.SummarizeAddmDbSchemaObjectsResponse>;
    /**
     * Summarizes SQL Statements for the specified databases for the specified sqlIdentifiers
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeAddmDbSqlStatementsRequest
     * @return SummarizeAddmDbSqlStatementsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/SummarizeAddmDbSqlStatements.ts.html |here} to see how to use SummarizeAddmDbSqlStatements API.
     */
    summarizeAddmDbSqlStatements(summarizeAddmDbSqlStatementsRequest: requests.SummarizeAddmDbSqlStatementsRequest): Promise<responses.SummarizeAddmDbSqlStatementsResponse>;
    /**
     * Summarizes the AWR CPU resource limits and metrics for the specified database in AWR.
     * Based on the time range provided as part of query param, the metrics points will be returned in the response as below.
     * - if time range is <=7 days then the metrics points will be for every MINUTES
     * - if time range is <=2 hours then the metrics points will be for every 10 SECONDS
     * - if time range is >7 days then the metrics points will be for every HOUR.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeAwrDatabaseCpuUsagesRequest
     * @return SummarizeAwrDatabaseCpuUsagesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/SummarizeAwrDatabaseCpuUsages.ts.html |here} to see how to use SummarizeAwrDatabaseCpuUsages API.
     */
    summarizeAwrDatabaseCpuUsages(summarizeAwrDatabaseCpuUsagesRequest: requests.SummarizeAwrDatabaseCpuUsagesRequest): Promise<responses.SummarizeAwrDatabaseCpuUsagesResponse>;
    /**
     * Summarizes the metric samples for the specified database in the AWR. The metric samples are summarized based on the Time dimension for each metric.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeAwrDatabaseMetricsRequest
     * @return SummarizeAwrDatabaseMetricsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/SummarizeAwrDatabaseMetrics.ts.html |here} to see how to use SummarizeAwrDatabaseMetrics API.
     */
    summarizeAwrDatabaseMetrics(summarizeAwrDatabaseMetricsRequest: requests.SummarizeAwrDatabaseMetricsRequest): Promise<responses.SummarizeAwrDatabaseMetricsResponse>;
    /**
     * Summarizes the database parameter change history for one database parameter of the specified database in AWR. One change history record contains
     * the previous value, the changed value, and the corresponding time range. If the database parameter value was changed multiple times within the time range, then multiple change history records are created for the same parameter.
     * Note that this API only returns information on change history details for one database parameter.
     * To get a list of all the database parameters whose values were changed during a specified time range, use the following API endpoint:
     * /awrHubs/{awrHubId}/awrDbParameters?awrSourceDatabaseIdentifier={awrSourceDbId}
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeAwrDatabaseParameterChangesRequest
     * @return SummarizeAwrDatabaseParameterChangesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/SummarizeAwrDatabaseParameterChanges.ts.html |here} to see how to use SummarizeAwrDatabaseParameterChanges API.
     */
    summarizeAwrDatabaseParameterChanges(summarizeAwrDatabaseParameterChangesRequest: requests.SummarizeAwrDatabaseParameterChangesRequest): Promise<responses.SummarizeAwrDatabaseParameterChangesResponse>;
    /**
       * Summarizes the database parameter history for the specified database in AWR. This includes the list of database
  * parameters, with information on whether the parameter values were modified within the query time range. Note that
  * each database parameter is only listed once. Depending on the optional query parameters, the returned summary gets all the database parameters, which include:
  * <p>
  Queryparam (valueChanged =\"Y\") - Each parameter whose value was changed during the time range, \"isChanged : true\" in response for the DB params.
  * Queryparam (valueChanged =\"N\") - Each parameter whose value was unchanged during the time range, \"isChanged : false\" in response for the DB params.
  * Queryparam (valueChanged =\"Y\"  and valueModified = \"SYSTEM_MOD\") - Each parameter whose value was changed at the system level during the time range, \"isChanged : true\" & \"valueModified : SYSTEM_MOD\" in response for the DB params.
  * Queryparam (valueChanged =\"N\" and  valueDefault = \"FALSE\") - Each parameter whose value was unchanged during the time range, however, the value is not the default value, \"isChanged : true\" & \"isDefault : false\" in response for the DB params.
  * <p>
  Note that this API does not return information on the number of times each database parameter has been changed within the time range. To get the database parameter value change history for a specific parameter, use the following API endpoint:
  * /awrHubs/{awrHubId}/awrDbParameterChanges?awrSourceDatabaseIdentifier={awrSourceDbId}
  *
       * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
       * @param SummarizeAwrDatabaseParametersRequest
       * @return SummarizeAwrDatabaseParametersResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/SummarizeAwrDatabaseParameters.ts.html |here} to see how to use SummarizeAwrDatabaseParameters API.
       */
    summarizeAwrDatabaseParameters(summarizeAwrDatabaseParametersRequest: requests.SummarizeAwrDatabaseParametersRequest): Promise<responses.SummarizeAwrDatabaseParametersResponse>;
    /**
     * Summarizes the AWR snapshot ranges that contain continuous snapshots, for the specified AWRHub.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeAwrDatabaseSnapshotRangesRequest
     * @return SummarizeAwrDatabaseSnapshotRangesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/SummarizeAwrDatabaseSnapshotRanges.ts.html |here} to see how to use SummarizeAwrDatabaseSnapshotRanges API.
     */
    summarizeAwrDatabaseSnapshotRanges(summarizeAwrDatabaseSnapshotRangesRequest: requests.SummarizeAwrDatabaseSnapshotRangesRequest): Promise<responses.SummarizeAwrDatabaseSnapshotRangesResponse>;
    /**
     * Summarizes the AWR SYSSTAT sample data for the specified database in AWR. The statistical data is summarized based on the Time dimension for each statistic.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeAwrDatabaseSysstatsRequest
     * @return SummarizeAwrDatabaseSysstatsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/SummarizeAwrDatabaseSysstats.ts.html |here} to see how to use SummarizeAwrDatabaseSysstats API.
     */
    summarizeAwrDatabaseSysstats(summarizeAwrDatabaseSysstatsRequest: requests.SummarizeAwrDatabaseSysstatsRequest): Promise<responses.SummarizeAwrDatabaseSysstatsResponse>;
    /**
     * Summarizes the AWR top wait events.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeAwrDatabaseTopWaitEventsRequest
     * @return SummarizeAwrDatabaseTopWaitEventsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/SummarizeAwrDatabaseTopWaitEvents.ts.html |here} to see how to use SummarizeAwrDatabaseTopWaitEvents API.
     */
    summarizeAwrDatabaseTopWaitEvents(summarizeAwrDatabaseTopWaitEventsRequest: requests.SummarizeAwrDatabaseTopWaitEventsRequest): Promise<responses.SummarizeAwrDatabaseTopWaitEventsResponse>;
    /**
     * Summarizes AWR wait event data into value buckets and frequency, for the specified database in the AWR.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeAwrDatabaseWaitEventBucketsRequest
     * @return SummarizeAwrDatabaseWaitEventBucketsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/SummarizeAwrDatabaseWaitEventBuckets.ts.html |here} to see how to use SummarizeAwrDatabaseWaitEventBuckets API.
     */
    summarizeAwrDatabaseWaitEventBuckets(summarizeAwrDatabaseWaitEventBucketsRequest: requests.SummarizeAwrDatabaseWaitEventBucketsRequest): Promise<responses.SummarizeAwrDatabaseWaitEventBucketsResponse>;
    /**
     * Summarizes the AWR wait event sample data for the specified database in the AWR. The event data is summarized based on the Time dimension for each event.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeAwrDatabaseWaitEventsRequest
     * @return SummarizeAwrDatabaseWaitEventsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/SummarizeAwrDatabaseWaitEvents.ts.html |here} to see how to use SummarizeAwrDatabaseWaitEvents API.
     */
    summarizeAwrDatabaseWaitEvents(summarizeAwrDatabaseWaitEventsRequest: requests.SummarizeAwrDatabaseWaitEventsRequest): Promise<responses.SummarizeAwrDatabaseWaitEventsResponse>;
    /**
     * Gets a list of summary of AWR Sources.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeAwrSourcesSummariesRequest
     * @return SummarizeAwrSourcesSummariesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/SummarizeAwrSourcesSummaries.ts.html |here} to see how to use SummarizeAwrSourcesSummaries API.
     */
    summarizeAwrSourcesSummaries(summarizeAwrSourcesSummariesRequest: requests.SummarizeAwrSourcesSummariesRequest): Promise<responses.SummarizeAwrSourcesSummariesResponse>;
    /**
     * Gets the applicable configuration items based on the query parameters specified. Configuration items for an opsiConfigType with respect to a compartmentId can be fetched.
     * Values specified in configItemField param will determine what fields for each configuration items have to be returned.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeConfigurationItemsRequest
     * @return SummarizeConfigurationItemsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/SummarizeConfigurationItems.ts.html |here} to see how to use SummarizeConfigurationItems API.
     */
    summarizeConfigurationItems(summarizeConfigurationItemsRequest: requests.SummarizeConfigurationItemsRequest): Promise<responses.SummarizeConfigurationItemsResponse>;
    /**
     * Returns response with time series data (endTimestamp, capacity, baseCapacity) for the time period specified.
     * The maximum time range for analysis is 2 years, hence this is intentionally not paginated.
     * If compartmentIdInSubtree is specified, aggregates resources in a compartment and in all sub-compartments.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeDatabaseInsightResourceCapacityTrendRequest
     * @return SummarizeDatabaseInsightResourceCapacityTrendResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/SummarizeDatabaseInsightResourceCapacityTrend.ts.html |here} to see how to use SummarizeDatabaseInsightResourceCapacityTrend API.
     */
    summarizeDatabaseInsightResourceCapacityTrend(summarizeDatabaseInsightResourceCapacityTrendRequest: requests.SummarizeDatabaseInsightResourceCapacityTrendRequest): Promise<responses.SummarizeDatabaseInsightResourceCapacityTrendResponse>;
    /**
     * Get Forecast predictions for CPU and Storage resources since a time in the past.
     * If compartmentIdInSubtree is specified, aggregates resources in a compartment and in all sub-compartments.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeDatabaseInsightResourceForecastTrendRequest
     * @return SummarizeDatabaseInsightResourceForecastTrendResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/SummarizeDatabaseInsightResourceForecastTrend.ts.html |here} to see how to use SummarizeDatabaseInsightResourceForecastTrend API.
     */
    summarizeDatabaseInsightResourceForecastTrend(summarizeDatabaseInsightResourceForecastTrendRequest: requests.SummarizeDatabaseInsightResourceForecastTrendRequest): Promise<responses.SummarizeDatabaseInsightResourceForecastTrendResponse>;
    /**
     * Lists the Resource statistics (usage,capacity, usage change percent, utilization percent, base capacity, isAutoScalingEnabled)
     * for each database filtered by utilization level in a compartment and in all sub-compartments if specified.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeDatabaseInsightResourceStatisticsRequest
     * @return SummarizeDatabaseInsightResourceStatisticsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/SummarizeDatabaseInsightResourceStatistics.ts.html |here} to see how to use SummarizeDatabaseInsightResourceStatistics API.
     */
    summarizeDatabaseInsightResourceStatistics(summarizeDatabaseInsightResourceStatisticsRequest: requests.SummarizeDatabaseInsightResourceStatisticsRequest): Promise<responses.SummarizeDatabaseInsightResourceStatisticsResponse>;
    /**
     * A cumulative distribution function is used to rank the usage data points per database within the specified time period.
     * For each database, the minimum data point with a ranking > the percentile value is included in the summation.
     * Linear regression functions are used to calculate the usage change percentage.
     * If compartmentIdInSubtree is specified, aggregates resources in a compartment and in all sub-compartments.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeDatabaseInsightResourceUsageRequest
     * @return SummarizeDatabaseInsightResourceUsageResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/SummarizeDatabaseInsightResourceUsage.ts.html |here} to see how to use SummarizeDatabaseInsightResourceUsage API.
     */
    summarizeDatabaseInsightResourceUsage(summarizeDatabaseInsightResourceUsageRequest: requests.SummarizeDatabaseInsightResourceUsageRequest): Promise<responses.SummarizeDatabaseInsightResourceUsageResponse>;
    /**
     * Returns response with time series data (endTimestamp, usage, capacity) for the time period specified.
     * The maximum time range for analysis is 2 years, hence this is intentionally not paginated.
     * If compartmentIdInSubtree is specified, aggregates resources in a compartment and in all sub-compartments.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeDatabaseInsightResourceUsageTrendRequest
     * @return SummarizeDatabaseInsightResourceUsageTrendResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/SummarizeDatabaseInsightResourceUsageTrend.ts.html |here} to see how to use SummarizeDatabaseInsightResourceUsageTrend API.
     */
    summarizeDatabaseInsightResourceUsageTrend(summarizeDatabaseInsightResourceUsageTrendRequest: requests.SummarizeDatabaseInsightResourceUsageTrendRequest): Promise<responses.SummarizeDatabaseInsightResourceUsageTrendResponse>;
    /**
     * Gets resources with current utilization (high and low) and projected utilization (high and low) for a resource type over specified time period.
     * If compartmentIdInSubtree is specified, aggregates resources in a compartment and in all sub-compartments.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeDatabaseInsightResourceUtilizationInsightRequest
     * @return SummarizeDatabaseInsightResourceUtilizationInsightResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/SummarizeDatabaseInsightResourceUtilizationInsight.ts.html |here} to see how to use SummarizeDatabaseInsightResourceUtilizationInsight API.
     */
    summarizeDatabaseInsightResourceUtilizationInsight(summarizeDatabaseInsightResourceUtilizationInsightRequest: requests.SummarizeDatabaseInsightResourceUtilizationInsightRequest): Promise<responses.SummarizeDatabaseInsightResourceUtilizationInsightResponse>;
    /**
     * Returns response with usage time series data (endTimestamp, usage, capacity) with breakdown by tablespaceName for the time period specified.
     * The maximum time range for analysis is 2 years, hence this is intentionally not paginated.
     * Either databaseId or id must be specified.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeDatabaseInsightTablespaceUsageTrendRequest
     * @return SummarizeDatabaseInsightTablespaceUsageTrendResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/SummarizeDatabaseInsightTablespaceUsageTrend.ts.html |here} to see how to use SummarizeDatabaseInsightTablespaceUsageTrend API.
     */
    summarizeDatabaseInsightTablespaceUsageTrend(summarizeDatabaseInsightTablespaceUsageTrendRequest: requests.SummarizeDatabaseInsightTablespaceUsageTrendRequest): Promise<responses.SummarizeDatabaseInsightTablespaceUsageTrendResponse>;
    /**
     * Returns response with time series data (endTimestamp, capacity) for the time period specified for an exadata system for a resource metric.
     * Additionally resources can be filtered using databaseInsightId, hostInsightId or storageServerName query parameters.
     * Top five resources are returned if total exceeds the limit specified.
     * Valid values for ResourceType DATABASE are CPU,MEMORY,IO and STORAGE. Database name is returned in name field. DatabaseInsightId, cdbName and hostName query parameter applies to ResourceType DATABASE.
     * Valid values for ResourceType HOST are CPU and MEMORY. HostName is returned in name field. HostInsightId and hostName query parameter applies to ResourceType HOST.
     * Valid values for ResourceType STORAGE_SERVER are STORAGE, IOPS and THROUGHPUT. Storage server name is returned in name field for resourceMetric IOPS and THROUGHPUT
     * and asmName is returned in name field for resourceMetric STORAGE. StorageServerName query parameter applies to ResourceType STORAGE_SERVER.
     * Valid values for ResourceType DISKGROUP is STORAGE. Comma delimited (asmName,diskgroupName) is returned in name field.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeExadataInsightResourceCapacityTrendRequest
     * @return SummarizeExadataInsightResourceCapacityTrendResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/SummarizeExadataInsightResourceCapacityTrend.ts.html |here} to see how to use SummarizeExadataInsightResourceCapacityTrend API.
     */
    summarizeExadataInsightResourceCapacityTrend(summarizeExadataInsightResourceCapacityTrendRequest: requests.SummarizeExadataInsightResourceCapacityTrendRequest): Promise<responses.SummarizeExadataInsightResourceCapacityTrendResponse>;
    /**
     * Returns response with time series data (endTimestamp, capacity) for the time period specified for an exadata system or fleet aggregation for a resource metric.
     * The maximum time range for analysis is 2 years, hence this is intentionally not paginated.
     * Valid values for ResourceType DATABASE are CPU,MEMORY,IO and STORAGE.
     * Valid values for ResourceType HOST are CPU and MEMORY.
     * Valid values for ResourceType STORAGE_SERVER are STORAGE, IOPS and THROUGHPUT.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeExadataInsightResourceCapacityTrendAggregatedRequest
     * @return SummarizeExadataInsightResourceCapacityTrendAggregatedResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/SummarizeExadataInsightResourceCapacityTrendAggregated.ts.html |here} to see how to use SummarizeExadataInsightResourceCapacityTrendAggregated API.
     */
    summarizeExadataInsightResourceCapacityTrendAggregated(summarizeExadataInsightResourceCapacityTrendAggregatedRequest: requests.SummarizeExadataInsightResourceCapacityTrendAggregatedRequest): Promise<responses.SummarizeExadataInsightResourceCapacityTrendAggregatedResponse>;
    /**
     * Get historical usage and forecast predictions for an exadata system with breakdown by databases, hosts or storage servers.
     * Additionally resources can be filtered using databaseInsightId, hostInsightId or storageServerName query parameters.
     * Top five resources are returned if total exceeds the limit specified.
     * Valid values for ResourceType DATABASE are CPU,MEMORY,IO and STORAGE. Database name is returned in name field. DatabaseInsightId , cdbName and hostName query parameter applies to ResourceType DATABASE.
     * Valid values for ResourceType HOST are CPU and MEMORY. HostName s returned in name field. HostInsightId and hostName query parameter applies to ResourceType HOST.
     * Valid values for ResourceType STORAGE_SERVER are STORAGE, IOPS and THROUGHPUT. Storage server name is returned in name field for resourceMetric IOPS and THROUGHPUT
     * and asmName is returned in name field for resourceMetric STORAGE. StorageServerName query parameter applies to ResourceType STORAGE_SERVER.
     * Valid value for ResourceType DISKGROUP is STORAGE. Comma delimited (asmName,diskgroupName) is returned in name field.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeExadataInsightResourceForecastTrendRequest
     * @return SummarizeExadataInsightResourceForecastTrendResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/SummarizeExadataInsightResourceForecastTrend.ts.html |here} to see how to use SummarizeExadataInsightResourceForecastTrend API.
     */
    summarizeExadataInsightResourceForecastTrend(summarizeExadataInsightResourceForecastTrendRequest: requests.SummarizeExadataInsightResourceForecastTrendRequest): Promise<responses.SummarizeExadataInsightResourceForecastTrendResponse>;
    /**
     * Get aggregated historical usage and forecast predictions for resources. Either compartmentId or exadataInsightsId query parameter must be specified.
     * Valid values for ResourceType DATABASE are CPU,MEMORY,IO and STORAGE.
     * Valid values for ResourceType HOST are CPU and MEMORY.
     * Valid values for ResourceType STORAGE_SERVER are STORAGE, IOPS and THROUGHPUT.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeExadataInsightResourceForecastTrendAggregatedRequest
     * @return SummarizeExadataInsightResourceForecastTrendAggregatedResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/SummarizeExadataInsightResourceForecastTrendAggregated.ts.html |here} to see how to use SummarizeExadataInsightResourceForecastTrendAggregated API.
     */
    summarizeExadataInsightResourceForecastTrendAggregated(summarizeExadataInsightResourceForecastTrendAggregatedRequest: requests.SummarizeExadataInsightResourceForecastTrendAggregatedRequest): Promise<responses.SummarizeExadataInsightResourceForecastTrendAggregatedResponse>;
    /**
     * Lists the Resource statistics (usage, capacity, usage change percent, utilization percent) for each resource based on resourceMetric filtered by utilization level.
     * Valid values for ResourceType DATABASE are CPU,MEMORY,IO and STORAGE.
     * Valid values for ResourceType HOST are CPU and MEMORY.
     * Valid values for ResourceType STORAGE_SERVER are STORAGE, IOPS, THROUGHPUT.
     * Valid value for ResourceType DISKGROUP is STORAGE.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeExadataInsightResourceStatisticsRequest
     * @return SummarizeExadataInsightResourceStatisticsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/SummarizeExadataInsightResourceStatistics.ts.html |here} to see how to use SummarizeExadataInsightResourceStatistics API.
     */
    summarizeExadataInsightResourceStatistics(summarizeExadataInsightResourceStatisticsRequest: requests.SummarizeExadataInsightResourceStatisticsRequest): Promise<responses.SummarizeExadataInsightResourceStatisticsResponse>;
    /**
     * A cumulative distribution function is used to rank the usage data points per resource within the specified time period.
     * For each resource, the minimum data point with a ranking > the percentile value is included in the summation.
     * Linear regression functions are used to calculate the usage change percentage.
     * Valid values for ResourceType DATABASE are CPU,MEMORY,IO and STORAGE.
     * Valid values for ResourceType HOST are CPU and MEMORY.
     * Valid values for ResourceType STORAGE_SERVER are STORAGE, IOPS and THROUGHPUT.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeExadataInsightResourceUsageRequest
     * @return SummarizeExadataInsightResourceUsageResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/SummarizeExadataInsightResourceUsage.ts.html |here} to see how to use SummarizeExadataInsightResourceUsage API.
     */
    summarizeExadataInsightResourceUsage(summarizeExadataInsightResourceUsageRequest: requests.SummarizeExadataInsightResourceUsageRequest): Promise<responses.SummarizeExadataInsightResourceUsageResponse>;
    /**
     * A cumulative distribution function is used to rank the usage data points per database within the specified time period.
     * For each database, the minimum data point with a ranking > the percentile value is included in the summation.
     * Linear regression functions are used to calculate the usage change percentage.
     * Valid values for ResourceType DATABASE are CPU,MEMORY,IO and STORAGE.
     * Valid values for ResourceType HOST are CPU and MEMORY.
     * Valid values for ResourceType STORAGE_SERVER are STORAGE, IOPS and THROUGHPUT.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeExadataInsightResourceUsageAggregatedRequest
     * @return SummarizeExadataInsightResourceUsageAggregatedResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/SummarizeExadataInsightResourceUsageAggregated.ts.html |here} to see how to use SummarizeExadataInsightResourceUsageAggregated API.
     */
    summarizeExadataInsightResourceUsageAggregated(summarizeExadataInsightResourceUsageAggregatedRequest: requests.SummarizeExadataInsightResourceUsageAggregatedRequest): Promise<responses.SummarizeExadataInsightResourceUsageAggregatedResponse>;
    /**
     * Gets current utilization, projected utilization and days to reach projectedUtilization for an exadata system over specified time period. Valid values for ResourceType DATABASE are CPU,MEMORY,IO and STORAGE. Valid values for ResourceType HOST are CPU and MEMORY. Valid values for ResourceType STORAGE_SERVER are STORAGE, IOPS and THROUGHPUT.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeExadataInsightResourceUtilizationInsightRequest
     * @return SummarizeExadataInsightResourceUtilizationInsightResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/SummarizeExadataInsightResourceUtilizationInsight.ts.html |here} to see how to use SummarizeExadataInsightResourceUtilizationInsight API.
     */
    summarizeExadataInsightResourceUtilizationInsight(summarizeExadataInsightResourceUtilizationInsightRequest: requests.SummarizeExadataInsightResourceUtilizationInsightRequest): Promise<responses.SummarizeExadataInsightResourceUtilizationInsightResponse>;
    /**
     * Lists the software and hardware inventory of the Exadata System.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeExadataMembersRequest
     * @return SummarizeExadataMembersResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/SummarizeExadataMembers.ts.html |here} to see how to use SummarizeExadataMembers API.
     */
    summarizeExadataMembers(summarizeExadataMembersRequest: requests.SummarizeExadataMembersRequest): Promise<responses.SummarizeExadataMembersResponse>;
    /**
     * Returns response with disk(s) statistics for a host.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeHostInsightDiskStatisticsRequest
     * @return SummarizeHostInsightDiskStatisticsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/SummarizeHostInsightDiskStatistics.ts.html |here} to see how to use SummarizeHostInsightDiskStatistics API.
     */
    summarizeHostInsightDiskStatistics(summarizeHostInsightDiskStatisticsRequest: requests.SummarizeHostInsightDiskStatisticsRequest): Promise<responses.SummarizeHostInsightDiskStatisticsResponse>;
    /**
     * Returns response with some recommendations if apply for a host.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeHostInsightHostRecommendationRequest
     * @return SummarizeHostInsightHostRecommendationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/SummarizeHostInsightHostRecommendation.ts.html |here} to see how to use SummarizeHostInsightHostRecommendation API.
     */
    summarizeHostInsightHostRecommendation(summarizeHostInsightHostRecommendationRequest: requests.SummarizeHostInsightHostRecommendationRequest): Promise<responses.SummarizeHostInsightHostRecommendationResponse>;
    /**
     * Returns response with usage time series data with breakdown by network interface for the time period specified.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeHostInsightNetworkUsageTrendRequest
     * @return SummarizeHostInsightNetworkUsageTrendResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/SummarizeHostInsightNetworkUsageTrend.ts.html |here} to see how to use SummarizeHostInsightNetworkUsageTrend API.
     */
    summarizeHostInsightNetworkUsageTrend(summarizeHostInsightNetworkUsageTrendRequest: requests.SummarizeHostInsightNetworkUsageTrendRequest): Promise<responses.SummarizeHostInsightNetworkUsageTrendResponse>;
    /**
     * Returns response with time series data (endTimestamp, capacity) for the time period specified.
     * The maximum time range for analysis is 2 years, hence this is intentionally not paginated.
     * If compartmentIdInSubtree is specified, aggregates resources in a compartment and in all sub-compartments.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeHostInsightResourceCapacityTrendRequest
     * @return SummarizeHostInsightResourceCapacityTrendResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/SummarizeHostInsightResourceCapacityTrend.ts.html |here} to see how to use SummarizeHostInsightResourceCapacityTrend API.
     */
    summarizeHostInsightResourceCapacityTrend(summarizeHostInsightResourceCapacityTrendRequest: requests.SummarizeHostInsightResourceCapacityTrendRequest): Promise<responses.SummarizeHostInsightResourceCapacityTrendResponse>;
    /**
     * Get Forecast predictions for CPU or memory resources since a time in the past.
     * If compartmentIdInSubtree is specified, aggregates resources in a compartment and in all sub-compartments.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeHostInsightResourceForecastTrendRequest
     * @return SummarizeHostInsightResourceForecastTrendResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/SummarizeHostInsightResourceForecastTrend.ts.html |here} to see how to use SummarizeHostInsightResourceForecastTrend API.
     */
    summarizeHostInsightResourceForecastTrend(summarizeHostInsightResourceForecastTrendRequest: requests.SummarizeHostInsightResourceForecastTrendRequest): Promise<responses.SummarizeHostInsightResourceForecastTrendResponse>;
    /**
     * Lists the resource statistics (usage, capacity, usage change percent, utilization percent, load) for each host filtered
     * by utilization level in a compartment and in all sub-compartments if specified.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeHostInsightResourceStatisticsRequest
     * @return SummarizeHostInsightResourceStatisticsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/SummarizeHostInsightResourceStatistics.ts.html |here} to see how to use SummarizeHostInsightResourceStatistics API.
     */
    summarizeHostInsightResourceStatistics(summarizeHostInsightResourceStatisticsRequest: requests.SummarizeHostInsightResourceStatisticsRequest): Promise<responses.SummarizeHostInsightResourceStatisticsResponse>;
    /**
     * A cumulative distribution function is used to rank the usage data points per host within the specified time period.
     * For each host, the minimum data point with a ranking > the percentile value is included in the summation.
     * Linear regression functions are used to calculate the usage change percentage.
     * If compartmentIdInSubtree is specified, aggregates resources in a compartment and in all sub-compartments.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeHostInsightResourceUsageRequest
     * @return SummarizeHostInsightResourceUsageResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/SummarizeHostInsightResourceUsage.ts.html |here} to see how to use SummarizeHostInsightResourceUsage API.
     */
    summarizeHostInsightResourceUsage(summarizeHostInsightResourceUsageRequest: requests.SummarizeHostInsightResourceUsageRequest): Promise<responses.SummarizeHostInsightResourceUsageResponse>;
    /**
     * Returns response with time series data (endTimestamp, usage, capacity) for the time period specified.
     * The maximum time range for analysis is 2 years, hence this is intentionally not paginated.
     * If compartmentIdInSubtree is specified, aggregates resources in a compartment and in all sub-compartments.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeHostInsightResourceUsageTrendRequest
     * @return SummarizeHostInsightResourceUsageTrendResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/SummarizeHostInsightResourceUsageTrend.ts.html |here} to see how to use SummarizeHostInsightResourceUsageTrend API.
     */
    summarizeHostInsightResourceUsageTrend(summarizeHostInsightResourceUsageTrendRequest: requests.SummarizeHostInsightResourceUsageTrendRequest): Promise<responses.SummarizeHostInsightResourceUsageTrendResponse>;
    /**
     * Gets resources with current utilization (high and low) and projected utilization (high and low) for a resource type over specified time period.
     * If compartmentIdInSubtree is specified, aggregates resources in a compartment and in all sub-compartments.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeHostInsightResourceUtilizationInsightRequest
     * @return SummarizeHostInsightResourceUtilizationInsightResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/SummarizeHostInsightResourceUtilizationInsight.ts.html |here} to see how to use SummarizeHostInsightResourceUtilizationInsight API.
     */
    summarizeHostInsightResourceUtilizationInsight(summarizeHostInsightResourceUtilizationInsightRequest: requests.SummarizeHostInsightResourceUtilizationInsightRequest): Promise<responses.SummarizeHostInsightResourceUtilizationInsightResponse>;
    /**
     * Returns response with usage time series data with breakdown by filesystem for the time period specified.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeHostInsightStorageUsageTrendRequest
     * @return SummarizeHostInsightStorageUsageTrendResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/SummarizeHostInsightStorageUsageTrend.ts.html |here} to see how to use SummarizeHostInsightStorageUsageTrend API.
     */
    summarizeHostInsightStorageUsageTrend(summarizeHostInsightStorageUsageTrendRequest: requests.SummarizeHostInsightStorageUsageTrendRequest): Promise<responses.SummarizeHostInsightStorageUsageTrendResponse>;
    /**
     * Returns response with aggregated data (timestamp, usageData) for top processes on a specific date.
     * Data is aggregated for the time specified and processes are sorted descendent by the process metric specified (CPU, MEMORY, VIRTUAL_MEMORY).
     * hostInsightId, processMetric must be specified.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeHostInsightTopProcessesUsageRequest
     * @return SummarizeHostInsightTopProcessesUsageResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/SummarizeHostInsightTopProcessesUsage.ts.html |here} to see how to use SummarizeHostInsightTopProcessesUsage API.
     */
    summarizeHostInsightTopProcessesUsage(summarizeHostInsightTopProcessesUsageRequest: requests.SummarizeHostInsightTopProcessesUsageRequest): Promise<responses.SummarizeHostInsightTopProcessesUsageResponse>;
    /**
     * Returns response with aggregated time series data (timeIntervalstart, timeIntervalEnd, commandArgs, usageData) for top processes.
     * Data is aggregated for the time period specified and proceses are sorted descendent by the proces metric specified (CPU, MEMORY, VIRTUAL_MEMORY).
     * HostInsight Id and Process metric must be specified
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeHostInsightTopProcessesUsageTrendRequest
     * @return SummarizeHostInsightTopProcessesUsageTrendResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/SummarizeHostInsightTopProcessesUsageTrend.ts.html |here} to see how to use SummarizeHostInsightTopProcessesUsageTrend API.
     */
    summarizeHostInsightTopProcessesUsageTrend(summarizeHostInsightTopProcessesUsageTrendRequest: requests.SummarizeHostInsightTopProcessesUsageTrendRequest): Promise<responses.SummarizeHostInsightTopProcessesUsageTrendResponse>;
    /**
     * Gets the details of resources used by an Operations Insights Warehouse.
     * There is only expected to be 1 warehouse per tenant. The warehouse is expected to be in the root compartment.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeOperationsInsightsWarehouseResourceUsageRequest
     * @return SummarizeOperationsInsightsWarehouseResourceUsageResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/SummarizeOperationsInsightsWarehouseResourceUsage.ts.html |here} to see how to use SummarizeOperationsInsightsWarehouseResourceUsage API.
     */
    summarizeOperationsInsightsWarehouseResourceUsage(summarizeOperationsInsightsWarehouseResourceUsageRequest: requests.SummarizeOperationsInsightsWarehouseResourceUsageRequest): Promise<responses.SummarizeOperationsInsightsWarehouseResourceUsageResponse>;
    /**
     * Query SQL Warehouse to get the performance insights for SQLs taking greater than X% database time for a given
     * time period across the given databases or database types in a compartment and in all sub-compartments if specified.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeSqlInsightsRequest
     * @return SummarizeSqlInsightsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/SummarizeSqlInsights.ts.html |here} to see how to use SummarizeSqlInsights API.
     */
    summarizeSqlInsights(summarizeSqlInsightsRequest: requests.SummarizeSqlInsightsRequest): Promise<responses.SummarizeSqlInsightsResponse>;
    /**
     * Query SQL Warehouse to get the performance insights on the execution plans for a given SQL for a given time period.
     * Either databaseId or id must be specified.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeSqlPlanInsightsRequest
     * @return SummarizeSqlPlanInsightsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/SummarizeSqlPlanInsights.ts.html |here} to see how to use SummarizeSqlPlanInsights API.
     */
    summarizeSqlPlanInsights(summarizeSqlPlanInsightsRequest: requests.SummarizeSqlPlanInsightsRequest): Promise<responses.SummarizeSqlPlanInsightsResponse>;
    /**
     * Query SQL Warehouse to summarize the response time distribution of query executions for a given SQL for a given time period.
     * Either databaseId or id must be specified.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeSqlResponseTimeDistributionsRequest
     * @return SummarizeSqlResponseTimeDistributionsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/SummarizeSqlResponseTimeDistributions.ts.html |here} to see how to use SummarizeSqlResponseTimeDistributions API.
     */
    summarizeSqlResponseTimeDistributions(summarizeSqlResponseTimeDistributionsRequest: requests.SummarizeSqlResponseTimeDistributionsRequest): Promise<responses.SummarizeSqlResponseTimeDistributionsResponse>;
    /**
     * Query SQL Warehouse to get the performance statistics for SQLs taking greater than X% database time for a given
     * time period across the given databases or database types in a compartment and in all sub-compartments if specified.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeSqlStatisticsRequest
     * @return SummarizeSqlStatisticsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/SummarizeSqlStatistics.ts.html |here} to see how to use SummarizeSqlStatistics API.
     */
    summarizeSqlStatistics(summarizeSqlStatisticsRequest: requests.SummarizeSqlStatisticsRequest): Promise<responses.SummarizeSqlStatisticsResponse>;
    /**
     * Query SQL Warehouse to get the performance statistics time series for a given SQL across given databases for a
     * given time period in a compartment and in all sub-compartments if specified.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeSqlStatisticsTimeSeriesRequest
     * @return SummarizeSqlStatisticsTimeSeriesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/SummarizeSqlStatisticsTimeSeries.ts.html |here} to see how to use SummarizeSqlStatisticsTimeSeries API.
     */
    summarizeSqlStatisticsTimeSeries(summarizeSqlStatisticsTimeSeriesRequest: requests.SummarizeSqlStatisticsTimeSeriesRequest): Promise<responses.SummarizeSqlStatisticsTimeSeriesResponse>;
    /**
     * Query SQL Warehouse to get the performance statistics time series for a given SQL by execution plans for a given time period.
     * Either databaseId or id must be specified.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param SummarizeSqlStatisticsTimeSeriesByPlanRequest
     * @return SummarizeSqlStatisticsTimeSeriesByPlanResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/SummarizeSqlStatisticsTimeSeriesByPlan.ts.html |here} to see how to use SummarizeSqlStatisticsTimeSeriesByPlan API.
     */
    summarizeSqlStatisticsTimeSeriesByPlan(summarizeSqlStatisticsTimeSeriesByPlanRequest: requests.SummarizeSqlStatisticsTimeSeriesByPlanRequest): Promise<responses.SummarizeSqlStatisticsTimeSeriesByPlanResponse>;
    /**
     * Updates the configuration of a hub .
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateAwrHubRequest
     * @return UpdateAwrHubResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/UpdateAwrHub.ts.html |here} to see how to use UpdateAwrHub API.
     */
    updateAwrHub(updateAwrHubRequest: requests.UpdateAwrHubRequest): Promise<responses.UpdateAwrHubResponse>;
    /**
     * Update Awr Hub Source object.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateAwrHubSourceRequest
     * @return UpdateAwrHubSourceResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/UpdateAwrHubSource.ts.html |here} to see how to use UpdateAwrHubSource API.
     */
    updateAwrHubSource(updateAwrHubSourceRequest: requests.UpdateAwrHubSourceRequest): Promise<responses.UpdateAwrHubSourceResponse>;
    /**
     * Updates configuration of a database insight.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateDatabaseInsightRequest
     * @return UpdateDatabaseInsightResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/UpdateDatabaseInsight.ts.html |here} to see how to use UpdateDatabaseInsight API.
     */
    updateDatabaseInsight(updateDatabaseInsightRequest: requests.UpdateDatabaseInsightRequest): Promise<responses.UpdateDatabaseInsightResponse>;
    /**
     * Updates configuration of an Operations Insights Enterprise Manager bridge.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateEnterpriseManagerBridgeRequest
     * @return UpdateEnterpriseManagerBridgeResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/UpdateEnterpriseManagerBridge.ts.html |here} to see how to use UpdateEnterpriseManagerBridge API.
     */
    updateEnterpriseManagerBridge(updateEnterpriseManagerBridgeRequest: requests.UpdateEnterpriseManagerBridgeRequest): Promise<responses.UpdateEnterpriseManagerBridgeResponse>;
    /**
     * Updates configuration of an Exadata insight.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateExadataInsightRequest
     * @return UpdateExadataInsightResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/UpdateExadataInsight.ts.html |here} to see how to use UpdateExadataInsight API.
     */
    updateExadataInsight(updateExadataInsightRequest: requests.UpdateExadataInsightRequest): Promise<responses.UpdateExadataInsightResponse>;
    /**
     * Updates configuration of a host insight.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateHostInsightRequest
     * @return UpdateHostInsightResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/UpdateHostInsight.ts.html |here} to see how to use UpdateHostInsight API.
     */
    updateHostInsight(updateHostInsightRequest: requests.UpdateHostInsightRequest): Promise<responses.UpdateHostInsightResponse>;
    /**
     * Updates the  configuration of a news report.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateNewsReportRequest
     * @return UpdateNewsReportResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/UpdateNewsReport.ts.html |here} to see how to use UpdateNewsReport API.
     */
    updateNewsReport(updateNewsReportRequest: requests.UpdateNewsReportRequest): Promise<responses.UpdateNewsReportResponse>;
    /**
     * Updates one or more attributes of the specified private endpoint.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateOperationsInsightsPrivateEndpointRequest
     * @return UpdateOperationsInsightsPrivateEndpointResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/UpdateOperationsInsightsPrivateEndpoint.ts.html |here} to see how to use UpdateOperationsInsightsPrivateEndpoint API.
     */
    updateOperationsInsightsPrivateEndpoint(updateOperationsInsightsPrivateEndpointRequest: requests.UpdateOperationsInsightsPrivateEndpointRequest): Promise<responses.UpdateOperationsInsightsPrivateEndpointResponse>;
    /**
     * Updates the configuration of an Ops Insights Warehouse.
     * There is only expected to be 1 warehouse per tenant. The warehouse is expected to be in the root compartment.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateOperationsInsightsWarehouseRequest
     * @return UpdateOperationsInsightsWarehouseResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/UpdateOperationsInsightsWarehouse.ts.html |here} to see how to use UpdateOperationsInsightsWarehouse API.
     */
    updateOperationsInsightsWarehouse(updateOperationsInsightsWarehouseRequest: requests.UpdateOperationsInsightsWarehouseRequest): Promise<responses.UpdateOperationsInsightsWarehouseResponse>;
    /**
     * Updates the configuration of an Operations Insights Warehouse User.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateOperationsInsightsWarehouseUserRequest
     * @return UpdateOperationsInsightsWarehouseUserResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/UpdateOperationsInsightsWarehouseUser.ts.html |here} to see how to use UpdateOperationsInsightsWarehouseUser API.
     */
    updateOperationsInsightsWarehouseUser(updateOperationsInsightsWarehouseUserRequest: requests.UpdateOperationsInsightsWarehouseUserRequest): Promise<responses.UpdateOperationsInsightsWarehouseUserResponse>;
    /**
     * Updates an OPSI configuration resource with the given ID.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateOpsiConfigurationRequest
     * @return UpdateOpsiConfigurationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/opsi/UpdateOpsiConfiguration.ts.html |here} to see how to use UpdateOpsiConfiguration API.
     */
    updateOpsiConfiguration(updateOpsiConfigurationRequest: requests.UpdateOpsiConfigurationRequest): Promise<responses.UpdateOpsiConfigurationResponse>;
}
export {};
