/**
 * Ops Insights API
 * Use the Ops Insights API to perform data extraction operations to obtain database
resource utilization, performance statistics, and reference information. For more information,
see [About Oracle Cloud Infrastructure Ops Insights](https://docs.cloud.oracle.com/en-us/iaas/operations-insights/doc/operations-insights.html).

 * OpenAPI spec version: 20200630
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * Awr hub source object
 */
export interface AwrHubSource {
    /**
     * The name of the Awr Hub source database.
     */
    "name": string;
    /**
     * AWR Hub OCID
     */
    "awrHubId": string;
    /**
     * The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment.
     */
    "compartmentId": string;
    /**
     * source type of the database
     */
    "type": model.AwrHubSourceType;
    /**
     * The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the Awr Hub source database.
     */
    "id": string;
    /**
     * The shorted string of the Awr Hub source database identifier.
     */
    "awrHubOpsiSourceId": string;
    /**
     * Opsi Mailbox URL based on the Awr Hub and Awr Hub source.
     */
    "sourceMailBoxUrl": string;
    /**
     * The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the database id.
     */
    "associatedResourceId"?: string;
    /**
     * The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the database id.
     */
    "associatedOpsiId"?: string;
    /**
     * The time at which the resource was first created. An RFC3339 formatted datetime string
     */
    "timeCreated": Date;
    /**
     * The time at which the resource was last updated. An RFC3339 formatted datetime string
     */
    "timeUpdated"?: Date;
    /**
     * Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
     * Example: {@code {\"bar-key\": \"value\"}}
     *
     */
    "freeformTags"?: {
        [key: string]: string;
    };
    /**
     * Defined tags for this resource. Each key is predefined and scoped to a namespace.
     * Example: {@code {\"foo-namespace\": {\"bar-key\": \"value\"}}}
     *
     */
    "definedTags"?: {
        [key: string]: {
            [key: string]: any;
        };
    };
    /**
     * System tags for this resource. Each key is predefined and scoped to a namespace.
     * Example: {@code {\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}}
     *
     */
    "systemTags"?: {
        [key: string]: {
            [key: string]: any;
        };
    };
    /**
     * This is {@code true} if the source databse is registered with a Awr Hub, otherwise {@code false}
     */
    "isRegisteredWithAwrHub"?: boolean;
    /**
     * DatabaseId of the Source database for which AWR Data will be uploaded to AWR Hub.
     */
    "awrSourceDatabaseId"?: string;
    /**
     * The minimum snapshot identifier of the source database for which AWR data is uploaded to AWR Hub. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "minSnapshotIdentifier"?: number;
    /**
     * The maximum snapshot identifier of the source database for which AWR data is uploaded to AWR Hub. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "maxSnapshotIdentifier"?: number;
    /**
     * The time at which the earliest snapshot was generated in the source database for which data is uploaded to AWR Hub. An RFC3339 formatted datetime string
     */
    "timeFirstSnapshotGenerated"?: Date;
    /**
     * The time at which the latest snapshot was generated in the source database for which data is uploaded to AWR Hub. An RFC3339 formatted datetime string
     */
    "timeLastSnapshotGenerated"?: Date;
    /**
     * Number of hours since last AWR snapshots import happened from the Source database. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "hoursSinceLastImport"?: number;
    /**
     * the current state of the source database
     */
    "lifecycleState": model.AwrHubSourceLifecycleState;
    /**
     * Indicates the status of a source database in Operations Insights
     */
    "status": model.AwrHubSourceStatus;
}
export declare namespace AwrHubSource {
    function getJsonObj(obj: AwrHubSource): object;
    function getDeserializedJsonObj(obj: AwrHubSource): object;
}
