/**
 * Ops Insights API
 * Use the Ops Insights API to perform data extraction operations to obtain database
resource utilization, performance statistics, and reference information. For more information,
see [About Oracle Cloud Infrastructure Ops Insights](https://docs.cloud.oracle.com/en-us/iaas/operations-insights/doc/operations-insights.html).

 * OpenAPI spec version: 20200630
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * OPSI warehouse resource.
 */
export interface OperationsInsightsWarehouse {
    /**
     * OPSI Warehouse OCID
     */
    "id": string;
    /**
     * The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment.
     */
    "compartmentId": string;
    /**
     * User-friedly name of Ops Insights Warehouse that does not have to be unique.
     */
    "displayName": string;
    /**
     * Number of OCPUs allocated to OPSI Warehouse ADW.
     *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "cpuAllocated": number;
    /**
     * Number of OCPUs used by OPSI Warehouse ADW. Can be fractional.
     *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "cpuUsed"?: number;
    /**
     * Storage allocated to OPSI Warehouse ADW.
     *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "storageAllocatedInGBs"?: number;
    /**
     * Storage by OPSI Warehouse ADW in GB.
     *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "storageUsedInGBs"?: number;
    /**
     * OCID of the dynamic group created for the warehouse
     */
    "dynamicGroupId"?: string;
    /**
     * Tenancy Identifier of Ops Insights service
     */
    "operationsInsightsTenancyId"?: string;
    /**
     * The time at which the ADW wallet was last rotated for the Ops Insights Warehouse. An RFC3339 formatted datetime string
     */
    "timeLastWalletRotated"?: Date;
    /**
     * Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
     * Example: {@code {\"bar-key\": \"value\"}}
     *
     */
    "freeformTags"?: {
        [key: string]: string;
    };
    /**
     * Defined tags for this resource. Each key is predefined and scoped to a namespace.
     * Example: {@code {\"foo-namespace\": {\"bar-key\": \"value\"}}}
     *
     */
    "definedTags"?: {
        [key: string]: {
            [key: string]: any;
        };
    };
    /**
     * System tags for this resource. Each key is predefined and scoped to a namespace.
     * Example: {@code {\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}}
     *
     */
    "systemTags"?: {
        [key: string]: {
            [key: string]: any;
        };
    };
    /**
     * The time at which the resource was first created. An RFC3339 formatted datetime string
     */
    "timeCreated": Date;
    /**
     * The time at which the resource was last updated. An RFC3339 formatted datetime string
     */
    "timeUpdated"?: Date;
    /**
     * Possible lifecycle states
     */
    "lifecycleState": model.OperationsInsightsWarehouseLifecycleState;
    /**
     * A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.
     */
    "lifecycleDetails"?: string;
}
export declare namespace OperationsInsightsWarehouse {
    function getJsonObj(obj: OperationsInsightsWarehouse): object;
    function getDeserializedJsonObj(obj: OperationsInsightsWarehouse): object;
}
