/**
 * Ops Insights API
 * Use the Ops Insights API to perform data extraction operations to obtain database
resource utilization, performance statistics, and reference information. For more information,
see [About Oracle Cloud Infrastructure Ops Insights](https://docs.cloud.oracle.com/en-us/iaas/operations-insights/doc/operations-insights.html).

 * OpenAPI spec version: 20200630
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
/**
 * Performance statistics for the SQL.
 */
export interface SqlStatistics {
    /**
     * Database Time in seconds Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "databaseTimeInSec": number;
    /**
     * Number of executions per hour Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "executionsPerHour": number;
    /**
     * Total number of executions Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "executionsCount": number;
    /**
     * CPU Time in seconds Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "cpuTimeInSec": number;
    /**
     * I/O Time in seconds Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "ioTimeInSec": number;
    /**
     * Inefficient Wait Time in seconds Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "inefficientWaitTimeInSec": number;
    /**
     * Response time is the average elaspsed time per execution. It is the ratio of Total Database Time to the number of executions Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "responseTimeInSec": number;
    /**
     * Number of SQL execution plans used by the SQL Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "planCount": number;
    /**
     * Variability is the ratio of the standard deviation in response time to the mean of response time of the SQL Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "variability": number;
    /**
     * Average Active Sessions represent the average active sessions at a point in time. It is the number of sessions that are either working or waiting. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "averageActiveSessions": number;
    /**
     * Percentage of Database Time Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "databaseTimePct": number;
    /**
     * Percentage of Inefficiency. It is calculated by Total Database Time divided by Total Wait Time Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "inefficiencyInPct": number;
    /**
     * Percent change in CPU Time based on linear regression Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "changeInCpuTimeInPct": number;
    /**
     * Percent change in IO Time based on linear regression Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "changeInIoTimeInPct": number;
    /**
     * Percent change in Inefficient Wait Time based on linear regression Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "changeInInefficientWaitTimeInPct": number;
    /**
     * Percent change in Response Time based on linear regression Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "changeInResponseTimeInPct": number;
    /**
     * Percent change in Average Active Sessions based on linear regression Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "changeInAverageActiveSessionsInPct": number;
    /**
     * Percent change in Executions per hour based on linear regression Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "changeInExecutionsPerHourInPct": number;
    /**
     * Percent change in Inefficiency based on linear regression Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "changeInInefficiencyInPct": number;
}
export declare namespace SqlStatistics {
    function getJsonObj(obj: SqlStatistics): object;
    function getDeserializedJsonObj(obj: SqlStatistics): object;
}
