/**
 * OS Management API
 * API for the OS Management service. Use these API operations for working
with Managed instances and Managed instance groups.

 * OpenAPI spec version: 20190801
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * A description of workrequest status
 */
export interface WorkRequest {
    /**
     * the type of operation this Work Request performs
     */
    "operationType": model.OperationTypes;
    /**
     * status of current work request.
     */
    "status": model.OperationStatus;
    /**
     * The id of the work request.
     */
    "id": string;
    /**
     * The ocid of the compartment that contains the work request. Work requests should be scoped to
     * the same compartment as the resource the work request affects. If the work request affects multiple resources,
     * and those resources are not in the same compartment, it is up to the service team to pick the primary
     * resource whose compartment should be used
     *
     */
    "compartmentId": string;
    /**
     * Description of the type of work.
     */
    "description"?: string;
    /**
     * A progress or error message, if there is any.
     */
    "message"?: string;
    "managedInstanceId"?: model.Id;
    /**
     * The resources affected by this work request.
     */
    "resources": Array<model.WorkRequestResource>;
    /**
     * Percentage of the request completed. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "percentComplete": number;
    /**
     * The date and time the request was created, as described in
     * [RFC 3339](https://tools.ietf.org/rfc/rfc3339), section 14.29.
     *
     */
    "timeAccepted": Date;
    /**
     * The date and time the request was started, as described in [RFC 3339](https://tools.ietf.org/rfc/rfc3339),
     * section 14.29.
     *
     */
    "timeStarted"?: Date;
    /**
     * The date and time the object was finished, as described in [RFC 3339](https://tools.ietf.org/rfc/rfc3339).
     *
     */
    "timeFinished"?: Date;
    /**
     * The Operating System type of the managed instance.
     */
    "osFamily"?: model.OsFamilies;
    /**
     * The parent of this work request, if one exists.
     */
    "parentId"?: string;
    /**
     * A list of the IDs of any children of this work request
     */
    "childrenIds"?: Array<string>;
}
export declare namespace WorkRequest {
    function getJsonObj(obj: WorkRequest): object;
    function getDeserializedJsonObj(obj: WorkRequest): object;
}
