/**
 * OS Management Hub API
 * Use the OS Management Hub API to manage and monitor updates and patches for instances in OCI, your private data center, or 3rd-party clouds.
For more information, see [Overview of OS Management Hub](https://docs.cloud.oracle.com/iaas/osmh/doc/overview.htm).

 * OpenAPI spec version: 20220901
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * Provides the information used to create a lifecycle environment. A lifecycle environment is a user-defined pipeline to deliver curated, versioned content in a prescribed, methodical manner.
 *
 */
export interface CreateLifecycleEnvironmentDetails {
    /**
     * The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment that contains the lifecycle environment.
     */
    "compartmentId": string;
    /**
     * A user-friendly name for the lifecycle environment. Does not have to be unique and you can change the name later. Avoid entering confidential information.
     */
    "displayName": string;
    /**
     * User-specified information about the lifecycle environment. Avoid entering confidential information.
     */
    "description"?: string;
    /**
     * User-specified list of ranked lifecycle stages used within the lifecycle environment.
     */
    "stages": Array<model.CreateLifecycleStageDetails>;
    /**
     * The CPU architecture of the managed instances in the lifecycle environment.
     */
    "archType": model.ArchType;
    /**
     * The operating system of the managed instances in the lifecycle environment.
     */
    "osFamily": model.OsFamily;
    /**
     * The vendor of the operating system used by the managed instances in the lifecycle environment.
     */
    "vendorName": model.VendorName;
    /**
     * The location of managed instances attached to the lifecycle environment. If no location is provided, the default is 'ON_PREMISE.'
     *
     */
    "location"?: model.ManagedInstanceLocation;
    /**
     * Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
     * For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
     * Example: {@code {\"Department\": \"Finance\"}}
     *
     */
    "freeformTags"?: {
        [key: string]: string;
    };
    /**
     * Defined tags for this resource. Each key is predefined and scoped to a namespace.
     * For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
     * Example: {@code {\"Operations\": {\"CostCenter\": \"42\"}}}
     *
     */
    "definedTags"?: {
        [key: string]: {
            [key: string]: any;
        };
    };
}
export declare namespace CreateLifecycleEnvironmentDetails {
    function getJsonObj(obj: CreateLifecycleEnvironmentDetails): object;
    function getDeserializedJsonObj(obj: CreateLifecycleEnvironmentDetails): object;
}
