/**
 * OS Management Hub API
 * Use the OS Management Hub API to manage and monitor updates and patches for instances in OCI, your private data center, or 3rd-party clouds.
For more information, see [Overview of OS Management Hub](https://docs.cloud.oracle.com/iaas/osmh/doc/overview.htm).

 * OpenAPI spec version: 20220901
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * Provides the information used to create a new managed instance group.
 */
export interface CreateManagedInstanceGroupDetails {
    /**
     * A user-friendly name for the managed instance group. Does not have to be unique and you can change the name later. Avoid entering confidential information.
     */
    "displayName": string;
    /**
     * User-specified description of the managed instance group. Avoid entering confidential information.
     */
    "description"?: string;
    /**
     * The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment that contains the managed instance group.
     */
    "compartmentId": string;
    /**
     * The operating system type of the managed instances that will be attached to this group.
     *
     */
    "osFamily": model.OsFamily;
    /**
     * The CPU architecture type of the managed instances that will be attached to this group.
     *
     */
    "archType": model.ArchType;
    /**
     * The vendor of the operating system that will be used by the managed instances in the group.
     *
     */
    "vendorName": model.VendorName;
    /**
     * The location of managed instances attached to the group. If no location is provided, the default is on premises.
     *
     */
    "location"?: model.ManagedInstanceLocation;
    /**
     * The list of software source [OCIDs](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) available to the managed instances in the group.
     */
    "softwareSourceIds"?: Array<string>;
    /**
     * The list of managed instance [OCIDs](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) to be added to the group.
     */
    "managedInstanceIds"?: Array<string>;
    /**
     * The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) for the Oracle Notifications service (ONS) topic. ONS is the channel used to send notifications to the customer.
     */
    "notificationTopicId"?: string;
    "autonomousSettings"?: model.UpdatableAutonomousSettings;
    /**
     * Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
     * For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
     * Example: {@code {\"Department\": \"Finance\"}}
     *
     */
    "freeformTags"?: {
        [key: string]: string;
    };
    /**
     * Defined tags for this resource. Each key is predefined and scoped to a namespace.
     * For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
     * Example: {@code {\"Operations\": {\"CostCenter\": \"42\"}}}
     *
     */
    "definedTags"?: {
        [key: string]: {
            [key: string]: any;
        };
    };
}
export declare namespace CreateManagedInstanceGroupDetails {
    function getJsonObj(obj: CreateManagedInstanceGroupDetails): object;
    function getDeserializedJsonObj(obj: CreateManagedInstanceGroupDetails): object;
}
