/**
 * OS Management Hub API
 * Use the OS Management Hub API to manage and monitor updates and patches for instances in OCI, your private data center, or 3rd-party clouds.
For more information, see [Overview of OS Management Hub](https://docs.cloud.oracle.com/iaas/osmh/doc/overview.htm).

 * OpenAPI spec version: 20220901
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * Summary of the managed instance group.
 */
export interface ManagedInstanceGroupSummary {
    /**
     * The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the managed instance group.
     */
    "id": string;
    /**
     * The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment that contains the managed instance group
     */
    "compartmentId": string;
    /**
     * A user-friendly name for the managed instance group.
     */
    "displayName"?: string;
    /**
     * User-specified information about the managed instance group.
     */
    "description"?: string;
    /**
     * The number of managed instances in the group. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "managedInstanceCount"?: number;
    /**
     * The location of managed instances attached to the group.
     */
    "location"?: model.ManagedInstanceLocation;
    /**
     * The time the managed instance group was created (in [RFC 3339](https://tools.ietf.org/rfc/rfc3339) format).
     */
    "timeCreated"?: Date;
    /**
     * The time the managed instance group was last modified (in [RFC 3339](https://tools.ietf.org/rfc/rfc3339) format).
     */
    "timeModified"?: Date;
    /**
     * The current state of the managed instance group.
     */
    "lifecycleState": string;
    /**
     * The operating system type of the instances in the managed instance group.
     */
    "osFamily"?: model.OsFamily;
    /**
     * The CPU architecture of the instances in the managed instance group.
     */
    "archType"?: model.ArchType;
    /**
     * The vendor of the operating system used by the managed instances in the group.
     */
    "vendorName"?: model.VendorName;
    /**
     * The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) for the Oracle Notifications service (ONS) topic. ONS is the channel used to send notifications to the customer.
     */
    "notificationTopicId"?: string;
    "autonomousSettings"?: model.AutonomousSettings;
    /**
     * Indicates whether the Autonomous Linux service manages the group.
     */
    "isManagedByAutonomousLinux"?: boolean;
    /**
     * Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
     * For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
     * Example: {@code {\"Department\": \"Finance\"}}
     *
     */
    "freeformTags"?: {
        [key: string]: string;
    };
    /**
     * Defined tags for this resource. Each key is predefined and scoped to a namespace.
     * For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
     * Example: {@code {\"Operations\": {\"CostCenter\": \"42\"}}}
     *
     */
    "definedTags"?: {
        [key: string]: {
            [key: string]: any;
        };
    };
    /**
     * System tags for this resource. Each key is predefined and scoped to a namespace.
     * Example: {@code {\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}}
     *
     */
    "systemTags"?: {
        [key: string]: {
            [key: string]: any;
        };
    };
}
export declare namespace ManagedInstanceGroupSummary {
    function getJsonObj(obj: ManagedInstanceGroupSummary): object;
    function getDeserializedJsonObj(obj: ManagedInstanceGroupSummary): object;
}
