/**
 * OS Management Hub API
 * Use the OS Management Hub API to manage and monitor updates and patches for instances in OCI, your private data center, or 3rd-party clouds.
For more information, see [Overview of OS Management Hub](https://docs.cloud.oracle.com/iaas/osmh/doc/overview.htm).

 * OpenAPI spec version: 20220901
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * An object that defines the instance being managed by the service.
 */
export interface ManagedInstance {
    /**
     * The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the managed instance.
     *
     */
    "id": string;
    /**
     * User-friendly name for the managed instance.
     */
    "displayName": string;
    /**
     * User-specified description for the managed instance.
     */
    "description"?: string;
    /**
     * The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the tenancy that the managed instance resides in.
     *
     */
    "tenancyId": string;
    /**
     * The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment that contains the managed instance.
     *
     */
    "compartmentId": string;
    /**
     * The location of the managed instance.
     */
    "location"?: model.ManagedInstanceLocation;
    /**
     * Time that the instance last checked in with the service (in [RFC 3339](https://tools.ietf.org/rfc/rfc3339) format).
     *
     */
    "timeLastCheckin"?: Date;
    /**
     * Time that the instance last booted (in [RFC 3339](https://tools.ietf.org/rfc/rfc3339) format).
     *
     */
    "timeLastBoot"?: Date;
    /**
     * Operating system name.
     */
    "osName"?: string;
    /**
     * Operating system version.
     */
    "osVersion"?: string;
    /**
     * Operating system kernel version.
     */
    "osKernelVersion"?: string;
    /**
     * The ksplice effective kernel version.
     */
    "kspliceEffectiveKernelVersion"?: string;
    /**
     * The CPU architecture type of the managed instance.
     */
    "architecture"?: model.ArchType;
    /**
     * The operating system type of the managed instance.
     */
    "osFamily"?: model.OsFamily;
    /**
     * Current status of the managed instance.
     */
    "status": model.ManagedInstanceStatus;
    /**
     * The profile that was used to register this instance with the service.
     */
    "profile"?: string;
    /**
     * Indicates whether this managed instance is acting as an on-premises management station.
     */
    "isManagementStation"?: boolean;
    /**
     * The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the management station for the instance to use as primary management station.
     *
     */
    "primaryManagementStationId"?: string;
    /**
     * The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the management station for the instance to use as secondary managment station.
     *
     */
    "secondaryManagementStationId"?: string;
    /**
     * The list of software sources currently attached to the managed instance.
     */
    "softwareSources"?: Array<model.SoftwareSourceDetails>;
    "managedInstanceGroup"?: model.Id;
    "lifecycleEnvironment"?: model.Id;
    "lifecycleStage"?: model.Id;
    /**
     * Indicates whether a reboot is required to complete installation of updates.
     */
    "isRebootRequired"?: boolean;
    /**
     * Number of packages installed on the instance. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "installedPackages"?: number;
    /**
     * Number of Windows updates installed on the instance. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "installedWindowsUpdates"?: number;
    /**
     * Number of updates available for installation. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "updatesAvailable"?: number;
    /**
     * Number of security type updates available for installation. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "securityUpdatesAvailable"?: number;
    /**
     * Number of bug fix type updates available for installation. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "bugUpdatesAvailable"?: number;
    /**
     * Number of enhancement type updates available for installation. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "enhancementUpdatesAvailable"?: number;
    /**
     * Number of non-classified (other) updates available for installation. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "otherUpdatesAvailable"?: number;
    /**
     * Number of scheduled jobs associated with this instance. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "scheduledJobCount"?: number;
    /**
     * Number of work requests associated with this instance. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "workRequestCount"?: number;
    /**
     * The date and time the instance was created (in [RFC 3339](https://tools.ietf.org/rfc/rfc3339) format).
     *
     */
    "timeCreated"?: Date;
    /**
     * The date and time the instance was last updated (in [RFC 3339](https://tools.ietf.org/rfc/rfc3339) format).
     *
     */
    "timeUpdated"?: Date;
    /**
     * The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) for the Oracle Notifications service (ONS) topic. ONS is the channel used to send notifications to the customer.
     *
     */
    "notificationTopicId"?: string;
    "autonomousSettings"?: model.AutonomousSettings;
    /**
     * Indicates whether the Autonomous Linux service manages the instance.
     */
    "isManagedByAutonomousLinux"?: boolean;
}
export declare namespace ManagedInstance {
    function getJsonObj(obj: ManagedInstance): object;
    function getDeserializedJsonObj(obj: ManagedInstance): object;
}
