/**
 * OS Management Hub API
 * Use the OS Management Hub API to manage and monitor updates and patches for instances in OCI, your private data center, or 3rd-party clouds.
For more information, see [Overview of OS Management Hub](https://docs.cloud.oracle.com/iaas/osmh/doc/overview.htm).

 * OpenAPI spec version: 20220901
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * An object that provides information about an update for a Windows instance.
 */
export interface WindowsUpdate {
    /**
     * Name of the Windows update.
     */
    "name": string;
    /**
     * Unique identifier for the Windows update. Note that this is not an OCID, but is a unique identifier assigned by Microsoft.
     * Example: '6981d463-cd91-4a26-b7c4-ea4ded9183ed'
     *
     */
    "updateId": string;
    /**
     * Description of the update.
     */
    "description"?: string;
    /**
     * The type of Windows update.
     */
    "updateType": model.ClassificationTypes;
    /**
     * size of the package in bytes Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "sizeInBytes"?: number;
    /**
     * Indicates whether the update can be installed using the service.
     */
    "installable"?: WindowsUpdate.Installable;
    /**
     * List of requirements for installing the update on the managed instance.
     */
    "installationRequirements"?: Array<model.InstallationRequirements>;
    /**
     * Indicates whether a reboot is required to complete the installation of this update.
     */
    "isRebootRequiredForInstallation"?: boolean;
    /**
     * List of the Microsoft Knowledge Base Article Ids related to this Windows Update.
     */
    "kbArticleIds"?: Array<string>;
}
export declare namespace WindowsUpdate {
    enum Installable {
        Installable = "INSTALLABLE",
        NotInstallable = "NOT_INSTALLABLE",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    function getJsonObj(obj: WindowsUpdate): object;
    function getDeserializedJsonObj(obj: WindowsUpdate): object;
}
