/**
 * PGSQL Control Plane API
 * Use the OCI Database with PostgreSQL API to manage resources such as database systems, database nodes, backups, and configurations.
For information, see the user guide documentation for the [service](/iaas/Content/postgresql/home.htm).

 * OpenAPI spec version: 20220915
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * The information about new database system.
 */
export interface CreateDbSystemDetails {
    /**
     * A user-friendly display name for the database system. Avoid entering confidential information.
     */
    "displayName": string;
    /**
     * A user-provided description of a database system.
     */
    "description"?: string;
    /**
     * The [OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment that contains the database system.
     */
    "compartmentId": string;
    /**
     * Type of the database system.
     */
    "systemType"?: string;
    /**
     * Version of database system software.
     */
    "dbVersion": string;
    /**
     * The [OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the configuration associated with the database system.
     */
    "configId"?: string;
    "storageDetails": model.OciOptimizedStorageDetails;
    /**
     * The name of the shape for the database instance node. Use the /shapes API for accepted shapes.
     * Example: {@code VM.Standard.E4.Flex}
     *
     */
    "shape": string;
    /**
     * The total number of OCPUs available to each database instance node. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "instanceOcpuCount"?: number;
    /**
     * The total amount of memory available to each database instance node, in gigabytes. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "instanceMemorySizeInGBs"?: number;
    /**
     * Count of database instances nodes to be created in the database system.
     *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "instanceCount"?: number;
    /**
     * Details of database instances nodes to be created. This parameter is optional.
     * If specified, its size must match {@code instanceCount}.
     *
     */
    "instancesDetails"?: Array<model.CreateDbInstanceDetails>;
    "credentials"?: model.Credentials;
    "networkDetails": model.NetworkDetails;
    "managementPolicy"?: model.ManagementPolicyDetails;
    "source"?: model.BackupSourceDetails | model.NoneSourceDetails;
    /**
     * Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
     * Example: {@code {\"bar-key\": \"value\"}}
     *
     */
    "freeformTags"?: {
        [key: string]: string;
    };
    /**
     * Defined tags for this resource. Each key is predefined and scoped to a namespace.
     * Example: {@code {\"foo-namespace\": {\"bar-key\": \"value\"}}}
     *
     */
    "definedTags"?: {
        [key: string]: {
            [key: string]: any;
        };
    };
}
export declare namespace CreateDbSystemDetails {
    function getJsonObj(obj: CreateDbSystemDetails): object;
    function getDeserializedJsonObj(obj: CreateDbSystemDetails): object;
}
