/**
 * RoverCloudService API
 * A description of the RoverCloudService API.
 * OpenAPI spec version: 20201210
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * The information required to create a RoverCluster.
 */
export interface CreateRoverClusterDetails {
    /**
     * A user-friendly name. Does not have to be unique, and it's changeable. Avoid entering confidential information.
     */
    "displayName": string;
    /**
     * The OCID of the compartment containing the RoverCluster.
     */
    "compartmentId": string;
    /**
     * Number of nodes desired in the cluster, in standalone clusters, between 5 and 15 inclusive. In station clusters, between 15 and 30 inclusive. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "clusterSize": number;
    "customerShippingAddress"?: model.ShippingAddress;
    /**
     * List of existing workloads that should be provisioned on the nodes.
     */
    "clusterWorkloads"?: Array<model.RoverWorkload>;
    /**
     * Type of cluster.
     */
    "clusterType"?: model.ClusterType;
    /**
     * Root password for the rover cluster.
     */
    "superUserPassword"?: string;
    /**
     * The type of enclosure rover nodes in this cluster are shipped in.
     */
    "enclosureType"?: model.EnclosureType;
    /**
     * Password to unlock the rover cluster.
     */
    "unlockPassphrase"?: string;
    /**
     * Name of point of contact for this order if customer is picking up.
     */
    "pointOfContact"?: string;
    /**
     * Phone number of point of contact for this order if customer is picking up.
     */
    "pointOfContactPhoneNumber"?: string;
    /**
     * Preference for device delivery.
     */
    "shippingPreference"?: CreateRoverClusterDetails.ShippingPreference;
    /**
     * Shipping vendor of choice for orace to customer shipping.
     */
    "shippingVendor"?: string;
    /**
     * Expected date when customer wants to pickup the cluster if they chose customer pickup.
     */
    "timePickupExpected"?: Date;
    /**
     * Tracking Url for the shipped Rover Cluster.
     */
    "oracleShippingTrackingUrl"?: string;
    /**
     * ID provided to customer after successful subscription to Rover Stations.
     */
    "subscriptionId"?: string;
    /**
     * The current state of the RoverCluster.
     */
    "lifecycleState"?: model.LifecycleState;
    /**
     * A property that can contain details on the lifecycle.
     */
    "lifecycleStateDetails"?: string;
    /**
     * The flag indicating that customer requests data to be imported to OCI upon Rover cluster return.
     */
    "isImportRequested"?: boolean;
    /**
     * An OCID of a compartment where data will be imported to upon Rover cluster return.
     */
    "importCompartmentId"?: string;
    /**
     * Name of a bucket where files from NFS share will be imported to upon Rover cluster return.
     */
    "importFileBucket"?: string;
    /**
     * Validation code returned by data validation tool. Required for return shipping label generation if data import was requested.
     */
    "dataValidationCode"?: string;
    /**
     * Customer provided master key ID to encrypt secret information. If not provided, Rover's master key will be used for encryption.
     */
    "masterKeyId"?: string;
    /**
     * The freeform tags associated with this resource, if any. Each tag is a simple key-value pair with no
     * predefined name, type, or namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
     * Example: {@code {\"Department\": \"Finance\"}}
     *
     */
    "freeformTags"?: {
        [key: string]: string;
    };
    /**
     * The defined tags associated with this resource, if any. Each key is predefined and scoped to namespaces.
     * For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
     * Example: {@code {\"Operations\": {\"CostCenter\": \"42\"}}}
     *
     */
    "definedTags"?: {
        [key: string]: {
            [key: string]: any;
        };
    };
    /**
     * The system tags associated with this resource, if any. The system tags are set by Oracle cloud infrastructure services. Each key is predefined and scoped to namespaces.
     * For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
     * Example: {@code {orcl-cloud: {free-tier-retain: true}}}
     *
     */
    "systemTags"?: {
        [key: string]: {
            [key: string]: any;
        };
    };
}
export declare namespace CreateRoverClusterDetails {
    enum ShippingPreference {
        OracleShipped = "ORACLE_SHIPPED",
        CustomerPickup = "CUSTOMER_PICKUP"
    }
    function getJsonObj(obj: CreateRoverClusterDetails): object;
    function getDeserializedJsonObj(obj: CreateRoverClusterDetails): object;
}
