/**
 * Service Catalog API
 * Manage solutions in Oracle Cloud Infrastructure Service Catalog.
 * OpenAPI spec version: 20210527
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * Full details of an application or a solution, which lives inside the tenancy and may be included into service catalogs.
 *
 */
export interface PrivateApplication {
    /**
     * The lifecycle state of the private application.
     */
    "lifecycleState": PrivateApplication.LifecycleState;
    /**
     * The [OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment where the private application resides.
     *
     */
    "compartmentId": string;
    /**
     * The unique identifier for the private application in Marketplace.
     */
    "id": string;
    /**
     * The name of the private application.
     */
    "displayName": string;
    /**
     * A short description of the private application.
     */
    "shortDescription"?: string;
    /**
     * A long description of the private application.
     */
    "longDescription"?: string;
    "logo"?: model.UploadData;
    /**
     * Type of packages within this private application.
     */
    "packageType": model.PackageTypeEnum;
    /**
      * The date and time the private application was created, expressed in [RFC 3339](https://tools.ietf.org/html/rfc3339)
  * timestamp format.
  * <p>
  Example: {@code 2021-05-26T21:10:29.600Z}
  *
      */
    "timeCreated": Date;
    /**
      * The date and time the private application was last modified, expressed in [RFC 3339](https://tools.ietf.org/html/rfc3339)
  * timestamp format.
  * <p>
  Example: {@code 2021-12-10T05:10:29.721Z}
  *
      */
    "timeUpdated"?: Date;
    /**
     * Defined tags for this resource. Each key is predefined and scoped to a namespace.
     * Example: {@code {\"foo-namespace\": {\"bar-key\": \"value\"}}}
     *
     */
    "definedTags"?: {
        [key: string]: {
            [key: string]: any;
        };
    };
    /**
     * Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
     * Example: {@code {\"bar-key\": \"value\"}}
     *
     */
    "freeformTags"?: {
        [key: string]: string;
    };
}
export declare namespace PrivateApplication {
    enum LifecycleState {
        Creating = "CREATING",
        Updating = "UPDATING",
        Active = "ACTIVE",
        Deleting = "DELETING",
        Deleted = "DELETED",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    function getJsonObj(obj: PrivateApplication): object;
    function getDeserializedJsonObj(obj: PrivateApplication): object;
}
