/**
 * Service Mesh API
 * Use the Service Mesh API to manage mesh, virtual service, access policy and other mesh related items.
 * OpenAPI spec version: 20220615
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import common = require("oci-common");
import * as requests from "./request";
import * as responses from "./response";
import { ServiceMeshWaiter } from "./servicemesh-waiter";
declare const Breaker: any;
export declare enum ServiceMeshApiKeys {
}
/**
 * This service client uses {@link common.CircuitBreaker.DefaultConfiguration} for all the operations by default if no circuit breaker configuration is defined by the user.
 */
export declare class ServiceMeshClient {
    protected static serviceEndpointTemplate: string;
    protected static endpointServiceName: string;
    protected "_realmSpecificEndpointTemplateEnabled": boolean | undefined;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_waiters": ServiceMeshWaiter;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: typeof Breaker | null;
    protected _httpOptions: any;
    protected _bodyDuplexMode: any;
    targetService: string;
    protected _regionId: string;
    protected "_region": common.Region;
    protected _lastSetRegionOrRegionId: string;
    protected _httpClient: common.HttpClient;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    get endpoint(): string;
    /**
     * Sets the endpoint to call (ex, https://www.example.com).
     * @param endpoint The endpoint of the service.
     */
    set endpoint(endpoint: string);
    get logger(): import("oci-common/lib/log").Logger;
    /**
     * Determines whether realm specific endpoint should be used or not.
     * Set realmSpecificEndpointTemplateEnabled to "true" if the user wants to enable use of realm specific endpoint template, otherwise set it to "false"
     * @param realmSpecificEndpointTemplateEnabled flag to enable the use of realm specific endpoint template
     */
    set useRealmSpecificEndpointTemplate(realmSpecificEndpointTemplateEnabled: boolean);
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    set region(region: common.Region);
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    set regionId(regionId: string);
    /**
     * Creates a new ServiceMeshWaiter for resources for this service.
     *
     * @param config The waiter configuration for termination and delay strategy
     * @return The service waiters.
     */
    createWaiters(config?: common.WaiterConfiguration): ServiceMeshWaiter;
    /**
     * Gets the waiters available for resources for this service.
     *
     * @return The service waiters.
     */
    getWaiters(): ServiceMeshWaiter;
    /**
     * Shutdown the circuit breaker used by the client when it is no longer needed
     */
    shutdownCircuitBreaker(): void;
    /**
     * Close the client once it is no longer needed
     */
    close(): void;
    /**
     * Cancels the work request with the given ID.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CancelWorkRequestRequest
     * @return CancelWorkRequestResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/servicemesh/CancelWorkRequest.ts.html |here} to see how to use CancelWorkRequest API.
     */
    cancelWorkRequest(cancelWorkRequestRequest: requests.CancelWorkRequestRequest): Promise<responses.CancelWorkRequestResponse>;
    /**
     * Moves an AccessPolicy resource from one compartment identifier to another. When provided, If-Match is checked against ETag values of the resource.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ChangeAccessPolicyCompartmentRequest
     * @return ChangeAccessPolicyCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/servicemesh/ChangeAccessPolicyCompartment.ts.html |here} to see how to use ChangeAccessPolicyCompartment API.
     */
    changeAccessPolicyCompartment(changeAccessPolicyCompartmentRequest: requests.ChangeAccessPolicyCompartmentRequest): Promise<responses.ChangeAccessPolicyCompartmentResponse>;
    /**
     * Moves a IngressGateway resource from one compartment identifier to another. When provided, If-Match is checked against ETag values of the resource.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ChangeIngressGatewayCompartmentRequest
     * @return ChangeIngressGatewayCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/servicemesh/ChangeIngressGatewayCompartment.ts.html |here} to see how to use ChangeIngressGatewayCompartment API.
     */
    changeIngressGatewayCompartment(changeIngressGatewayCompartmentRequest: requests.ChangeIngressGatewayCompartmentRequest): Promise<responses.ChangeIngressGatewayCompartmentResponse>;
    /**
     * Moves a IngressGatewayRouteTable resource from one compartment identifier to another. When provided, If-Match is checked against ETag values of the resource.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ChangeIngressGatewayRouteTableCompartmentRequest
     * @return ChangeIngressGatewayRouteTableCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/servicemesh/ChangeIngressGatewayRouteTableCompartment.ts.html |here} to see how to use ChangeIngressGatewayRouteTableCompartment API.
     */
    changeIngressGatewayRouteTableCompartment(changeIngressGatewayRouteTableCompartmentRequest: requests.ChangeIngressGatewayRouteTableCompartmentRequest): Promise<responses.ChangeIngressGatewayRouteTableCompartmentResponse>;
    /**
     * Moves a Mesh resource from one compartment identifier to another. When provided, If-Match is checked against ETag values of the resource.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ChangeMeshCompartmentRequest
     * @return ChangeMeshCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/servicemesh/ChangeMeshCompartment.ts.html |here} to see how to use ChangeMeshCompartment API.
     */
    changeMeshCompartment(changeMeshCompartmentRequest: requests.ChangeMeshCompartmentRequest): Promise<responses.ChangeMeshCompartmentResponse>;
    /**
     * Moves a VirtualDeployment resource from one compartment identifier to another. When provided, If-Match is checked against ETag values of the resource.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ChangeVirtualDeploymentCompartmentRequest
     * @return ChangeVirtualDeploymentCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/servicemesh/ChangeVirtualDeploymentCompartment.ts.html |here} to see how to use ChangeVirtualDeploymentCompartment API.
     */
    changeVirtualDeploymentCompartment(changeVirtualDeploymentCompartmentRequest: requests.ChangeVirtualDeploymentCompartmentRequest): Promise<responses.ChangeVirtualDeploymentCompartmentResponse>;
    /**
     * Moves a VirtualService resource from one compartment identifier to another. When provided, If-Match is checked against ETag values of the resource.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ChangeVirtualServiceCompartmentRequest
     * @return ChangeVirtualServiceCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/servicemesh/ChangeVirtualServiceCompartment.ts.html |here} to see how to use ChangeVirtualServiceCompartment API.
     */
    changeVirtualServiceCompartment(changeVirtualServiceCompartmentRequest: requests.ChangeVirtualServiceCompartmentRequest): Promise<responses.ChangeVirtualServiceCompartmentResponse>;
    /**
     * Moves a VirtualServiceRouteTable resource from one compartment identifier to another. When provided, If-Match is checked against ETag values of the resource.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ChangeVirtualServiceRouteTableCompartmentRequest
     * @return ChangeVirtualServiceRouteTableCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/servicemesh/ChangeVirtualServiceRouteTableCompartment.ts.html |here} to see how to use ChangeVirtualServiceRouteTableCompartment API.
     */
    changeVirtualServiceRouteTableCompartment(changeVirtualServiceRouteTableCompartmentRequest: requests.ChangeVirtualServiceRouteTableCompartmentRequest): Promise<responses.ChangeVirtualServiceRouteTableCompartmentResponse>;
    /**
     * Creates a new AccessPolicy.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateAccessPolicyRequest
     * @return CreateAccessPolicyResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/servicemesh/CreateAccessPolicy.ts.html |here} to see how to use CreateAccessPolicy API.
     */
    createAccessPolicy(createAccessPolicyRequest: requests.CreateAccessPolicyRequest): Promise<responses.CreateAccessPolicyResponse>;
    /**
     * Creates a new IngressGateway.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateIngressGatewayRequest
     * @return CreateIngressGatewayResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/servicemesh/CreateIngressGateway.ts.html |here} to see how to use CreateIngressGateway API.
     */
    createIngressGateway(createIngressGatewayRequest: requests.CreateIngressGatewayRequest): Promise<responses.CreateIngressGatewayResponse>;
    /**
     * Creates a new IngressGatewayRouteTable.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateIngressGatewayRouteTableRequest
     * @return CreateIngressGatewayRouteTableResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/servicemesh/CreateIngressGatewayRouteTable.ts.html |here} to see how to use CreateIngressGatewayRouteTable API.
     */
    createIngressGatewayRouteTable(createIngressGatewayRouteTableRequest: requests.CreateIngressGatewayRouteTableRequest): Promise<responses.CreateIngressGatewayRouteTableResponse>;
    /**
     * Creates a new Mesh.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateMeshRequest
     * @return CreateMeshResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/servicemesh/CreateMesh.ts.html |here} to see how to use CreateMesh API.
     */
    createMesh(createMeshRequest: requests.CreateMeshRequest): Promise<responses.CreateMeshResponse>;
    /**
     * Creates a new VirtualDeployment.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateVirtualDeploymentRequest
     * @return CreateVirtualDeploymentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/servicemesh/CreateVirtualDeployment.ts.html |here} to see how to use CreateVirtualDeployment API.
     */
    createVirtualDeployment(createVirtualDeploymentRequest: requests.CreateVirtualDeploymentRequest): Promise<responses.CreateVirtualDeploymentResponse>;
    /**
     * Creates a new VirtualService.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateVirtualServiceRequest
     * @return CreateVirtualServiceResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/servicemesh/CreateVirtualService.ts.html |here} to see how to use CreateVirtualService API.
     */
    createVirtualService(createVirtualServiceRequest: requests.CreateVirtualServiceRequest): Promise<responses.CreateVirtualServiceResponse>;
    /**
     * Creates a new VirtualServiceRouteTable.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateVirtualServiceRouteTableRequest
     * @return CreateVirtualServiceRouteTableResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/servicemesh/CreateVirtualServiceRouteTable.ts.html |here} to see how to use CreateVirtualServiceRouteTable API.
     */
    createVirtualServiceRouteTable(createVirtualServiceRouteTableRequest: requests.CreateVirtualServiceRouteTableRequest): Promise<responses.CreateVirtualServiceRouteTableResponse>;
    /**
     * Deletes an AccessPolicy resource by identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteAccessPolicyRequest
     * @return DeleteAccessPolicyResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/servicemesh/DeleteAccessPolicy.ts.html |here} to see how to use DeleteAccessPolicy API.
     */
    deleteAccessPolicy(deleteAccessPolicyRequest: requests.DeleteAccessPolicyRequest): Promise<responses.DeleteAccessPolicyResponse>;
    /**
     * Deletes an IngressGateway resource by identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteIngressGatewayRequest
     * @return DeleteIngressGatewayResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/servicemesh/DeleteIngressGateway.ts.html |here} to see how to use DeleteIngressGateway API.
     */
    deleteIngressGateway(deleteIngressGatewayRequest: requests.DeleteIngressGatewayRequest): Promise<responses.DeleteIngressGatewayResponse>;
    /**
     * Deletes a IngressGatewayRouteTable resource by identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteIngressGatewayRouteTableRequest
     * @return DeleteIngressGatewayRouteTableResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/servicemesh/DeleteIngressGatewayRouteTable.ts.html |here} to see how to use DeleteIngressGatewayRouteTable API.
     */
    deleteIngressGatewayRouteTable(deleteIngressGatewayRouteTableRequest: requests.DeleteIngressGatewayRouteTableRequest): Promise<responses.DeleteIngressGatewayRouteTableResponse>;
    /**
     * Deletes a Mesh resource by identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteMeshRequest
     * @return DeleteMeshResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/servicemesh/DeleteMesh.ts.html |here} to see how to use DeleteMesh API.
     */
    deleteMesh(deleteMeshRequest: requests.DeleteMeshRequest): Promise<responses.DeleteMeshResponse>;
    /**
     * Deletes a VirtualDeployment resource by identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteVirtualDeploymentRequest
     * @return DeleteVirtualDeploymentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/servicemesh/DeleteVirtualDeployment.ts.html |here} to see how to use DeleteVirtualDeployment API.
     */
    deleteVirtualDeployment(deleteVirtualDeploymentRequest: requests.DeleteVirtualDeploymentRequest): Promise<responses.DeleteVirtualDeploymentResponse>;
    /**
     * Deletes a VirtualService resource by identifier
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteVirtualServiceRequest
     * @return DeleteVirtualServiceResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/servicemesh/DeleteVirtualService.ts.html |here} to see how to use DeleteVirtualService API.
     */
    deleteVirtualService(deleteVirtualServiceRequest: requests.DeleteVirtualServiceRequest): Promise<responses.DeleteVirtualServiceResponse>;
    /**
     * Deletes a VirtualServiceRouteTable resource by identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteVirtualServiceRouteTableRequest
     * @return DeleteVirtualServiceRouteTableResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/servicemesh/DeleteVirtualServiceRouteTable.ts.html |here} to see how to use DeleteVirtualServiceRouteTable API.
     */
    deleteVirtualServiceRouteTable(deleteVirtualServiceRouteTableRequest: requests.DeleteVirtualServiceRouteTableRequest): Promise<responses.DeleteVirtualServiceRouteTableResponse>;
    /**
     * Get an AccessPolicy by identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetAccessPolicyRequest
     * @return GetAccessPolicyResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/servicemesh/GetAccessPolicy.ts.html |here} to see how to use GetAccessPolicy API.
     */
    getAccessPolicy(getAccessPolicyRequest: requests.GetAccessPolicyRequest): Promise<responses.GetAccessPolicyResponse>;
    /**
     * Gets an IngressGateway by identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetIngressGatewayRequest
     * @return GetIngressGatewayResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/servicemesh/GetIngressGateway.ts.html |here} to see how to use GetIngressGateway API.
     */
    getIngressGateway(getIngressGatewayRequest: requests.GetIngressGatewayRequest): Promise<responses.GetIngressGatewayResponse>;
    /**
     * Gets a IngressGatewayRouteTable by identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetIngressGatewayRouteTableRequest
     * @return GetIngressGatewayRouteTableResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/servicemesh/GetIngressGatewayRouteTable.ts.html |here} to see how to use GetIngressGatewayRouteTable API.
     */
    getIngressGatewayRouteTable(getIngressGatewayRouteTableRequest: requests.GetIngressGatewayRouteTableRequest): Promise<responses.GetIngressGatewayRouteTableResponse>;
    /**
     * Gets a Mesh by identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetMeshRequest
     * @return GetMeshResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/servicemesh/GetMesh.ts.html |here} to see how to use GetMesh API.
     */
    getMesh(getMeshRequest: requests.GetMeshRequest): Promise<responses.GetMeshResponse>;
    /**
     * Returns the attributes of the Proxy such as proxy image version.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetProxyDetailsRequest
     * @return GetProxyDetailsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/servicemesh/GetProxyDetails.ts.html |here} to see how to use GetProxyDetails API.
     */
    getProxyDetails(getProxyDetailsRequest: requests.GetProxyDetailsRequest): Promise<responses.GetProxyDetailsResponse>;
    /**
     * Gets a VirtualDeployment by identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetVirtualDeploymentRequest
     * @return GetVirtualDeploymentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/servicemesh/GetVirtualDeployment.ts.html |here} to see how to use GetVirtualDeployment API.
     */
    getVirtualDeployment(getVirtualDeploymentRequest: requests.GetVirtualDeploymentRequest): Promise<responses.GetVirtualDeploymentResponse>;
    /**
     * Gets a VirtualService by identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetVirtualServiceRequest
     * @return GetVirtualServiceResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/servicemesh/GetVirtualService.ts.html |here} to see how to use GetVirtualService API.
     */
    getVirtualService(getVirtualServiceRequest: requests.GetVirtualServiceRequest): Promise<responses.GetVirtualServiceResponse>;
    /**
     * Gets a VirtualServiceRouteTable by identifier.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetVirtualServiceRouteTableRequest
     * @return GetVirtualServiceRouteTableResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/servicemesh/GetVirtualServiceRouteTable.ts.html |here} to see how to use GetVirtualServiceRouteTable API.
     */
    getVirtualServiceRouteTable(getVirtualServiceRouteTableRequest: requests.GetVirtualServiceRouteTableRequest): Promise<responses.GetVirtualServiceRouteTableResponse>;
    /**
     * Gets the status of the work request with the given ID.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetWorkRequestRequest
     * @return GetWorkRequestResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/servicemesh/GetWorkRequest.ts.html |here} to see how to use GetWorkRequest API.
     */
    getWorkRequest(getWorkRequestRequest: requests.GetWorkRequestRequest): Promise<responses.GetWorkRequestResponse>;
    /**
     * Returns a list of AccessPolicy objects.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListAccessPoliciesRequest
     * @return ListAccessPoliciesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/servicemesh/ListAccessPolicies.ts.html |here} to see how to use ListAccessPolicies API.
     */
    listAccessPolicies(listAccessPoliciesRequest: requests.ListAccessPoliciesRequest): Promise<responses.ListAccessPoliciesResponse>;
    /**
     * Returns a list of IngressGatewayRouteTable objects.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListIngressGatewayRouteTablesRequest
     * @return ListIngressGatewayRouteTablesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/servicemesh/ListIngressGatewayRouteTables.ts.html |here} to see how to use ListIngressGatewayRouteTables API.
     */
    listIngressGatewayRouteTables(listIngressGatewayRouteTablesRequest: requests.ListIngressGatewayRouteTablesRequest): Promise<responses.ListIngressGatewayRouteTablesResponse>;
    /**
     * Returns a list of IngressGateway objects.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListIngressGatewaysRequest
     * @return ListIngressGatewaysResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/servicemesh/ListIngressGateways.ts.html |here} to see how to use ListIngressGateways API.
     */
    listIngressGateways(listIngressGatewaysRequest: requests.ListIngressGatewaysRequest): Promise<responses.ListIngressGatewaysResponse>;
    /**
     * Returns a list of Mesh objects.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListMeshesRequest
     * @return ListMeshesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/servicemesh/ListMeshes.ts.html |here} to see how to use ListMeshes API.
     */
    listMeshes(listMeshesRequest: requests.ListMeshesRequest): Promise<responses.ListMeshesResponse>;
    /**
     * Returns a list of VirtualDeployments.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListVirtualDeploymentsRequest
     * @return ListVirtualDeploymentsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/servicemesh/ListVirtualDeployments.ts.html |here} to see how to use ListVirtualDeployments API.
     */
    listVirtualDeployments(listVirtualDeploymentsRequest: requests.ListVirtualDeploymentsRequest): Promise<responses.ListVirtualDeploymentsResponse>;
    /**
     * Returns a list of VirtualServiceRouteTable objects.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListVirtualServiceRouteTablesRequest
     * @return ListVirtualServiceRouteTablesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/servicemesh/ListVirtualServiceRouteTables.ts.html |here} to see how to use ListVirtualServiceRouteTables API.
     */
    listVirtualServiceRouteTables(listVirtualServiceRouteTablesRequest: requests.ListVirtualServiceRouteTablesRequest): Promise<responses.ListVirtualServiceRouteTablesResponse>;
    /**
     * Returns a list of VirtualService objects.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListVirtualServicesRequest
     * @return ListVirtualServicesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/servicemesh/ListVirtualServices.ts.html |here} to see how to use ListVirtualServices API.
     */
    listVirtualServices(listVirtualServicesRequest: requests.ListVirtualServicesRequest): Promise<responses.ListVirtualServicesResponse>;
    /**
     * Return a (paginated) list of errors for a given work request.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListWorkRequestErrorsRequest
     * @return ListWorkRequestErrorsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/servicemesh/ListWorkRequestErrors.ts.html |here} to see how to use ListWorkRequestErrors API.
     */
    listWorkRequestErrors(listWorkRequestErrorsRequest: requests.ListWorkRequestErrorsRequest): Promise<responses.ListWorkRequestErrorsResponse>;
    /**
     * Return a (paginated) list of logs for a given work request.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListWorkRequestLogsRequest
     * @return ListWorkRequestLogsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/servicemesh/ListWorkRequestLogs.ts.html |here} to see how to use ListWorkRequestLogs API.
     */
    listWorkRequestLogs(listWorkRequestLogsRequest: requests.ListWorkRequestLogsRequest): Promise<responses.ListWorkRequestLogsResponse>;
    /**
     * Lists the work requests in a compartment.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListWorkRequestsRequest
     * @return ListWorkRequestsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/servicemesh/ListWorkRequests.ts.html |here} to see how to use ListWorkRequests API.
     */
    listWorkRequests(listWorkRequestsRequest: requests.ListWorkRequestsRequest): Promise<responses.ListWorkRequestsResponse>;
    /**
     * Updates the AccessPolicy.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateAccessPolicyRequest
     * @return UpdateAccessPolicyResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/servicemesh/UpdateAccessPolicy.ts.html |here} to see how to use UpdateAccessPolicy API.
     */
    updateAccessPolicy(updateAccessPolicyRequest: requests.UpdateAccessPolicyRequest): Promise<responses.UpdateAccessPolicyResponse>;
    /**
     * Updates the IngressGateway.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateIngressGatewayRequest
     * @return UpdateIngressGatewayResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/servicemesh/UpdateIngressGateway.ts.html |here} to see how to use UpdateIngressGateway API.
     */
    updateIngressGateway(updateIngressGatewayRequest: requests.UpdateIngressGatewayRequest): Promise<responses.UpdateIngressGatewayResponse>;
    /**
     * Updates the IngressGatewayRouteTable.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateIngressGatewayRouteTableRequest
     * @return UpdateIngressGatewayRouteTableResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/servicemesh/UpdateIngressGatewayRouteTable.ts.html |here} to see how to use UpdateIngressGatewayRouteTable API.
     */
    updateIngressGatewayRouteTable(updateIngressGatewayRouteTableRequest: requests.UpdateIngressGatewayRouteTableRequest): Promise<responses.UpdateIngressGatewayRouteTableResponse>;
    /**
     * Updates the Mesh.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateMeshRequest
     * @return UpdateMeshResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/servicemesh/UpdateMesh.ts.html |here} to see how to use UpdateMesh API.
     */
    updateMesh(updateMeshRequest: requests.UpdateMeshRequest): Promise<responses.UpdateMeshResponse>;
    /**
     * Updates the VirtualDeployment.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateVirtualDeploymentRequest
     * @return UpdateVirtualDeploymentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/servicemesh/UpdateVirtualDeployment.ts.html |here} to see how to use UpdateVirtualDeployment API.
     */
    updateVirtualDeployment(updateVirtualDeploymentRequest: requests.UpdateVirtualDeploymentRequest): Promise<responses.UpdateVirtualDeploymentResponse>;
    /**
     * Updates the VirtualService.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateVirtualServiceRequest
     * @return UpdateVirtualServiceResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/servicemesh/UpdateVirtualService.ts.html |here} to see how to use UpdateVirtualService API.
     */
    updateVirtualService(updateVirtualServiceRequest: requests.UpdateVirtualServiceRequest): Promise<responses.UpdateVirtualServiceResponse>;
    /**
     * Updates the VirtualServiceRouteTable.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateVirtualServiceRouteTableRequest
     * @return UpdateVirtualServiceRouteTableResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/servicemesh/UpdateVirtualServiceRouteTable.ts.html |here} to see how to use UpdateVirtualServiceRouteTable API.
     */
    updateVirtualServiceRouteTable(updateVirtualServiceRouteTableRequest: requests.UpdateVirtualServiceRouteTableRequest): Promise<responses.UpdateVirtualServiceRouteTableResponse>;
}
export {};
