/**
 * Stack Monitoring API
 * Stack Monitoring API.
 * OpenAPI spec version: 20210330
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * The property search criteria for listing monitored resources.
 */
export interface SearchMonitoredResourcesDetails {
    /**
     * Compartment Identifier [OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm).
     *
     */
    "compartmentId": string;
    /**
     * Multiple compartment identifiers [OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm).
     *
     */
    "compartmentIds"?: Array<string>;
    /**
     * Multiple lifecycle states filter.
     *
     */
    "lifecycleStates"?: Array<model.ResourceLifecycleState>;
    /**
     * Source type filter.
     */
    "sourceType"?: model.SourceType;
    /**
     * Resource category filter.
     */
    "resourceCategory"?: model.ResourceCategory;
    /**
     * A filter to return resources that match exact resource name.
     *
     */
    "name"?: string;
    /**
     * A filter to return resources that match resource name pattern given. The match is not case sensitive.
     */
    "nameContains"?: string;
    /**
     * A filter to return resources that match resource type.
     *
     */
    "type"?: string;
    /**
     * A filter to return resources with host name match.
     *
     */
    "hostName"?: string;
    /**
     * External resource is any OCI resource identifier [OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm)
     * which is not a Stack Monitoring service resource.
     * Currently supports only following resource types - Container database, non-container database,
     * pluggable database and OCI compute instance.
     *
     */
    "externalId"?: string;
    /**
     * A filter to return resources with host name pattern.
     *
     */
    "hostNameContains"?: string;
    /**
     * A filter to return resources with matching management agent id.
     */
    "managementAgentId"?: string;
    /**
     * A filter to return resources with matching lifecycle state.
     */
    "lifecycleState"?: model.ResourceLifecycleState;
    /**
     * License edition of the monitored resource.
     */
    "license"?: model.LicenseType;
    /**
     * Search for resources that were created within a specific date range,
     * using this parameter to specify the earliest creation date for the
     * returned list (inclusive). Specifying this parameter without the
     * corresponding {@code timeCreatedLessThan} parameter will retrieve resources created from the
     * given {@code timeCreatedGreaterThanOrEqualTo} to the current time, in \"YYYY-MM-ddThh:mmZ\" format with a
     * Z offset, as defined by [RFC 3339](https://tools.ietf.org/html/rfc3339).
     * <p>
     **Example:** 2016-12-19T16:39:57.600Z
     *
     */
    "timeCreatedGreaterThanOrEqualTo"?: Date;
    /**
     * Search for resources that were created within a specific date range,
     * using this parameter to specify the latest creation date for the returned
     * list (exclusive). Specifying this parameter without the corresponding
     * {@code timeCreatedGreaterThanOrEqualTo} parameter will retrieve all resources created before the
     * specified end date, in \"YYYY-MM-ddThh:mmZ\" format with a Z offset, as
     * defined by [RFC 3339](https://tools.ietf.org/html/rfc3339).
     * <p>
     **Example:** 2016-12-19T16:39:57.600Z
     *
     */
    "timeCreatedLessThan"?: Date;
    /**
     * Search for resources that were updated within a specific date range,
     * using this parameter to specify the earliest update date for the
     * returned list (inclusive). Specifying this parameter without the
     * corresponding {@code timeUpdatedLessThan} parameter will retrieve resources updated from the
     * given {@code timeUpdatedGreaterThanOrEqualTo} to the current time, in \"YYYY-MM-ddThh:mmZ\" format with a
     * Z offset, as defined by [RFC 3339](https://tools.ietf.org/html/rfc3339).
     * <p>
     **Example:** 2016-12-19T16:39:57.600Z
     *
     */
    "timeUpdatedGreaterThanOrEqualTo"?: Date;
    /**
     * Search for resources that were updated within a specific date range,
     * using this parameter to specify the latest creation date for the returned
     * list (exclusive). Specifying this parameter without the corresponding
     * {@code timeUpdatedGreaterThanOrEqualTo} parameter will retrieve all resources updated before the
     * specified end date, in \"YYYY-MM-ddThh:mmZ\" format with a Z offset, as
     * defined by [RFC 3339](https://tools.ietf.org/html/rfc3339).
     * <p>
     **Example:** 2016-12-19T16:39:57.600Z
     *
     */
    "timeUpdatedLessThan"?: Date;
    /**
     * Time zone in the form of tz database canonical zone ID. Specifies the preference with
     * a value that uses the IANA Time Zone Database format (x-obmcs-time-zone).
     * For example - America/Los_Angeles
     *
     */
    "resourceTimeZone"?: string;
    /**
     * The sort order to use, either 'ASC' or 'DESC'.
     */
    "sortOrder"?: model.SortOrder;
    /**
     * The field to sort by. Only one sort order may be provided.
     * Default order for timeCreated is descending. Default order for resources is ascending.
     *
     */
    "sortBy"?: SearchMonitoredResourcesDetails.SortBy;
    /**
     * Criteria based on resource property.
     */
    "propertyEquals"?: {
        [key: string]: string;
    };
}
export declare namespace SearchMonitoredResourcesDetails {
    enum SortBy {
        TimeCreated = "TIME_CREATED",
        ResourceName = "RESOURCE_NAME"
    }
    function getJsonObj(obj: SearchMonitoredResourcesDetails): object;
    function getDeserializedJsonObj(obj: SearchMonitoredResourcesDetails): object;
}
