/**
 * Threat Intelligence API
 * Use the Threat Intelligence API to search for information about known threat indicators, including suspicious IP addresses, domain names, and other digital fingerprints. Threat Intelligence is a managed database of curated threat intelligence that comes from first party Oracle security insights, open source feeds, and vendor-procured data. For more information, see the [Threat Intelligence documentation](/iaas/Content/threat-intel/home.htm).
 * OpenAPI spec version: 20220901
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * Query parameters to filter indicators
 */
export interface SummarizeIndicatorsDetails {
    /**
     * The type of indicator this is
     */
    "indicatorType"?: model.IndicatorType;
    /**
     * The value for the type of indicator this is
     */
    "indicatorValue"?: string;
    /**
     * The threat type of entites to be returned.
     */
    "threatTypes"?: Array<string>;
    /**
     * The minimum level of confidence to return Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "confidenceGreaterThanOrEqualTo"?: number;
    /**
     * The oldest update time of entities to be returned.
     */
    "timeUpdatedGreaterThanOrEqualTo"?: Date;
    /**
     * The newest update time of entities to be returned.
     */
    "timeUpdatedLessThan"?: Date;
    /**
     * The oldest last seen time of entities to be returned.
     */
    "timeLastSeenGreaterThanOrEqualTo"?: Date;
    /**
     * The newest last seen time of entities to be returned.
     */
    "timeLastSeenLessThan"?: Date;
    /**
     * The oldest creation time of entities to be returned.
     */
    "timeCreatedGreaterThanOrEqualTo"?: Date;
    /**
     * The newest creation time of entities to be returned.
     */
    "timeCreatedLessThan"?: Date;
    /**
     * Filter to include indicators that have been seen by the provided source.
     */
    "indicatorSeenBy"?: string;
    /**
     * Filter to include indicators associated with the provided malware.
     */
    "malware"?: string;
    /**
     * Filter to included indicators associated with the provided threat actor.
     */
    "threatActor"?: string;
    /**
     * The sort order to use, either 'ASC' or 'DESC'.
     */
    "sortOrder"?: model.SortOrder;
    /**
     * The field to sort by. Only one field to sort by may be provided
     */
    "sortBy"?: SummarizeIndicatorsDetails.SortBy;
}
export declare namespace SummarizeIndicatorsDetails {
    enum SortBy {
        Confidence = "CONFIDENCE",
        Timecreated = "TIMECREATED",
        Timeupdated = "TIMEUPDATED",
        Timelastseen = "TIMELASTSEEN"
    }
    function getJsonObj(obj: SummarizeIndicatorsDetails): object;
    function getDeserializedJsonObj(obj: SummarizeIndicatorsDetails): object;
}
