/**
 * Usage Proxy API
 * Use the Usage Proxy API to list Oracle Support Rewards, view related detailed usage information, and manage users who redeem rewards. For more information, see [Oracle Support Rewards Overview](/iaas/Content/Billing/Concepts/supportrewardsoverview.htm).
 * OpenAPI spec version: 20190111
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
/**
 * Encapsulates a collection of Hard and Soft Limits for a resource within a subscription.
 */
export interface UsageLimitSummary {
    /**
     * Time when the usage limit was created
     */
    "timeCreated": Date;
    /**
     * Entitlement ID of the usage limit
     */
    "entitlementId": string;
    /**
     * The usage limit ID
     */
    "id": string;
    /**
     * Time when the usage limit was modified
     */
    "timeModified": Date;
    /**
     * The resource for which the limit is defined
     */
    "resourceName": string;
    /**
     * The service for which the limit is defined
     */
    "serviceName": string;
    /**
     * The limit value
     */
    "limit": string;
    /**
     * The user who created the limit
     */
    "createdBy": string;
    /**
     * The user who modified the limit
     */
    "modifiedBy": string;
    /**
     * The action when usage limit is hit
     */
    "action": UsageLimitSummary.Action;
    /**
     * The alert level of the usage limit Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "alertLevel": number;
    /**
     * The limit type of the usage limit
     */
    "limitType": UsageLimitSummary.LimitType;
    /**
     * The value type of the usage limit
     */
    "valueType": UsageLimitSummary.ValueType;
    /**
     * The usage limit lifecycle state.
     */
    "lifecycleState": UsageLimitSummary.LifecycleState;
    /**
     * The maximum hard limit set for the usage limit
     */
    "maxHardLimit"?: string;
    /**
     * The SKU for which the usage limit is set
     */
    "skuPartId"?: string;
}
export declare namespace UsageLimitSummary {
    enum Action {
        QuotaBreach = "QUOTA_BREACH",
        QuotaAlert = "QUOTA_ALERT",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    enum LimitType {
        Hard = "HARD",
        Soft = "SOFT",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    enum ValueType {
        Absolute = "ABSOLUTE",
        Percentage = "PERCENTAGE",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    enum LifecycleState {
        Active = "ACTIVE",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    function getJsonObj(obj: UsageLimitSummary): object;
    function getDeserializedJsonObj(obj: UsageLimitSummary): object;
}
