/**
 * Usage API
 * Use the Usage API to view your Oracle Cloud usage and costs. The API allows you to request data that meets the specified filter criteria, and to group that data by the chosen dimension. The Usage API is used by the Cost Analysis and Carbon Emissions Analysis tools in the Console. See [Cost Analysis Overview](/Content/Billing/Concepts/costanalysisoverview.htm) and [Using the Usage API](/Content/Billing/Concepts/costanalysisoverview.htm#cost_analysis_using_the_api) for more information.
 * OpenAPI spec version: 20200107
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * The query properties.
 */
export interface QueryProperties {
    /**
     * Aggregate the result by. For example: [ \"tagNamespace\", \"tagKey\", \"tagValue\", \"service\", \"skuName\", \"skuPartNumber\", \"unit\", \"compartmentName\", \"compartmentPath\", \"compartmentId\", \"platform\", \"region\", \"logicalAd\", \"resourceId\", \"tenantId\", \"tenantName\" ]
     *
     */
    "groupBy"?: Array<string>;
    /**
     * GroupBy a specific tagKey. Provide the tagNamespace and tagKey in the tag object. Only supports one tag in the list. For example: [ { \"namespace\": \"oracle\", \"key\": \"createdBy\" ]
     *
     */
    "groupByTag"?: Array<model.Tag>;
    "filter"?: model.Filter;
    /**
     * The depth level of the compartment. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "compartmentDepth"?: number;
    /**
     * The usage granularity. DAILY - Daily data aggregation. MONTHLY - Monthly data aggregation.
     * Allowed values are:
     *   DAILY
     *   MONTHLY
     *
     */
    "granularity": QueryProperties.Granularity;
    /**
     * The query usage type. COST by default if it is missing. Usage - Query the usage data. Cost - Query the cost/billing data.
     * Allowed values are:
     *   USAGE
     *   COST
     *   USAGE_AND_COST
     *
     */
    "queryType"?: QueryProperties.QueryType;
    /**
     * Specifies whether aggregated by time. If isAggregateByTime is true, all usage or cost over the query time period will be added up.
     */
    "isAggregateByTime"?: boolean;
    "dateRange": model.StaticDateRange | model.DynamicDateRange;
}
export declare namespace QueryProperties {
    enum Granularity {
        Daily = "DAILY",
        Monthly = "MONTHLY",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    enum QueryType {
        Usage = "USAGE",
        Cost = "COST",
        UsageAndCost = "USAGE_AND_COST",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    function getJsonObj(obj: QueryProperties): object;
    function getDeserializedJsonObj(obj: QueryProperties): object;
}
