/**
 * Usage API
 * Use the Usage API to view your Oracle Cloud usage and costs. The API allows you to request data that meets the specified filter criteria, and to group that data by the chosen dimension. The Usage API is used by the Cost Analysis and Carbon Emissions Analysis tools in the Console. See [Cost Analysis Overview](/Content/Billing/Concepts/costanalysisoverview.htm) and [Using the Usage API](/Content/Billing/Concepts/costanalysisoverview.htm#cost_analysis_using_the_api) for more information.
 * OpenAPI spec version: 20200107
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * Details for the '/usageCarbonEmissions' query.
 */
export interface RequestUsageCarbonEmissionsDetails {
    /**
     * Tenant ID.
     */
    "tenantId": string;
    /**
     * The usage start time.
     */
    "timeUsageStarted": Date;
    /**
     * The usage end time.
     */
    "timeUsageEnded": Date;
    /**
     * Specifies whether aggregated by time. If isAggregateByTime is true, all usage carbon emissions over the query time period will be added up.
     */
    "isAggregateByTime"?: boolean;
    /**
     * Aggregate the result by.
     * For example:
     *   {@code [\"tagNamespace\", \"tagKey\", \"tagValue\", \"service\", \"skuName\", \"skuPartNumber\", \"unit\",
     *     \"compartmentName\", \"compartmentPath\", \"compartmentId\", \"platform\", \"region\", \"logicalAd\",
     *     \"resourceId\", \"resourceName\", \"tenantId\", \"tenantName\", \"subscriptionId\"]}
     *
     */
    "groupBy"?: Array<string>;
    /**
     * GroupBy a specific tagKey. Provide the tagNamespace and tagKey in the tag object. Only supports one tag in the list.
     * For example:
     *   {@code [{\"namespace\":\"oracle\", \"key\":\"createdBy\"]}
     *
     */
    "groupByTag"?: Array<model.Tag>;
    /**
     * The compartment depth level. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "compartmentDepth"?: number;
    "filter"?: model.Filter;
}
export declare namespace RequestUsageCarbonEmissionsDetails {
    function getJsonObj(obj: RequestUsageCarbonEmissionsDetails): object;
    function getDeserializedJsonObj(obj: RequestUsageCarbonEmissionsDetails): object;
}
