/**
 * Visual Builder API
 * Oracle Visual Builder enables developers to quickly build web and mobile applications. With a visual development environment that makes it easy to connect to Oracle data and third-party REST services, developers can build modern, consumer-grade applications in a fraction of the time it would take in other tools.
The Visual Builder Instance Management API allows users to create and manage a Visual Builder instance.

 * OpenAPI spec version: 20210601
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * A description of work request status.
 */
export interface WorkRequest {
    /**
     * Type of the work request.
     */
    "operationType": WorkRequest.OperationType;
    /**
     * Status of current work request.
     */
    "status": WorkRequest.Status;
    /**
     * The id of the work request.
     */
    "id": string;
    /**
     * The ocid of the compartment that contains the work request. Work
     * requests should be scoped to the same compartment as the resource the
     * work request affects. If the work request affects multiple resources,
     * and those resources are not in the same compartment, it is up to the
     * service team to pick the primary resource whose compartment should be
     * used.
     *
     */
    "compartmentId": string;
    /**
     * The resources affected by this work request.
     */
    "resources": Array<model.WorkRequestResource>;
    /**
     * Percentage of the request completed. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "percentComplete": number;
    /**
     * The date and time the request was created, as described in
     * [RFC 3339](https://tools.ietf.org/rfc/rfc3339), section 14.29.
     *
     */
    "timeAccepted": Date;
    /**
     * The date and time the request was started, as described in
     * [RFC 3339](https://tools.ietf.org/rfc/rfc3339),
     * section 14.29.
     *
     */
    "timeStarted"?: Date;
    /**
     * The date and time the object was finished, as described in
     * [RFC 3339](https://tools.ietf.org/rfc/rfc3339).
     *
     */
    "timeFinished"?: Date;
}
export declare namespace WorkRequest {
    enum OperationType {
        CreateVbInstance = "CREATE_VB_INSTANCE",
        UpdateVbInstance = "UPDATE_VB_INSTANCE",
        StopVbInstance = "STOP_VB_INSTANCE",
        StartVbInstance = "START_VB_INSTANCE",
        DeleteVbInstance = "DELETE_VB_INSTANCE",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    enum Status {
        Accepted = "ACCEPTED",
        InProgress = "IN_PROGRESS",
        Failed = "FAILED",
        Succeeded = "SUCCEEDED",
        Canceling = "CANCELING",
        Canceled = "CANCELED",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    function getJsonObj(obj: WorkRequest): object;
    function getDeserializedJsonObj(obj: WorkRequest): object;
}
