/**
 * Network Monitoring API
 * Use the Network Monitoring API to troubleshoot routing and security issues for resources such as virtual cloud networks (VCNs) and compute instances. For more information, see the console
documentation for the [Network Path Analyzer](/iaas/Content/Network/Concepts/path_analyzer.htm) tool.

 * OpenAPI spec version: 20160918
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import common = require("oci-common");
import * as requests from "./request";
import * as responses from "./response";
import { VnMonitoringWaiter } from "./vnmonitoring-waiter";
declare const Breaker: any;
export declare enum VnMonitoringApiKeys {
}
/**
 * This service client uses {@link common.CircuitBreaker.DefaultConfiguration} for all the operations by default if no circuit breaker configuration is defined by the user.
 */
export declare class VnMonitoringClient {
    protected static serviceEndpointTemplate: string;
    protected static endpointServiceName: string;
    protected "_realmSpecificEndpointTemplateEnabled": boolean | undefined;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_waiters": VnMonitoringWaiter;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: typeof Breaker | null;
    protected _httpOptions: any;
    protected _bodyDuplexMode: any;
    targetService: string;
    protected _regionId: string;
    protected "_region": common.Region;
    protected _lastSetRegionOrRegionId: string;
    protected _httpClient: common.HttpClient;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    get endpoint(): string;
    /**
     * Sets the endpoint to call (ex, https://www.example.com).
     * @param endpoint The endpoint of the service.
     */
    set endpoint(endpoint: string);
    get logger(): import("oci-common/lib/log").Logger;
    /**
     * Determines whether realm specific endpoint should be used or not.
     * Set realmSpecificEndpointTemplateEnabled to "true" if the user wants to enable use of realm specific endpoint template, otherwise set it to "false"
     * @param realmSpecificEndpointTemplateEnabled flag to enable the use of realm specific endpoint template
     */
    set useRealmSpecificEndpointTemplate(realmSpecificEndpointTemplateEnabled: boolean);
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    set region(region: common.Region);
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    set regionId(regionId: string);
    /**
     * Creates a new VnMonitoringWaiter for resources for this service.
     *
     * @param config The waiter configuration for termination and delay strategy
     * @return The service waiters.
     */
    createWaiters(config?: common.WaiterConfiguration): VnMonitoringWaiter;
    /**
     * Gets the waiters available for resources for this service.
     *
     * @return The service waiters.
     */
    getWaiters(): VnMonitoringWaiter;
    /**
     * Shutdown the circuit breaker used by the client when it is no longer needed
     */
    shutdownCircuitBreaker(): void;
    /**
     * Close the client once it is no longer needed
     */
    close(): void;
    /**
     * Moves a `PathAnalyzerTest` resource from one compartment to another based on the identifier.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangePathAnalyzerTestCompartmentRequest
     * @return ChangePathAnalyzerTestCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/vnmonitoring/ChangePathAnalyzerTestCompartment.ts.html |here} to see how to use ChangePathAnalyzerTestCompartment API.
     */
    changePathAnalyzerTestCompartment(changePathAnalyzerTestCompartmentRequest: requests.ChangePathAnalyzerTestCompartmentRequest): Promise<responses.ChangePathAnalyzerTestCompartmentResponse>;
    /**
     * Creates a new `PathAnalyzerTest` resource.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreatePathAnalyzerTestRequest
     * @return CreatePathAnalyzerTestResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/vnmonitoring/CreatePathAnalyzerTest.ts.html |here} to see how to use CreatePathAnalyzerTest API.
     */
    createPathAnalyzerTest(createPathAnalyzerTestRequest: requests.CreatePathAnalyzerTestRequest): Promise<responses.CreatePathAnalyzerTestResponse>;
    /**
     * Deletes a `PathAnalyzerTest` resource using its identifier.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeletePathAnalyzerTestRequest
     * @return DeletePathAnalyzerTestResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/vnmonitoring/DeletePathAnalyzerTest.ts.html |here} to see how to use DeletePathAnalyzerTest API.
     */
    deletePathAnalyzerTest(deletePathAnalyzerTestRequest: requests.DeletePathAnalyzerTestRequest): Promise<responses.DeletePathAnalyzerTestResponse>;
    /**
       * Use this method to initiate a [Network Path Analyzer](https://docs.cloud.oracle.com/iaas/Content/Network/Concepts/path_analyzer.htm) analysis. This method returns
  * an opc-work-request-id, and you can poll the status of the work request until it either fails or succeeds.
  * <p>
  If the work request status is successful, use {@link #listWorkRequestResults(ListWorkRequestResultsRequest) listWorkRequestResults}
  * with the work request ID to ask for the successful analysis results. If the work request status is failed, use
  * {@link #listWorkRequestErrors(ListWorkRequestErrorsRequest) listWorkRequestErrors}
  * with the work request ID to ask for the analysis failure information. The information
  * returned from either of these methods can be used to build a final report.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param GetPathAnalysisRequest
       * @return GetPathAnalysisResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/vnmonitoring/GetPathAnalysis.ts.html |here} to see how to use GetPathAnalysis API.
       */
    getPathAnalysis(getPathAnalysisRequest: requests.GetPathAnalysisRequest): Promise<responses.GetPathAnalysisResponse>;
    /**
     * Gets a `PathAnalyzerTest` using its identifier.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetPathAnalyzerTestRequest
     * @return GetPathAnalyzerTestResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/vnmonitoring/GetPathAnalyzerTest.ts.html |here} to see how to use GetPathAnalyzerTest API.
     */
    getPathAnalyzerTest(getPathAnalyzerTestRequest: requests.GetPathAnalyzerTestRequest): Promise<responses.GetPathAnalyzerTestResponse>;
    /**
     * Gets the details of a work request.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetWorkRequestRequest
     * @return GetWorkRequestResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/vnmonitoring/GetWorkRequest.ts.html |here} to see how to use GetWorkRequest API.
     */
    getWorkRequest(getWorkRequestRequest: requests.GetWorkRequestRequest): Promise<responses.GetWorkRequestResponse>;
    /**
     * Returns a list of all `PathAnalyzerTests` in a compartment.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListPathAnalyzerTestsRequest
     * @return ListPathAnalyzerTestsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/vnmonitoring/ListPathAnalyzerTests.ts.html |here} to see how to use ListPathAnalyzerTests API.
     */
    listPathAnalyzerTests(listPathAnalyzerTestsRequest: requests.ListPathAnalyzerTestsRequest): Promise<responses.ListPathAnalyzerTestsResponse>;
    /**
     * Returns a (paginated) list of errors for the work request with the given ID. This information is used to build the final report output.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListWorkRequestErrorsRequest
     * @return ListWorkRequestErrorsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/vnmonitoring/ListWorkRequestErrors.ts.html |here} to see how to use ListWorkRequestErrors API.
     */
    listWorkRequestErrors(listWorkRequestErrorsRequest: requests.ListWorkRequestErrorsRequest): Promise<responses.ListWorkRequestErrorsResponse>;
    /**
     * Returns a (paginated) list of logs for the work request with the given ID.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListWorkRequestLogsRequest
     * @return ListWorkRequestLogsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/vnmonitoring/ListWorkRequestLogs.ts.html |here} to see how to use ListWorkRequestLogs API.
     */
    listWorkRequestLogs(listWorkRequestLogsRequest: requests.ListWorkRequestLogsRequest): Promise<responses.ListWorkRequestLogsResponse>;
    /**
     * Returns a (paginated) list of results for a successful work request. This information is used to
     * build the final report output.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListWorkRequestResultsRequest
     * @return ListWorkRequestResultsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/vnmonitoring/ListWorkRequestResults.ts.html |here} to see how to use ListWorkRequestResults API.
     */
    listWorkRequestResults(listWorkRequestResultsRequest: requests.ListWorkRequestResultsRequest): Promise<responses.ListWorkRequestResultsResponse>;
    /**
     * Lists the work requests in a compartment.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListWorkRequestsRequest
     * @return ListWorkRequestsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/vnmonitoring/ListWorkRequests.ts.html |here} to see how to use ListWorkRequests API.
     */
    listWorkRequests(listWorkRequestsRequest: requests.ListWorkRequestsRequest): Promise<responses.ListWorkRequestsResponse>;
    /**
     * Updates a `PathAnalyzerTest` using its identifier.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdatePathAnalyzerTestRequest
     * @return UpdatePathAnalyzerTestResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/vnmonitoring/UpdatePathAnalyzerTest.ts.html |here} to see how to use UpdatePathAnalyzerTest API.
     */
    updatePathAnalyzerTest(updatePathAnalyzerTestRequest: requests.UpdatePathAnalyzerTestRequest): Promise<responses.UpdatePathAnalyzerTestResponse>;
}
export {};
