/**
 * Network Monitoring API
 * Use the Network Monitoring API to troubleshoot routing and security issues for resources such as virtual cloud networks (VCNs) and compute instances. For more information, see the console
documentation for the [Network Path Analyzer](/iaas/Content/Network/Concepts/path_analyzer.htm) tool.

 * OpenAPI spec version: 20160918
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
export interface CreateIPSecConnectionTunnelDetails {
    /**
     * A user-friendly name. Does not have to be unique, and it's changeable.
     * Avoid entering confidential information.
     *
     */
    "displayName"?: string;
    /**
     * The type of routing to use for this tunnel (BGP dynamic routing, static routing, or policy-based routing).
     *
     */
    "routing"?: CreateIPSecConnectionTunnelDetails.Routing;
    /**
     * Internet Key Exchange protocol version.
     *
     */
    "ikeVersion"?: CreateIPSecConnectionTunnelDetails.IkeVersion;
    /**
     * The shared secret (pre-shared key) to use for the IPSec tunnel. Only numbers, letters, and
     * spaces are allowed. If you don't provide a value,
     * Oracle generates a value for you. You can specify your own shared secret later if
     * you like with {@link #updateIPSecConnectionTunnelSharedSecret(UpdateIPSecConnectionTunnelSharedSecretRequest) updateIPSecConnectionTunnelSharedSecret}.
     *
     */
    "sharedSecret"?: string;
    "bgpSessionConfig"?: model.CreateIPSecTunnelBgpSessionDetails;
    /**
     * Indicates whether the Oracle end of the IPSec connection is able to initiate starting up the IPSec tunnel.
     *
     */
    "oracleInitiation"?: CreateIPSecConnectionTunnelDetails.OracleInitiation;
    /**
      * By default (the {@code AUTO} setting), IKE sends packets with a source and destination port set to 500,
  * and when it detects that the port used to forward packets has changed (most likely because a NAT device
  * is between the CPE device and the Oracle VPN headend) it will try to negotiate the use of NAT-T.
  * <p>
  The {@code ENABLED} option sets the IKE protocol to use port 4500 instead of 500 and forces encapsulating traffic with the ESP protocol inside UDP packets.
  * <p>
  The {@code DISABLED} option directs IKE to completely refuse to negotiate NAT-T
  * even if it senses there may be a NAT device in use.
  *
      */
    "natTranslationEnabled"?: CreateIPSecConnectionTunnelDetails.NatTranslationEnabled;
    "phaseOneConfig"?: model.PhaseOneConfigDetails;
    "phaseTwoConfig"?: model.PhaseTwoConfigDetails;
    "dpdConfig"?: model.DpdConfig;
    /**
     * The headend IP that you can choose on the Oracle side to terminate your private IPSec tunnel.
     *
     */
    "oracleTunnelIp"?: string;
    /**
     * The list of virtual circuit [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm)s over which your network can reach this tunnel.
     *
     */
    "associatedVirtualCircuits"?: Array<string>;
    /**
      * The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the DRG route table assigned to this attachment.
  * <p>
  The DRG route table manages traffic inside the DRG.
  *
      */
    "drgRouteTableId"?: string;
    "encryptionDomainConfig"?: model.CreateIPSecTunnelEncryptionDomainDetails;
}
export declare namespace CreateIPSecConnectionTunnelDetails {
    enum Routing {
        Bgp = "BGP",
        Static = "STATIC",
        Policy = "POLICY"
    }
    enum IkeVersion {
        V1 = "V1",
        V2 = "V2"
    }
    enum OracleInitiation {
        InitiatorOrResponder = "INITIATOR_OR_RESPONDER",
        ResponderOnly = "RESPONDER_ONLY"
    }
    enum NatTranslationEnabled {
        Enabled = "ENABLED",
        Disabled = "DISABLED",
        Auto = "AUTO"
    }
    function getJsonObj(obj: CreateIPSecConnectionTunnelDetails): object;
    function getDeserializedJsonObj(obj: CreateIPSecConnectionTunnelDetails): object;
}
