/**
 * Network Monitoring API
 * Use the Network Monitoring API to troubleshoot routing and security issues for resources such as virtual cloud networks (VCNs) and compute instances. For more information, see the console
documentation for the [Network Path Analyzer](/iaas/Content/Network/Concepts/path_analyzer.htm) tool.

 * OpenAPI spec version: 20160918
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
export interface CreateVcnDetails {
    /**
     * **Deprecated.** Do *not* set this value. Use {@code cidrBlocks} instead.
     * Example: {@code 10.0.0.0/16}
     *
     */
    "cidrBlock"?: string;
    /**
     * The list of one or more IPv4 CIDR blocks for the VCN that meet the following criteria:
     * - The CIDR blocks must be valid.
     * - They must not overlap with each other or with the on-premises network CIDR block.
     * - The number of CIDR blocks must not exceed the limit of CIDR blocks allowed per VCN.
     * <p>
     **Important:** Do *not* specify a value for {@code cidrBlock}. Use this parameter instead.
     *
     */
    "cidrBlocks"?: Array<string>;
    /**
     * The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment to contain the VCN.
     */
    "compartmentId": string;
    /**
     * The list of one or more ULA or Private IPv6 CIDR blocks for the vcn that meets the following criteria:
     * - The CIDR blocks must be valid.
     * - Multiple CIDR blocks must not overlap each other or the on-premises network CIDR block.
     * - The number of CIDR blocks must not exceed the limit of IPv6 CIDR blocks allowed to a vcn.
     * <p>
     **Important:** Do *not* specify a value for {@code ipv6CidrBlock}. Use this parameter instead.
     *
     */
    "ipv6PrivateCidrBlocks"?: Array<string>;
    /**
     * Specifies whether to skip Oracle allocated IPv6 GUA. By default, Oracle will allocate one GUA of /56
     * size for an IPv6 enabled VCN.
     *
     */
    "isOracleGuaAllocationEnabled"?: boolean;
    /**
     * The list of BYOIPv6 OCIDs and BYOIPv6 CIDR blocks required to create a VCN that uses BYOIPv6 ranges.
     *
     */
    "byoipv6CidrDetails"?: Array<model.Byoipv6CidrDetails>;
    /**
     * Defined tags for this resource. Each key is predefined and scoped to a namespace.
     * Example: {@code {\"foo-namespace\": {\"bar-key\": \"value\"}}}
     *
     */
    "definedTags"?: {
        [key: string]: {
            [key: string]: any;
        };
    };
    /**
     * A user-friendly name. Does not have to be unique, and it's changeable.
     * Avoid entering confidential information.
     *
     */
    "displayName"?: string;
    /**
      * A DNS label for the VCN, used in conjunction with the VNIC's hostname and
  * subnet's DNS label to form a fully qualified domain name (FQDN) for each VNIC
  * within this subnet (for example, {@code bminstance1.subnet123.vcn1.oraclevcn.com}).
  * Not required to be unique, but it's a best practice to set unique DNS labels
  * for VCNs in your tenancy. Must be an alphanumeric string that begins with a letter.
  * The value cannot be changed.
  * <p>
  You must set this value if you want instances to be able to use hostnames to
  * resolve other instances in the VCN. Otherwise the Internet and VCN Resolver
  * will not work.
  * <p>
  For more information, see
  * [DNS in Your Virtual Cloud Network](https://docs.cloud.oracle.com/iaas/Content/Network/Concepts/dns.htm).
  * <p>
  Example: {@code vcn1}
  *
      */
    "dnsLabel"?: string;
    /**
     * Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
     * Example: {@code {\"bar-key\": \"value\"}}
     *
     */
    "freeformTags"?: {
        [key: string]: string;
    };
    /**
      * Whether IPv6 is enabled for the VCN. Default is {@code false}.
  * If enabled, Oracle will assign the VCN a IPv6 /56 CIDR block.
  * You may skip having Oracle allocate the VCN a IPv6 /56 CIDR block by setting isOracleGuaAllocationEnabled to {@code false}.
  * For important details about IPv6 addressing in a VCN, see [IPv6 Addresses](https://docs.cloud.oracle.com/iaas/Content/Network/Concepts/ipv6.htm).
  * <p>
  Example: {@code true}
  *
      */
    "isIpv6Enabled"?: boolean;
}
export declare namespace CreateVcnDetails {
    function getJsonObj(obj: CreateVcnDetails): object;
    function getDeserializedJsonObj(obj: CreateVcnDetails): object;
}
