/**
 * Network Monitoring API
 * Use the Network Monitoring API to troubleshoot routing and security issues for resources such as virtual cloud networks (VCNs) and compute instances. For more information, see the console
documentation for the [Network Path Analyzer](/iaas/Content/Network/Concepts/path_analyzer.htm) tool.

 * OpenAPI spec version: 20160918
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * A security rule is one of the items in a {@link NetworkSecurityGroup}.
 * It is a virtual firewall rule for the VNICs in the network security group. A rule can be for
 * either inbound ({@code direction}= INGRESS) or outbound ({@code direction}= EGRESS) IP packets.
 *
 */
export interface SecurityRule {
    /**
     * An optional description of your choice for the rule.
     *
     */
    "description"?: string;
    /**
      * Conceptually, this is the range of IP addresses that a packet originating from the instance
  * can go to.
  * <p>
  Allowed values:
  * <p>
    * An IP address range in CIDR notation. For example: {@code 192.168.1.0/24} or {@code 2001:0db8:0123:45::/56}
  *     IPv6 addressing is supported for all commercial and government regions.
  *     See [IPv6 Addresses](https://docs.cloud.oracle.com/iaas/Content/Network/Concepts/ipv6.htm).
  * <p>
    * The {@code cidrBlock} value for a {@link Service}, if you're
  *     setting up a security rule for traffic destined for a particular {@code Service} through
  *     a service gateway. For example: {@code oci-phx-objectstorage}.
  * <p>
    * The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of a {@link NetworkSecurityGroup} in the same
  *     VCN. The value can be the NSG that the rule belongs to if the rule's intent is to control
  *     traffic between VNICs in the same NSG.
  *
      */
    "destination"?: string;
    /**
      * Type of destination for the rule. Required if {@code direction} = {@code EGRESS}.
  * <p>
  Allowed values:
  * <p>
    * {@code CIDR_BLOCK}: If the rule's {@code destination} is an IP address range in CIDR notation.
  * <p>
    * {@code SERVICE_CIDR_BLOCK}: If the rule's {@code destination} is the {@code cidrBlock} value for a
  *     {@link Service} (the rule is for traffic destined for a
  *     particular {@code Service} through a service gateway).
  * <p>
    * {@code NETWORK_SECURITY_GROUP}: If the rule's {@code destination} is the [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of a
  *     {@link NetworkSecurityGroup}.
  *
      */
    "destinationType"?: SecurityRule.DestinationType;
    /**
     * Direction of the security rule. Set to {@code EGRESS} for rules to allow outbound IP packets,
     * or {@code INGRESS} for rules to allow inbound IP packets.
     *
     */
    "direction": SecurityRule.Direction;
    "icmpOptions"?: model.IcmpOptions;
    /**
      * An Oracle-assigned identifier for the security rule. You specify this ID when you want to
  * update or delete the rule.
  * <p>
  Example: {@code 04ABEC}
  *
      */
    "id"?: string;
    /**
     * A stateless rule allows traffic in one direction. Remember to add a corresponding
     * stateless rule in the other direction if you need to support bidirectional traffic. For
     * example, if egress traffic allows TCP destination port 80, there should be an ingress
     * rule to allow TCP source port 80. Defaults to false, which means the rule is stateful
     * and a corresponding rule is not necessary for bidirectional traffic.
     *
     */
    "isStateless"?: boolean;
    /**
     * Whether the rule is valid. The value is {@code True} when the rule is first created. If
     * the rule's {@code source} or {@code destination} is a network security group, the value changes to
     * {@code False} if that network security group is deleted.
     *
     */
    "isValid"?: boolean;
    /**
     * The transport protocol. Specify either {@code all} or an IPv4 protocol number as
     * defined in
     * [Protocol Numbers](http://www.iana.org/assignments/protocol-numbers/protocol-numbers.xhtml).
     * Options are supported only for ICMP (\"1\"), TCP (\"6\"), UDP (\"17\"), and ICMPv6 (\"58\").
     *
     */
    "protocol": string;
    /**
      * Conceptually, this is the range of IP addresses that a packet coming into the instance
  * can come from.
  * <p>
  Allowed values:
  * <p>
    * An IP address range in CIDR notation. For example: {@code 192.168.1.0/24} or {@code 2001:0db8:0123:45::/56}
  *     IPv6 addressing is supported for all commercial and government regions.
  *     See [IPv6 Addresses](https://docs.cloud.oracle.com/iaas/Content/Network/Concepts/ipv6.htm).
  * <p>
    * The {@code cidrBlock} value for a {@link Service}, if you're
  *     setting up a security rule for traffic coming from a particular {@code Service} through
  *     a service gateway. For example: {@code oci-phx-objectstorage}.
  * <p>
    * The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of a {@link NetworkSecurityGroup} in the same
  *     VCN. The value can be the NSG that the rule belongs to if the rule's intent is to control
  *     traffic between VNICs in the same NSG.
  *
      */
    "source"?: string;
    /**
     * Type of source for the rule. Required if {@code direction} = {@code INGRESS}.
     * <p>
     * {@code CIDR_BLOCK}: If the rule's {@code source} is an IP address range in CIDR notation.
     * <p>
     * {@code SERVICE_CIDR_BLOCK}: If the rule's {@code source} is the {@code cidrBlock} value for a
     *     {@link Service} (the rule is for traffic coming from a
     *     particular {@code Service} through a service gateway).
     * <p>
     * {@code NETWORK_SECURITY_GROUP}: If the rule's {@code source} is the [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of a
     *     {@link NetworkSecurityGroup}.
     *
     */
    "sourceType"?: SecurityRule.SourceType;
    "tcpOptions"?: model.TcpOptions;
    /**
     * The date and time the security rule was created. Format defined by [RFC3339](https://tools.ietf.org/html/rfc3339).
     */
    "timeCreated"?: Date;
    "udpOptions"?: model.UdpOptions;
}
export declare namespace SecurityRule {
    enum DestinationType {
        CidrBlock = "CIDR_BLOCK",
        ServiceCidrBlock = "SERVICE_CIDR_BLOCK",
        NetworkSecurityGroup = "NETWORK_SECURITY_GROUP",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    enum Direction {
        Egress = "EGRESS",
        Ingress = "INGRESS",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    enum SourceType {
        CidrBlock = "CIDR_BLOCK",
        ServiceCidrBlock = "SERVICE_CIDR_BLOCK",
        NetworkSecurityGroup = "NETWORK_SECURITY_GROUP",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    function getJsonObj(obj: SecurityRule): object;
    function getDeserializedJsonObj(obj: SecurityRule): object;
}
