/**
 * Network Monitoring API
 * Use the Network Monitoring API to troubleshoot routing and security issues for resources such as virtual cloud networks (VCNs) and compute instances. For more information, see the console
documentation for the [Network Path Analyzer](/iaas/Content/Network/Concepts/path_analyzer.htm) tool.

 * OpenAPI spec version: 20160918
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
/**
 * These details can be included in a request to update a virtual test access point (VTAP).
 */
export interface UpdateVtapDetails {
    /**
     * Defined tags for this resource. Each key is predefined and scoped to a namespace.
     * Example: {@code {\"foo-namespace\": {\"bar-key\": \"value\"}}}
     *
     */
    "definedTags"?: {
        [key: string]: {
            [key: string]: any;
        };
    };
    /**
     * A user-friendly name. Does not have to be unique, and it's changeable.
     * Avoid entering confidential information.
     *
     */
    "displayName"?: string;
    /**
     * Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
     * Example: {@code {\"bar-key\": \"value\"}}
     *
     */
    "freeformTags"?: {
        [key: string]: string;
    };
    /**
     * The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the source point where packets are captured.
     *
     */
    "sourceId"?: string;
    /**
     * The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the destination resource where mirrored packets are sent.
     *
     */
    "targetId"?: string;
    /**
     * The IP address of the destination resource where mirrored packets are sent.
     *
     */
    "targetIp"?: string;
    /**
     * The capture filter's Oracle ID ([OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm)).
     *
     */
    "captureFilterId"?: string;
    /**
     * Defines an encapsulation header type for the VTAP's mirrored traffic.
     *
     */
    "encapsulationProtocol"?: UpdateVtapDetails.EncapsulationProtocol;
    /**
     * The virtual extensible LAN (VXLAN) network identifier (or VXLAN segment ID) that uniquely identifies the VXLAN.
     *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "vxlanNetworkIdentifier"?: number;
    /**
     * Used to start or stop a {@code Vtap} resource.
     * <p>
     * {@code TRUE} directs the VTAP to start mirroring traffic.
     * * {@code FALSE} (Default) directs the VTAP to stop mirroring traffic.
     *
     */
    "isVtapEnabled"?: boolean;
    /**
     * Used to control the priority of traffic. It is an optional field. If it not passed, the value is DEFAULT
     */
    "trafficMode"?: UpdateVtapDetails.TrafficMode;
    /**
     * The maximum size of the packets to be included in the filter. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "maxPacketSize"?: number;
    /**
     * The IP Address of the source private endpoint.
     *
     */
    "sourcePrivateEndpointIp"?: string;
    /**
     * The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the subnet that source private endpoint belongs to.
     *
     */
    "sourcePrivateEndpointSubnetId"?: string;
    /**
     * The target type for the VTAP.
     *
     */
    "targetType"?: UpdateVtapDetails.TargetType;
    /**
     * The source type for the VTAP.
     *
     */
    "sourceType"?: UpdateVtapDetails.SourceType;
}
export declare namespace UpdateVtapDetails {
    enum EncapsulationProtocol {
        Vxlan = "VXLAN"
    }
    enum TrafficMode {
        Default = "DEFAULT",
        Priority = "PRIORITY"
    }
    enum TargetType {
        Vnic = "VNIC",
        NetworkLoadBalancer = "NETWORK_LOAD_BALANCER",
        IpAddress = "IP_ADDRESS"
    }
    enum SourceType {
        Vnic = "VNIC",
        Subnet = "SUBNET",
        LoadBalancer = "LOAD_BALANCER",
        DbSystem = "DB_SYSTEM",
        ExadataVmCluster = "EXADATA_VM_CLUSTER",
        AutonomousDataWarehouse = "AUTONOMOUS_DATA_WAREHOUSE"
    }
    function getJsonObj(obj: UpdateVtapDetails): object;
    function getDeserializedJsonObj(obj: UpdateVtapDetails): object;
}
