/**
 * Web Application Acceleration and Security Services API
 * OCI Web Application Acceleration and Security Services
 * OpenAPI spec version: 20181116
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * The configuration details for the WAAS policy.
 */
export interface PolicyConfig {
    /**
     * The OCID of the SSL certificate to use if HTTPS is supported.
     */
    "certificateId"?: string;
    /**
     * Enable or disable HTTPS support. If true, a {@code certificateId} is required. If unspecified, defaults to {@code false}.
     */
    "isHttpsEnabled"?: boolean;
    /**
     * Force HTTP to HTTPS redirection. If unspecified, defaults to {@code false}.
     */
    "isHttpsForced"?: boolean;
    /**
      * A list of allowed TLS protocols. Only applicable when HTTPS support is enabled.
  * The TLS protocol is negotiated while the request is connecting and the most recent protocol supported by both the edge node and client browser will be selected. If no such version exists, the connection will be aborted.
  * - **TLS_V1:** corresponds to TLS 1.0 specification.
  * <p>
  - **TLS_V1_1:** corresponds to TLS 1.1 specification.
  * <p>
  - **TLS_V1_2:** corresponds to TLS 1.2 specification.
  * <p>
  - **TLS_V1_3:** corresponds to TLS 1.3 specification.
  * <p>
  Enabled TLS protocols must go in a row. For example if {@code TLS_v1_1} and {@code TLS_V1_3} are enabled, {@code TLS_V1_2} must be enabled too.
      */
    "tlsProtocols"?: Array<PolicyConfig.TlsProtocols>;
    /**
     * Enable or disable GZIP compression of origin responses. If enabled, the header {@code Accept-Encoding: gzip} is sent to origin, otherwise, the empty {@code Accept-Encoding:} header is used.
     */
    "isOriginCompressionEnabled"?: boolean;
    /**
     * Enabling {@code isBehindCdn} allows for the collection of IP addresses from client requests if the WAF is connected to a CDN.
     */
    "isBehindCdn"?: boolean;
    /**
      * Specifies an HTTP header name which is treated as the connecting client's IP address. Applicable only if {@code isBehindCdn} is enabled.
  * <p>
  The edge node reads this header and its value and sets the client IP address as specified. It does not create the header if the header is not present in the request. If the header is not present, the connecting IP address will be used as the client's true IP address. It uses the last IP address in the header's value as the true IP address.
  * <p>
  Example: {@code X-Client-Ip: 11.1.1.1, 13.3.3.3}
  * <p>
  In the case of multiple headers with the same name, only the first header will be used. It is assumed that CDN sets the correct client IP address to prevent spoofing.
  * <p>
  - **X_FORWARDED_FOR:** Corresponds to {@code X-Forwarded-For} header name.
  * <p>
  - **X_CLIENT_IP:** Corresponds to {@code X-Client-Ip} header name.
  * <p>
  - **X_REAL_IP:** Corresponds to {@code X-Real-Ip} header name.
  * <p>
  - **CLIENT_IP:** Corresponds to {@code Client-Ip} header name.
  * <p>
  - **TRUE_CLIENT_IP:** Corresponds to {@code True-Client-Ip} header name.
      */
    "clientAddressHeader"?: PolicyConfig.ClientAddressHeader;
    /**
     * Enable or disable automatic content caching based on the response {@code cache-control} header. This feature enables the origin to act as a proxy cache. Caching is usually defined using {@code cache-control} header. For example {@code cache-control: max-age=120} means that the returned resource is valid for 120 seconds. Caching rules will overwrite this setting.
     */
    "isCacheControlRespected"?: boolean;
    /**
     * Enable or disable buffering of responses from the origin. Buffering improves overall stability in case of network issues, but slightly increases Time To First Byte.
     */
    "isResponseBufferingEnabled"?: boolean;
    /**
     * The set cipher group for the configured TLS protocol. This sets the configuration for the TLS connections between clients and edge nodes only.
     * - **DEFAULT:** Cipher group supports TLS 1.0, TLS 1.1, TLS 1.2, TLS 1.3 protocols. It has the following ciphers enabled: {@code ECDHE-RSA-AES128-GCM-SHA256:ECDHE-ECDSA-AES128-GCM-SHA256:ECDHE-RSA-AES256-GCM-SHA384:ECDHE-ECDSA-AES256-GCM-SHA384:DHE-RSA-AES128-GCM-SHA256:DHE-DSS-AES128-GCM-SHA256:kEDH+AESGCM:ECDHE-RSA-AES128-SHA256:ECDHE-ECDSA-AES128-SHA256:ECDHE-RSA-AES128-SHA:ECDHE-ECDSA-AES128-SHA:ECDHE-RSA-AES256-SHA384:ECDHE-ECDSA-AES256-SHA384:ECDHE-RSA-AES256-SHA:ECDHE-ECDSA-AES256-SHA:DHE-RSA-AES128-SHA256:DHE-RSA-AES128-SHA:DHE-DSS-AES128-SHA256:DHE-RSA-AES256-SHA256:DHE-DSS-AES256-SHA:DHE-RSA-AES256-SHA:AES128-GCM-SHA256:AES256-GCM-SHA384:AES128-SHA256:AES256-SHA256:AES128-SHA:AES256-SHA:AES:CAMELLIA:!DES-CBC3-SHA:!aNULL:!eNULL:!EXPORT:!DES:!RC4:!MD5:!PSK:!aECDH:!EDH-DSS-DES-CBC3-SHA:!EDH-RSA-DES-CBC3-SHA:!KRB5-DES-CBC3-SHA}
     */
    "cipherGroup"?: PolicyConfig.CipherGroup;
    /**
     * An object that represents a load balancing method and its properties.
     */
    "loadBalancingMethod"?: model.RoundRobinLoadBalancingMethod | model.StickyCookieLoadBalancingMethod | model.IPHashLoadBalancingMethod;
    /**
     * ModSecurity is not capable to inspect WebSockets. Therefore paths specified here have WAF disabled if Connection request header from the client has the value Upgrade (case insensitive matching) and Upgrade request header has the value websocket (case insensitive matching). Paths matches if the concatenation of request URL path and query starts with the contents of the one of {@code websocketPathPrefixes} array value. In All other cases challenges, like JSC, HIC and etc., remain active.
     */
    "websocketPathPrefixes"?: Array<string>;
    /**
     * SNI stands for Server Name Indication and is an extension of the TLS protocol. It indicates which hostname is being contacted by the browser at the beginning of the 'handshake'-process. This allows a server to connect multiple SSL Certificates to one IP address and port.
     */
    "isSniEnabled"?: boolean;
    "healthChecks"?: model.HealthCheck;
}
export declare namespace PolicyConfig {
    enum TlsProtocols {
        TlsV1 = "TLS_V1",
        TlsV11 = "TLS_V1_1",
        TlsV12 = "TLS_V1_2",
        TlsV13 = "TLS_V1_3",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    enum ClientAddressHeader {
        XForwardedFor = "X_FORWARDED_FOR",
        XClientIp = "X_CLIENT_IP",
        XRealIp = "X_REAL_IP",
        ClientIp = "CLIENT_IP",
        TrueClientIp = "TRUE_CLIENT_IP",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    enum CipherGroup {
        Default = "DEFAULT",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    function getJsonObj(obj: PolicyConfig): object;
    function getDeserializedJsonObj(obj: PolicyConfig): object;
}
