/**
 * Web Application Firewall (WAF) API
 * API for the Web Application Firewall service.
Use this API to manage regional Web App Firewalls and corresponding policies for protecting HTTP services.

 * OpenAPI spec version: 20210930
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import common = require("oci-common");
import * as requests from "./request";
import * as responses from "./response";
import { WafWaiter } from "./waf-waiter";
declare const Breaker: any;
export declare enum WafApiKeys {
}
/**
 * This service client uses {@link common.CircuitBreaker.DefaultConfiguration} for all the operations by default if no circuit breaker configuration is defined by the user.
 */
export declare class WafClient {
    protected static serviceEndpointTemplate: string;
    protected static endpointServiceName: string;
    protected "_realmSpecificEndpointTemplateEnabled": boolean | undefined;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_waiters": WafWaiter;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: typeof Breaker | null;
    protected _httpOptions: any;
    protected _bodyDuplexMode: any;
    targetService: string;
    protected _regionId: string;
    protected "_region": common.Region;
    protected _lastSetRegionOrRegionId: string;
    protected _httpClient: common.HttpClient;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    get endpoint(): string;
    /**
     * Sets the endpoint to call (ex, https://www.example.com).
     * @param endpoint The endpoint of the service.
     */
    set endpoint(endpoint: string);
    get logger(): import("oci-common/lib/log").Logger;
    /**
     * Determines whether realm specific endpoint should be used or not.
     * Set realmSpecificEndpointTemplateEnabled to "true" if the user wants to enable use of realm specific endpoint template, otherwise set it to "false"
     * @param realmSpecificEndpointTemplateEnabled flag to enable the use of realm specific endpoint template
     */
    set useRealmSpecificEndpointTemplate(realmSpecificEndpointTemplateEnabled: boolean);
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    set region(region: common.Region);
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    set regionId(regionId: string);
    /**
     * Creates a new WafWaiter for resources for this service.
     *
     * @param config The waiter configuration for termination and delay strategy
     * @return The service waiters.
     */
    createWaiters(config?: common.WaiterConfiguration): WafWaiter;
    /**
     * Gets the waiters available for resources for this service.
     *
     * @return The service waiters.
     */
    getWaiters(): WafWaiter;
    /**
     * Shutdown the circuit breaker used by the client when it is no longer needed
     */
    shutdownCircuitBreaker(): void;
    /**
     * Close the client once it is no longer needed
     */
    close(): void;
    /**
     * Moves a NetworkAddressList resource from one compartment to another.
     * When provided, If-Match is checked against ETag values of the resource.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ChangeNetworkAddressListCompartmentRequest
     * @return ChangeNetworkAddressListCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/waf/ChangeNetworkAddressListCompartment.ts.html |here} to see how to use ChangeNetworkAddressListCompartment API.
     */
    changeNetworkAddressListCompartment(changeNetworkAddressListCompartmentRequest: requests.ChangeNetworkAddressListCompartmentRequest): Promise<responses.ChangeNetworkAddressListCompartmentResponse>;
    /**
     * Moves a Web App Firewall resource from one compartment to another.
     * When provided, If-Match is checked against ETag values of the resource.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ChangeWebAppFirewallCompartmentRequest
     * @return ChangeWebAppFirewallCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/waf/ChangeWebAppFirewallCompartment.ts.html |here} to see how to use ChangeWebAppFirewallCompartment API.
     */
    changeWebAppFirewallCompartment(changeWebAppFirewallCompartmentRequest: requests.ChangeWebAppFirewallCompartmentRequest): Promise<responses.ChangeWebAppFirewallCompartmentResponse>;
    /**
     * Moves a WebAppFirewallfPolicy resource from one compartment to another.
     * When provided, If-Match is checked against ETag values of the resource.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ChangeWebAppFirewallPolicyCompartmentRequest
     * @return ChangeWebAppFirewallPolicyCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/waf/ChangeWebAppFirewallPolicyCompartment.ts.html |here} to see how to use ChangeWebAppFirewallPolicyCompartment API.
     */
    changeWebAppFirewallPolicyCompartment(changeWebAppFirewallPolicyCompartmentRequest: requests.ChangeWebAppFirewallPolicyCompartmentRequest): Promise<responses.ChangeWebAppFirewallPolicyCompartmentResponse>;
    /**
     * Creates a new NetworkAddressList.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateNetworkAddressListRequest
     * @return CreateNetworkAddressListResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/waf/CreateNetworkAddressList.ts.html |here} to see how to use CreateNetworkAddressList API.
     */
    createNetworkAddressList(createNetworkAddressListRequest: requests.CreateNetworkAddressListRequest): Promise<responses.CreateNetworkAddressListResponse>;
    /**
     * Creates a new WebAppFirewall.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateWebAppFirewallRequest
     * @return CreateWebAppFirewallResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/waf/CreateWebAppFirewall.ts.html |here} to see how to use CreateWebAppFirewall API.
     */
    createWebAppFirewall(createWebAppFirewallRequest: requests.CreateWebAppFirewallRequest): Promise<responses.CreateWebAppFirewallResponse>;
    /**
     * Creates a new WebAppFirewallPolicy.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateWebAppFirewallPolicyRequest
     * @return CreateWebAppFirewallPolicyResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/waf/CreateWebAppFirewallPolicy.ts.html |here} to see how to use CreateWebAppFirewallPolicy API.
     */
    createWebAppFirewallPolicy(createWebAppFirewallPolicyRequest: requests.CreateWebAppFirewallPolicyRequest): Promise<responses.CreateWebAppFirewallPolicyResponse>;
    /**
     * Deletes a NetworkAddressList resource identified by the OCID.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteNetworkAddressListRequest
     * @return DeleteNetworkAddressListResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/waf/DeleteNetworkAddressList.ts.html |here} to see how to use DeleteNetworkAddressList API.
     */
    deleteNetworkAddressList(deleteNetworkAddressListRequest: requests.DeleteNetworkAddressListRequest): Promise<responses.DeleteNetworkAddressListResponse>;
    /**
     * Deletes a WebAppFirewall resource identified by the OCID.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteWebAppFirewallRequest
     * @return DeleteWebAppFirewallResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/waf/DeleteWebAppFirewall.ts.html |here} to see how to use DeleteWebAppFirewall API.
     */
    deleteWebAppFirewall(deleteWebAppFirewallRequest: requests.DeleteWebAppFirewallRequest): Promise<responses.DeleteWebAppFirewallResponse>;
    /**
     * Deletes a WebAppFirewallPolicy resource identified by the OCID.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteWebAppFirewallPolicyRequest
     * @return DeleteWebAppFirewallPolicyResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/waf/DeleteWebAppFirewallPolicy.ts.html |here} to see how to use DeleteWebAppFirewallPolicy API.
     */
    deleteWebAppFirewallPolicy(deleteWebAppFirewallPolicyRequest: requests.DeleteWebAppFirewallPolicyRequest): Promise<responses.DeleteWebAppFirewallPolicyResponse>;
    /**
     * Gets a NetworkAddressList by OCID.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetNetworkAddressListRequest
     * @return GetNetworkAddressListResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/waf/GetNetworkAddressList.ts.html |here} to see how to use GetNetworkAddressList API.
     */
    getNetworkAddressList(getNetworkAddressListRequest: requests.GetNetworkAddressListRequest): Promise<responses.GetNetworkAddressListResponse>;
    /**
     * Gets a WebAppFirewall by OCID.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetWebAppFirewallRequest
     * @return GetWebAppFirewallResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/waf/GetWebAppFirewall.ts.html |here} to see how to use GetWebAppFirewall API.
     */
    getWebAppFirewall(getWebAppFirewallRequest: requests.GetWebAppFirewallRequest): Promise<responses.GetWebAppFirewallResponse>;
    /**
     * Gets a WebAppFirewallPolicy with the given OCID.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetWebAppFirewallPolicyRequest
     * @return GetWebAppFirewallPolicyResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/waf/GetWebAppFirewallPolicy.ts.html |here} to see how to use GetWebAppFirewallPolicy API.
     */
    getWebAppFirewallPolicy(getWebAppFirewallPolicyRequest: requests.GetWebAppFirewallPolicyRequest): Promise<responses.GetWebAppFirewallPolicyResponse>;
    /**
     * Gets the status of the WorkRequest with the given OCID.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetWorkRequestRequest
     * @return GetWorkRequestResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/waf/GetWorkRequest.ts.html |here} to see how to use GetWorkRequest API.
     */
    getWorkRequest(getWorkRequestRequest: requests.GetWorkRequestRequest): Promise<responses.GetWorkRequestResponse>;
    /**
     * Gets a list of all NetworkAddressLists in a compartment.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListNetworkAddressListsRequest
     * @return ListNetworkAddressListsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/waf/ListNetworkAddressLists.ts.html |here} to see how to use ListNetworkAddressLists API.
     */
    listNetworkAddressLists(listNetworkAddressListsRequest: requests.ListNetworkAddressListsRequest): Promise<responses.ListNetworkAddressListsResponse>;
    /**
     * Lists of protection capabilities filtered by query parameters.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListProtectionCapabilitiesRequest
     * @return ListProtectionCapabilitiesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/waf/ListProtectionCapabilities.ts.html |here} to see how to use ListProtectionCapabilities API.
     */
    listProtectionCapabilities(listProtectionCapabilitiesRequest: requests.ListProtectionCapabilitiesRequest): Promise<responses.ListProtectionCapabilitiesResponse>;
    /**
     * Lists of available group tags filtered by query parameters.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListProtectionCapabilityGroupTagsRequest
     * @return ListProtectionCapabilityGroupTagsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/waf/ListProtectionCapabilityGroupTags.ts.html |here} to see how to use ListProtectionCapabilityGroupTags API.
     */
    listProtectionCapabilityGroupTags(listProtectionCapabilityGroupTagsRequest: requests.ListProtectionCapabilityGroupTagsRequest): Promise<responses.ListProtectionCapabilityGroupTagsResponse>;
    /**
     * Gets a list of all WebAppFirewallPolicies in a compartment.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListWebAppFirewallPoliciesRequest
     * @return ListWebAppFirewallPoliciesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/waf/ListWebAppFirewallPolicies.ts.html |here} to see how to use ListWebAppFirewallPolicies API.
     */
    listWebAppFirewallPolicies(listWebAppFirewallPoliciesRequest: requests.ListWebAppFirewallPoliciesRequest): Promise<responses.ListWebAppFirewallPoliciesResponse>;
    /**
     * Gets a list of all WebAppFirewalls in a compartment.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListWebAppFirewallsRequest
     * @return ListWebAppFirewallsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/waf/ListWebAppFirewalls.ts.html |here} to see how to use ListWebAppFirewalls API.
     */
    listWebAppFirewalls(listWebAppFirewallsRequest: requests.ListWebAppFirewallsRequest): Promise<responses.ListWebAppFirewallsResponse>;
    /**
     * Return a (paginated) list of errors for a given WorkRequest.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListWorkRequestErrorsRequest
     * @return ListWorkRequestErrorsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/waf/ListWorkRequestErrors.ts.html |here} to see how to use ListWorkRequestErrors API.
     */
    listWorkRequestErrors(listWorkRequestErrorsRequest: requests.ListWorkRequestErrorsRequest): Promise<responses.ListWorkRequestErrorsResponse>;
    /**
     * Return a (paginated) list of logs for a given WorkRequest.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListWorkRequestLogsRequest
     * @return ListWorkRequestLogsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/waf/ListWorkRequestLogs.ts.html |here} to see how to use ListWorkRequestLogs API.
     */
    listWorkRequestLogs(listWorkRequestLogsRequest: requests.ListWorkRequestLogsRequest): Promise<responses.ListWorkRequestLogsResponse>;
    /**
     * Lists the WorkRequests in a compartment.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListWorkRequestsRequest
     * @return ListWorkRequestsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/waf/ListWorkRequests.ts.html |here} to see how to use ListWorkRequests API.
     */
    listWorkRequests(listWorkRequestsRequest: requests.ListWorkRequestsRequest): Promise<responses.ListWorkRequestsResponse>;
    /**
     * Update the NetworkAddressList identified by the OCID.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateNetworkAddressListRequest
     * @return UpdateNetworkAddressListResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/waf/UpdateNetworkAddressList.ts.html |here} to see how to use UpdateNetworkAddressList API.
     */
    updateNetworkAddressList(updateNetworkAddressListRequest: requests.UpdateNetworkAddressListRequest): Promise<responses.UpdateNetworkAddressListResponse>;
    /**
     * Updates the WebAppFirewall identified by the OCID.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateWebAppFirewallRequest
     * @return UpdateWebAppFirewallResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/waf/UpdateWebAppFirewall.ts.html |here} to see how to use UpdateWebAppFirewall API.
     */
    updateWebAppFirewall(updateWebAppFirewallRequest: requests.UpdateWebAppFirewallRequest): Promise<responses.UpdateWebAppFirewallResponse>;
    /**
     * Update the WebAppFirewallPolicy identified by the OCID.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateWebAppFirewallPolicyRequest
     * @return UpdateWebAppFirewallPolicyResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/waf/UpdateWebAppFirewallPolicy.ts.html |here} to see how to use UpdateWebAppFirewallPolicy API.
     */
    updateWebAppFirewallPolicy(updateWebAppFirewallPolicyRequest: requests.UpdateWebAppFirewallPolicyRequest): Promise<responses.UpdateWebAppFirewallPolicyResponse>;
}
export {};
