/**
 * Web Application Firewall (WAF) API
 * API for the Web Application Firewall service.
Use this API to manage regional Web App Firewalls and corresponding policies for protecting HTTP services.

 * OpenAPI spec version: 20210930
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * A summary of available OCI-managed protection capabilities in WebAppFirewallPolicy.
 * Protection capabilies checks HTTP requests/responses if they are malicious.
 *
 */
export interface ProtectionCapabilitySummary {
    /**
     * Unique key of protection capability.
     */
    "key": string;
    /**
     * The display name of protection capability.
     */
    "displayName": string;
    /**
     * The description of protection capability.
     */
    "description": string;
    /**
     * The version of protection capability. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "version": number;
    /**
     * The field that shows if this is the latest version of protection capability.
     */
    "isLatestVersion": boolean;
    /**
     * The list of unique names protection capability group tags that are associated with this capability.
     * Example: [\"PCI\", \"Recommended\"]
     *
     */
    "groupTags"?: Array<string>;
    /**
     * The type of protection capability.
     * <p>
     * **REQUEST_PROTECTION_CAPABILITY** can only be used in {@code requestProtection} module of WebAppFirewallPolicy.
     * <p>
     * **RESPONSE_PROTECTION_CAPABILITY** can only be used in {@code responseProtection} module of WebAppFirewallPolicy.
     *
     */
    "type": ProtectionCapabilitySummary.Type;
    /**
      * The default collaborative action threshold for OCI-managed collaborative protection capability.
  * Collaborative protection capabilities are made of several simple, non-collaborative protection capabilities
  * (referred to as {@code contributing capabilities} later on) which have weights assigned to them. These weights can
  * be found in the {@code collaborativeWeights} array.
  * For incoming/outgoing HTTP messages, all contributing capabilities are executed and the sum of all triggered
  * contributing capabilities weights is calculated. Only if this sum is greater than or equal to
  * {@code collaborativeActionThreshold} is the incoming/outgoing HTTP message marked as malicious.
  * <p>
  This field is ignored for non-collaborative capabilities.
  *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
      */
    "collaborativeActionThreshold"?: number;
    /**
      * The weights of contributing capabilities.
  * Defines how much each contributing capability contributes towards the action threshold of a collaborative protection capability.
  * <p>
  This field is ignored for non-collaborative capabilities.
  *
      */
    "collaborativeWeights"?: Array<model.CollaborativeCapabilityWeight>;
}
export declare namespace ProtectionCapabilitySummary {
    enum Type {
        RequestProtectionCapability = "REQUEST_PROTECTION_CAPABILITY",
        ResponseProtectionCapability = "RESPONSE_PROTECTION_CAPABILITY",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    function getJsonObj(obj: ProtectionCapabilitySummary): object;
    function getDeserializedJsonObj(obj: ProtectionCapabilitySummary): object;
}
