/**
 * Web Application Firewall (WAF) API
 * API for the Web Application Firewall service.
Use this API to manage regional Web App Firewalls and corresponding policies for protecting HTTP services.

 * OpenAPI spec version: 20210930
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * Module that allows to enable OCI-managed protection capabilities for incoming HTTP requests.
 */
export interface RequestProtection {
    /**
     * Ordered list of ProtectionRules. Rules are executed in order of appearance in this array.
     * ProtectionRules in this array can only use protection Capabilities of REQUEST_PROTECTION_CAPABILITY type.
     *
     */
    "rules"?: Array<model.ProtectionRule>;
    /**
      * Maximum size of inspected HTTP message body in bytes. Actions to take if this limit is exceeded are defined in {@code bodyInspectionSizeLimitExceededActionName}.
  * <p>
  Body inspection maximum size allowed is defined with per-tenancy limit: 8192 bytes.
  *  Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
      */
    "bodyInspectionSizeLimitInBytes"?: number;
    /**
      * References action by name from actions defined in WebAppFirewallPolicy. Executed if HTTP message
  * body size exceeds limit set in field {@code bodyInspectionSizeLimitInBytes}.
  * <p>
  If this field is {@code null} HTTP message body will inspected up to {@code bodyInspectionSizeLimitInBytes} and the rest
  * will not be inspected by Protection Capabilities.
  * <p>
  Allowed action types:
  * * **RETURN_HTTP_RESPONSE** terminates further execution of modules and rules and returns defined HTTP response.
  *
      */
    "bodyInspectionSizeLimitExceededActionName"?: string;
}
export declare namespace RequestProtection {
    function getJsonObj(obj: RequestProtection): object;
    function getDeserializedJsonObj(obj: RequestProtection): object;
}
