/**
 * Core Services API
 * Use the Core Services API to manage resources such as virtual cloud networks (VCNs),
compute instances, and block storage volumes. For more information, see the console
documentation for the [Networking](/iaas/Content/Network/Concepts/overview.htm),
[Compute](/iaas/Content/Compute/Concepts/computeoverview.htm), and
[Block Volume](/iaas/Content/Block/Concepts/overview.htm) services.
The required permissions are documented in the
[Details for the Core Services](/iaas/Content/Identity/Reference/corepolicyreference.htm) article.

 * OpenAPI spec version: 20160918
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import common = require("oci-common");
import * as requests from "./request";
import * as model from "./model";
import * as responses from "./response";
import { WorkRequestClient } from "oci-workrequests";
import { BlockstorageWaiter } from "./blockstorage-waiter";
import { ComputeWaiter } from "./compute-waiter";
import { ComputeManagementWaiter } from "./computemanagement-waiter";
import { VirtualNetworkWaiter } from "./virtualnetwork-waiter";
declare const Breaker: any;
export declare enum BlockstorageApiKeys {
}
/**
 * This service client uses {@link common.CircuitBreaker.DefaultConfiguration} for all the operations by default if no circuit breaker configuration is defined by the user.
 */
export declare class BlockstorageClient {
    protected static serviceEndpointTemplate: string;
    protected static endpointServiceName: string;
    protected "_realmSpecificEndpointTemplateEnabled": boolean | undefined;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_waiters": BlockstorageWaiter;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: typeof Breaker | null;
    protected _httpOptions: any;
    protected _bodyDuplexMode: any;
    targetService: string;
    protected _regionId: string;
    protected "_region": common.Region;
    protected _lastSetRegionOrRegionId: string;
    protected _httpClient: common.HttpClient;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    get endpoint(): string;
    /**
     * Sets the endpoint to call (ex, https://www.example.com).
     * @param endpoint The endpoint of the service.
     */
    set endpoint(endpoint: string);
    get logger(): import("oci-common/lib/log").Logger;
    /**
     * Determines whether realm specific endpoint should be used or not.
     * Set realmSpecificEndpointTemplateEnabled to "true" if the user wants to enable use of realm specific endpoint template, otherwise set it to "false"
     * @param realmSpecificEndpointTemplateEnabled flag to enable the use of realm specific endpoint template
     */
    set useRealmSpecificEndpointTemplate(realmSpecificEndpointTemplateEnabled: boolean);
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    set region(region: common.Region);
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    set regionId(regionId: string);
    /**
     * Creates a new BlockstorageWaiter for resources for this service.
     *
     * @param workRequestClient The work request service client used to query for work request status
     * @param config The waiter configuration for termination and delay strategy
     * @return The service waiters.
     */
    createWaiters(workRequestClient: WorkRequestClient, config?: common.WaiterConfiguration): BlockstorageWaiter;
    /**
     * Gets the waiters available for resources for this service.
     *
     * @return The service waiters.
     */
    getWaiters(): BlockstorageWaiter;
    /**
     * Shutdown the circuit breaker used by the client when it is no longer needed
     */
    shutdownCircuitBreaker(): void;
    /**
     * Close the client once it is no longer needed
     */
    close(): void;
    /**
     * Moves a boot volume backup into a different compartment within the same tenancy.
     * For information about moving resources between compartments,
     * see [Moving Resources to a Different Compartment](https://docs.cloud.oracle.com/iaas/Content/Identity/Tasks/managingcompartments.htm#moveRes).
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangeBootVolumeBackupCompartmentRequest
     * @return ChangeBootVolumeBackupCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ChangeBootVolumeBackupCompartment.ts.html |here} to see how to use ChangeBootVolumeBackupCompartment API.
     */
    changeBootVolumeBackupCompartment(changeBootVolumeBackupCompartmentRequest: requests.ChangeBootVolumeBackupCompartmentRequest): Promise<responses.ChangeBootVolumeBackupCompartmentResponse>;
    /**
     * Moves a boot volume into a different compartment within the same tenancy.
     * For information about moving resources between compartments,
     * see [Moving Resources to a Different Compartment](https://docs.cloud.oracle.com/iaas/Content/Identity/Tasks/managingcompartments.htm#moveRes).
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangeBootVolumeCompartmentRequest
     * @return ChangeBootVolumeCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ChangeBootVolumeCompartment.ts.html |here} to see how to use ChangeBootVolumeCompartment API.
     */
    changeBootVolumeCompartment(changeBootVolumeCompartmentRequest: requests.ChangeBootVolumeCompartmentRequest): Promise<responses.ChangeBootVolumeCompartmentResponse>;
    /**
     * Moves a volume backup into a different compartment within the same tenancy.
     * For information about moving resources between compartments,
     * see [Moving Resources to a Different Compartment](https://docs.cloud.oracle.com/iaas/Content/Identity/Tasks/managingcompartments.htm#moveRes).
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangeVolumeBackupCompartmentRequest
     * @return ChangeVolumeBackupCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ChangeVolumeBackupCompartment.ts.html |here} to see how to use ChangeVolumeBackupCompartment API.
     */
    changeVolumeBackupCompartment(changeVolumeBackupCompartmentRequest: requests.ChangeVolumeBackupCompartmentRequest): Promise<responses.ChangeVolumeBackupCompartmentResponse>;
    /**
     * Moves a volume into a different compartment within the same tenancy.
     * For information about moving resources between compartments,
     * see [Moving Resources to a Different Compartment](https://docs.cloud.oracle.com/iaas/Content/Identity/Tasks/managingcompartments.htm#moveRes).
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangeVolumeCompartmentRequest
     * @return ChangeVolumeCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ChangeVolumeCompartment.ts.html |here} to see how to use ChangeVolumeCompartment API.
     */
    changeVolumeCompartment(changeVolumeCompartmentRequest: requests.ChangeVolumeCompartmentRequest): Promise<responses.ChangeVolumeCompartmentResponse>;
    /**
     * Moves a volume group backup into a different compartment within the same tenancy.
     * For information about moving resources between compartments,
     * see [Moving Resources to a Different Compartment](https://docs.cloud.oracle.com/iaas/Content/Identity/Tasks/managingcompartments.htm#moveRes).
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangeVolumeGroupBackupCompartmentRequest
     * @return ChangeVolumeGroupBackupCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ChangeVolumeGroupBackupCompartment.ts.html |here} to see how to use ChangeVolumeGroupBackupCompartment API.
     */
    changeVolumeGroupBackupCompartment(changeVolumeGroupBackupCompartmentRequest: requests.ChangeVolumeGroupBackupCompartmentRequest): Promise<responses.ChangeVolumeGroupBackupCompartmentResponse>;
    /**
     * Moves a volume group into a different compartment within the same tenancy.
     * For information about moving resources between compartments,
     * see [Moving Resources to a Different Compartment](https://docs.cloud.oracle.com/iaas/Content/Identity/Tasks/managingcompartments.htm#moveRes).
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangeVolumeGroupCompartmentRequest
     * @return ChangeVolumeGroupCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ChangeVolumeGroupCompartment.ts.html |here} to see how to use ChangeVolumeGroupCompartment API.
     */
    changeVolumeGroupCompartment(changeVolumeGroupCompartmentRequest: requests.ChangeVolumeGroupCompartmentRequest): Promise<responses.ChangeVolumeGroupCompartmentResponse>;
    /**
     * Creates a boot volume backup copy in specified region. For general information about volume backups,
     * see [Overview of Boot Volume Backups](https://docs.cloud.oracle.com/iaas/Content/Block/Concepts/bootvolumebackups.htm)
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CopyBootVolumeBackupRequest
     * @return CopyBootVolumeBackupResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/CopyBootVolumeBackup.ts.html |here} to see how to use CopyBootVolumeBackup API.
     */
    copyBootVolumeBackup(copyBootVolumeBackupRequest: requests.CopyBootVolumeBackupRequest): Promise<responses.CopyBootVolumeBackupResponse>;
    /**
     * Creates a volume backup copy in specified region. For general information about volume backups,
     * see [Overview of Block Volume Service Backups](https://docs.cloud.oracle.com/iaas/Content/Block/Concepts/blockvolumebackups.htm)
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CopyVolumeBackupRequest
     * @return CopyVolumeBackupResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/CopyVolumeBackup.ts.html |here} to see how to use CopyVolumeBackup API.
     */
    copyVolumeBackup(copyVolumeBackupRequest: requests.CopyVolumeBackupRequest): Promise<responses.CopyVolumeBackupResponse>;
    /**
     * Creates a volume group backup copy in specified region. For general information about volume group backups,
     * see [Overview of Block Volume Backups](https://docs.cloud.oracle.com/iaas/Content/Block/Concepts/blockvolumebackups.htm).
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CopyVolumeGroupBackupRequest
     * @return CopyVolumeGroupBackupResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/CopyVolumeGroupBackup.ts.html |here} to see how to use CopyVolumeGroupBackup API.
     */
    copyVolumeGroupBackup(copyVolumeGroupBackupRequest: requests.CopyVolumeGroupBackupRequest): Promise<responses.CopyVolumeGroupBackupResponse>;
    /**
     * Creates a new boot volume in the specified compartment from an existing boot volume or a boot volume backup.
     * For general information about boot volumes, see [Boot Volumes](https://docs.cloud.oracle.com/iaas/Content/Block/Concepts/bootvolumes.htm).
     * You may optionally specify a *display name* for the volume, which is simply a friendly name or
     * description. It does not have to be unique, and you can change it. Avoid entering confidential information.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateBootVolumeRequest
     * @return CreateBootVolumeResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/CreateBootVolume.ts.html |here} to see how to use CreateBootVolume API.
     */
    createBootVolume(createBootVolumeRequest: requests.CreateBootVolumeRequest): Promise<responses.CreateBootVolumeResponse>;
    /**
       * Creates a new boot volume backup of the specified boot volume. For general information about boot volume backups,
  * see [Overview of Boot Volume Backups](https://docs.cloud.oracle.com/iaas/Content/Block/Concepts/bootvolumebackups.htm)
  * <p>
  When the request is received, the backup object is in a REQUEST_RECEIVED state.
  * When the data is imaged, it goes into a CREATING state.
  * After the backup is fully uploaded to the cloud, it goes into an AVAILABLE state.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param CreateBootVolumeBackupRequest
       * @return CreateBootVolumeBackupResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/CreateBootVolumeBackup.ts.html |here} to see how to use CreateBootVolumeBackup API.
       */
    createBootVolumeBackup(createBootVolumeBackupRequest: requests.CreateBootVolumeBackupRequest): Promise<responses.CreateBootVolumeBackupResponse>;
    /**
       * Creates a new volume in the specified compartment. Volumes can be created in sizes ranging from
  * 50 GB (51200 MB) to 32 TB (33554432 MB), in 1 GB (1024 MB) increments. By default, volumes are 1 TB (1048576 MB).
  * For general information about block volumes, see
  * [Overview of Block Volume Service](https://docs.cloud.oracle.com/iaas/Content/Block/Concepts/overview.htm).
  * <p>
  A volume and instance can be in separate compartments but must be in the same availability domain.
  * For information about access control and compartments, see
  * [Overview of the IAM Service](https://docs.cloud.oracle.com/iaas/Content/Identity/Concepts/overview.htm). For information about
  * availability domains, see [Regions and Availability Domains](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/regions.htm).
  * To get a list of availability domains, use the `ListAvailabilityDomains` operation
  * in the Identity and Access Management Service API.
  * <p>
  You may optionally specify a *display name* for the volume, which is simply a friendly name or
  * description. It does not have to be unique, and you can change it. Avoid entering confidential information.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param CreateVolumeRequest
       * @return CreateVolumeResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/CreateVolume.ts.html |here} to see how to use CreateVolume API.
       */
    createVolume(createVolumeRequest: requests.CreateVolumeRequest): Promise<responses.CreateVolumeResponse>;
    /**
       * Creates a new backup of the specified volume. For general information about volume backups,
  * see [Overview of Block Volume Service Backups](https://docs.cloud.oracle.com/iaas/Content/Block/Concepts/blockvolumebackups.htm)
  * <p>
  When the request is received, the backup object is in a REQUEST_RECEIVED state.
  * When the data is imaged, it goes into a CREATING state.
  * After the backup is fully uploaded to the cloud, it goes into an AVAILABLE state.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param CreateVolumeBackupRequest
       * @return CreateVolumeBackupResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/CreateVolumeBackup.ts.html |here} to see how to use CreateVolumeBackup API.
       */
    createVolumeBackup(createVolumeBackupRequest: requests.CreateVolumeBackupRequest): Promise<responses.CreateVolumeBackupResponse>;
    /**
       * Creates a new user defined backup policy.
  * <p>
  For more information about Oracle defined backup policies and user defined backup policies,
  * see [Policy-Based Backups](https://docs.cloud.oracle.com/iaas/Content/Block/Tasks/schedulingvolumebackups.htm).
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param CreateVolumeBackupPolicyRequest
       * @return CreateVolumeBackupPolicyResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/CreateVolumeBackupPolicy.ts.html |here} to see how to use CreateVolumeBackupPolicy API.
       */
    createVolumeBackupPolicy(createVolumeBackupPolicyRequest: requests.CreateVolumeBackupPolicyRequest): Promise<responses.CreateVolumeBackupPolicyResponse>;
    /**
     * Assigns a volume backup policy to the specified volume. Note that a given volume can
     * only have one backup policy assigned to it. If this operation is used for a volume that already
     * has a different backup policy assigned, the prior backup policy will be silently unassigned.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateVolumeBackupPolicyAssignmentRequest
     * @return CreateVolumeBackupPolicyAssignmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/CreateVolumeBackupPolicyAssignment.ts.html |here} to see how to use CreateVolumeBackupPolicyAssignment API.
     */
    createVolumeBackupPolicyAssignment(createVolumeBackupPolicyAssignmentRequest: requests.CreateVolumeBackupPolicyAssignmentRequest): Promise<responses.CreateVolumeBackupPolicyAssignmentResponse>;
    /**
       * Creates a new volume group in the specified compartment.
  * A volume group is a collection of volumes and may be created from a list of volumes, cloning an existing
  * volume group, or by restoring a volume group backup.
  * You may optionally specify a *display name* for the volume group, which is simply a friendly name or
  * description. It does not have to be unique, and you can change it. Avoid entering confidential information.
  * <p>
  For more information, see [Volume Groups](https://docs.cloud.oracle.com/iaas/Content/Block/Concepts/volumegroups.htm).
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param CreateVolumeGroupRequest
       * @return CreateVolumeGroupResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/CreateVolumeGroup.ts.html |here} to see how to use CreateVolumeGroup API.
       */
    createVolumeGroup(createVolumeGroupRequest: requests.CreateVolumeGroupRequest): Promise<responses.CreateVolumeGroupResponse>;
    /**
     * Creates a new backup volume group of the specified volume group.
     * For more information, see [Volume Groups](https://docs.cloud.oracle.com/iaas/Content/Block/Concepts/volumegroups.htm).
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateVolumeGroupBackupRequest
     * @return CreateVolumeGroupBackupResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/CreateVolumeGroupBackup.ts.html |here} to see how to use CreateVolumeGroupBackup API.
     */
    createVolumeGroupBackup(createVolumeGroupBackupRequest: requests.CreateVolumeGroupBackupRequest): Promise<responses.CreateVolumeGroupBackupResponse>;
    /**
     * Deletes the specified boot volume. The volume cannot have an active connection to an instance.
     * To disconnect the boot volume from a connected instance, see
     * [Disconnecting From a Boot Volume](https://docs.cloud.oracle.com/iaas/Content/Block/Tasks/deletingbootvolume.htm).
     * **Warning:** All data on the boot volume will be permanently lost when the boot volume is deleted.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteBootVolumeRequest
     * @return DeleteBootVolumeResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/DeleteBootVolume.ts.html |here} to see how to use DeleteBootVolume API.
     */
    deleteBootVolume(deleteBootVolumeRequest: requests.DeleteBootVolumeRequest): Promise<responses.DeleteBootVolumeResponse>;
    /**
     * Deletes a boot volume backup.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteBootVolumeBackupRequest
     * @return DeleteBootVolumeBackupResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/DeleteBootVolumeBackup.ts.html |here} to see how to use DeleteBootVolumeBackup API.
     */
    deleteBootVolumeBackup(deleteBootVolumeBackupRequest: requests.DeleteBootVolumeBackupRequest): Promise<responses.DeleteBootVolumeBackupResponse>;
    /**
     * Removes the specified boot volume's assigned Vault Service encryption key.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteBootVolumeKmsKeyRequest
     * @return DeleteBootVolumeKmsKeyResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/DeleteBootVolumeKmsKey.ts.html |here} to see how to use DeleteBootVolumeKmsKey API.
     */
    deleteBootVolumeKmsKey(deleteBootVolumeKmsKeyRequest: requests.DeleteBootVolumeKmsKeyRequest): Promise<responses.DeleteBootVolumeKmsKeyResponse>;
    /**
     * Deletes the specified volume. The volume cannot have an active connection to an instance.
     * To disconnect the volume from a connected instance, see
     * [Disconnecting From a Volume](https://docs.cloud.oracle.com/iaas/Content/Block/Tasks/disconnectingfromavolume.htm).
     * **Warning:** All data on the volume will be permanently lost when the volume is deleted.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteVolumeRequest
     * @return DeleteVolumeResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/DeleteVolume.ts.html |here} to see how to use DeleteVolume API.
     */
    deleteVolume(deleteVolumeRequest: requests.DeleteVolumeRequest): Promise<responses.DeleteVolumeResponse>;
    /**
     * Deletes a volume backup.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteVolumeBackupRequest
     * @return DeleteVolumeBackupResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/DeleteVolumeBackup.ts.html |here} to see how to use DeleteVolumeBackup API.
     */
    deleteVolumeBackup(deleteVolumeBackupRequest: requests.DeleteVolumeBackupRequest): Promise<responses.DeleteVolumeBackupResponse>;
    /**
       * Deletes a user defined backup policy.
  *  For more information about user defined backup policies,
  *  see [Policy-Based Backups](https://docs.cloud.oracle.com/iaas/Content/Block/Tasks/schedulingvolumebackups.htm#UserDefinedBackupPolicies).
  * <p>
   Avoid entering confidential information.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param DeleteVolumeBackupPolicyRequest
       * @return DeleteVolumeBackupPolicyResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/DeleteVolumeBackupPolicy.ts.html |here} to see how to use DeleteVolumeBackupPolicy API.
       */
    deleteVolumeBackupPolicy(deleteVolumeBackupPolicyRequest: requests.DeleteVolumeBackupPolicyRequest): Promise<responses.DeleteVolumeBackupPolicyResponse>;
    /**
     * Deletes a volume backup policy assignment.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteVolumeBackupPolicyAssignmentRequest
     * @return DeleteVolumeBackupPolicyAssignmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/DeleteVolumeBackupPolicyAssignment.ts.html |here} to see how to use DeleteVolumeBackupPolicyAssignment API.
     */
    deleteVolumeBackupPolicyAssignment(deleteVolumeBackupPolicyAssignmentRequest: requests.DeleteVolumeBackupPolicyAssignmentRequest): Promise<responses.DeleteVolumeBackupPolicyAssignmentResponse>;
    /**
     * Deletes the specified volume group. Individual volumes are not deleted, only the volume group is deleted.
     * For more information, see [Volume Groups](https://docs.cloud.oracle.com/iaas/Content/Block/Concepts/volumegroups.htm).
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteVolumeGroupRequest
     * @return DeleteVolumeGroupResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/DeleteVolumeGroup.ts.html |here} to see how to use DeleteVolumeGroup API.
     */
    deleteVolumeGroup(deleteVolumeGroupRequest: requests.DeleteVolumeGroupRequest): Promise<responses.DeleteVolumeGroupResponse>;
    /**
     * Deletes a volume group backup. This operation deletes all the backups in
     * the volume group. For more information, see [Volume Groups](https://docs.cloud.oracle.com/iaas/Content/Block/Concepts/volumegroups.htm).
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteVolumeGroupBackupRequest
     * @return DeleteVolumeGroupBackupResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/DeleteVolumeGroupBackup.ts.html |here} to see how to use DeleteVolumeGroupBackup API.
     */
    deleteVolumeGroupBackup(deleteVolumeGroupBackupRequest: requests.DeleteVolumeGroupBackupRequest): Promise<responses.DeleteVolumeGroupBackupResponse>;
    /**
     * Removes the specified volume's assigned Vault service encryption key.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteVolumeKmsKeyRequest
     * @return DeleteVolumeKmsKeyResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/DeleteVolumeKmsKey.ts.html |here} to see how to use DeleteVolumeKmsKey API.
     */
    deleteVolumeKmsKey(deleteVolumeKmsKeyRequest: requests.DeleteVolumeKmsKeyRequest): Promise<responses.DeleteVolumeKmsKeyResponse>;
    /**
     * Gets information for the specified block volume replica.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetBlockVolumeReplicaRequest
     * @return GetBlockVolumeReplicaResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetBlockVolumeReplica.ts.html |here} to see how to use GetBlockVolumeReplica API.
     */
    getBlockVolumeReplica(getBlockVolumeReplicaRequest: requests.GetBlockVolumeReplicaRequest): Promise<responses.GetBlockVolumeReplicaResponse>;
    /**
     * Gets information for the specified boot volume.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetBootVolumeRequest
     * @return GetBootVolumeResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetBootVolume.ts.html |here} to see how to use GetBootVolume API.
     */
    getBootVolume(getBootVolumeRequest: requests.GetBootVolumeRequest): Promise<responses.GetBootVolumeResponse>;
    /**
     * Gets information for the specified boot volume backup.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetBootVolumeBackupRequest
     * @return GetBootVolumeBackupResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetBootVolumeBackup.ts.html |here} to see how to use GetBootVolumeBackup API.
     */
    getBootVolumeBackup(getBootVolumeBackupRequest: requests.GetBootVolumeBackupRequest): Promise<responses.GetBootVolumeBackupResponse>;
    /**
     * Gets the Vault service encryption key assigned to the specified boot volume.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetBootVolumeKmsKeyRequest
     * @return GetBootVolumeKmsKeyResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetBootVolumeKmsKey.ts.html |here} to see how to use GetBootVolumeKmsKey API.
     */
    getBootVolumeKmsKey(getBootVolumeKmsKeyRequest: requests.GetBootVolumeKmsKeyRequest): Promise<responses.GetBootVolumeKmsKeyResponse>;
    /**
     * Gets information for the specified boot volume replica.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetBootVolumeReplicaRequest
     * @return GetBootVolumeReplicaResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetBootVolumeReplica.ts.html |here} to see how to use GetBootVolumeReplica API.
     */
    getBootVolumeReplica(getBootVolumeReplicaRequest: requests.GetBootVolumeReplicaRequest): Promise<responses.GetBootVolumeReplicaResponse>;
    /**
     * Gets information for the specified volume.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetVolumeRequest
     * @return GetVolumeResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetVolume.ts.html |here} to see how to use GetVolume API.
     */
    getVolume(getVolumeRequest: requests.GetVolumeRequest): Promise<responses.GetVolumeResponse>;
    /**
     * Gets information for the specified volume backup.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetVolumeBackupRequest
     * @return GetVolumeBackupResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetVolumeBackup.ts.html |here} to see how to use GetVolumeBackup API.
     */
    getVolumeBackup(getVolumeBackupRequest: requests.GetVolumeBackupRequest): Promise<responses.GetVolumeBackupResponse>;
    /**
     * Gets information for the specified volume backup policy.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetVolumeBackupPolicyRequest
     * @return GetVolumeBackupPolicyResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetVolumeBackupPolicy.ts.html |here} to see how to use GetVolumeBackupPolicy API.
     */
    getVolumeBackupPolicy(getVolumeBackupPolicyRequest: requests.GetVolumeBackupPolicyRequest): Promise<responses.GetVolumeBackupPolicyResponse>;
    /**
     * Gets the volume backup policy assignment for the specified volume. The
     * `assetId` query parameter is required, and the returned list will contain at most
     * one item, since volume can only have one volume backup policy assigned at a time.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetVolumeBackupPolicyAssetAssignmentRequest
     * @return GetVolumeBackupPolicyAssetAssignmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetVolumeBackupPolicyAssetAssignment.ts.html |here} to see how to use GetVolumeBackupPolicyAssetAssignment API.
     */
    getVolumeBackupPolicyAssetAssignment(getVolumeBackupPolicyAssetAssignmentRequest: requests.GetVolumeBackupPolicyAssetAssignmentRequest): Promise<responses.GetVolumeBackupPolicyAssetAssignmentResponse>;
    /**
     * NOTE: This function is deprecated in favor of getVolumeBackupPolicyAssetAssignmentRecordIterator function.
     * Creates a new async iterator which will iterate over the models.VolumeBackupPolicyAssignment objects
     * contained in responses from the getVolumeBackupPolicyAssetAssignment operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    getAllVolumeBackupPolicyAssetAssignment(request: requests.GetVolumeBackupPolicyAssetAssignmentRequest): AsyncIterableIterator<model.VolumeBackupPolicyAssignment>;
    /**
     * NOTE: This function is deprecated in favor of getVolumeBackupPolicyAssetAssignmentResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the getVolumeBackupPolicyAssetAssignment operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    getAllVolumeBackupPolicyAssetAssignmentResponses(request: requests.GetVolumeBackupPolicyAssetAssignmentRequest): AsyncIterableIterator<responses.GetVolumeBackupPolicyAssetAssignmentResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.VolumeBackupPolicyAssignment objects
     * contained in responses from the getVolumeBackupPolicyAssetAssignment operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    getVolumeBackupPolicyAssetAssignmentRecordIterator(request: requests.GetVolumeBackupPolicyAssetAssignmentRequest): AsyncIterableIterator<model.VolumeBackupPolicyAssignment>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the getVolumeBackupPolicyAssetAssignment operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    getVolumeBackupPolicyAssetAssignmentResponseIterator(request: requests.GetVolumeBackupPolicyAssetAssignmentRequest): AsyncIterableIterator<responses.GetVolumeBackupPolicyAssetAssignmentResponse>;
    /**
     * Gets information for the specified volume backup policy assignment.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetVolumeBackupPolicyAssignmentRequest
     * @return GetVolumeBackupPolicyAssignmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetVolumeBackupPolicyAssignment.ts.html |here} to see how to use GetVolumeBackupPolicyAssignment API.
     */
    getVolumeBackupPolicyAssignment(getVolumeBackupPolicyAssignmentRequest: requests.GetVolumeBackupPolicyAssignmentRequest): Promise<responses.GetVolumeBackupPolicyAssignmentResponse>;
    /**
     * Gets information for the specified volume group. For more information, see [Volume Groups](https://docs.cloud.oracle.com/iaas/Content/Block/Concepts/volumegroups.htm).
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetVolumeGroupRequest
     * @return GetVolumeGroupResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetVolumeGroup.ts.html |here} to see how to use GetVolumeGroup API.
     */
    getVolumeGroup(getVolumeGroupRequest: requests.GetVolumeGroupRequest): Promise<responses.GetVolumeGroupResponse>;
    /**
     * Gets information for the specified volume group backup. For more information, see [Volume Groups](https://docs.cloud.oracle.com/iaas/Content/Block/Concepts/volumegroups.htm).
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetVolumeGroupBackupRequest
     * @return GetVolumeGroupBackupResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetVolumeGroupBackup.ts.html |here} to see how to use GetVolumeGroupBackup API.
     */
    getVolumeGroupBackup(getVolumeGroupBackupRequest: requests.GetVolumeGroupBackupRequest): Promise<responses.GetVolumeGroupBackupResponse>;
    /**
     * Gets information for the specified volume group replica.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetVolumeGroupReplicaRequest
     * @return GetVolumeGroupReplicaResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetVolumeGroupReplica.ts.html |here} to see how to use GetVolumeGroupReplica API.
     */
    getVolumeGroupReplica(getVolumeGroupReplicaRequest: requests.GetVolumeGroupReplicaRequest): Promise<responses.GetVolumeGroupReplicaResponse>;
    /**
     * Gets the Vault service encryption key assigned to the specified volume.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetVolumeKmsKeyRequest
     * @return GetVolumeKmsKeyResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetVolumeKmsKey.ts.html |here} to see how to use GetVolumeKmsKey API.
     */
    getVolumeKmsKey(getVolumeKmsKeyRequest: requests.GetVolumeKmsKeyRequest): Promise<responses.GetVolumeKmsKeyResponse>;
    /**
     * Lists the block volume replicas in the specified compartment and availability domain.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListBlockVolumeReplicasRequest
     * @return ListBlockVolumeReplicasResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ListBlockVolumeReplicas.ts.html |here} to see how to use ListBlockVolumeReplicas API.
     */
    listBlockVolumeReplicas(listBlockVolumeReplicasRequest: requests.ListBlockVolumeReplicasRequest): Promise<responses.ListBlockVolumeReplicasResponse>;
    /**
     * NOTE: This function is deprecated in favor of listBlockVolumeReplicasRecordIterator function.
     * Creates a new async iterator which will iterate over the models.BlockVolumeReplica objects
     * contained in responses from the listBlockVolumeReplicas operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllBlockVolumeReplicas(request: requests.ListBlockVolumeReplicasRequest): AsyncIterableIterator<model.BlockVolumeReplica>;
    /**
     * NOTE: This function is deprecated in favor of listBlockVolumeReplicasResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listBlockVolumeReplicas operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllBlockVolumeReplicasResponses(request: requests.ListBlockVolumeReplicasRequest): AsyncIterableIterator<responses.ListBlockVolumeReplicasResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.BlockVolumeReplica objects
     * contained in responses from the listBlockVolumeReplicas operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listBlockVolumeReplicasRecordIterator(request: requests.ListBlockVolumeReplicasRequest): AsyncIterableIterator<model.BlockVolumeReplica>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listBlockVolumeReplicas operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listBlockVolumeReplicasResponseIterator(request: requests.ListBlockVolumeReplicasRequest): AsyncIterableIterator<responses.ListBlockVolumeReplicasResponse>;
    /**
     * Lists the boot volume backups in the specified compartment. You can filter the results by boot volume.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListBootVolumeBackupsRequest
     * @return ListBootVolumeBackupsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ListBootVolumeBackups.ts.html |here} to see how to use ListBootVolumeBackups API.
     */
    listBootVolumeBackups(listBootVolumeBackupsRequest: requests.ListBootVolumeBackupsRequest): Promise<responses.ListBootVolumeBackupsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listBootVolumeBackupsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.BootVolumeBackup objects
     * contained in responses from the listBootVolumeBackups operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllBootVolumeBackups(request: requests.ListBootVolumeBackupsRequest): AsyncIterableIterator<model.BootVolumeBackup>;
    /**
     * NOTE: This function is deprecated in favor of listBootVolumeBackupsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listBootVolumeBackups operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllBootVolumeBackupsResponses(request: requests.ListBootVolumeBackupsRequest): AsyncIterableIterator<responses.ListBootVolumeBackupsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.BootVolumeBackup objects
     * contained in responses from the listBootVolumeBackups operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listBootVolumeBackupsRecordIterator(request: requests.ListBootVolumeBackupsRequest): AsyncIterableIterator<model.BootVolumeBackup>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listBootVolumeBackups operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listBootVolumeBackupsResponseIterator(request: requests.ListBootVolumeBackupsRequest): AsyncIterableIterator<responses.ListBootVolumeBackupsResponse>;
    /**
     * Lists the boot volume replicas in the specified compartment and availability domain.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListBootVolumeReplicasRequest
     * @return ListBootVolumeReplicasResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ListBootVolumeReplicas.ts.html |here} to see how to use ListBootVolumeReplicas API.
     */
    listBootVolumeReplicas(listBootVolumeReplicasRequest: requests.ListBootVolumeReplicasRequest): Promise<responses.ListBootVolumeReplicasResponse>;
    /**
     * NOTE: This function is deprecated in favor of listBootVolumeReplicasRecordIterator function.
     * Creates a new async iterator which will iterate over the models.BootVolumeReplica objects
     * contained in responses from the listBootVolumeReplicas operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllBootVolumeReplicas(request: requests.ListBootVolumeReplicasRequest): AsyncIterableIterator<model.BootVolumeReplica>;
    /**
     * NOTE: This function is deprecated in favor of listBootVolumeReplicasResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listBootVolumeReplicas operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllBootVolumeReplicasResponses(request: requests.ListBootVolumeReplicasRequest): AsyncIterableIterator<responses.ListBootVolumeReplicasResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.BootVolumeReplica objects
     * contained in responses from the listBootVolumeReplicas operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listBootVolumeReplicasRecordIterator(request: requests.ListBootVolumeReplicasRequest): AsyncIterableIterator<model.BootVolumeReplica>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listBootVolumeReplicas operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listBootVolumeReplicasResponseIterator(request: requests.ListBootVolumeReplicasRequest): AsyncIterableIterator<responses.ListBootVolumeReplicasResponse>;
    /**
     * Lists the boot volumes in the specified compartment and availability domain.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListBootVolumesRequest
     * @return ListBootVolumesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ListBootVolumes.ts.html |here} to see how to use ListBootVolumes API.
     */
    listBootVolumes(listBootVolumesRequest: requests.ListBootVolumesRequest): Promise<responses.ListBootVolumesResponse>;
    /**
     * NOTE: This function is deprecated in favor of listBootVolumesRecordIterator function.
     * Creates a new async iterator which will iterate over the models.BootVolume objects
     * contained in responses from the listBootVolumes operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllBootVolumes(request: requests.ListBootVolumesRequest): AsyncIterableIterator<model.BootVolume>;
    /**
     * NOTE: This function is deprecated in favor of listBootVolumesResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listBootVolumes operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllBootVolumesResponses(request: requests.ListBootVolumesRequest): AsyncIterableIterator<responses.ListBootVolumesResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.BootVolume objects
     * contained in responses from the listBootVolumes operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listBootVolumesRecordIterator(request: requests.ListBootVolumesRequest): AsyncIterableIterator<model.BootVolume>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listBootVolumes operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listBootVolumesResponseIterator(request: requests.ListBootVolumesRequest): AsyncIterableIterator<responses.ListBootVolumesResponse>;
    /**
       * Lists all the volume backup policies available in the specified compartment.
  * <p>
  For more information about Oracle defined backup policies and user defined backup policies,
  * see [Policy-Based Backups](https://docs.cloud.oracle.com/iaas/Content/Block/Tasks/schedulingvolumebackups.htm).
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param ListVolumeBackupPoliciesRequest
       * @return ListVolumeBackupPoliciesResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ListVolumeBackupPolicies.ts.html |here} to see how to use ListVolumeBackupPolicies API.
       */
    listVolumeBackupPolicies(listVolumeBackupPoliciesRequest: requests.ListVolumeBackupPoliciesRequest): Promise<responses.ListVolumeBackupPoliciesResponse>;
    /**
     * NOTE: This function is deprecated in favor of listVolumeBackupPoliciesRecordIterator function.
     * Creates a new async iterator which will iterate over the models.VolumeBackupPolicy objects
     * contained in responses from the listVolumeBackupPolicies operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllVolumeBackupPolicies(request: requests.ListVolumeBackupPoliciesRequest): AsyncIterableIterator<model.VolumeBackupPolicy>;
    /**
     * NOTE: This function is deprecated in favor of listVolumeBackupPoliciesResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listVolumeBackupPolicies operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllVolumeBackupPoliciesResponses(request: requests.ListVolumeBackupPoliciesRequest): AsyncIterableIterator<responses.ListVolumeBackupPoliciesResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.VolumeBackupPolicy objects
     * contained in responses from the listVolumeBackupPolicies operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listVolumeBackupPoliciesRecordIterator(request: requests.ListVolumeBackupPoliciesRequest): AsyncIterableIterator<model.VolumeBackupPolicy>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listVolumeBackupPolicies operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listVolumeBackupPoliciesResponseIterator(request: requests.ListVolumeBackupPoliciesRequest): AsyncIterableIterator<responses.ListVolumeBackupPoliciesResponse>;
    /**
     * Lists the volume backups in the specified compartment. You can filter the results by volume.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListVolumeBackupsRequest
     * @return ListVolumeBackupsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ListVolumeBackups.ts.html |here} to see how to use ListVolumeBackups API.
     */
    listVolumeBackups(listVolumeBackupsRequest: requests.ListVolumeBackupsRequest): Promise<responses.ListVolumeBackupsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listVolumeBackupsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.VolumeBackup objects
     * contained in responses from the listVolumeBackups operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllVolumeBackups(request: requests.ListVolumeBackupsRequest): AsyncIterableIterator<model.VolumeBackup>;
    /**
     * NOTE: This function is deprecated in favor of listVolumeBackupsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listVolumeBackups operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllVolumeBackupsResponses(request: requests.ListVolumeBackupsRequest): AsyncIterableIterator<responses.ListVolumeBackupsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.VolumeBackup objects
     * contained in responses from the listVolumeBackups operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listVolumeBackupsRecordIterator(request: requests.ListVolumeBackupsRequest): AsyncIterableIterator<model.VolumeBackup>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listVolumeBackups operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listVolumeBackupsResponseIterator(request: requests.ListVolumeBackupsRequest): AsyncIterableIterator<responses.ListVolumeBackupsResponse>;
    /**
     * Lists the volume group backups in the specified compartment. You can filter the results by volume group.
     * For more information, see [Volume Groups](https://docs.cloud.oracle.com/iaas/Content/Block/Concepts/volumegroups.htm).
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListVolumeGroupBackupsRequest
     * @return ListVolumeGroupBackupsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ListVolumeGroupBackups.ts.html |here} to see how to use ListVolumeGroupBackups API.
     */
    listVolumeGroupBackups(listVolumeGroupBackupsRequest: requests.ListVolumeGroupBackupsRequest): Promise<responses.ListVolumeGroupBackupsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listVolumeGroupBackupsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.VolumeGroupBackup objects
     * contained in responses from the listVolumeGroupBackups operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllVolumeGroupBackups(request: requests.ListVolumeGroupBackupsRequest): AsyncIterableIterator<model.VolumeGroupBackup>;
    /**
     * NOTE: This function is deprecated in favor of listVolumeGroupBackupsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listVolumeGroupBackups operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllVolumeGroupBackupsResponses(request: requests.ListVolumeGroupBackupsRequest): AsyncIterableIterator<responses.ListVolumeGroupBackupsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.VolumeGroupBackup objects
     * contained in responses from the listVolumeGroupBackups operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listVolumeGroupBackupsRecordIterator(request: requests.ListVolumeGroupBackupsRequest): AsyncIterableIterator<model.VolumeGroupBackup>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listVolumeGroupBackups operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listVolumeGroupBackupsResponseIterator(request: requests.ListVolumeGroupBackupsRequest): AsyncIterableIterator<responses.ListVolumeGroupBackupsResponse>;
    /**
     * Lists the volume group replicas in the specified compartment. You can filter the results by volume group.
     * For more information, see [Volume Group Replication](https://docs.cloud.oracle.com/iaas/Content/Block/Concepts/volumegroupreplication.htm).
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListVolumeGroupReplicasRequest
     * @return ListVolumeGroupReplicasResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ListVolumeGroupReplicas.ts.html |here} to see how to use ListVolumeGroupReplicas API.
     */
    listVolumeGroupReplicas(listVolumeGroupReplicasRequest: requests.ListVolumeGroupReplicasRequest): Promise<responses.ListVolumeGroupReplicasResponse>;
    /**
     * NOTE: This function is deprecated in favor of listVolumeGroupReplicasRecordIterator function.
     * Creates a new async iterator which will iterate over the models.VolumeGroupReplica objects
     * contained in responses from the listVolumeGroupReplicas operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllVolumeGroupReplicas(request: requests.ListVolumeGroupReplicasRequest): AsyncIterableIterator<model.VolumeGroupReplica>;
    /**
     * NOTE: This function is deprecated in favor of listVolumeGroupReplicasResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listVolumeGroupReplicas operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllVolumeGroupReplicasResponses(request: requests.ListVolumeGroupReplicasRequest): AsyncIterableIterator<responses.ListVolumeGroupReplicasResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.VolumeGroupReplica objects
     * contained in responses from the listVolumeGroupReplicas operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listVolumeGroupReplicasRecordIterator(request: requests.ListVolumeGroupReplicasRequest): AsyncIterableIterator<model.VolumeGroupReplica>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listVolumeGroupReplicas operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listVolumeGroupReplicasResponseIterator(request: requests.ListVolumeGroupReplicasRequest): AsyncIterableIterator<responses.ListVolumeGroupReplicasResponse>;
    /**
     * Lists the volume groups in the specified compartment and availability domain.
     * For more information, see [Volume Groups](https://docs.cloud.oracle.com/iaas/Content/Block/Concepts/volumegroups.htm).
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListVolumeGroupsRequest
     * @return ListVolumeGroupsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ListVolumeGroups.ts.html |here} to see how to use ListVolumeGroups API.
     */
    listVolumeGroups(listVolumeGroupsRequest: requests.ListVolumeGroupsRequest): Promise<responses.ListVolumeGroupsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listVolumeGroupsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.VolumeGroup objects
     * contained in responses from the listVolumeGroups operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllVolumeGroups(request: requests.ListVolumeGroupsRequest): AsyncIterableIterator<model.VolumeGroup>;
    /**
     * NOTE: This function is deprecated in favor of listVolumeGroupsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listVolumeGroups operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllVolumeGroupsResponses(request: requests.ListVolumeGroupsRequest): AsyncIterableIterator<responses.ListVolumeGroupsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.VolumeGroup objects
     * contained in responses from the listVolumeGroups operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listVolumeGroupsRecordIterator(request: requests.ListVolumeGroupsRequest): AsyncIterableIterator<model.VolumeGroup>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listVolumeGroups operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listVolumeGroupsResponseIterator(request: requests.ListVolumeGroupsRequest): AsyncIterableIterator<responses.ListVolumeGroupsResponse>;
    /**
     * Lists the volumes in the specified compartment and availability domain.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListVolumesRequest
     * @return ListVolumesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ListVolumes.ts.html |here} to see how to use ListVolumes API.
     */
    listVolumes(listVolumesRequest: requests.ListVolumesRequest): Promise<responses.ListVolumesResponse>;
    /**
     * NOTE: This function is deprecated in favor of listVolumesRecordIterator function.
     * Creates a new async iterator which will iterate over the models.Volume objects
     * contained in responses from the listVolumes operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllVolumes(request: requests.ListVolumesRequest): AsyncIterableIterator<model.Volume>;
    /**
     * NOTE: This function is deprecated in favor of listVolumesResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listVolumes operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllVolumesResponses(request: requests.ListVolumesRequest): AsyncIterableIterator<responses.ListVolumesResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.Volume objects
     * contained in responses from the listVolumes operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listVolumesRecordIterator(request: requests.ListVolumesRequest): AsyncIterableIterator<model.Volume>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listVolumes operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listVolumesResponseIterator(request: requests.ListVolumesRequest): AsyncIterableIterator<responses.ListVolumesResponse>;
    /**
     * Updates the specified boot volume's display name, defined tags, and free-form tags.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateBootVolumeRequest
     * @return UpdateBootVolumeResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/UpdateBootVolume.ts.html |here} to see how to use UpdateBootVolume API.
     */
    updateBootVolume(updateBootVolumeRequest: requests.UpdateBootVolumeRequest): Promise<responses.UpdateBootVolumeResponse>;
    /**
     * Updates the display name for the specified boot volume backup.
     * Avoid entering confidential information.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateBootVolumeBackupRequest
     * @return UpdateBootVolumeBackupResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/UpdateBootVolumeBackup.ts.html |here} to see how to use UpdateBootVolumeBackup API.
     */
    updateBootVolumeBackup(updateBootVolumeBackupRequest: requests.UpdateBootVolumeBackupRequest): Promise<responses.UpdateBootVolumeBackupResponse>;
    /**
     * Updates the specified volume with a new Vault service master encryption key.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateBootVolumeKmsKeyRequest
     * @return UpdateBootVolumeKmsKeyResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/UpdateBootVolumeKmsKey.ts.html |here} to see how to use UpdateBootVolumeKmsKey API.
     */
    updateBootVolumeKmsKey(updateBootVolumeKmsKeyRequest: requests.UpdateBootVolumeKmsKeyRequest): Promise<responses.UpdateBootVolumeKmsKeyResponse>;
    /**
     * Updates the specified volume's display name.
     * Avoid entering confidential information.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateVolumeRequest
     * @return UpdateVolumeResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/UpdateVolume.ts.html |here} to see how to use UpdateVolume API.
     */
    updateVolume(updateVolumeRequest: requests.UpdateVolumeRequest): Promise<responses.UpdateVolumeResponse>;
    /**
     * Updates the display name for the specified volume backup.
     * Avoid entering confidential information.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateVolumeBackupRequest
     * @return UpdateVolumeBackupResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/UpdateVolumeBackup.ts.html |here} to see how to use UpdateVolumeBackup API.
     */
    updateVolumeBackup(updateVolumeBackupRequest: requests.UpdateVolumeBackupRequest): Promise<responses.UpdateVolumeBackupResponse>;
    /**
       * Updates a user defined backup policy.
  *  For more information about user defined backup policies,
  *  see [Policy-Based Backups](https://docs.cloud.oracle.com/iaas/Content/Block/Tasks/schedulingvolumebackups.htm#UserDefinedBackupPolicies).
  * <p>
   Avoid entering confidential information.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param UpdateVolumeBackupPolicyRequest
       * @return UpdateVolumeBackupPolicyResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/UpdateVolumeBackupPolicy.ts.html |here} to see how to use UpdateVolumeBackupPolicy API.
       */
    updateVolumeBackupPolicy(updateVolumeBackupPolicyRequest: requests.UpdateVolumeBackupPolicyRequest): Promise<responses.UpdateVolumeBackupPolicyResponse>;
    /**
       * Updates the set of volumes in a volume group along with the display name. Use this operation
  * to add or remove volumes in a volume group. Specify the full list of volume IDs to include in the
  * volume group. If the volume ID is not specified in the call, it will be removed from the volume group.
  * Avoid entering confidential information.
  * <p>
  For more information, see [Volume Groups](https://docs.cloud.oracle.com/iaas/Content/Block/Concepts/volumegroups.htm).
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param UpdateVolumeGroupRequest
       * @return UpdateVolumeGroupResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/UpdateVolumeGroup.ts.html |here} to see how to use UpdateVolumeGroup API.
       */
    updateVolumeGroup(updateVolumeGroupRequest: requests.UpdateVolumeGroupRequest): Promise<responses.UpdateVolumeGroupResponse>;
    /**
     * Updates the display name for the specified volume group backup. For more information, see [Volume Groups](https://docs.cloud.oracle.com/iaas/Content/Block/Concepts/volumegroups.htm).
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateVolumeGroupBackupRequest
     * @return UpdateVolumeGroupBackupResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/UpdateVolumeGroupBackup.ts.html |here} to see how to use UpdateVolumeGroupBackup API.
     */
    updateVolumeGroupBackup(updateVolumeGroupBackupRequest: requests.UpdateVolumeGroupBackupRequest): Promise<responses.UpdateVolumeGroupBackupResponse>;
    /**
     * Updates the specified volume with a new Key Management master encryption key.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateVolumeKmsKeyRequest
     * @return UpdateVolumeKmsKeyResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/UpdateVolumeKmsKey.ts.html |here} to see how to use UpdateVolumeKmsKey API.
     */
    updateVolumeKmsKey(updateVolumeKmsKeyRequest: requests.UpdateVolumeKmsKeyRequest): Promise<responses.UpdateVolumeKmsKeyResponse>;
}
export declare enum ComputeApiKeys {
}
/**
 * This service client does not use circuit breakers by default if the user has not defined a circuit breaker configuration.
 */
export declare class ComputeClient {
    protected static serviceEndpointTemplate: string;
    protected static endpointServiceName: string;
    protected "_realmSpecificEndpointTemplateEnabled": boolean | undefined;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_waiters": ComputeWaiter;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: typeof Breaker | null;
    protected _httpOptions: any;
    protected _bodyDuplexMode: any;
    targetService: string;
    protected _regionId: string;
    protected "_region": common.Region;
    protected _lastSetRegionOrRegionId: string;
    protected _httpClient: common.HttpClient;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    get endpoint(): string;
    /**
     * Sets the endpoint to call (ex, https://www.example.com).
     * @param endpoint The endpoint of the service.
     */
    set endpoint(endpoint: string);
    get logger(): import("oci-common/lib/log").Logger;
    /**
     * Determines whether realm specific endpoint should be used or not.
     * Set realmSpecificEndpointTemplateEnabled to "true" if the user wants to enable use of realm specific endpoint template, otherwise set it to "false"
     * @param realmSpecificEndpointTemplateEnabled flag to enable the use of realm specific endpoint template
     */
    set useRealmSpecificEndpointTemplate(realmSpecificEndpointTemplateEnabled: boolean);
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    set region(region: common.Region);
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    set regionId(regionId: string);
    /**
     * Creates a new ComputeWaiter for resources for this service.
     *
     * @param workRequestClient The work request service client used to query for work request status
     * @param config The waiter configuration for termination and delay strategy
     * @return The service waiters.
     */
    createWaiters(workRequestClient: WorkRequestClient, config?: common.WaiterConfiguration): ComputeWaiter;
    /**
     * Gets the waiters available for resources for this service.
     *
     * @return The service waiters.
     */
    getWaiters(): ComputeWaiter;
    /**
     * Shutdown the circuit breaker used by the client when it is no longer needed
     */
    shutdownCircuitBreaker(): void;
    /**
     * Close the client once it is no longer needed
     */
    close(): void;
    /**
     * Accept the changes to the PCR values in the measured boot report.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param AcceptShieldedIntegrityPolicyRequest
     * @return AcceptShieldedIntegrityPolicyResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/AcceptShieldedIntegrityPolicy.ts.html |here} to see how to use AcceptShieldedIntegrityPolicy API.
     */
    acceptShieldedIntegrityPolicy(acceptShieldedIntegrityPolicyRequest: requests.AcceptShieldedIntegrityPolicyRequest): Promise<responses.AcceptShieldedIntegrityPolicyResponse>;
    /**
     * Adds a shape to the compatible shapes list for the image.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param AddImageShapeCompatibilityEntryRequest
     * @return AddImageShapeCompatibilityEntryResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/AddImageShapeCompatibilityEntry.ts.html |here} to see how to use AddImageShapeCompatibilityEntry API.
     */
    addImageShapeCompatibilityEntry(addImageShapeCompatibilityEntryRequest: requests.AddImageShapeCompatibilityEntryRequest): Promise<responses.AddImageShapeCompatibilityEntryResponse>;
    /**
     * Attaches the specified boot volume to the specified instance.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param AttachBootVolumeRequest
     * @return AttachBootVolumeResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/AttachBootVolume.ts.html |here} to see how to use AttachBootVolume API.
     */
    attachBootVolume(attachBootVolumeRequest: requests.AttachBootVolumeRequest): Promise<responses.AttachBootVolumeResponse>;
    /**
     * Creates a secondary VNIC and attaches it to the specified instance.
     * For more information about secondary VNICs, see
     * [Virtual Network Interface Cards (VNICs)](https://docs.cloud.oracle.com/iaas/Content/Network/Tasks/managingVNICs.htm).
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param AttachVnicRequest
     * @return AttachVnicResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/AttachVnic.ts.html |here} to see how to use AttachVnic API.
     */
    attachVnic(attachVnicRequest: requests.AttachVnicRequest): Promise<responses.AttachVnicResponse>;
    /**
     * Attaches the specified storage volume to the specified instance.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param AttachVolumeRequest
     * @return AttachVolumeResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/AttachVolume.ts.html |here} to see how to use AttachVolume API.
     */
    attachVolume(attachVolumeRequest: requests.AttachVolumeRequest): Promise<responses.AttachVolumeResponse>;
    /**
       * Captures the most recent serial console data (up to a megabyte) for the
  * specified instance.
  * <p>
  The `CaptureConsoleHistory` operation works with the other console history operations
  * as described below.
  * <p>
  1. Use `CaptureConsoleHistory` to request the capture of up to a megabyte of the
  * most recent console history. This call returns a `ConsoleHistory`
  * object. The object will have a state of REQUESTED.
  * 2. Wait for the capture operation to succeed by polling `GetConsoleHistory` with
  * the identifier of the console history metadata. The state of the
  * `ConsoleHistory` object will go from REQUESTED to GETTING-HISTORY and
  * then SUCCEEDED (or FAILED).
  * 3. Use `GetConsoleHistoryContent` to get the actual console history data (not the
  * metadata).
  * 4. Optionally, use `DeleteConsoleHistory` to delete the console history metadata
  * and the console history data.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param CaptureConsoleHistoryRequest
       * @return CaptureConsoleHistoryResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/CaptureConsoleHistory.ts.html |here} to see how to use CaptureConsoleHistory API.
       */
    captureConsoleHistory(captureConsoleHistoryRequest: requests.CaptureConsoleHistoryRequest): Promise<responses.CaptureConsoleHistoryResponse>;
    /**
     * Moves a compute capacity reservation into a different compartment. For information about
     * moving resources between compartments, see
     * [Moving Resources to a Different Compartment](https://docs.cloud.oracle.com/iaas/Content/Identity/Tasks/managingcompartments.htm#moveRes).
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangeComputeCapacityReservationCompartmentRequest
     * @return ChangeComputeCapacityReservationCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ChangeComputeCapacityReservationCompartment.ts.html |here} to see how to use ChangeComputeCapacityReservationCompartment API.
     */
    changeComputeCapacityReservationCompartment(changeComputeCapacityReservationCompartmentRequest: requests.ChangeComputeCapacityReservationCompartmentRequest): Promise<responses.ChangeComputeCapacityReservationCompartmentResponse>;
    /**
     * Moves a compute capacity topology into a different compartment. For information about moving resources between
     * compartments, see [Moving Resources to a Different Compartment](https://docs.cloud.oracle.com/iaas/Content/Identity/Tasks/managingcompartments.htm#moveRes).
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ChangeComputeCapacityTopologyCompartmentRequest
     * @return ChangeComputeCapacityTopologyCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ChangeComputeCapacityTopologyCompartment.ts.html |here} to see how to use ChangeComputeCapacityTopologyCompartment API.
     */
    changeComputeCapacityTopologyCompartment(changeComputeCapacityTopologyCompartmentRequest: requests.ChangeComputeCapacityTopologyCompartmentRequest): Promise<responses.ChangeComputeCapacityTopologyCompartmentResponse>;
    /**
       * Moves a compute cluster into a different compartment within the same tenancy.
  * A [compute cluster](https://docs.cloud.oracle.com/iaas/Content/Compute/Tasks/compute-clusters.htm) is a remote direct memory access (RDMA) network group.
  * <p>
  For information about moving resources between compartments, see
  * [Moving Resources to a Different Compartment](https://docs.cloud.oracle.com/iaas/Content/Identity/Tasks/managingcompartments.htm#moveRes).
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param ChangeComputeClusterCompartmentRequest
       * @return ChangeComputeClusterCompartmentResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ChangeComputeClusterCompartment.ts.html |here} to see how to use ChangeComputeClusterCompartment API.
       */
    changeComputeClusterCompartment(changeComputeClusterCompartmentRequest: requests.ChangeComputeClusterCompartmentRequest): Promise<responses.ChangeComputeClusterCompartmentResponse>;
    /**
     * Moves a compute image capability schema into a different compartment within the same tenancy.
     * For information about moving resources between compartments, see
     *         [Moving Resources to a Different Compartment](https://docs.cloud.oracle.com/iaas/Content/Identity/Tasks/managingcompartments.htm#moveRes).
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ChangeComputeImageCapabilitySchemaCompartmentRequest
     * @return ChangeComputeImageCapabilitySchemaCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ChangeComputeImageCapabilitySchemaCompartment.ts.html |here} to see how to use ChangeComputeImageCapabilitySchemaCompartment API.
     */
    changeComputeImageCapabilitySchemaCompartment(changeComputeImageCapabilitySchemaCompartmentRequest: requests.ChangeComputeImageCapabilitySchemaCompartmentRequest): Promise<responses.ChangeComputeImageCapabilitySchemaCompartmentResponse>;
    /**
     * Moves a dedicated virtual machine host from one compartment to another.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangeDedicatedVmHostCompartmentRequest
     * @return ChangeDedicatedVmHostCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ChangeDedicatedVmHostCompartment.ts.html |here} to see how to use ChangeDedicatedVmHostCompartment API.
     */
    changeDedicatedVmHostCompartment(changeDedicatedVmHostCompartmentRequest: requests.ChangeDedicatedVmHostCompartmentRequest): Promise<responses.ChangeDedicatedVmHostCompartmentResponse>;
    /**
     * Moves an image into a different compartment within the same tenancy. For information about moving
     * resources between compartments, see
     * [Moving Resources to a Different Compartment](https://docs.cloud.oracle.com/iaas/Content/Identity/Tasks/managingcompartments.htm#moveRes).
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ChangeImageCompartmentRequest
     * @return ChangeImageCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ChangeImageCompartment.ts.html |here} to see how to use ChangeImageCompartment API.
     */
    changeImageCompartment(changeImageCompartmentRequest: requests.ChangeImageCompartmentRequest): Promise<responses.ChangeImageCompartmentResponse>;
    /**
       * Moves an instance into a different compartment within the same tenancy. For information about
  * moving resources between compartments, see
  * [Moving Resources to a Different Compartment](https://docs.cloud.oracle.com/iaas/Content/Identity/Tasks/managingcompartments.htm#moveRes).
  * <p>
  When you move an instance to a different compartment, associated resources such as boot volumes and VNICs
  * are not moved.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param ChangeInstanceCompartmentRequest
       * @return ChangeInstanceCompartmentResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ChangeInstanceCompartment.ts.html |here} to see how to use ChangeInstanceCompartment API.
       */
    changeInstanceCompartment(changeInstanceCompartmentRequest: requests.ChangeInstanceCompartmentRequest): Promise<responses.ChangeInstanceCompartmentResponse>;
    /**
     * Create a subscription for listing resource version for a compartment. It will take some time to propagate to all regions.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateAppCatalogSubscriptionRequest
     * @return CreateAppCatalogSubscriptionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/CreateAppCatalogSubscription.ts.html |here} to see how to use CreateAppCatalogSubscription API.
     */
    createAppCatalogSubscription(createAppCatalogSubscriptionRequest: requests.CreateAppCatalogSubscriptionRequest): Promise<responses.CreateAppCatalogSubscriptionResponse>;
    /**
       * Generates a report of the host capacity within an availability domain that is available for you
  * to create compute instances. Host capacity is the physical infrastructure that resources such as compute
  * instances run on.
  * <p>
  Use the capacity report to determine whether sufficient capacity is available for a shape before
  * you create an instance or change the shape of an instance.
  *
       * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
       * @param CreateComputeCapacityReportRequest
       * @return CreateComputeCapacityReportResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/CreateComputeCapacityReport.ts.html |here} to see how to use CreateComputeCapacityReport API.
       */
    createComputeCapacityReport(createComputeCapacityReportRequest: requests.CreateComputeCapacityReportRequest): Promise<responses.CreateComputeCapacityReportResponse>;
    /**
     * Creates a new compute capacity reservation in the specified compartment and availability domain.
     * Compute capacity reservations let you reserve instances in a compartment.
     * When you launch an instance using this reservation, you are assured that you have enough space for your instance,
     * and you won't get out of capacity errors.
     * For more information, see [Reserved Capacity](https://docs.cloud.oracle.com/iaas/Content/Compute/Tasks/reserve-capacity.htm).
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateComputeCapacityReservationRequest
     * @return CreateComputeCapacityReservationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/CreateComputeCapacityReservation.ts.html |here} to see how to use CreateComputeCapacityReservation API.
     */
    createComputeCapacityReservation(createComputeCapacityReservationRequest: requests.CreateComputeCapacityReservationRequest): Promise<responses.CreateComputeCapacityReservationResponse>;
    /**
       * Creates a new compute capacity topology in the specified compartment and availability domain.
  * <p>
  Compute capacity topologies provide the RDMA network topology of your bare metal hosts so that you can launch
  * instances on your bare metal hosts with targeted network locations.
  * <p>
  Compute capacity topologies report the health status of your bare metal hosts.
  *
       * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
       * @param CreateComputeCapacityTopologyRequest
       * @return CreateComputeCapacityTopologyResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/CreateComputeCapacityTopology.ts.html |here} to see how to use CreateComputeCapacityTopology API.
       */
    createComputeCapacityTopology(createComputeCapacityTopologyRequest: requests.CreateComputeCapacityTopologyRequest): Promise<responses.CreateComputeCapacityTopologyResponse>;
    /**
       * Creates an empty [compute cluster](https://docs.cloud.oracle.com/iaas/Content/Compute/Tasks/compute-clusters.htm). A compute cluster
  * is a remote direct memory access (RDMA) network group.
  * <p>
  After the compute cluster is created, you can use the compute cluster's OCID with the
  * {@link #launchInstance(LaunchInstanceRequest) launchInstance} operation to create instances in the compute cluster.
  * The instances must be created in the same compartment and availability domain as the cluster.
  * <p>
  Use compute clusters when you want to manage instances in the cluster individually in the RDMA network group.
  * <p>
  If you want predictable capacity for a specific number of identical instances that are managed as a group,
  * create a cluster network that uses instance pools by using the
  * {@link #createClusterNetwork(CreateClusterNetworkRequest) createClusterNetwork} operation.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param CreateComputeClusterRequest
       * @return CreateComputeClusterResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/CreateComputeCluster.ts.html |here} to see how to use CreateComputeCluster API.
       */
    createComputeCluster(createComputeClusterRequest: requests.CreateComputeClusterRequest): Promise<responses.CreateComputeClusterResponse>;
    /**
     * Creates compute image capability schema.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateComputeImageCapabilitySchemaRequest
     * @return CreateComputeImageCapabilitySchemaResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/CreateComputeImageCapabilitySchema.ts.html |here} to see how to use CreateComputeImageCapabilitySchema API.
     */
    createComputeImageCapabilitySchema(createComputeImageCapabilitySchemaRequest: requests.CreateComputeImageCapabilitySchemaRequest): Promise<responses.CreateComputeImageCapabilitySchemaResponse>;
    /**
     * Creates a new dedicated virtual machine host in the specified compartment and the specified availability domain.
     * Dedicated virtual machine hosts enable you to run your Compute virtual machine (VM) instances on dedicated servers
     * that are a single tenant and not shared with other customers.
     * For more information, see [Dedicated Virtual Machine Hosts](https://docs.cloud.oracle.com/iaas/Content/Compute/Concepts/dedicatedvmhosts.htm).
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateDedicatedVmHostRequest
     * @return CreateDedicatedVmHostResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/CreateDedicatedVmHost.ts.html |here} to see how to use CreateDedicatedVmHost API.
     */
    createDedicatedVmHost(createDedicatedVmHostRequest: requests.CreateDedicatedVmHostRequest): Promise<responses.CreateDedicatedVmHostResponse>;
    /**
       * Creates a boot disk image for the specified instance or imports an exported image from the Oracle Cloud Infrastructure Object Storage service.
  * <p>
  When creating a new image, you must provide the OCID of the instance you want to use as the basis for the image, and
  * the OCID of the compartment containing that instance. For more information about images,
  * see [Managing Custom Images](https://docs.cloud.oracle.com/iaas/Content/Compute/Tasks/managingcustomimages.htm).
  * <p>
  When importing an exported image from Object Storage, you specify the source information
  * in {@link #imageSourceDetails(ImageSourceDetailsRequest) imageSourceDetails}.
  * <p>
  When importing an image based on the namespace, bucket name, and object name,
  * use {@link #imageSourceViaObjectStorageTupleDetails(ImageSourceViaObjectStorageTupleDetailsRequest) imageSourceViaObjectStorageTupleDetails}.
  * <p>
  When importing an image based on the Object Storage URL, use
  * {@link #imageSourceViaObjectStorageUriDetails(ImageSourceViaObjectStorageUriDetailsRequest) imageSourceViaObjectStorageUriDetails}.
  * See [Object Storage URLs](https://docs.cloud.oracle.com/iaas/Content/Compute/Tasks/imageimportexport.htm#URLs) and [Using Pre-Authenticated Requests](https://docs.cloud.oracle.com/iaas/Content/Object/Tasks/usingpreauthenticatedrequests.htm)
  * for constructing URLs for image import/export.
  * <p>
  For more information about importing exported images, see
  * [Image Import/Export](https://docs.cloud.oracle.com/iaas/Content/Compute/Tasks/imageimportexport.htm).
  * <p>
  You may optionally specify a *display name* for the image, which is simply a friendly name or description.
  * It does not have to be unique, and you can change it. See {@link #updateImage(UpdateImageRequest) updateImage}.
  * Avoid entering confidential information.
  *
       * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
       * @param CreateImageRequest
       * @return CreateImageResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/CreateImage.ts.html |here} to see how to use CreateImage API.
       */
    createImage(createImageRequest: requests.CreateImageRequest): Promise<responses.CreateImageResponse>;
    /**
       * Creates a new console connection to the specified instance.
  * After the console connection has been created and is available,
  * you connect to the console using SSH.
  * <p>
  For more information about instance console connections, see [Troubleshooting Instances Using Instance Console Connections](https://docs.cloud.oracle.com/iaas/Content/Compute/References/serialconsole.htm).
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param CreateInstanceConsoleConnectionRequest
       * @return CreateInstanceConsoleConnectionResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/CreateInstanceConsoleConnection.ts.html |here} to see how to use CreateInstanceConsoleConnection API.
       */
    createInstanceConsoleConnection(createInstanceConsoleConnectionRequest: requests.CreateInstanceConsoleConnectionRequest): Promise<responses.CreateInstanceConsoleConnectionResponse>;
    /**
     * Delete a subscription for a listing resource version for a compartment.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteAppCatalogSubscriptionRequest
     * @return DeleteAppCatalogSubscriptionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/DeleteAppCatalogSubscription.ts.html |here} to see how to use DeleteAppCatalogSubscription API.
     */
    deleteAppCatalogSubscription(deleteAppCatalogSubscriptionRequest: requests.DeleteAppCatalogSubscriptionRequest): Promise<responses.DeleteAppCatalogSubscriptionResponse>;
    /**
     * Deletes the specified compute capacity reservation.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteComputeCapacityReservationRequest
     * @return DeleteComputeCapacityReservationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/DeleteComputeCapacityReservation.ts.html |here} to see how to use DeleteComputeCapacityReservation API.
     */
    deleteComputeCapacityReservation(deleteComputeCapacityReservationRequest: requests.DeleteComputeCapacityReservationRequest): Promise<responses.DeleteComputeCapacityReservationResponse>;
    /**
     * Deletes the specified compute capacity topology.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteComputeCapacityTopologyRequest
     * @return DeleteComputeCapacityTopologyResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/DeleteComputeCapacityTopology.ts.html |here} to see how to use DeleteComputeCapacityTopology API.
     */
    deleteComputeCapacityTopology(deleteComputeCapacityTopologyRequest: requests.DeleteComputeCapacityTopologyRequest): Promise<responses.DeleteComputeCapacityTopologyResponse>;
    /**
       * Deletes a compute cluster. A [compute cluster](https://docs.cloud.oracle.com/iaas/Content/Compute/Tasks/compute-clusters.htm) is a
  * remote direct memory access (RDMA) network group.
  * <p>
  Before you delete a compute cluster, first delete all instances in the cluster by using
  * the {@link #terminateInstance(TerminateInstanceRequest) terminateInstance} operation.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param DeleteComputeClusterRequest
       * @return DeleteComputeClusterResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/DeleteComputeCluster.ts.html |here} to see how to use DeleteComputeCluster API.
       */
    deleteComputeCluster(deleteComputeClusterRequest: requests.DeleteComputeClusterRequest): Promise<responses.DeleteComputeClusterResponse>;
    /**
     * Deletes the specified Compute Image Capability Schema
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteComputeImageCapabilitySchemaRequest
     * @return DeleteComputeImageCapabilitySchemaResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/DeleteComputeImageCapabilitySchema.ts.html |here} to see how to use DeleteComputeImageCapabilitySchema API.
     */
    deleteComputeImageCapabilitySchema(deleteComputeImageCapabilitySchemaRequest: requests.DeleteComputeImageCapabilitySchemaRequest): Promise<responses.DeleteComputeImageCapabilitySchemaResponse>;
    /**
     * Deletes the specified console history metadata and the console history data.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteConsoleHistoryRequest
     * @return DeleteConsoleHistoryResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/DeleteConsoleHistory.ts.html |here} to see how to use DeleteConsoleHistory API.
     */
    deleteConsoleHistory(deleteConsoleHistoryRequest: requests.DeleteConsoleHistoryRequest): Promise<responses.DeleteConsoleHistoryResponse>;
    /**
       * Deletes the specified dedicated virtual machine host.
  * <p>
  If any VM instances are assigned to the dedicated virtual machine host,
  * the delete operation will fail and the service will return a 409 response code.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param DeleteDedicatedVmHostRequest
       * @return DeleteDedicatedVmHostResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/DeleteDedicatedVmHost.ts.html |here} to see how to use DeleteDedicatedVmHost API.
       */
    deleteDedicatedVmHost(deleteDedicatedVmHostRequest: requests.DeleteDedicatedVmHostRequest): Promise<responses.DeleteDedicatedVmHostResponse>;
    /**
     * Deletes an image.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteImageRequest
     * @return DeleteImageResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/DeleteImage.ts.html |here} to see how to use DeleteImage API.
     */
    deleteImage(deleteImageRequest: requests.DeleteImageRequest): Promise<responses.DeleteImageResponse>;
    /**
     * Deletes the specified instance console connection.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteInstanceConsoleConnectionRequest
     * @return DeleteInstanceConsoleConnectionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/DeleteInstanceConsoleConnection.ts.html |here} to see how to use DeleteInstanceConsoleConnection API.
     */
    deleteInstanceConsoleConnection(deleteInstanceConsoleConnectionRequest: requests.DeleteInstanceConsoleConnectionRequest): Promise<responses.DeleteInstanceConsoleConnectionResponse>;
    /**
       * Detaches a boot volume from an instance. You must specify the OCID of the boot volume attachment.
  * <p>
  This is an asynchronous operation. The attachment's `lifecycleState` will change to DETACHING temporarily
  * until the attachment is completely removed.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param DetachBootVolumeRequest
       * @return DetachBootVolumeResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/DetachBootVolume.ts.html |here} to see how to use DetachBootVolume API.
       */
    detachBootVolume(detachBootVolumeRequest: requests.DetachBootVolumeRequest): Promise<responses.DetachBootVolumeResponse>;
    /**
     * Detaches and deletes the specified secondary VNIC.
     * This operation cannot be used on the instance's primary VNIC.
     * When you terminate an instance, all attached VNICs (primary
     * and secondary) are automatically detached and deleted.
     * <p>
     **Important:** If the VNIC has a
     * {@link PrivateIp} that is the
     * [target of a route rule](https://docs.cloud.oracle.com/iaas/Content/Network/Tasks/managingroutetables.htm#privateip),
     * deleting the VNIC causes that route rule to blackhole and the traffic
     * will be dropped.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DetachVnicRequest
     * @return DetachVnicResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/DetachVnic.ts.html |here} to see how to use DetachVnic API.
     */
    detachVnic(detachVnicRequest: requests.DetachVnicRequest): Promise<responses.DetachVnicResponse>;
    /**
       * Detaches a storage volume from an instance. You must specify the OCID of the volume attachment.
  * <p>
  This is an asynchronous operation. The attachment's `lifecycleState` will change to DETACHING temporarily
  * until the attachment is completely removed.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param DetachVolumeRequest
       * @return DetachVolumeResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/DetachVolume.ts.html |here} to see how to use DetachVolume API.
       */
    detachVolume(detachVolumeRequest: requests.DetachVolumeRequest): Promise<responses.DetachVolumeResponse>;
    /**
       * Exports the specified image to the Oracle Cloud Infrastructure Object Storage service. You can use the Object Storage URL,
  * or the namespace, bucket name, and object name when specifying the location to export to.
  * <p>
  For more information about exporting images, see [Image Import/Export](https://docs.cloud.oracle.com/iaas/Content/Compute/Tasks/imageimportexport.htm).
  * <p>
  To perform an image export, you need write access to the Object Storage bucket for the image,
  * see [Let Users Write Objects to Object Storage Buckets](https://docs.cloud.oracle.com/iaas/Content/Identity/Concepts/commonpolicies.htm#Let4).
  * <p>
  See [Object Storage URLs](https://docs.cloud.oracle.com/iaas/Content/Compute/Tasks/imageimportexport.htm#URLs) and [Using Pre-Authenticated Requests](https://docs.cloud.oracle.com/iaas/Content/Object/Tasks/usingpreauthenticatedrequests.htm)
  * for constructing URLs for image import/export.
  *
       * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
       * @param ExportImageRequest
       * @return ExportImageResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ExportImage.ts.html |here} to see how to use ExportImage API.
       */
    exportImage(exportImageRequest: requests.ExportImageRequest): Promise<responses.ExportImageResponse>;
    /**
     * Gets the specified listing.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetAppCatalogListingRequest
     * @return GetAppCatalogListingResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetAppCatalogListing.ts.html |here} to see how to use GetAppCatalogListing API.
     */
    getAppCatalogListing(getAppCatalogListingRequest: requests.GetAppCatalogListingRequest): Promise<responses.GetAppCatalogListingResponse>;
    /**
     * Retrieves the agreements for a particular resource version of a listing.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetAppCatalogListingAgreementsRequest
     * @return GetAppCatalogListingAgreementsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetAppCatalogListingAgreements.ts.html |here} to see how to use GetAppCatalogListingAgreements API.
     */
    getAppCatalogListingAgreements(getAppCatalogListingAgreementsRequest: requests.GetAppCatalogListingAgreementsRequest): Promise<responses.GetAppCatalogListingAgreementsResponse>;
    /**
     * Gets the specified listing resource version.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetAppCatalogListingResourceVersionRequest
     * @return GetAppCatalogListingResourceVersionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetAppCatalogListingResourceVersion.ts.html |here} to see how to use GetAppCatalogListingResourceVersion API.
     */
    getAppCatalogListingResourceVersion(getAppCatalogListingResourceVersionRequest: requests.GetAppCatalogListingResourceVersionRequest): Promise<responses.GetAppCatalogListingResourceVersionResponse>;
    /**
     * Gets information about the specified boot volume attachment.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetBootVolumeAttachmentRequest
     * @return GetBootVolumeAttachmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetBootVolumeAttachment.ts.html |here} to see how to use GetBootVolumeAttachment API.
     */
    getBootVolumeAttachment(getBootVolumeAttachmentRequest: requests.GetBootVolumeAttachmentRequest): Promise<responses.GetBootVolumeAttachmentResponse>;
    /**
     * Gets information about the specified compute capacity reservation.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetComputeCapacityReservationRequest
     * @return GetComputeCapacityReservationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetComputeCapacityReservation.ts.html |here} to see how to use GetComputeCapacityReservation API.
     */
    getComputeCapacityReservation(getComputeCapacityReservationRequest: requests.GetComputeCapacityReservationRequest): Promise<responses.GetComputeCapacityReservationResponse>;
    /**
     * Gets information about the specified compute capacity topology.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetComputeCapacityTopologyRequest
     * @return GetComputeCapacityTopologyResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetComputeCapacityTopology.ts.html |here} to see how to use GetComputeCapacityTopology API.
     */
    getComputeCapacityTopology(getComputeCapacityTopologyRequest: requests.GetComputeCapacityTopologyRequest): Promise<responses.GetComputeCapacityTopologyResponse>;
    /**
     * Gets information about a compute cluster. A [compute cluster](https://docs.cloud.oracle.com/iaas/Content/Compute/Tasks/compute-clusters.htm)
     * is a remote direct memory access (RDMA) network group.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetComputeClusterRequest
     * @return GetComputeClusterResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetComputeCluster.ts.html |here} to see how to use GetComputeCluster API.
     */
    getComputeCluster(getComputeClusterRequest: requests.GetComputeClusterRequest): Promise<responses.GetComputeClusterResponse>;
    /**
     * Gets the specified Compute Global Image Capability Schema
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetComputeGlobalImageCapabilitySchemaRequest
     * @return GetComputeGlobalImageCapabilitySchemaResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetComputeGlobalImageCapabilitySchema.ts.html |here} to see how to use GetComputeGlobalImageCapabilitySchema API.
     */
    getComputeGlobalImageCapabilitySchema(getComputeGlobalImageCapabilitySchemaRequest: requests.GetComputeGlobalImageCapabilitySchemaRequest): Promise<responses.GetComputeGlobalImageCapabilitySchemaResponse>;
    /**
     * Gets the specified Compute Global Image Capability Schema Version
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetComputeGlobalImageCapabilitySchemaVersionRequest
     * @return GetComputeGlobalImageCapabilitySchemaVersionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetComputeGlobalImageCapabilitySchemaVersion.ts.html |here} to see how to use GetComputeGlobalImageCapabilitySchemaVersion API.
     */
    getComputeGlobalImageCapabilitySchemaVersion(getComputeGlobalImageCapabilitySchemaVersionRequest: requests.GetComputeGlobalImageCapabilitySchemaVersionRequest): Promise<responses.GetComputeGlobalImageCapabilitySchemaVersionResponse>;
    /**
     * Gets the specified Compute Image Capability Schema
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetComputeImageCapabilitySchemaRequest
     * @return GetComputeImageCapabilitySchemaResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetComputeImageCapabilitySchema.ts.html |here} to see how to use GetComputeImageCapabilitySchema API.
     */
    getComputeImageCapabilitySchema(getComputeImageCapabilitySchemaRequest: requests.GetComputeImageCapabilitySchemaRequest): Promise<responses.GetComputeImageCapabilitySchemaResponse>;
    /**
     * Shows the metadata for the specified console history.
     * See {@link #captureConsoleHistory(CaptureConsoleHistoryRequest) captureConsoleHistory}
     * for details about using the console history operations.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetConsoleHistoryRequest
     * @return GetConsoleHistoryResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetConsoleHistory.ts.html |here} to see how to use GetConsoleHistory API.
     */
    getConsoleHistory(getConsoleHistoryRequest: requests.GetConsoleHistoryRequest): Promise<responses.GetConsoleHistoryResponse>;
    /**
     * Gets the actual console history data (not the metadata).
     * See {@link #captureConsoleHistory(CaptureConsoleHistoryRequest) captureConsoleHistory}
     * for details about using the console history operations.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetConsoleHistoryContentRequest
     * @return GetConsoleHistoryContentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetConsoleHistoryContent.ts.html |here} to see how to use GetConsoleHistoryContent API.
     */
    getConsoleHistoryContent(getConsoleHistoryContentRequest: requests.GetConsoleHistoryContentRequest): Promise<responses.GetConsoleHistoryContentResponse>;
    /**
     * Gets information about the specified dedicated virtual machine host.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetDedicatedVmHostRequest
     * @return GetDedicatedVmHostResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetDedicatedVmHost.ts.html |here} to see how to use GetDedicatedVmHost API.
     */
    getDedicatedVmHost(getDedicatedVmHostRequest: requests.GetDedicatedVmHostRequest): Promise<responses.GetDedicatedVmHostResponse>;
    /**
     * Gets the specified image.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetImageRequest
     * @return GetImageResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetImage.ts.html |here} to see how to use GetImage API.
     */
    getImage(getImageRequest: requests.GetImageRequest): Promise<responses.GetImageResponse>;
    /**
     * Retrieves an image shape compatibility entry.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetImageShapeCompatibilityEntryRequest
     * @return GetImageShapeCompatibilityEntryResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetImageShapeCompatibilityEntry.ts.html |here} to see how to use GetImageShapeCompatibilityEntry API.
     */
    getImageShapeCompatibilityEntry(getImageShapeCompatibilityEntryRequest: requests.GetImageShapeCompatibilityEntryRequest): Promise<responses.GetImageShapeCompatibilityEntryResponse>;
    /**
     * Gets information about the specified instance.
     * <p>
     **Note:** To retrieve public and private IP addresses for an instance, use the {@link #listVnicAttachments(ListVnicAttachmentsRequest) listVnicAttachments}
     * operation to get the VNIC ID for the instance, and then call {@link #getVnic(GetVnicRequest) getVnic} with the VNIC ID.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetInstanceRequest
     * @return GetInstanceResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetInstance.ts.html |here} to see how to use GetInstance API.
     */
    getInstance(getInstanceRequest: requests.GetInstanceRequest): Promise<responses.GetInstanceResponse>;
    /**
     * Gets the specified instance console connection's information.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetInstanceConsoleConnectionRequest
     * @return GetInstanceConsoleConnectionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetInstanceConsoleConnection.ts.html |here} to see how to use GetInstanceConsoleConnection API.
     */
    getInstanceConsoleConnection(getInstanceConsoleConnectionRequest: requests.GetInstanceConsoleConnectionRequest): Promise<responses.GetInstanceConsoleConnectionResponse>;
    /**
     * Gets the maximum possible date that a maintenance reboot can be extended. For more information, see
     * [Infrastructure Maintenance](https://docs.cloud.oracle.com/iaas/Content/Compute/References/infrastructure-maintenance.htm).
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetInstanceMaintenanceRebootRequest
     * @return GetInstanceMaintenanceRebootResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetInstanceMaintenanceReboot.ts.html |here} to see how to use GetInstanceMaintenanceReboot API.
     */
    getInstanceMaintenanceReboot(getInstanceMaintenanceRebootRequest: requests.GetInstanceMaintenanceRebootRequest): Promise<responses.GetInstanceMaintenanceRebootResponse>;
    /**
     * Gets the measured boot report for this shielded instance.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetMeasuredBootReportRequest
     * @return GetMeasuredBootReportResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetMeasuredBootReport.ts.html |here} to see how to use GetMeasuredBootReport API.
     */
    getMeasuredBootReport(getMeasuredBootReportRequest: requests.GetMeasuredBootReportRequest): Promise<responses.GetMeasuredBootReportResponse>;
    /**
     * Gets the information for the specified VNIC attachment.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetVnicAttachmentRequest
     * @return GetVnicAttachmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetVnicAttachment.ts.html |here} to see how to use GetVnicAttachment API.
     */
    getVnicAttachment(getVnicAttachmentRequest: requests.GetVnicAttachmentRequest): Promise<responses.GetVnicAttachmentResponse>;
    /**
     * Gets information about the specified volume attachment.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetVolumeAttachmentRequest
     * @return GetVolumeAttachmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetVolumeAttachment.ts.html |here} to see how to use GetVolumeAttachment API.
     */
    getVolumeAttachment(getVolumeAttachmentRequest: requests.GetVolumeAttachmentRequest): Promise<responses.GetVolumeAttachmentResponse>;
    /**
     * Gets the generated credentials for the instance. Only works for instances that require a password to log in, such as Windows.
     * For certain operating systems, users will be forced to change the initial credentials.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetWindowsInstanceInitialCredentialsRequest
     * @return GetWindowsInstanceInitialCredentialsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetWindowsInstanceInitialCredentials.ts.html |here} to see how to use GetWindowsInstanceInitialCredentials API.
     */
    getWindowsInstanceInitialCredentials(getWindowsInstanceInitialCredentialsRequest: requests.GetWindowsInstanceInitialCredentialsRequest): Promise<responses.GetWindowsInstanceInitialCredentialsResponse>;
    /**
       * Performs one of the following power actions on the specified instance:
  * <p>
  - **START** - Powers on the instance.
  * <p>
  - **STOP** - Powers off the instance.
  * <p>
  - **RESET** - Powers off the instance and then powers it back on.
  * <p>
  - **SOFTSTOP** - Gracefully shuts down the instance by sending a shutdown command to the operating system.
  * After waiting 15 minutes for the OS to shut down, the instance is powered off.
  * If the applications that run on the instance take more than 15 minutes to shut down, they could be improperly stopped, resulting
  * in data corruption. To avoid this, manually shut down the instance using the commands available in the OS before you softstop the
  * instance.
  * <p>
  - **SOFTRESET** - Gracefully reboots the instance by sending a shutdown command to the operating system.
  * After waiting 15 minutes for the OS to shut down, the instance is powered off and
  * then powered back on.
  * <p>
  
  * - **SENDDIAGNOSTICINTERRUPT** - For advanced users. **Caution: Sending a diagnostic interrupt to a live system can
  * cause data corruption or system failure.** Sends a diagnostic interrupt that causes the instance's
  * OS to crash and then reboot. Before you send a diagnostic interrupt, you must configure the instance to generate a
  * crash dump file when it crashes. The crash dump captures information about the state of the OS at the time of
  * the crash. After the OS restarts, you can analyze the crash dump to diagnose the issue. For more information, see
  * [Sending a Diagnostic Interrupt](https://docs.cloud.oracle.com/iaas/Content/Compute/Tasks/sendingdiagnosticinterrupt.htm).
  * <p>
  
  * <p>
  - **DIAGNOSTICREBOOT** - Powers off the instance, rebuilds it, and then powers it back on.
  * Before you send a diagnostic reboot, restart the instance's OS, confirm that the instance and networking settings are configured
  * correctly, and try other [troubleshooting steps](https://docs.cloud.oracle.com/iaas/Content/Compute/References/troubleshooting-compute-instances.htm).
  * Use diagnostic reboot as a final attempt to troubleshoot an unreachable instance. For virtual machine (VM) instances only.
  * For more information, see [Performing a Diagnostic Reboot](https://docs.cloud.oracle.com/iaas/Content/Compute/Tasks/diagnostic-reboot.htm).
  * <p>
  
  * - **REBOOTMIGRATE** - Powers off the instance, moves it to new hardware, and then powers it back on. For more information, see
  * [Infrastructure Maintenance](https://docs.cloud.oracle.com/iaas/Content/Compute/References/infrastructure-maintenance.htm).
  * <p>
  
  * For more information about managing instance lifecycle states, see
  * [Stopping and Starting an Instance](https://docs.cloud.oracle.com/iaas/Content/Compute/Tasks/restartinginstance.htm).
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param InstanceActionRequest
       * @return InstanceActionResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/InstanceAction.ts.html |here} to see how to use InstanceAction API.
       */
    instanceAction(instanceActionRequest: requests.InstanceActionRequest): Promise<responses.InstanceActionResponse>;
    /**
       * Creates a new instance in the specified compartment and the specified availability domain.
  * For general information about instances, see
  * [Overview of the Compute Service](https://docs.cloud.oracle.com/iaas/Content/Compute/Concepts/computeoverview.htm).
  * <p>
  For information about access control and compartments, see
  * [Overview of the IAM Service](https://docs.cloud.oracle.com/iaas/Content/Identity/Concepts/overview.htm).
  * <p>
  For information about availability domains, see
  * [Regions and Availability Domains](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/regions.htm).
  * To get a list of availability domains, use the `ListAvailabilityDomains` operation
  * in the Identity and Access Management Service API.
  * <p>
  All Oracle Cloud Infrastructure resources, including instances, get an Oracle-assigned,
  * unique ID called an Oracle Cloud Identifier (OCID).
  * When you create a resource, you can find its OCID in the response. You can
  * also retrieve a resource's OCID by using a List API operation
  * on that resource type, or by viewing the resource in the Console.
  * <p>
  To launch an instance using an image or a boot volume use the `sourceDetails` parameter in {@link LaunchInstanceDetails}.
  * <p>
  When you launch an instance, it is automatically attached to a virtual
  * network interface card (VNIC), called the *primary VNIC*. The VNIC
  * has a private IP address from the subnet's CIDR. You can either assign a
  * private IP address of your choice or let Oracle automatically assign one.
  * You can choose whether the instance has a public IP address. To retrieve the
  * addresses, use the {@link #listVnicAttachments(ListVnicAttachmentsRequest) listVnicAttachments}
  * operation to get the VNIC ID for the instance, and then call
  * {@link #getVnic(GetVnicRequest) getVnic} with the VNIC ID.
  * <p>
  You can later add secondary VNICs to an instance. For more information, see
  * [Virtual Network Interface Cards (VNICs)](https://docs.cloud.oracle.com/iaas/Content/Network/Tasks/managingVNICs.htm).
  * <p>
  To launch an instance from a Marketplace image listing, you must provide the image ID of the
  * listing resource version that you want, but you also must subscribe to the listing before you try
  * to launch the instance. To subscribe to the listing, use the {@link #getAppCatalogListingAgreements(GetAppCatalogListingAgreementsRequest) getAppCatalogListingAgreements}
  * operation to get the signature for the terms of use agreement for the desired listing resource version.
  * Then, call {@link #createAppCatalogSubscription(CreateAppCatalogSubscriptionRequest) createAppCatalogSubscription}
  * with the signature. To get the image ID for the LaunchInstance operation, call
  * {@link #getAppCatalogListingResourceVersion(GetAppCatalogListingResourceVersionRequest) getAppCatalogListingResourceVersion}.
  * <p>
  To determine whether capacity is available for a specific shape before you create an instance,
  * use the {@link #createComputeCapacityReport(CreateComputeCapacityReportRequest) createComputeCapacityReport}
  * operation.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param LaunchInstanceRequest
       * @return LaunchInstanceResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/LaunchInstance.ts.html |here} to see how to use LaunchInstance API.
       */
    launchInstance(launchInstanceRequest: requests.LaunchInstanceRequest): Promise<responses.LaunchInstanceResponse>;
    /**
     * Gets all resource versions for a particular listing.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListAppCatalogListingResourceVersionsRequest
     * @return ListAppCatalogListingResourceVersionsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ListAppCatalogListingResourceVersions.ts.html |here} to see how to use ListAppCatalogListingResourceVersions API.
     */
    listAppCatalogListingResourceVersions(listAppCatalogListingResourceVersionsRequest: requests.ListAppCatalogListingResourceVersionsRequest): Promise<responses.ListAppCatalogListingResourceVersionsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listAppCatalogListingResourceVersionsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.AppCatalogListingResourceVersionSummary objects
     * contained in responses from the listAppCatalogListingResourceVersions operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllAppCatalogListingResourceVersions(request: requests.ListAppCatalogListingResourceVersionsRequest): AsyncIterableIterator<model.AppCatalogListingResourceVersionSummary>;
    /**
     * NOTE: This function is deprecated in favor of listAppCatalogListingResourceVersionsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listAppCatalogListingResourceVersions operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllAppCatalogListingResourceVersionsResponses(request: requests.ListAppCatalogListingResourceVersionsRequest): AsyncIterableIterator<responses.ListAppCatalogListingResourceVersionsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.AppCatalogListingResourceVersionSummary objects
     * contained in responses from the listAppCatalogListingResourceVersions operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAppCatalogListingResourceVersionsRecordIterator(request: requests.ListAppCatalogListingResourceVersionsRequest): AsyncIterableIterator<model.AppCatalogListingResourceVersionSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listAppCatalogListingResourceVersions operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAppCatalogListingResourceVersionsResponseIterator(request: requests.ListAppCatalogListingResourceVersionsRequest): AsyncIterableIterator<responses.ListAppCatalogListingResourceVersionsResponse>;
    /**
     * Lists the published listings.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListAppCatalogListingsRequest
     * @return ListAppCatalogListingsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ListAppCatalogListings.ts.html |here} to see how to use ListAppCatalogListings API.
     */
    listAppCatalogListings(listAppCatalogListingsRequest: requests.ListAppCatalogListingsRequest): Promise<responses.ListAppCatalogListingsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listAppCatalogListingsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.AppCatalogListingSummary objects
     * contained in responses from the listAppCatalogListings operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllAppCatalogListings(request: requests.ListAppCatalogListingsRequest): AsyncIterableIterator<model.AppCatalogListingSummary>;
    /**
     * NOTE: This function is deprecated in favor of listAppCatalogListingsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listAppCatalogListings operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllAppCatalogListingsResponses(request: requests.ListAppCatalogListingsRequest): AsyncIterableIterator<responses.ListAppCatalogListingsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.AppCatalogListingSummary objects
     * contained in responses from the listAppCatalogListings operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAppCatalogListingsRecordIterator(request: requests.ListAppCatalogListingsRequest): AsyncIterableIterator<model.AppCatalogListingSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listAppCatalogListings operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAppCatalogListingsResponseIterator(request: requests.ListAppCatalogListingsRequest): AsyncIterableIterator<responses.ListAppCatalogListingsResponse>;
    /**
     * Lists subscriptions for a compartment.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListAppCatalogSubscriptionsRequest
     * @return ListAppCatalogSubscriptionsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ListAppCatalogSubscriptions.ts.html |here} to see how to use ListAppCatalogSubscriptions API.
     */
    listAppCatalogSubscriptions(listAppCatalogSubscriptionsRequest: requests.ListAppCatalogSubscriptionsRequest): Promise<responses.ListAppCatalogSubscriptionsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listAppCatalogSubscriptionsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.AppCatalogSubscriptionSummary objects
     * contained in responses from the listAppCatalogSubscriptions operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllAppCatalogSubscriptions(request: requests.ListAppCatalogSubscriptionsRequest): AsyncIterableIterator<model.AppCatalogSubscriptionSummary>;
    /**
     * NOTE: This function is deprecated in favor of listAppCatalogSubscriptionsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listAppCatalogSubscriptions operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllAppCatalogSubscriptionsResponses(request: requests.ListAppCatalogSubscriptionsRequest): AsyncIterableIterator<responses.ListAppCatalogSubscriptionsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.AppCatalogSubscriptionSummary objects
     * contained in responses from the listAppCatalogSubscriptions operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAppCatalogSubscriptionsRecordIterator(request: requests.ListAppCatalogSubscriptionsRequest): AsyncIterableIterator<model.AppCatalogSubscriptionSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listAppCatalogSubscriptions operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAppCatalogSubscriptionsResponseIterator(request: requests.ListAppCatalogSubscriptionsRequest): AsyncIterableIterator<responses.ListAppCatalogSubscriptionsResponse>;
    /**
     * Lists the boot volume attachments in the specified compartment. You can filter the
     * list by specifying an instance OCID, boot volume OCID, or both.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListBootVolumeAttachmentsRequest
     * @return ListBootVolumeAttachmentsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ListBootVolumeAttachments.ts.html |here} to see how to use ListBootVolumeAttachments API.
     */
    listBootVolumeAttachments(listBootVolumeAttachmentsRequest: requests.ListBootVolumeAttachmentsRequest): Promise<responses.ListBootVolumeAttachmentsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listBootVolumeAttachmentsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.BootVolumeAttachment objects
     * contained in responses from the listBootVolumeAttachments operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllBootVolumeAttachments(request: requests.ListBootVolumeAttachmentsRequest): AsyncIterableIterator<model.BootVolumeAttachment>;
    /**
     * NOTE: This function is deprecated in favor of listBootVolumeAttachmentsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listBootVolumeAttachments operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllBootVolumeAttachmentsResponses(request: requests.ListBootVolumeAttachmentsRequest): AsyncIterableIterator<responses.ListBootVolumeAttachmentsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.BootVolumeAttachment objects
     * contained in responses from the listBootVolumeAttachments operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listBootVolumeAttachmentsRecordIterator(request: requests.ListBootVolumeAttachmentsRequest): AsyncIterableIterator<model.BootVolumeAttachment>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listBootVolumeAttachments operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listBootVolumeAttachmentsResponseIterator(request: requests.ListBootVolumeAttachmentsRequest): AsyncIterableIterator<responses.ListBootVolumeAttachmentsResponse>;
    /**
     * Lists the shapes that can be reserved within the specified compartment.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListComputeCapacityReservationInstanceShapesRequest
     * @return ListComputeCapacityReservationInstanceShapesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ListComputeCapacityReservationInstanceShapes.ts.html |here} to see how to use ListComputeCapacityReservationInstanceShapes API.
     */
    listComputeCapacityReservationInstanceShapes(listComputeCapacityReservationInstanceShapesRequest: requests.ListComputeCapacityReservationInstanceShapesRequest): Promise<responses.ListComputeCapacityReservationInstanceShapesResponse>;
    /**
     * NOTE: This function is deprecated in favor of listComputeCapacityReservationInstanceShapesRecordIterator function.
     * Creates a new async iterator which will iterate over the models.ComputeCapacityReservationInstanceShapeSummary objects
     * contained in responses from the listComputeCapacityReservationInstanceShapes operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllComputeCapacityReservationInstanceShapes(request: requests.ListComputeCapacityReservationInstanceShapesRequest): AsyncIterableIterator<model.ComputeCapacityReservationInstanceShapeSummary>;
    /**
     * NOTE: This function is deprecated in favor of listComputeCapacityReservationInstanceShapesResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listComputeCapacityReservationInstanceShapes operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllComputeCapacityReservationInstanceShapesResponses(request: requests.ListComputeCapacityReservationInstanceShapesRequest): AsyncIterableIterator<responses.ListComputeCapacityReservationInstanceShapesResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.ComputeCapacityReservationInstanceShapeSummary objects
     * contained in responses from the listComputeCapacityReservationInstanceShapes operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listComputeCapacityReservationInstanceShapesRecordIterator(request: requests.ListComputeCapacityReservationInstanceShapesRequest): AsyncIterableIterator<model.ComputeCapacityReservationInstanceShapeSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listComputeCapacityReservationInstanceShapes operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listComputeCapacityReservationInstanceShapesResponseIterator(request: requests.ListComputeCapacityReservationInstanceShapesRequest): AsyncIterableIterator<responses.ListComputeCapacityReservationInstanceShapesResponse>;
    /**
     * Lists the instances launched under a capacity reservation. You can filter results by specifying criteria.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListComputeCapacityReservationInstancesRequest
     * @return ListComputeCapacityReservationInstancesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ListComputeCapacityReservationInstances.ts.html |here} to see how to use ListComputeCapacityReservationInstances API.
     */
    listComputeCapacityReservationInstances(listComputeCapacityReservationInstancesRequest: requests.ListComputeCapacityReservationInstancesRequest): Promise<responses.ListComputeCapacityReservationInstancesResponse>;
    /**
     * NOTE: This function is deprecated in favor of listComputeCapacityReservationInstancesRecordIterator function.
     * Creates a new async iterator which will iterate over the models.CapacityReservationInstanceSummary objects
     * contained in responses from the listComputeCapacityReservationInstances operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllComputeCapacityReservationInstances(request: requests.ListComputeCapacityReservationInstancesRequest): AsyncIterableIterator<model.CapacityReservationInstanceSummary>;
    /**
     * NOTE: This function is deprecated in favor of listComputeCapacityReservationInstancesResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listComputeCapacityReservationInstances operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllComputeCapacityReservationInstancesResponses(request: requests.ListComputeCapacityReservationInstancesRequest): AsyncIterableIterator<responses.ListComputeCapacityReservationInstancesResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.CapacityReservationInstanceSummary objects
     * contained in responses from the listComputeCapacityReservationInstances operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listComputeCapacityReservationInstancesRecordIterator(request: requests.ListComputeCapacityReservationInstancesRequest): AsyncIterableIterator<model.CapacityReservationInstanceSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listComputeCapacityReservationInstances operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listComputeCapacityReservationInstancesResponseIterator(request: requests.ListComputeCapacityReservationInstancesRequest): AsyncIterableIterator<responses.ListComputeCapacityReservationInstancesResponse>;
    /**
       * Lists the compute capacity reservations that match the specified criteria and compartment.
  * <p>
  You can limit the list by specifying a compute capacity reservation display name
  * (the list will include all the identically-named compute capacity reservations in the compartment).
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param ListComputeCapacityReservationsRequest
       * @return ListComputeCapacityReservationsResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ListComputeCapacityReservations.ts.html |here} to see how to use ListComputeCapacityReservations API.
       */
    listComputeCapacityReservations(listComputeCapacityReservationsRequest: requests.ListComputeCapacityReservationsRequest): Promise<responses.ListComputeCapacityReservationsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listComputeCapacityReservationsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.ComputeCapacityReservationSummary objects
     * contained in responses from the listComputeCapacityReservations operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllComputeCapacityReservations(request: requests.ListComputeCapacityReservationsRequest): AsyncIterableIterator<model.ComputeCapacityReservationSummary>;
    /**
     * NOTE: This function is deprecated in favor of listComputeCapacityReservationsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listComputeCapacityReservations operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllComputeCapacityReservationsResponses(request: requests.ListComputeCapacityReservationsRequest): AsyncIterableIterator<responses.ListComputeCapacityReservationsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.ComputeCapacityReservationSummary objects
     * contained in responses from the listComputeCapacityReservations operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listComputeCapacityReservationsRecordIterator(request: requests.ListComputeCapacityReservationsRequest): AsyncIterableIterator<model.ComputeCapacityReservationSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listComputeCapacityReservations operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listComputeCapacityReservationsResponseIterator(request: requests.ListComputeCapacityReservationsRequest): AsyncIterableIterator<responses.ListComputeCapacityReservationsResponse>;
    /**
     * Lists the compute capacity topologies in the specified compartment. You can filter the list by a compute
     * capacity topology display name.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListComputeCapacityTopologiesRequest
     * @return ListComputeCapacityTopologiesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ListComputeCapacityTopologies.ts.html |here} to see how to use ListComputeCapacityTopologies API.
     */
    listComputeCapacityTopologies(listComputeCapacityTopologiesRequest: requests.ListComputeCapacityTopologiesRequest): Promise<responses.ListComputeCapacityTopologiesResponse>;
    /**
     * Lists compute bare metal hosts in the specified compute capacity topology.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListComputeCapacityTopologyComputeBareMetalHostsRequest
     * @return ListComputeCapacityTopologyComputeBareMetalHostsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ListComputeCapacityTopologyComputeBareMetalHosts.ts.html |here} to see how to use ListComputeCapacityTopologyComputeBareMetalHosts API.
     */
    listComputeCapacityTopologyComputeBareMetalHosts(listComputeCapacityTopologyComputeBareMetalHostsRequest: requests.ListComputeCapacityTopologyComputeBareMetalHostsRequest): Promise<responses.ListComputeCapacityTopologyComputeBareMetalHostsResponse>;
    /**
     * Lists compute HPC islands in the specified compute capacity topology.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListComputeCapacityTopologyComputeHpcIslandsRequest
     * @return ListComputeCapacityTopologyComputeHpcIslandsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ListComputeCapacityTopologyComputeHpcIslands.ts.html |here} to see how to use ListComputeCapacityTopologyComputeHpcIslands API.
     */
    listComputeCapacityTopologyComputeHpcIslands(listComputeCapacityTopologyComputeHpcIslandsRequest: requests.ListComputeCapacityTopologyComputeHpcIslandsRequest): Promise<responses.ListComputeCapacityTopologyComputeHpcIslandsResponse>;
    /**
     * Lists compute network blocks in the specified compute capacity topology.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListComputeCapacityTopologyComputeNetworkBlocksRequest
     * @return ListComputeCapacityTopologyComputeNetworkBlocksResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ListComputeCapacityTopologyComputeNetworkBlocks.ts.html |here} to see how to use ListComputeCapacityTopologyComputeNetworkBlocks API.
     */
    listComputeCapacityTopologyComputeNetworkBlocks(listComputeCapacityTopologyComputeNetworkBlocksRequest: requests.ListComputeCapacityTopologyComputeNetworkBlocksRequest): Promise<responses.ListComputeCapacityTopologyComputeNetworkBlocksResponse>;
    /**
     * Lists the compute clusters in the specified compartment.
     * A [compute cluster](https://docs.cloud.oracle.com/iaas/Content/Compute/Tasks/compute-clusters.htm) is a remote direct memory access (RDMA) network group.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListComputeClustersRequest
     * @return ListComputeClustersResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ListComputeClusters.ts.html |here} to see how to use ListComputeClusters API.
     */
    listComputeClusters(listComputeClustersRequest: requests.ListComputeClustersRequest): Promise<responses.ListComputeClustersResponse>;
    /**
     * Lists Compute Global Image Capability Schema versions in the specified compartment.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListComputeGlobalImageCapabilitySchemaVersionsRequest
     * @return ListComputeGlobalImageCapabilitySchemaVersionsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ListComputeGlobalImageCapabilitySchemaVersions.ts.html |here} to see how to use ListComputeGlobalImageCapabilitySchemaVersions API.
     */
    listComputeGlobalImageCapabilitySchemaVersions(listComputeGlobalImageCapabilitySchemaVersionsRequest: requests.ListComputeGlobalImageCapabilitySchemaVersionsRequest): Promise<responses.ListComputeGlobalImageCapabilitySchemaVersionsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listComputeGlobalImageCapabilitySchemaVersionsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.ComputeGlobalImageCapabilitySchemaVersionSummary objects
     * contained in responses from the listComputeGlobalImageCapabilitySchemaVersions operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllComputeGlobalImageCapabilitySchemaVersions(request: requests.ListComputeGlobalImageCapabilitySchemaVersionsRequest): AsyncIterableIterator<model.ComputeGlobalImageCapabilitySchemaVersionSummary>;
    /**
     * NOTE: This function is deprecated in favor of listComputeGlobalImageCapabilitySchemaVersionsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listComputeGlobalImageCapabilitySchemaVersions operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllComputeGlobalImageCapabilitySchemaVersionsResponses(request: requests.ListComputeGlobalImageCapabilitySchemaVersionsRequest): AsyncIterableIterator<responses.ListComputeGlobalImageCapabilitySchemaVersionsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.ComputeGlobalImageCapabilitySchemaVersionSummary objects
     * contained in responses from the listComputeGlobalImageCapabilitySchemaVersions operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listComputeGlobalImageCapabilitySchemaVersionsRecordIterator(request: requests.ListComputeGlobalImageCapabilitySchemaVersionsRequest): AsyncIterableIterator<model.ComputeGlobalImageCapabilitySchemaVersionSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listComputeGlobalImageCapabilitySchemaVersions operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listComputeGlobalImageCapabilitySchemaVersionsResponseIterator(request: requests.ListComputeGlobalImageCapabilitySchemaVersionsRequest): AsyncIterableIterator<responses.ListComputeGlobalImageCapabilitySchemaVersionsResponse>;
    /**
     * Lists Compute Global Image Capability Schema in the specified compartment.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListComputeGlobalImageCapabilitySchemasRequest
     * @return ListComputeGlobalImageCapabilitySchemasResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ListComputeGlobalImageCapabilitySchemas.ts.html |here} to see how to use ListComputeGlobalImageCapabilitySchemas API.
     */
    listComputeGlobalImageCapabilitySchemas(listComputeGlobalImageCapabilitySchemasRequest: requests.ListComputeGlobalImageCapabilitySchemasRequest): Promise<responses.ListComputeGlobalImageCapabilitySchemasResponse>;
    /**
     * NOTE: This function is deprecated in favor of listComputeGlobalImageCapabilitySchemasRecordIterator function.
     * Creates a new async iterator which will iterate over the models.ComputeGlobalImageCapabilitySchemaSummary objects
     * contained in responses from the listComputeGlobalImageCapabilitySchemas operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllComputeGlobalImageCapabilitySchemas(request: requests.ListComputeGlobalImageCapabilitySchemasRequest): AsyncIterableIterator<model.ComputeGlobalImageCapabilitySchemaSummary>;
    /**
     * NOTE: This function is deprecated in favor of listComputeGlobalImageCapabilitySchemasResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listComputeGlobalImageCapabilitySchemas operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllComputeGlobalImageCapabilitySchemasResponses(request: requests.ListComputeGlobalImageCapabilitySchemasRequest): AsyncIterableIterator<responses.ListComputeGlobalImageCapabilitySchemasResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.ComputeGlobalImageCapabilitySchemaSummary objects
     * contained in responses from the listComputeGlobalImageCapabilitySchemas operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listComputeGlobalImageCapabilitySchemasRecordIterator(request: requests.ListComputeGlobalImageCapabilitySchemasRequest): AsyncIterableIterator<model.ComputeGlobalImageCapabilitySchemaSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listComputeGlobalImageCapabilitySchemas operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listComputeGlobalImageCapabilitySchemasResponseIterator(request: requests.ListComputeGlobalImageCapabilitySchemasRequest): AsyncIterableIterator<responses.ListComputeGlobalImageCapabilitySchemasResponse>;
    /**
     * Lists Compute Image Capability Schema in the specified compartment. You can also query by a specific imageId.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListComputeImageCapabilitySchemasRequest
     * @return ListComputeImageCapabilitySchemasResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ListComputeImageCapabilitySchemas.ts.html |here} to see how to use ListComputeImageCapabilitySchemas API.
     */
    listComputeImageCapabilitySchemas(listComputeImageCapabilitySchemasRequest: requests.ListComputeImageCapabilitySchemasRequest): Promise<responses.ListComputeImageCapabilitySchemasResponse>;
    /**
     * NOTE: This function is deprecated in favor of listComputeImageCapabilitySchemasRecordIterator function.
     * Creates a new async iterator which will iterate over the models.ComputeImageCapabilitySchemaSummary objects
     * contained in responses from the listComputeImageCapabilitySchemas operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllComputeImageCapabilitySchemas(request: requests.ListComputeImageCapabilitySchemasRequest): AsyncIterableIterator<model.ComputeImageCapabilitySchemaSummary>;
    /**
     * NOTE: This function is deprecated in favor of listComputeImageCapabilitySchemasResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listComputeImageCapabilitySchemas operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllComputeImageCapabilitySchemasResponses(request: requests.ListComputeImageCapabilitySchemasRequest): AsyncIterableIterator<responses.ListComputeImageCapabilitySchemasResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.ComputeImageCapabilitySchemaSummary objects
     * contained in responses from the listComputeImageCapabilitySchemas operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listComputeImageCapabilitySchemasRecordIterator(request: requests.ListComputeImageCapabilitySchemasRequest): AsyncIterableIterator<model.ComputeImageCapabilitySchemaSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listComputeImageCapabilitySchemas operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listComputeImageCapabilitySchemasResponseIterator(request: requests.ListComputeImageCapabilitySchemasRequest): AsyncIterableIterator<responses.ListComputeImageCapabilitySchemasResponse>;
    /**
     * Lists the console history metadata for the specified compartment or instance.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListConsoleHistoriesRequest
     * @return ListConsoleHistoriesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ListConsoleHistories.ts.html |here} to see how to use ListConsoleHistories API.
     */
    listConsoleHistories(listConsoleHistoriesRequest: requests.ListConsoleHistoriesRequest): Promise<responses.ListConsoleHistoriesResponse>;
    /**
     * NOTE: This function is deprecated in favor of listConsoleHistoriesRecordIterator function.
     * Creates a new async iterator which will iterate over the models.ConsoleHistory objects
     * contained in responses from the listConsoleHistories operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllConsoleHistories(request: requests.ListConsoleHistoriesRequest): AsyncIterableIterator<model.ConsoleHistory>;
    /**
     * NOTE: This function is deprecated in favor of listConsoleHistoriesResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listConsoleHistories operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllConsoleHistoriesResponses(request: requests.ListConsoleHistoriesRequest): AsyncIterableIterator<responses.ListConsoleHistoriesResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.ConsoleHistory objects
     * contained in responses from the listConsoleHistories operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listConsoleHistoriesRecordIterator(request: requests.ListConsoleHistoriesRequest): AsyncIterableIterator<model.ConsoleHistory>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listConsoleHistories operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listConsoleHistoriesResponseIterator(request: requests.ListConsoleHistoriesRequest): AsyncIterableIterator<responses.ListConsoleHistoriesResponse>;
    /**
     * Lists the shapes that can be used to launch a virtual machine instance on a dedicated virtual machine host within the specified compartment.
     * You can filter the list by compatibility with a specific dedicated virtual machine host shape.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListDedicatedVmHostInstanceShapesRequest
     * @return ListDedicatedVmHostInstanceShapesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ListDedicatedVmHostInstanceShapes.ts.html |here} to see how to use ListDedicatedVmHostInstanceShapes API.
     */
    listDedicatedVmHostInstanceShapes(listDedicatedVmHostInstanceShapesRequest: requests.ListDedicatedVmHostInstanceShapesRequest): Promise<responses.ListDedicatedVmHostInstanceShapesResponse>;
    /**
     * NOTE: This function is deprecated in favor of listDedicatedVmHostInstanceShapesRecordIterator function.
     * Creates a new async iterator which will iterate over the models.DedicatedVmHostInstanceShapeSummary objects
     * contained in responses from the listDedicatedVmHostInstanceShapes operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllDedicatedVmHostInstanceShapes(request: requests.ListDedicatedVmHostInstanceShapesRequest): AsyncIterableIterator<model.DedicatedVmHostInstanceShapeSummary>;
    /**
     * NOTE: This function is deprecated in favor of listDedicatedVmHostInstanceShapesResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listDedicatedVmHostInstanceShapes operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllDedicatedVmHostInstanceShapesResponses(request: requests.ListDedicatedVmHostInstanceShapesRequest): AsyncIterableIterator<responses.ListDedicatedVmHostInstanceShapesResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.DedicatedVmHostInstanceShapeSummary objects
     * contained in responses from the listDedicatedVmHostInstanceShapes operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listDedicatedVmHostInstanceShapesRecordIterator(request: requests.ListDedicatedVmHostInstanceShapesRequest): AsyncIterableIterator<model.DedicatedVmHostInstanceShapeSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listDedicatedVmHostInstanceShapes operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listDedicatedVmHostInstanceShapesResponseIterator(request: requests.ListDedicatedVmHostInstanceShapesRequest): AsyncIterableIterator<responses.ListDedicatedVmHostInstanceShapesResponse>;
    /**
     * Returns the list of instances on the dedicated virtual machine hosts that match the specified criteria.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListDedicatedVmHostInstancesRequest
     * @return ListDedicatedVmHostInstancesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ListDedicatedVmHostInstances.ts.html |here} to see how to use ListDedicatedVmHostInstances API.
     */
    listDedicatedVmHostInstances(listDedicatedVmHostInstancesRequest: requests.ListDedicatedVmHostInstancesRequest): Promise<responses.ListDedicatedVmHostInstancesResponse>;
    /**
     * NOTE: This function is deprecated in favor of listDedicatedVmHostInstancesRecordIterator function.
     * Creates a new async iterator which will iterate over the models.DedicatedVmHostInstanceSummary objects
     * contained in responses from the listDedicatedVmHostInstances operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllDedicatedVmHostInstances(request: requests.ListDedicatedVmHostInstancesRequest): AsyncIterableIterator<model.DedicatedVmHostInstanceSummary>;
    /**
     * NOTE: This function is deprecated in favor of listDedicatedVmHostInstancesResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listDedicatedVmHostInstances operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllDedicatedVmHostInstancesResponses(request: requests.ListDedicatedVmHostInstancesRequest): AsyncIterableIterator<responses.ListDedicatedVmHostInstancesResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.DedicatedVmHostInstanceSummary objects
     * contained in responses from the listDedicatedVmHostInstances operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listDedicatedVmHostInstancesRecordIterator(request: requests.ListDedicatedVmHostInstancesRequest): AsyncIterableIterator<model.DedicatedVmHostInstanceSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listDedicatedVmHostInstances operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listDedicatedVmHostInstancesResponseIterator(request: requests.ListDedicatedVmHostInstancesRequest): AsyncIterableIterator<responses.ListDedicatedVmHostInstancesResponse>;
    /**
     * Lists the shapes that can be used to launch a dedicated virtual machine host within the specified compartment.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListDedicatedVmHostShapesRequest
     * @return ListDedicatedVmHostShapesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ListDedicatedVmHostShapes.ts.html |here} to see how to use ListDedicatedVmHostShapes API.
     */
    listDedicatedVmHostShapes(listDedicatedVmHostShapesRequest: requests.ListDedicatedVmHostShapesRequest): Promise<responses.ListDedicatedVmHostShapesResponse>;
    /**
     * NOTE: This function is deprecated in favor of listDedicatedVmHostShapesRecordIterator function.
     * Creates a new async iterator which will iterate over the models.DedicatedVmHostShapeSummary objects
     * contained in responses from the listDedicatedVmHostShapes operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllDedicatedVmHostShapes(request: requests.ListDedicatedVmHostShapesRequest): AsyncIterableIterator<model.DedicatedVmHostShapeSummary>;
    /**
     * NOTE: This function is deprecated in favor of listDedicatedVmHostShapesResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listDedicatedVmHostShapes operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllDedicatedVmHostShapesResponses(request: requests.ListDedicatedVmHostShapesRequest): AsyncIterableIterator<responses.ListDedicatedVmHostShapesResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.DedicatedVmHostShapeSummary objects
     * contained in responses from the listDedicatedVmHostShapes operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listDedicatedVmHostShapesRecordIterator(request: requests.ListDedicatedVmHostShapesRequest): AsyncIterableIterator<model.DedicatedVmHostShapeSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listDedicatedVmHostShapes operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listDedicatedVmHostShapesResponseIterator(request: requests.ListDedicatedVmHostShapesRequest): AsyncIterableIterator<responses.ListDedicatedVmHostShapesResponse>;
    /**
       * Returns the list of dedicated virtual machine hosts that match the specified criteria in the specified compartment.
  * <p>
  You can limit the list by specifying a dedicated virtual machine host display name. The list will include all the identically-named
  * dedicated virtual machine hosts in the compartment.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param ListDedicatedVmHostsRequest
       * @return ListDedicatedVmHostsResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ListDedicatedVmHosts.ts.html |here} to see how to use ListDedicatedVmHosts API.
       */
    listDedicatedVmHosts(listDedicatedVmHostsRequest: requests.ListDedicatedVmHostsRequest): Promise<responses.ListDedicatedVmHostsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listDedicatedVmHostsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.DedicatedVmHostSummary objects
     * contained in responses from the listDedicatedVmHosts operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllDedicatedVmHosts(request: requests.ListDedicatedVmHostsRequest): AsyncIterableIterator<model.DedicatedVmHostSummary>;
    /**
     * NOTE: This function is deprecated in favor of listDedicatedVmHostsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listDedicatedVmHosts operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllDedicatedVmHostsResponses(request: requests.ListDedicatedVmHostsRequest): AsyncIterableIterator<responses.ListDedicatedVmHostsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.DedicatedVmHostSummary objects
     * contained in responses from the listDedicatedVmHosts operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listDedicatedVmHostsRecordIterator(request: requests.ListDedicatedVmHostsRequest): AsyncIterableIterator<model.DedicatedVmHostSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listDedicatedVmHosts operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listDedicatedVmHostsResponseIterator(request: requests.ListDedicatedVmHostsRequest): AsyncIterableIterator<responses.ListDedicatedVmHostsResponse>;
    /**
     * Lists the compatible shapes for the specified image.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListImageShapeCompatibilityEntriesRequest
     * @return ListImageShapeCompatibilityEntriesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ListImageShapeCompatibilityEntries.ts.html |here} to see how to use ListImageShapeCompatibilityEntries API.
     */
    listImageShapeCompatibilityEntries(listImageShapeCompatibilityEntriesRequest: requests.ListImageShapeCompatibilityEntriesRequest): Promise<responses.ListImageShapeCompatibilityEntriesResponse>;
    /**
     * NOTE: This function is deprecated in favor of listImageShapeCompatibilityEntriesRecordIterator function.
     * Creates a new async iterator which will iterate over the models.ImageShapeCompatibilitySummary objects
     * contained in responses from the listImageShapeCompatibilityEntries operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllImageShapeCompatibilityEntries(request: requests.ListImageShapeCompatibilityEntriesRequest): AsyncIterableIterator<model.ImageShapeCompatibilitySummary>;
    /**
     * NOTE: This function is deprecated in favor of listImageShapeCompatibilityEntriesResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listImageShapeCompatibilityEntries operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllImageShapeCompatibilityEntriesResponses(request: requests.ListImageShapeCompatibilityEntriesRequest): AsyncIterableIterator<responses.ListImageShapeCompatibilityEntriesResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.ImageShapeCompatibilitySummary objects
     * contained in responses from the listImageShapeCompatibilityEntries operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listImageShapeCompatibilityEntriesRecordIterator(request: requests.ListImageShapeCompatibilityEntriesRequest): AsyncIterableIterator<model.ImageShapeCompatibilitySummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listImageShapeCompatibilityEntries operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listImageShapeCompatibilityEntriesResponseIterator(request: requests.ListImageShapeCompatibilityEntriesRequest): AsyncIterableIterator<responses.ListImageShapeCompatibilityEntriesResponse>;
    /**
       * Lists a subset of images available in the specified compartment, including
  * [platform images](https://docs.cloud.oracle.com/iaas/Content/Compute/References/images.htm) and
  * [custom images](https://docs.cloud.oracle.com/iaas/Content/Compute/Tasks/managingcustomimages.htm).
  * The list of platform images includes the three most recently published versions
  * of each major distribution. The list does not support filtering based on image tags.
  * <p>
  The list of images returned is ordered to first show the recent platform images,
  * then all of the custom images.
  * <p>
  **Caution:** Platform images are refreshed regularly. When new images are released, older versions are replaced.
  * The image OCIDs remain available, but when the platform image is replaced, the image OCIDs are no longer returned as part of the platform image list.
  *
       * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
       * @param ListImagesRequest
       * @return ListImagesResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ListImages.ts.html |here} to see how to use ListImages API.
       */
    listImages(listImagesRequest: requests.ListImagesRequest): Promise<responses.ListImagesResponse>;
    /**
     * NOTE: This function is deprecated in favor of listImagesRecordIterator function.
     * Creates a new async iterator which will iterate over the models.Image objects
     * contained in responses from the listImages operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllImages(request: requests.ListImagesRequest): AsyncIterableIterator<model.Image>;
    /**
     * NOTE: This function is deprecated in favor of listImagesResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listImages operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllImagesResponses(request: requests.ListImagesRequest): AsyncIterableIterator<responses.ListImagesResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.Image objects
     * contained in responses from the listImages operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listImagesRecordIterator(request: requests.ListImagesRequest): AsyncIterableIterator<model.Image>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listImages operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listImagesResponseIterator(request: requests.ListImagesRequest): AsyncIterableIterator<responses.ListImagesResponse>;
    /**
       * Lists the console connections for the specified compartment or instance.
  * <p>
  For more information about instance console connections, see [Troubleshooting Instances Using Instance Console Connections](https://docs.cloud.oracle.com/iaas/Content/Compute/References/serialconsole.htm).
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param ListInstanceConsoleConnectionsRequest
       * @return ListInstanceConsoleConnectionsResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ListInstanceConsoleConnections.ts.html |here} to see how to use ListInstanceConsoleConnections API.
       */
    listInstanceConsoleConnections(listInstanceConsoleConnectionsRequest: requests.ListInstanceConsoleConnectionsRequest): Promise<responses.ListInstanceConsoleConnectionsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listInstanceConsoleConnectionsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.InstanceConsoleConnection objects
     * contained in responses from the listInstanceConsoleConnections operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllInstanceConsoleConnections(request: requests.ListInstanceConsoleConnectionsRequest): AsyncIterableIterator<model.InstanceConsoleConnection>;
    /**
     * NOTE: This function is deprecated in favor of listInstanceConsoleConnectionsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listInstanceConsoleConnections operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllInstanceConsoleConnectionsResponses(request: requests.ListInstanceConsoleConnectionsRequest): AsyncIterableIterator<responses.ListInstanceConsoleConnectionsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.InstanceConsoleConnection objects
     * contained in responses from the listInstanceConsoleConnections operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listInstanceConsoleConnectionsRecordIterator(request: requests.ListInstanceConsoleConnectionsRequest): AsyncIterableIterator<model.InstanceConsoleConnection>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listInstanceConsoleConnections operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listInstanceConsoleConnectionsResponseIterator(request: requests.ListInstanceConsoleConnectionsRequest): AsyncIterableIterator<responses.ListInstanceConsoleConnectionsResponse>;
    /**
     * Gets a list of all the devices for given instance. You can optionally filter results by device availability.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListInstanceDevicesRequest
     * @return ListInstanceDevicesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ListInstanceDevices.ts.html |here} to see how to use ListInstanceDevices API.
     */
    listInstanceDevices(listInstanceDevicesRequest: requests.ListInstanceDevicesRequest): Promise<responses.ListInstanceDevicesResponse>;
    /**
     * NOTE: This function is deprecated in favor of listInstanceDevicesRecordIterator function.
     * Creates a new async iterator which will iterate over the models.Device objects
     * contained in responses from the listInstanceDevices operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllInstanceDevices(request: requests.ListInstanceDevicesRequest): AsyncIterableIterator<model.Device>;
    /**
     * NOTE: This function is deprecated in favor of listInstanceDevicesResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listInstanceDevices operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllInstanceDevicesResponses(request: requests.ListInstanceDevicesRequest): AsyncIterableIterator<responses.ListInstanceDevicesResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.Device objects
     * contained in responses from the listInstanceDevices operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listInstanceDevicesRecordIterator(request: requests.ListInstanceDevicesRequest): AsyncIterableIterator<model.Device>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listInstanceDevices operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listInstanceDevicesResponseIterator(request: requests.ListInstanceDevicesRequest): AsyncIterableIterator<responses.ListInstanceDevicesResponse>;
    /**
     * Lists the instances in the specified compartment and the specified availability domain.
     * You can filter the results by specifying an instance name (the list will include all the identically-named
     * instances in the compartment).
     * <p>
     **Note:** To retrieve public and private IP addresses for an instance, use the {@link #listVnicAttachments(ListVnicAttachmentsRequest) listVnicAttachments}
     * operation to get the VNIC ID for the instance, and then call {@link #getVnic(GetVnicRequest) getVnic} with the VNIC ID.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListInstancesRequest
     * @return ListInstancesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ListInstances.ts.html |here} to see how to use ListInstances API.
     */
    listInstances(listInstancesRequest: requests.ListInstancesRequest): Promise<responses.ListInstancesResponse>;
    /**
     * NOTE: This function is deprecated in favor of listInstancesRecordIterator function.
     * Creates a new async iterator which will iterate over the models.Instance objects
     * contained in responses from the listInstances operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllInstances(request: requests.ListInstancesRequest): AsyncIterableIterator<model.Instance>;
    /**
     * NOTE: This function is deprecated in favor of listInstancesResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listInstances operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllInstancesResponses(request: requests.ListInstancesRequest): AsyncIterableIterator<responses.ListInstancesResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.Instance objects
     * contained in responses from the listInstances operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listInstancesRecordIterator(request: requests.ListInstancesRequest): AsyncIterableIterator<model.Instance>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listInstances operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listInstancesResponseIterator(request: requests.ListInstancesRequest): AsyncIterableIterator<responses.ListInstancesResponse>;
    /**
     * Lists the shapes that can be used to launch an instance within the specified compartment. You can
     * filter the list by compatibility with a specific image.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListShapesRequest
     * @return ListShapesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ListShapes.ts.html |here} to see how to use ListShapes API.
     */
    listShapes(listShapesRequest: requests.ListShapesRequest): Promise<responses.ListShapesResponse>;
    /**
     * NOTE: This function is deprecated in favor of listShapesRecordIterator function.
     * Creates a new async iterator which will iterate over the models.Shape objects
     * contained in responses from the listShapes operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllShapes(request: requests.ListShapesRequest): AsyncIterableIterator<model.Shape>;
    /**
     * NOTE: This function is deprecated in favor of listShapesResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listShapes operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllShapesResponses(request: requests.ListShapesRequest): AsyncIterableIterator<responses.ListShapesResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.Shape objects
     * contained in responses from the listShapes operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listShapesRecordIterator(request: requests.ListShapesRequest): AsyncIterableIterator<model.Shape>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listShapes operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listShapesResponseIterator(request: requests.ListShapesRequest): AsyncIterableIterator<responses.ListShapesResponse>;
    /**
     * Lists the VNIC attachments in the specified compartment. A VNIC attachment
     * resides in the same compartment as the attached instance. The list can be
     * filtered by instance, VNIC, or availability domain.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListVnicAttachmentsRequest
     * @return ListVnicAttachmentsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ListVnicAttachments.ts.html |here} to see how to use ListVnicAttachments API.
     */
    listVnicAttachments(listVnicAttachmentsRequest: requests.ListVnicAttachmentsRequest): Promise<responses.ListVnicAttachmentsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listVnicAttachmentsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.VnicAttachment objects
     * contained in responses from the listVnicAttachments operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllVnicAttachments(request: requests.ListVnicAttachmentsRequest): AsyncIterableIterator<model.VnicAttachment>;
    /**
     * NOTE: This function is deprecated in favor of listVnicAttachmentsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listVnicAttachments operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllVnicAttachmentsResponses(request: requests.ListVnicAttachmentsRequest): AsyncIterableIterator<responses.ListVnicAttachmentsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.VnicAttachment objects
     * contained in responses from the listVnicAttachments operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listVnicAttachmentsRecordIterator(request: requests.ListVnicAttachmentsRequest): AsyncIterableIterator<model.VnicAttachment>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listVnicAttachments operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listVnicAttachmentsResponseIterator(request: requests.ListVnicAttachmentsRequest): AsyncIterableIterator<responses.ListVnicAttachmentsResponse>;
    /**
       * Lists the volume attachments in the specified compartment. You can filter the
  * list by specifying an instance OCID, volume OCID, or both.
  * <p>
  Currently, the only supported volume attachment type are {@link IScsiVolumeAttachment} and
  * {@link ParavirtualizedVolumeAttachment}.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param ListVolumeAttachmentsRequest
       * @return ListVolumeAttachmentsResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ListVolumeAttachments.ts.html |here} to see how to use ListVolumeAttachments API.
       */
    listVolumeAttachments(listVolumeAttachmentsRequest: requests.ListVolumeAttachmentsRequest): Promise<responses.ListVolumeAttachmentsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listVolumeAttachmentsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.VolumeAttachment objects
     * contained in responses from the listVolumeAttachments operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllVolumeAttachments(request: requests.ListVolumeAttachmentsRequest): AsyncIterableIterator<model.VolumeAttachment>;
    /**
     * NOTE: This function is deprecated in favor of listVolumeAttachmentsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listVolumeAttachments operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllVolumeAttachmentsResponses(request: requests.ListVolumeAttachmentsRequest): AsyncIterableIterator<responses.ListVolumeAttachmentsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.VolumeAttachment objects
     * contained in responses from the listVolumeAttachments operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listVolumeAttachmentsRecordIterator(request: requests.ListVolumeAttachmentsRequest): AsyncIterableIterator<model.VolumeAttachment>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listVolumeAttachments operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listVolumeAttachmentsResponseIterator(request: requests.ListVolumeAttachmentsRequest): AsyncIterableIterator<responses.ListVolumeAttachmentsResponse>;
    /**
     * Removes a shape from the compatible shapes list for the image.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param RemoveImageShapeCompatibilityEntryRequest
     * @return RemoveImageShapeCompatibilityEntryResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/RemoveImageShapeCompatibilityEntry.ts.html |here} to see how to use RemoveImageShapeCompatibilityEntry API.
     */
    removeImageShapeCompatibilityEntry(removeImageShapeCompatibilityEntryRequest: requests.RemoveImageShapeCompatibilityEntryRequest): Promise<responses.RemoveImageShapeCompatibilityEntryResponse>;
    /**
       * Permanently terminates (deletes) the specified instance. Any attached VNICs and volumes are automatically detached
  * when the instance terminates.
  * <p>
  To preserve the boot volume associated with the instance, specify `true` for `PreserveBootVolumeQueryParam`.
  * To delete the boot volume when the instance is deleted, specify `false` or do not specify a value for `PreserveBootVolumeQueryParam`.
  * <p>
  To preserve data volumes created with the instance, specify `true` or do not specify a value for `PreserveDataVolumesQueryParam`.
  * To delete the data volumes when the instance itself is deleted, specify `false` for `PreserveDataVolumesQueryParam`.
  * <p>
  This is an asynchronous operation. The instance's `lifecycleState` changes to TERMINATING temporarily
  * until the instance is completely deleted. After the instance is deleted, the record remains visible in the list of instances
  * with the state TERMINATED for at least 12 hours, but no further action is needed.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param TerminateInstanceRequest
       * @return TerminateInstanceResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/TerminateInstance.ts.html |here} to see how to use TerminateInstance API.
       */
    terminateInstance(terminateInstanceRequest: requests.TerminateInstanceRequest): Promise<responses.TerminateInstanceResponse>;
    /**
     * Updates the specified capacity reservation and its associated capacity configurations.
     * Fields that are not provided in the request will not be updated. Capacity configurations that are not included will be deleted.
     * Avoid entering confidential information.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateComputeCapacityReservationRequest
     * @return UpdateComputeCapacityReservationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/UpdateComputeCapacityReservation.ts.html |here} to see how to use UpdateComputeCapacityReservation API.
     */
    updateComputeCapacityReservation(updateComputeCapacityReservationRequest: requests.UpdateComputeCapacityReservationRequest): Promise<responses.UpdateComputeCapacityReservationResponse>;
    /**
     * Updates the specified compute capacity topology. Fields that are not provided in the request will not be updated.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateComputeCapacityTopologyRequest
     * @return UpdateComputeCapacityTopologyResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/UpdateComputeCapacityTopology.ts.html |here} to see how to use UpdateComputeCapacityTopology API.
     */
    updateComputeCapacityTopology(updateComputeCapacityTopologyRequest: requests.UpdateComputeCapacityTopologyRequest): Promise<responses.UpdateComputeCapacityTopologyResponse>;
    /**
       * Updates a compute cluster. A [compute cluster](https://docs.cloud.oracle.com/iaas/Content/Compute/Tasks/compute-clusters.htm) is a
  * remote direct memory access (RDMA) network group.
  * <p>
  To create instances within a compute cluster, use the {@link #launchInstance(LaunchInstanceRequest) launchInstance}
  * operation.
  * <p>
  To delete instances from a compute cluster, use the {@link #terminateInstance(TerminateInstanceRequest) terminateInstance}
  * operation.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param UpdateComputeClusterRequest
       * @return UpdateComputeClusterResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/UpdateComputeCluster.ts.html |here} to see how to use UpdateComputeCluster API.
       */
    updateComputeCluster(updateComputeClusterRequest: requests.UpdateComputeClusterRequest): Promise<responses.UpdateComputeClusterResponse>;
    /**
     * Updates the specified Compute Image Capability Schema
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateComputeImageCapabilitySchemaRequest
     * @return UpdateComputeImageCapabilitySchemaResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/UpdateComputeImageCapabilitySchema.ts.html |here} to see how to use UpdateComputeImageCapabilitySchema API.
     */
    updateComputeImageCapabilitySchema(updateComputeImageCapabilitySchemaRequest: requests.UpdateComputeImageCapabilitySchemaRequest): Promise<responses.UpdateComputeImageCapabilitySchemaResponse>;
    /**
     * Updates the specified console history metadata.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateConsoleHistoryRequest
     * @return UpdateConsoleHistoryResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/UpdateConsoleHistory.ts.html |here} to see how to use UpdateConsoleHistory API.
     */
    updateConsoleHistory(updateConsoleHistoryRequest: requests.UpdateConsoleHistoryRequest): Promise<responses.UpdateConsoleHistoryResponse>;
    /**
     * Updates the displayName, freeformTags, and definedTags attributes for the specified dedicated virtual machine host.
     * If an attribute value is not included, it will not be updated.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateDedicatedVmHostRequest
     * @return UpdateDedicatedVmHostResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/UpdateDedicatedVmHost.ts.html |here} to see how to use UpdateDedicatedVmHost API.
     */
    updateDedicatedVmHost(updateDedicatedVmHostRequest: requests.UpdateDedicatedVmHostRequest): Promise<responses.UpdateDedicatedVmHostResponse>;
    /**
     * Updates the display name of the image. Avoid entering confidential information.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateImageRequest
     * @return UpdateImageResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/UpdateImage.ts.html |here} to see how to use UpdateImage API.
     */
    updateImage(updateImageRequest: requests.UpdateImageRequest): Promise<responses.UpdateImageResponse>;
    /**
       * Updates certain fields on the specified instance. Fields that are not provided in the
  * request will not be updated. Avoid entering confidential information.
  * <p>
  Changes to metadata fields will be reflected in the instance metadata service (this may take
  * up to a minute).
  * <p>
  The OCID of the instance remains the same.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param UpdateInstanceRequest
       * @return UpdateInstanceResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/UpdateInstance.ts.html |here} to see how to use UpdateInstance API.
       */
    updateInstance(updateInstanceRequest: requests.UpdateInstanceRequest): Promise<responses.UpdateInstanceResponse>;
    /**
     * Updates the defined tags and free-form tags for the specified instance console connection.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateInstanceConsoleConnectionRequest
     * @return UpdateInstanceConsoleConnectionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/UpdateInstanceConsoleConnection.ts.html |here} to see how to use UpdateInstanceConsoleConnection API.
     */
    updateInstanceConsoleConnection(updateInstanceConsoleConnectionRequest: requests.UpdateInstanceConsoleConnectionRequest): Promise<responses.UpdateInstanceConsoleConnectionResponse>;
    /**
     * Updates information about the specified volume attachment.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateVolumeAttachmentRequest
     * @return UpdateVolumeAttachmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/UpdateVolumeAttachment.ts.html |here} to see how to use UpdateVolumeAttachment API.
     */
    updateVolumeAttachment(updateVolumeAttachmentRequest: requests.UpdateVolumeAttachmentRequest): Promise<responses.UpdateVolumeAttachmentResponse>;
}
export declare enum ComputeManagementApiKeys {
}
/**
 * This service client uses {@link common.CircuitBreaker.DefaultConfiguration} for all the operations by default if no circuit breaker configuration is defined by the user.
 */
export declare class ComputeManagementClient {
    protected static serviceEndpointTemplate: string;
    protected static endpointServiceName: string;
    protected "_realmSpecificEndpointTemplateEnabled": boolean | undefined;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_waiters": ComputeManagementWaiter;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: typeof Breaker | null;
    protected _httpOptions: any;
    protected _bodyDuplexMode: any;
    targetService: string;
    protected _regionId: string;
    protected "_region": common.Region;
    protected _lastSetRegionOrRegionId: string;
    protected _httpClient: common.HttpClient;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    get endpoint(): string;
    /**
     * Sets the endpoint to call (ex, https://www.example.com).
     * @param endpoint The endpoint of the service.
     */
    set endpoint(endpoint: string);
    get logger(): import("oci-common/lib/log").Logger;
    /**
     * Determines whether realm specific endpoint should be used or not.
     * Set realmSpecificEndpointTemplateEnabled to "true" if the user wants to enable use of realm specific endpoint template, otherwise set it to "false"
     * @param realmSpecificEndpointTemplateEnabled flag to enable the use of realm specific endpoint template
     */
    set useRealmSpecificEndpointTemplate(realmSpecificEndpointTemplateEnabled: boolean);
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    set region(region: common.Region);
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    set regionId(regionId: string);
    /**
     * Creates a new ComputeManagementWaiter for resources for this service.
     *
     * @param workRequestClient The work request service client used to query for work request status
     * @param config The waiter configuration for termination and delay strategy
     * @return The service waiters.
     */
    createWaiters(workRequestClient: WorkRequestClient, config?: common.WaiterConfiguration): ComputeManagementWaiter;
    /**
     * Gets the waiters available for resources for this service.
     *
     * @return The service waiters.
     */
    getWaiters(): ComputeManagementWaiter;
    /**
     * Shutdown the circuit breaker used by the client when it is no longer needed
     */
    shutdownCircuitBreaker(): void;
    /**
     * Close the client once it is no longer needed
     */
    close(): void;
    /**
     * Attaches an instance to an instance pool. For information about the prerequisites
     * that an instance must meet before you can attach it to a pool, see
     * [Attaching an Instance to an Instance Pool](https://docs.cloud.oracle.com/iaas/Content/Compute/Tasks/updatinginstancepool.htm#attach-instance).
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param AttachInstancePoolInstanceRequest
     * @return AttachInstancePoolInstanceResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/AttachInstancePoolInstance.ts.html |here} to see how to use AttachInstancePoolInstance API.
     */
    attachInstancePoolInstance(attachInstancePoolInstanceRequest: requests.AttachInstancePoolInstanceRequest): Promise<responses.AttachInstancePoolInstanceResponse>;
    /**
     * Attach a load balancer to the instance pool.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param AttachLoadBalancerRequest
     * @return AttachLoadBalancerResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/AttachLoadBalancer.ts.html |here} to see how to use AttachLoadBalancer API.
     */
    attachLoadBalancer(attachLoadBalancerRequest: requests.AttachLoadBalancerRequest): Promise<responses.AttachLoadBalancerResponse>;
    /**
       * Moves a [cluster network with instance pools](https://docs.cloud.oracle.com/iaas/Content/Compute/Tasks/managingclusternetworks.htm)
  * into a different compartment within the same tenancy. For
  * information about moving resources between compartments, see
  * [Moving Resources to a Different Compartment](https://docs.cloud.oracle.com/iaas/Content/Identity/Tasks/managingcompartments.htm#moveRes).
  * <p>
  When you move a cluster network to a different compartment, associated resources such as the instances
  * in the cluster network, boot volumes, and VNICs are not moved.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param ChangeClusterNetworkCompartmentRequest
       * @return ChangeClusterNetworkCompartmentResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ChangeClusterNetworkCompartment.ts.html |here} to see how to use ChangeClusterNetworkCompartment API.
       */
    changeClusterNetworkCompartment(changeClusterNetworkCompartmentRequest: requests.ChangeClusterNetworkCompartmentRequest): Promise<responses.ChangeClusterNetworkCompartmentResponse>;
    /**
       * Moves an instance configuration into a different compartment within the same tenancy.
  * For information about moving resources between compartments, see
  * [Moving Resources to a Different Compartment](https://docs.cloud.oracle.com/iaas/Content/Identity/Tasks/managingcompartments.htm#moveRes).
  * <p>
  When you move an instance configuration to a different compartment, associated resources such as
  * instance pools are not moved.
  * <p>
  **Important:** Most of the properties for an existing instance configuration, including the compartment,
  * cannot be modified after you create the instance configuration. Although you can move an instance configuration
  * to a different compartment, you will not be able to use the instance configuration to manage instance pools
  * in the new compartment. If you want to update an instance configuration to point to a different compartment,
  * you should instead create a new instance configuration in the target compartment using
  * [CreateInstanceConfiguration](https://docs.cloud.oracle.com/iaas/api/#/en/iaas/20160918/InstanceConfiguration/CreateInstanceConfiguration).
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param ChangeInstanceConfigurationCompartmentRequest
       * @return ChangeInstanceConfigurationCompartmentResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ChangeInstanceConfigurationCompartment.ts.html |here} to see how to use ChangeInstanceConfigurationCompartment API.
       */
    changeInstanceConfigurationCompartment(changeInstanceConfigurationCompartmentRequest: requests.ChangeInstanceConfigurationCompartmentRequest): Promise<responses.ChangeInstanceConfigurationCompartmentResponse>;
    /**
       * Moves an instance pool into a different compartment within the same tenancy. For
  * information about moving resources between compartments, see
  * [Moving Resources to a Different Compartment](https://docs.cloud.oracle.com/iaas/Content/Identity/Tasks/managingcompartments.htm#moveRes).
  * <p>
  When you move an instance pool to a different compartment, associated resources such as the instances in
  * the pool, boot volumes, VNICs, and autoscaling configurations are not moved.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param ChangeInstancePoolCompartmentRequest
       * @return ChangeInstancePoolCompartmentResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ChangeInstancePoolCompartment.ts.html |here} to see how to use ChangeInstancePoolCompartment API.
       */
    changeInstancePoolCompartment(changeInstancePoolCompartmentRequest: requests.ChangeInstancePoolCompartmentRequest): Promise<responses.ChangeInstancePoolCompartmentResponse>;
    /**
       * Creates a [cluster network with instance pools](https://docs.cloud.oracle.com/iaas/Content/Compute/Tasks/managingclusternetworks.htm).
  * A cluster network is a group of high performance computing (HPC), GPU, or optimized bare metal
  * instances that are connected with an ultra low-latency remote direct memory access (RDMA) network.
  * Cluster networks with instance pools use instance pools to manage groups of identical instances.
  * <p>
  Use cluster networks with instance pools when you want predictable capacity for a specific number of identical
  * instances that are managed as a group.
  * <p>
  If you want to manage instances in the RDMA network independently of each other or use different types of instances
  * in the network group, create a compute cluster by using the {@link #createComputeCluster(CreateComputeClusterRequest) createComputeCluster}
  * operation.
  * <p>
  To determine whether capacity is available for a specific shape before you create a cluster network,
  * use the {@link #createComputeCapacityReport(CreateComputeCapacityReportRequest) createComputeCapacityReport}
  * operation.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param CreateClusterNetworkRequest
       * @return CreateClusterNetworkResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/CreateClusterNetwork.ts.html |here} to see how to use CreateClusterNetwork API.
       */
    createClusterNetwork(createClusterNetworkRequest: requests.CreateClusterNetworkRequest): Promise<responses.CreateClusterNetworkResponse>;
    /**
     * Creates an instance configuration. An instance configuration is a template that defines the
     * settings to use when creating Compute instances.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateInstanceConfigurationRequest
     * @return CreateInstanceConfigurationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/CreateInstanceConfiguration.ts.html |here} to see how to use CreateInstanceConfiguration API.
     */
    createInstanceConfiguration(createInstanceConfigurationRequest: requests.CreateInstanceConfigurationRequest): Promise<responses.CreateInstanceConfigurationResponse>;
    /**
       * Creates an instance pool.
  * <p>
  To determine whether capacity is available for a specific shape before you create an instance pool,
  * use the {@link #createComputeCapacityReport(CreateComputeCapacityReportRequest) createComputeCapacityReport}
  * operation.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param CreateInstancePoolRequest
       * @return CreateInstancePoolResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/CreateInstancePool.ts.html |here} to see how to use CreateInstancePool API.
       */
    createInstancePool(createInstancePoolRequest: requests.CreateInstancePoolRequest): Promise<responses.CreateInstancePoolResponse>;
    /**
     * Deletes an instance configuration.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteInstanceConfigurationRequest
     * @return DeleteInstanceConfigurationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/DeleteInstanceConfiguration.ts.html |here} to see how to use DeleteInstanceConfiguration API.
     */
    deleteInstanceConfiguration(deleteInstanceConfigurationRequest: requests.DeleteInstanceConfigurationRequest): Promise<responses.DeleteInstanceConfigurationResponse>;
    /**
     * Detaches an instance from an instance pool.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DetachInstancePoolInstanceRequest
     * @return DetachInstancePoolInstanceResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/DetachInstancePoolInstance.ts.html |here} to see how to use DetachInstancePoolInstance API.
     */
    detachInstancePoolInstance(detachInstancePoolInstanceRequest: requests.DetachInstancePoolInstanceRequest): Promise<responses.DetachInstancePoolInstanceResponse>;
    /**
     * Detach a load balancer from the instance pool.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DetachLoadBalancerRequest
     * @return DetachLoadBalancerResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/DetachLoadBalancer.ts.html |here} to see how to use DetachLoadBalancer API.
     */
    detachLoadBalancer(detachLoadBalancerRequest: requests.DetachLoadBalancerRequest): Promise<responses.DetachLoadBalancerResponse>;
    /**
     * Gets information about a [cluster network with instance pools](https://docs.cloud.oracle.com/iaas/Content/Compute/Tasks/managingclusternetworks.htm).
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetClusterNetworkRequest
     * @return GetClusterNetworkResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetClusterNetwork.ts.html |here} to see how to use GetClusterNetwork API.
     */
    getClusterNetwork(getClusterNetworkRequest: requests.GetClusterNetworkRequest): Promise<responses.GetClusterNetworkResponse>;
    /**
     * Gets the specified instance configuration
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetInstanceConfigurationRequest
     * @return GetInstanceConfigurationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetInstanceConfiguration.ts.html |here} to see how to use GetInstanceConfiguration API.
     */
    getInstanceConfiguration(getInstanceConfigurationRequest: requests.GetInstanceConfigurationRequest): Promise<responses.GetInstanceConfigurationResponse>;
    /**
     * Gets the specified instance pool
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetInstancePoolRequest
     * @return GetInstancePoolResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetInstancePool.ts.html |here} to see how to use GetInstancePool API.
     */
    getInstancePool(getInstancePoolRequest: requests.GetInstancePoolRequest): Promise<responses.GetInstancePoolResponse>;
    /**
     * Gets information about an instance that belongs to an instance pool.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetInstancePoolInstanceRequest
     * @return GetInstancePoolInstanceResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetInstancePoolInstance.ts.html |here} to see how to use GetInstancePoolInstance API.
     */
    getInstancePoolInstance(getInstancePoolInstanceRequest: requests.GetInstancePoolInstanceRequest): Promise<responses.GetInstancePoolInstanceResponse>;
    /**
     * Gets information about a load balancer that is attached to the specified instance pool.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetInstancePoolLoadBalancerAttachmentRequest
     * @return GetInstancePoolLoadBalancerAttachmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetInstancePoolLoadBalancerAttachment.ts.html |here} to see how to use GetInstancePoolLoadBalancerAttachment API.
     */
    getInstancePoolLoadBalancerAttachment(getInstancePoolLoadBalancerAttachmentRequest: requests.GetInstancePoolLoadBalancerAttachmentRequest): Promise<responses.GetInstancePoolLoadBalancerAttachmentResponse>;
    /**
       * Creates an instance from an instance configuration.
  * <p>
  If the instance configuration does not include all of the parameters that are
  * required to create an instance, such as the availability domain and subnet ID, you must
  * provide these parameters when you create an instance from the instance configuration.
  * For more information, see the {@link InstanceConfiguration}
  * resource.
  * <p>
  To determine whether capacity is available for a specific shape before you create an instance,
  * use the {@link #createComputeCapacityReport(CreateComputeCapacityReportRequest) createComputeCapacityReport}
  * operation.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param LaunchInstanceConfigurationRequest
       * @return LaunchInstanceConfigurationResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/LaunchInstanceConfiguration.ts.html |here} to see how to use LaunchInstanceConfiguration API.
       */
    launchInstanceConfiguration(launchInstanceConfigurationRequest: requests.LaunchInstanceConfigurationRequest): Promise<responses.LaunchInstanceConfigurationResponse>;
    /**
     * Lists the instances in a [cluster network with instance pools](https://docs.cloud.oracle.com/iaas/Content/Compute/Tasks/managingclusternetworks.htm).
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListClusterNetworkInstancesRequest
     * @return ListClusterNetworkInstancesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ListClusterNetworkInstances.ts.html |here} to see how to use ListClusterNetworkInstances API.
     */
    listClusterNetworkInstances(listClusterNetworkInstancesRequest: requests.ListClusterNetworkInstancesRequest): Promise<responses.ListClusterNetworkInstancesResponse>;
    /**
     * NOTE: This function is deprecated in favor of listClusterNetworkInstancesRecordIterator function.
     * Creates a new async iterator which will iterate over the models.InstanceSummary objects
     * contained in responses from the listClusterNetworkInstances operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllClusterNetworkInstances(request: requests.ListClusterNetworkInstancesRequest): AsyncIterableIterator<model.InstanceSummary>;
    /**
     * NOTE: This function is deprecated in favor of listClusterNetworkInstancesResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listClusterNetworkInstances operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllClusterNetworkInstancesResponses(request: requests.ListClusterNetworkInstancesRequest): AsyncIterableIterator<responses.ListClusterNetworkInstancesResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.InstanceSummary objects
     * contained in responses from the listClusterNetworkInstances operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listClusterNetworkInstancesRecordIterator(request: requests.ListClusterNetworkInstancesRequest): AsyncIterableIterator<model.InstanceSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listClusterNetworkInstances operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listClusterNetworkInstancesResponseIterator(request: requests.ListClusterNetworkInstancesRequest): AsyncIterableIterator<responses.ListClusterNetworkInstancesResponse>;
    /**
     * Lists the [cluster networks with instance pools](https://docs.cloud.oracle.com/iaas/Content/Compute/Tasks/managingclusternetworks.htm)
     * in the specified compartment.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListClusterNetworksRequest
     * @return ListClusterNetworksResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ListClusterNetworks.ts.html |here} to see how to use ListClusterNetworks API.
     */
    listClusterNetworks(listClusterNetworksRequest: requests.ListClusterNetworksRequest): Promise<responses.ListClusterNetworksResponse>;
    /**
     * NOTE: This function is deprecated in favor of listClusterNetworksRecordIterator function.
     * Creates a new async iterator which will iterate over the models.ClusterNetworkSummary objects
     * contained in responses from the listClusterNetworks operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllClusterNetworks(request: requests.ListClusterNetworksRequest): AsyncIterableIterator<model.ClusterNetworkSummary>;
    /**
     * NOTE: This function is deprecated in favor of listClusterNetworksResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listClusterNetworks operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllClusterNetworksResponses(request: requests.ListClusterNetworksRequest): AsyncIterableIterator<responses.ListClusterNetworksResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.ClusterNetworkSummary objects
     * contained in responses from the listClusterNetworks operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listClusterNetworksRecordIterator(request: requests.ListClusterNetworksRequest): AsyncIterableIterator<model.ClusterNetworkSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listClusterNetworks operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listClusterNetworksResponseIterator(request: requests.ListClusterNetworksRequest): AsyncIterableIterator<responses.ListClusterNetworksResponse>;
    /**
     * Lists the instance configurations in the specified compartment.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListInstanceConfigurationsRequest
     * @return ListInstanceConfigurationsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ListInstanceConfigurations.ts.html |here} to see how to use ListInstanceConfigurations API.
     */
    listInstanceConfigurations(listInstanceConfigurationsRequest: requests.ListInstanceConfigurationsRequest): Promise<responses.ListInstanceConfigurationsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listInstanceConfigurationsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.InstanceConfigurationSummary objects
     * contained in responses from the listInstanceConfigurations operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllInstanceConfigurations(request: requests.ListInstanceConfigurationsRequest): AsyncIterableIterator<model.InstanceConfigurationSummary>;
    /**
     * NOTE: This function is deprecated in favor of listInstanceConfigurationsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listInstanceConfigurations operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllInstanceConfigurationsResponses(request: requests.ListInstanceConfigurationsRequest): AsyncIterableIterator<responses.ListInstanceConfigurationsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.InstanceConfigurationSummary objects
     * contained in responses from the listInstanceConfigurations operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listInstanceConfigurationsRecordIterator(request: requests.ListInstanceConfigurationsRequest): AsyncIterableIterator<model.InstanceConfigurationSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listInstanceConfigurations operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listInstanceConfigurationsResponseIterator(request: requests.ListInstanceConfigurationsRequest): AsyncIterableIterator<responses.ListInstanceConfigurationsResponse>;
    /**
     * List the instances in the specified instance pool.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListInstancePoolInstancesRequest
     * @return ListInstancePoolInstancesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ListInstancePoolInstances.ts.html |here} to see how to use ListInstancePoolInstances API.
     */
    listInstancePoolInstances(listInstancePoolInstancesRequest: requests.ListInstancePoolInstancesRequest): Promise<responses.ListInstancePoolInstancesResponse>;
    /**
     * NOTE: This function is deprecated in favor of listInstancePoolInstancesRecordIterator function.
     * Creates a new async iterator which will iterate over the models.InstanceSummary objects
     * contained in responses from the listInstancePoolInstances operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllInstancePoolInstances(request: requests.ListInstancePoolInstancesRequest): AsyncIterableIterator<model.InstanceSummary>;
    /**
     * NOTE: This function is deprecated in favor of listInstancePoolInstancesResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listInstancePoolInstances operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllInstancePoolInstancesResponses(request: requests.ListInstancePoolInstancesRequest): AsyncIterableIterator<responses.ListInstancePoolInstancesResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.InstanceSummary objects
     * contained in responses from the listInstancePoolInstances operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listInstancePoolInstancesRecordIterator(request: requests.ListInstancePoolInstancesRequest): AsyncIterableIterator<model.InstanceSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listInstancePoolInstances operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listInstancePoolInstancesResponseIterator(request: requests.ListInstancePoolInstancesRequest): AsyncIterableIterator<responses.ListInstancePoolInstancesResponse>;
    /**
     * Lists the instance pools in the specified compartment.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListInstancePoolsRequest
     * @return ListInstancePoolsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ListInstancePools.ts.html |here} to see how to use ListInstancePools API.
     */
    listInstancePools(listInstancePoolsRequest: requests.ListInstancePoolsRequest): Promise<responses.ListInstancePoolsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listInstancePoolsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.InstancePoolSummary objects
     * contained in responses from the listInstancePools operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllInstancePools(request: requests.ListInstancePoolsRequest): AsyncIterableIterator<model.InstancePoolSummary>;
    /**
     * NOTE: This function is deprecated in favor of listInstancePoolsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listInstancePools operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllInstancePoolsResponses(request: requests.ListInstancePoolsRequest): AsyncIterableIterator<responses.ListInstancePoolsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.InstancePoolSummary objects
     * contained in responses from the listInstancePools operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listInstancePoolsRecordIterator(request: requests.ListInstancePoolsRequest): AsyncIterableIterator<model.InstancePoolSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listInstancePools operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listInstancePoolsResponseIterator(request: requests.ListInstancePoolsRequest): AsyncIterableIterator<responses.ListInstancePoolsResponse>;
    /**
     * Performs the reset (immediate power off and power on) action on the specified instance pool,
     * which performs the action on all the instances in the pool.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ResetInstancePoolRequest
     * @return ResetInstancePoolResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ResetInstancePool.ts.html |here} to see how to use ResetInstancePool API.
     */
    resetInstancePool(resetInstancePoolRequest: requests.ResetInstancePoolRequest): Promise<responses.ResetInstancePoolResponse>;
    /**
       * Performs the softreset (ACPI shutdown and power on) action on the specified instance pool,
  * which performs the action on all the instances in the pool.
  * <p>
  Softreset gracefully reboots the instances by sending a shutdown command to the operating systems.
  * After waiting 15 minutes for the OS to shut down, the instances are powered off and then powered back on.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param SoftresetInstancePoolRequest
       * @return SoftresetInstancePoolResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/SoftresetInstancePool.ts.html |here} to see how to use SoftresetInstancePool API.
       */
    softresetInstancePool(softresetInstancePoolRequest: requests.SoftresetInstancePoolRequest): Promise<responses.SoftresetInstancePoolResponse>;
    /**
       * Performs the softstop (ACPI shutdown and power on) action on the specified instance pool,
  * which performs the action on all the instances in the pool.
  * <p>
  Softstop gracefully reboots the instances by sending a shutdown command to the operating systems.
  * After waiting 15 minutes for the OS to shutdown, the instances are powered off and then powered back on.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param SoftstopInstancePoolRequest
       * @return SoftstopInstancePoolResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/SoftstopInstancePool.ts.html |here} to see how to use SoftstopInstancePool API.
       */
    softstopInstancePool(softstopInstancePoolRequest: requests.SoftstopInstancePoolRequest): Promise<responses.SoftstopInstancePoolResponse>;
    /**
     * Performs the start (power on) action on the specified instance pool,
     * which performs the action on all the instances in the pool.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param StartInstancePoolRequest
     * @return StartInstancePoolResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/StartInstancePool.ts.html |here} to see how to use StartInstancePool API.
     */
    startInstancePool(startInstancePoolRequest: requests.StartInstancePoolRequest): Promise<responses.StartInstancePoolResponse>;
    /**
     * Performs the stop (immediate power off) action on the specified instance pool,
     * which performs the action on all the instances in the pool.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param StopInstancePoolRequest
     * @return StopInstancePoolResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/StopInstancePool.ts.html |here} to see how to use StopInstancePool API.
     */
    stopInstancePool(stopInstancePoolRequest: requests.StopInstancePoolRequest): Promise<responses.StopInstancePoolResponse>;
    /**
       * Deletes (terminates) a [cluster network with instance pools](https://docs.cloud.oracle.com/iaas/Content/Compute/Tasks/managingclusternetworks.htm).
  * <p>
  When you delete a cluster network, all of its resources are permanently deleted,
  * including associated instances and instance pools.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param TerminateClusterNetworkRequest
       * @return TerminateClusterNetworkResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/TerminateClusterNetwork.ts.html |here} to see how to use TerminateClusterNetwork API.
       */
    terminateClusterNetwork(terminateClusterNetworkRequest: requests.TerminateClusterNetworkRequest): Promise<responses.TerminateClusterNetworkResponse>;
    /**
       * Terminate the specified instance pool.
  * <p>
  **Warning:** When you delete an instance pool, the resources that were created by the pool are permanently
  * deleted, including associated instances, attached boot volumes, and block volumes.
  * <p>
  If an autoscaling configuration applies to the instance pool, the autoscaling configuration will be deleted
  * asynchronously after the pool is deleted. You can also manually delete the autoscaling configuration using
  * the `DeleteAutoScalingConfiguration` operation in the Autoscaling API.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param TerminateInstancePoolRequest
       * @return TerminateInstancePoolResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/TerminateInstancePool.ts.html |here} to see how to use TerminateInstancePool API.
       */
    terminateInstancePool(terminateInstancePoolRequest: requests.TerminateInstancePoolRequest): Promise<responses.TerminateInstancePoolResponse>;
    /**
     * Updates a [cluster network with instance pools](https://docs.cloud.oracle.com/iaas/Content/Compute/Tasks/managingclusternetworks.htm).
     * The OCID of the cluster network remains the same.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateClusterNetworkRequest
     * @return UpdateClusterNetworkResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/UpdateClusterNetwork.ts.html |here} to see how to use UpdateClusterNetwork API.
     */
    updateClusterNetwork(updateClusterNetworkRequest: requests.UpdateClusterNetworkRequest): Promise<responses.UpdateClusterNetworkResponse>;
    /**
     * Updates the free-form tags, defined tags, and display name of an instance configuration.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateInstanceConfigurationRequest
     * @return UpdateInstanceConfigurationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/UpdateInstanceConfiguration.ts.html |here} to see how to use UpdateInstanceConfiguration API.
     */
    updateInstanceConfiguration(updateInstanceConfigurationRequest: requests.UpdateInstanceConfigurationRequest): Promise<responses.UpdateInstanceConfigurationResponse>;
    /**
       * Update the specified instance pool.
  * <p>
  The OCID of the instance pool remains the same.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param UpdateInstancePoolRequest
       * @return UpdateInstancePoolResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/UpdateInstancePool.ts.html |here} to see how to use UpdateInstancePool API.
       */
    updateInstancePool(updateInstancePoolRequest: requests.UpdateInstancePoolRequest): Promise<responses.UpdateInstancePoolResponse>;
}
export declare enum VirtualNetworkApiKeys {
}
/**
 * This service client uses {@link common.CircuitBreaker.DefaultConfiguration} for all the operations by default if no circuit breaker configuration is defined by the user.
 */
export declare class VirtualNetworkClient {
    protected static serviceEndpointTemplate: string;
    protected static endpointServiceName: string;
    protected "_realmSpecificEndpointTemplateEnabled": boolean | undefined;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_waiters": VirtualNetworkWaiter;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: typeof Breaker | null;
    protected _httpOptions: any;
    protected _bodyDuplexMode: any;
    targetService: string;
    protected _regionId: string;
    protected "_region": common.Region;
    protected _lastSetRegionOrRegionId: string;
    protected _httpClient: common.HttpClient;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    get endpoint(): string;
    /**
     * Sets the endpoint to call (ex, https://www.example.com).
     * @param endpoint The endpoint of the service.
     */
    set endpoint(endpoint: string);
    get logger(): import("oci-common/lib/log").Logger;
    /**
     * Determines whether realm specific endpoint should be used or not.
     * Set realmSpecificEndpointTemplateEnabled to "true" if the user wants to enable use of realm specific endpoint template, otherwise set it to "false"
     * @param realmSpecificEndpointTemplateEnabled flag to enable the use of realm specific endpoint template
     */
    set useRealmSpecificEndpointTemplate(realmSpecificEndpointTemplateEnabled: boolean);
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    set region(region: common.Region);
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    set regionId(regionId: string);
    /**
     * Creates a new VirtualNetworkWaiter for resources for this service.
     *
     * @param workRequestClient The work request service client used to query for work request status
     * @param config The waiter configuration for termination and delay strategy
     * @return The service waiters.
     */
    createWaiters(workRequestClient: WorkRequestClient, config?: common.WaiterConfiguration): VirtualNetworkWaiter;
    /**
     * Gets the waiters available for resources for this service.
     *
     * @return The service waiters.
     */
    getWaiters(): VirtualNetworkWaiter;
    /**
     * Shutdown the circuit breaker used by the client when it is no longer needed
     */
    shutdownCircuitBreaker(): void;
    /**
     * Close the client once it is no longer needed
     */
    close(): void;
    /**
     * Adds one or more route distribution statements to the specified route distribution.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param AddDrgRouteDistributionStatementsRequest
     * @return AddDrgRouteDistributionStatementsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/AddDrgRouteDistributionStatements.ts.html |here} to see how to use AddDrgRouteDistributionStatements API.
     */
    addDrgRouteDistributionStatements(addDrgRouteDistributionStatementsRequest: requests.AddDrgRouteDistributionStatementsRequest): Promise<responses.AddDrgRouteDistributionStatementsResponse>;
    /**
     * Adds one or more static route rules to the specified DRG route table.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param AddDrgRouteRulesRequest
     * @return AddDrgRouteRulesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/AddDrgRouteRules.ts.html |here} to see how to use AddDrgRouteRules API.
     */
    addDrgRouteRules(addDrgRouteRulesRequest: requests.AddDrgRouteRulesRequest): Promise<responses.AddDrgRouteRulesResponse>;
    /**
     * Add an IPv6 prefix to a subnet.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param AddIpv6SubnetCidrRequest
     * @return AddIpv6SubnetCidrResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/AddIpv6SubnetCidr.ts.html |here} to see how to use AddIpv6SubnetCidr API.
     */
    addIpv6SubnetCidr(addIpv6SubnetCidrRequest: requests.AddIpv6SubnetCidrRequest): Promise<responses.AddIpv6SubnetCidrResponse>;
    /**
     * Add an IPv6 prefix to a VCN. The VCN size is always /56 and assigned by Oracle.
     * Once added the IPv6 prefix cannot be removed or modified.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param AddIpv6VcnCidrRequest
     * @return AddIpv6VcnCidrResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/AddIpv6VcnCidr.ts.html |here} to see how to use AddIpv6VcnCidr API.
     */
    addIpv6VcnCidr(addIpv6VcnCidrRequest: requests.AddIpv6VcnCidrRequest): Promise<responses.AddIpv6VcnCidrResponse>;
    /**
     * Adds one or more security rules to the specified network security group.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param AddNetworkSecurityGroupSecurityRulesRequest
     * @return AddNetworkSecurityGroupSecurityRulesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/AddNetworkSecurityGroupSecurityRules.ts.html |here} to see how to use AddNetworkSecurityGroupSecurityRules API.
     */
    addNetworkSecurityGroupSecurityRules(addNetworkSecurityGroupSecurityRulesRequest: requests.AddNetworkSecurityGroupSecurityRulesRequest): Promise<responses.AddNetworkSecurityGroupSecurityRulesResponse>;
    /**
       * Adds some or all of a CIDR block to a public IP pool.
  * <p>
  The CIDR block (or subrange) must not overlap with any other CIDR block already added to this or any other public IP pool.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param AddPublicIpPoolCapacityRequest
       * @return AddPublicIpPoolCapacityResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/AddPublicIpPoolCapacity.ts.html |here} to see how to use AddPublicIpPoolCapacity API.
       */
    addPublicIpPoolCapacity(addPublicIpPoolCapacityRequest: requests.AddPublicIpPoolCapacityRequest): Promise<responses.AddPublicIpPoolCapacityResponse>;
    /**
       * Adds a CIDR block to a VCN. The CIDR block you add:
  * <p>
  - Must be valid.
  * - Must not overlap with another CIDR block in the VCN, a CIDR block of a peered VCN, or the on-premises network CIDR block.
  * - Must not exceed the limit of CIDR blocks allowed per VCN.
  * <p>
  **Note:** Adding a CIDR block places your VCN in an updating state until the changes are complete. You cannot create or update the VCN's subnets, VLANs, LPGs, or route tables during this operation. The time to completion can take a few minutes. You can use the `GetWorkRequest` operation to check the status of the update.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param AddVcnCidrRequest
       * @return AddVcnCidrResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/AddVcnCidr.ts.html |here} to see how to use AddVcnCidr API.
       */
    addVcnCidr(addVcnCidrRequest: requests.AddVcnCidrRequest): Promise<responses.AddVcnCidrResponse>;
    /**
     * Begins BGP route advertisements for the BYOIP CIDR block you imported to the Oracle Cloud.
     * The `ByoipRange` resource must be in the PROVISIONED state before the BYOIP CIDR block routes can be advertised with BGP.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param AdvertiseByoipRangeRequest
     * @return AdvertiseByoipRangeResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/AdvertiseByoipRange.ts.html |here} to see how to use AdvertiseByoipRange API.
     */
    advertiseByoipRange(advertiseByoipRangeRequest: requests.AdvertiseByoipRangeRequest): Promise<responses.AdvertiseByoipRangeResponse>;
    /**
     * Adds the specified {@link Service} to the list of enabled
     * `Service` objects for the specified gateway. You must also set up a route rule with the
     * `cidrBlock` of the `Service` as the rule's destination and the service gateway as the rule's
     * target. See {@link RouteTable}.
     * <p>
     **Note:** The `AttachServiceId` operation is an easy way to add an individual `Service` to
     * the service gateway. Compare it with
     * {@link #updateServiceGateway(UpdateServiceGatewayRequest) updateServiceGateway}, which replaces
     * the entire existing list of enabled `Service` objects with the list that you provide in the
     * `Update` call.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param AttachServiceIdRequest
     * @return AttachServiceIdResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/AttachServiceId.ts.html |here} to see how to use AttachServiceId API.
     */
    attachServiceId(attachServiceIdRequest: requests.AttachServiceIdRequest): Promise<responses.AttachServiceIdResponse>;
    /**
     * Adds one or more customer public IP prefixes to the specified public virtual circuit.
     * Use this operation (and not {@link #updateVirtualCircuit(UpdateVirtualCircuitRequest) updateVirtualCircuit})
     * to add prefixes to the virtual circuit. Oracle must verify the customer's ownership
     * of each prefix before traffic for that prefix will flow across the virtual circuit.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param BulkAddVirtualCircuitPublicPrefixesRequest
     * @return BulkAddVirtualCircuitPublicPrefixesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/BulkAddVirtualCircuitPublicPrefixes.ts.html |here} to see how to use BulkAddVirtualCircuitPublicPrefixes API.
     */
    bulkAddVirtualCircuitPublicPrefixes(bulkAddVirtualCircuitPublicPrefixesRequest: requests.BulkAddVirtualCircuitPublicPrefixesRequest): Promise<responses.BulkAddVirtualCircuitPublicPrefixesResponse>;
    /**
     * Removes one or more customer public IP prefixes from the specified public virtual circuit.
     * Use this operation (and not {@link #updateVirtualCircuit(UpdateVirtualCircuitRequest) updateVirtualCircuit})
     * to remove prefixes from the virtual circuit. When the virtual circuit's state switches
     * back to PROVISIONED, Oracle stops advertising the specified prefixes across the connection.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param BulkDeleteVirtualCircuitPublicPrefixesRequest
     * @return BulkDeleteVirtualCircuitPublicPrefixesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/BulkDeleteVirtualCircuitPublicPrefixes.ts.html |here} to see how to use BulkDeleteVirtualCircuitPublicPrefixes API.
     */
    bulkDeleteVirtualCircuitPublicPrefixes(bulkDeleteVirtualCircuitPublicPrefixesRequest: requests.BulkDeleteVirtualCircuitPublicPrefixesRequest): Promise<responses.BulkDeleteVirtualCircuitPublicPrefixesResponse>;
    /**
     * Moves a BYOIP CIDR block to a different compartment. For information
     * about moving resources between compartments, see
     * [Moving Resources to a Different Compartment](https://docs.cloud.oracle.com/iaas/Content/Identity/Tasks/managingcompartments.htm#moveRes).
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangeByoipRangeCompartmentRequest
     * @return ChangeByoipRangeCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ChangeByoipRangeCompartment.ts.html |here} to see how to use ChangeByoipRangeCompartment API.
     */
    changeByoipRangeCompartment(changeByoipRangeCompartmentRequest: requests.ChangeByoipRangeCompartmentRequest): Promise<responses.ChangeByoipRangeCompartmentResponse>;
    /**
     * Moves a capture filter to a new compartment in the same tenancy. For information
     * about moving resources between compartments, see
     * [Moving Resources to a Different Compartment](https://docs.cloud.oracle.com/iaas/Content/Identity/Tasks/managingcompartments.htm#moveRes).
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangeCaptureFilterCompartmentRequest
     * @return ChangeCaptureFilterCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ChangeCaptureFilterCompartment.ts.html |here} to see how to use ChangeCaptureFilterCompartment API.
     */
    changeCaptureFilterCompartment(changeCaptureFilterCompartmentRequest: requests.ChangeCaptureFilterCompartmentRequest): Promise<responses.ChangeCaptureFilterCompartmentResponse>;
    /**
     * Moves a CPE object into a different compartment within the same tenancy. For information
     * about moving resources between compartments, see
     * [Moving Resources to a Different Compartment](https://docs.cloud.oracle.com/iaas/Content/Identity/Tasks/managingcompartments.htm#moveRes).
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ChangeCpeCompartmentRequest
     * @return ChangeCpeCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ChangeCpeCompartment.ts.html |here} to see how to use ChangeCpeCompartment API.
     */
    changeCpeCompartment(changeCpeCompartmentRequest: requests.ChangeCpeCompartmentRequest): Promise<responses.ChangeCpeCompartmentResponse>;
    /**
     * Moves a cross-connect into a different compartment within the same tenancy. For information
     * about moving resources between compartments, see
     * [Moving Resources to a Different Compartment](https://docs.cloud.oracle.com/iaas/Content/Identity/Tasks/managingcompartments.htm#moveRes).
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ChangeCrossConnectCompartmentRequest
     * @return ChangeCrossConnectCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ChangeCrossConnectCompartment.ts.html |here} to see how to use ChangeCrossConnectCompartment API.
     */
    changeCrossConnectCompartment(changeCrossConnectCompartmentRequest: requests.ChangeCrossConnectCompartmentRequest): Promise<responses.ChangeCrossConnectCompartmentResponse>;
    /**
     * Moves a cross-connect group into a different compartment within the same tenancy. For information
     * about moving resources between compartments, see
     * [Moving Resources to a Different Compartment](https://docs.cloud.oracle.com/iaas/Content/Identity/Tasks/managingcompartments.htm#moveRes).
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ChangeCrossConnectGroupCompartmentRequest
     * @return ChangeCrossConnectGroupCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ChangeCrossConnectGroupCompartment.ts.html |here} to see how to use ChangeCrossConnectGroupCompartment API.
     */
    changeCrossConnectGroupCompartment(changeCrossConnectGroupCompartmentRequest: requests.ChangeCrossConnectGroupCompartmentRequest): Promise<responses.ChangeCrossConnectGroupCompartmentResponse>;
    /**
     * Moves a set of DHCP options into a different compartment within the same tenancy. For information
     * about moving resources between compartments, see
     * [Moving Resources to a Different Compartment](https://docs.cloud.oracle.com/iaas/Content/Identity/Tasks/managingcompartments.htm#moveRes).
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangeDhcpOptionsCompartmentRequest
     * @return ChangeDhcpOptionsCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ChangeDhcpOptionsCompartment.ts.html |here} to see how to use ChangeDhcpOptionsCompartment API.
     */
    changeDhcpOptionsCompartment(changeDhcpOptionsCompartmentRequest: requests.ChangeDhcpOptionsCompartmentRequest): Promise<responses.ChangeDhcpOptionsCompartmentResponse>;
    /**
     * Moves a DRG into a different compartment within the same tenancy. For information
     * about moving resources between compartments, see
     * [Moving Resources to a Different Compartment](https://docs.cloud.oracle.com/iaas/Content/Identity/Tasks/managingcompartments.htm#moveRes).
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangeDrgCompartmentRequest
     * @return ChangeDrgCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ChangeDrgCompartment.ts.html |here} to see how to use ChangeDrgCompartment API.
     */
    changeDrgCompartment(changeDrgCompartmentRequest: requests.ChangeDrgCompartmentRequest): Promise<responses.ChangeDrgCompartmentResponse>;
    /**
     * Moves an IPSec connection into a different compartment within the same tenancy. For information
     * about moving resources between compartments, see
     * [Moving Resources to a Different Compartment](https://docs.cloud.oracle.com/iaas/Content/Identity/Tasks/managingcompartments.htm#moveRes).
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ChangeIPSecConnectionCompartmentRequest
     * @return ChangeIPSecConnectionCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ChangeIPSecConnectionCompartment.ts.html |here} to see how to use ChangeIPSecConnectionCompartment API.
     */
    changeIPSecConnectionCompartment(changeIPSecConnectionCompartmentRequest: requests.ChangeIPSecConnectionCompartmentRequest): Promise<responses.ChangeIPSecConnectionCompartmentResponse>;
    /**
     * Moves an internet gateway into a different compartment within the same tenancy. For information
     * about moving resources between compartments, see
     * [Moving Resources to a Different Compartment](https://docs.cloud.oracle.com/iaas/Content/Identity/Tasks/managingcompartments.htm#moveRes).
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangeInternetGatewayCompartmentRequest
     * @return ChangeInternetGatewayCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ChangeInternetGatewayCompartment.ts.html |here} to see how to use ChangeInternetGatewayCompartment API.
     */
    changeInternetGatewayCompartment(changeInternetGatewayCompartmentRequest: requests.ChangeInternetGatewayCompartmentRequest): Promise<responses.ChangeInternetGatewayCompartmentResponse>;
    /**
     * Moves a local peering gateway into a different compartment within the same tenancy. For information
     * about moving resources between compartments, see
     * [Moving Resources to a Different Compartment](https://docs.cloud.oracle.com/iaas/Content/Identity/Tasks/managingcompartments.htm#moveRes).
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangeLocalPeeringGatewayCompartmentRequest
     * @return ChangeLocalPeeringGatewayCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ChangeLocalPeeringGatewayCompartment.ts.html |here} to see how to use ChangeLocalPeeringGatewayCompartment API.
     */
    changeLocalPeeringGatewayCompartment(changeLocalPeeringGatewayCompartmentRequest: requests.ChangeLocalPeeringGatewayCompartmentRequest): Promise<responses.ChangeLocalPeeringGatewayCompartmentResponse>;
    /**
     * Moves a NAT gateway into a different compartment within the same tenancy. For information
     * about moving resources between compartments, see
     * [Moving Resources to a Different Compartment](https://docs.cloud.oracle.com/iaas/Content/Identity/Tasks/managingcompartments.htm#moveRes).
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangeNatGatewayCompartmentRequest
     * @return ChangeNatGatewayCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ChangeNatGatewayCompartment.ts.html |here} to see how to use ChangeNatGatewayCompartment API.
     */
    changeNatGatewayCompartment(changeNatGatewayCompartmentRequest: requests.ChangeNatGatewayCompartmentRequest): Promise<responses.ChangeNatGatewayCompartmentResponse>;
    /**
     * Moves a network security group into a different compartment within the same tenancy. For
     * information about moving resources between compartments, see [Moving Resources to a Different Compartment](https://docs.cloud.oracle.com/iaas/Content/Identity/Tasks/managingcompartments.htm#moveRes).
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangeNetworkSecurityGroupCompartmentRequest
     * @return ChangeNetworkSecurityGroupCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ChangeNetworkSecurityGroupCompartment.ts.html |here} to see how to use ChangeNetworkSecurityGroupCompartment API.
     */
    changeNetworkSecurityGroupCompartment(changeNetworkSecurityGroupCompartmentRequest: requests.ChangeNetworkSecurityGroupCompartmentRequest): Promise<responses.ChangeNetworkSecurityGroupCompartmentResponse>;
    /**
       * Moves a public IP into a different compartment within the same tenancy. For information
  * about moving resources between compartments, see
  * [Moving Resources to a Different Compartment](https://docs.cloud.oracle.com/iaas/Content/Identity/Tasks/managingcompartments.htm#moveRes).
  * <p>
  This operation applies only to reserved public IPs. Ephemeral public IPs always belong to the
  * same compartment as their VNIC and move accordingly.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param ChangePublicIpCompartmentRequest
       * @return ChangePublicIpCompartmentResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ChangePublicIpCompartment.ts.html |here} to see how to use ChangePublicIpCompartment API.
       */
    changePublicIpCompartment(changePublicIpCompartmentRequest: requests.ChangePublicIpCompartmentRequest): Promise<responses.ChangePublicIpCompartmentResponse>;
    /**
     * Moves a public IP pool to a different compartment. For information
     * about moving resources between compartments, see
     * [Moving Resources to a Different Compartment](https://docs.cloud.oracle.com/iaas/Content/Identity/Tasks/managingcompartments.htm#moveRes).
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangePublicIpPoolCompartmentRequest
     * @return ChangePublicIpPoolCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ChangePublicIpPoolCompartment.ts.html |here} to see how to use ChangePublicIpPoolCompartment API.
     */
    changePublicIpPoolCompartment(changePublicIpPoolCompartmentRequest: requests.ChangePublicIpPoolCompartmentRequest): Promise<responses.ChangePublicIpPoolCompartmentResponse>;
    /**
     * Moves a remote peering connection (RPC) into a different compartment within the same tenancy. For information
     * about moving resources between compartments, see
     * [Moving Resources to a Different Compartment](https://docs.cloud.oracle.com/iaas/Content/Identity/Tasks/managingcompartments.htm#moveRes).
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ChangeRemotePeeringConnectionCompartmentRequest
     * @return ChangeRemotePeeringConnectionCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ChangeRemotePeeringConnectionCompartment.ts.html |here} to see how to use ChangeRemotePeeringConnectionCompartment API.
     */
    changeRemotePeeringConnectionCompartment(changeRemotePeeringConnectionCompartmentRequest: requests.ChangeRemotePeeringConnectionCompartmentRequest): Promise<responses.ChangeRemotePeeringConnectionCompartmentResponse>;
    /**
     * Moves a route table into a different compartment within the same tenancy. For information
     * about moving resources between compartments, see
     * [Moving Resources to a Different Compartment](https://docs.cloud.oracle.com/iaas/Content/Identity/Tasks/managingcompartments.htm#moveRes).
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangeRouteTableCompartmentRequest
     * @return ChangeRouteTableCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ChangeRouteTableCompartment.ts.html |here} to see how to use ChangeRouteTableCompartment API.
     */
    changeRouteTableCompartment(changeRouteTableCompartmentRequest: requests.ChangeRouteTableCompartmentRequest): Promise<responses.ChangeRouteTableCompartmentResponse>;
    /**
     * Moves a security list into a different compartment within the same tenancy. For information
     * about moving resources between compartments, see
     * [Moving Resources to a Different Compartment](https://docs.cloud.oracle.com/iaas/Content/Identity/Tasks/managingcompartments.htm#moveRes).
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangeSecurityListCompartmentRequest
     * @return ChangeSecurityListCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ChangeSecurityListCompartment.ts.html |here} to see how to use ChangeSecurityListCompartment API.
     */
    changeSecurityListCompartment(changeSecurityListCompartmentRequest: requests.ChangeSecurityListCompartmentRequest): Promise<responses.ChangeSecurityListCompartmentResponse>;
    /**
     * Moves a service gateway into a different compartment within the same tenancy. For information
     * about moving resources between compartments, see
     * [Moving Resources to a Different Compartment](https://docs.cloud.oracle.com/iaas/Content/Identity/Tasks/managingcompartments.htm#moveRes).
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangeServiceGatewayCompartmentRequest
     * @return ChangeServiceGatewayCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ChangeServiceGatewayCompartment.ts.html |here} to see how to use ChangeServiceGatewayCompartment API.
     */
    changeServiceGatewayCompartment(changeServiceGatewayCompartmentRequest: requests.ChangeServiceGatewayCompartmentRequest): Promise<responses.ChangeServiceGatewayCompartmentResponse>;
    /**
     * Moves a subnet into a different compartment within the same tenancy. For information
     * about moving resources between compartments, see
     * [Moving Resources to a Different Compartment](https://docs.cloud.oracle.com/iaas/Content/Identity/Tasks/managingcompartments.htm#moveRes).
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangeSubnetCompartmentRequest
     * @return ChangeSubnetCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ChangeSubnetCompartment.ts.html |here} to see how to use ChangeSubnetCompartment API.
     */
    changeSubnetCompartment(changeSubnetCompartmentRequest: requests.ChangeSubnetCompartmentRequest): Promise<responses.ChangeSubnetCompartmentResponse>;
    /**
     * Moves a VCN into a different compartment within the same tenancy. For information
     * about moving resources between compartments, see
     * [Moving Resources to a Different Compartment](https://docs.cloud.oracle.com/iaas/Content/Identity/Tasks/managingcompartments.htm#moveRes).
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangeVcnCompartmentRequest
     * @return ChangeVcnCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ChangeVcnCompartment.ts.html |here} to see how to use ChangeVcnCompartment API.
     */
    changeVcnCompartment(changeVcnCompartmentRequest: requests.ChangeVcnCompartmentRequest): Promise<responses.ChangeVcnCompartmentResponse>;
    /**
     * Moves a virtual circuit into a different compartment within the same tenancy. For information
     * about moving resources between compartments, see
     * [Moving Resources to a Different Compartment](https://docs.cloud.oracle.com/iaas/Content/Identity/Tasks/managingcompartments.htm#moveRes).
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ChangeVirtualCircuitCompartmentRequest
     * @return ChangeVirtualCircuitCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ChangeVirtualCircuitCompartment.ts.html |here} to see how to use ChangeVirtualCircuitCompartment API.
     */
    changeVirtualCircuitCompartment(changeVirtualCircuitCompartmentRequest: requests.ChangeVirtualCircuitCompartmentRequest): Promise<responses.ChangeVirtualCircuitCompartmentResponse>;
    /**
     * Moves a VLAN into a different compartment within the same tenancy.
     * For information about moving resources between compartments, see
     * [Moving Resources to a Different Compartment](https://docs.cloud.oracle.com/iaas/Content/Identity/Tasks/managingcompartments.htm#moveRes).
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangeVlanCompartmentRequest
     * @return ChangeVlanCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ChangeVlanCompartment.ts.html |here} to see how to use ChangeVlanCompartment API.
     */
    changeVlanCompartment(changeVlanCompartmentRequest: requests.ChangeVlanCompartmentRequest): Promise<responses.ChangeVlanCompartmentResponse>;
    /**
     * Moves a VTAP to a new compartment within the same tenancy. For information
     * about moving resources between compartments, see
     * [Moving Resources to a Different Compartment](https://docs.cloud.oracle.com/iaas/Content/Identity/Tasks/managingcompartments.htm#moveRes).
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangeVtapCompartmentRequest
     * @return ChangeVtapCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ChangeVtapCompartment.ts.html |here} to see how to use ChangeVtapCompartment API.
     */
    changeVtapCompartment(changeVtapCompartmentRequest: requests.ChangeVtapCompartmentRequest): Promise<responses.ChangeVtapCompartmentResponse>;
    /**
       * Connects this local peering gateway (LPG) to another one in the same region.
  * <p>
  This operation must be called by the VCN administrator who is designated as
  * the *requestor* in the peering relationship. The *acceptor* must implement
  * an Identity and Access Management (IAM) policy that gives the requestor permission
  * to connect to LPGs in the acceptor's compartment. Without that permission, this
  * operation will fail. For more information, see
  * [VCN Peering](https://docs.cloud.oracle.com/iaas/Content/Network/Tasks/VCNpeering.htm).
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param ConnectLocalPeeringGatewaysRequest
       * @return ConnectLocalPeeringGatewaysResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ConnectLocalPeeringGateways.ts.html |here} to see how to use ConnectLocalPeeringGateways API.
       */
    connectLocalPeeringGateways(connectLocalPeeringGatewaysRequest: requests.ConnectLocalPeeringGatewaysRequest): Promise<responses.ConnectLocalPeeringGatewaysResponse>;
    /**
       * Connects this RPC to another one in a different region.
  * <p>
  This operation must be called by the VCN administrator who is designated as
  * the *requestor* in the peering relationship. The *acceptor* must implement
  * an Identity and Access Management (IAM) policy that gives the requestor permission
  * to connect to RPCs in the acceptor's compartment. Without that permission, this
  * operation will fail. For more information, see
  * [VCN Peering](https://docs.cloud.oracle.com/iaas/Content/Network/Tasks/VCNpeering.htm).
  *
       * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
       * @param ConnectRemotePeeringConnectionsRequest
       * @return ConnectRemotePeeringConnectionsResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ConnectRemotePeeringConnections.ts.html |here} to see how to use ConnectRemotePeeringConnections API.
       */
    connectRemotePeeringConnections(connectRemotePeeringConnectionsRequest: requests.ConnectRemotePeeringConnectionsRequest): Promise<responses.ConnectRemotePeeringConnectionsResponse>;
    /**
     * Creates a subrange of the BYOIP CIDR block.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateByoipRangeRequest
     * @return CreateByoipRangeResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/CreateByoipRange.ts.html |here} to see how to use CreateByoipRange API.
     */
    createByoipRange(createByoipRangeRequest: requests.CreateByoipRangeRequest): Promise<responses.CreateByoipRangeResponse>;
    /**
       * Creates a virtual test access point (VTAP) capture filter in the specified compartment.
  * <p>
  For the purposes of access control, you must provide the [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment that contains
  * the VTAP. For more information about compartments and access control, see
  * [Overview of the IAM Service](https://docs.cloud.oracle.com/iaas/Content/Identity/Concepts/overview.htm).
  * For information about OCIDs, see [Resource Identifiers](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
  * <p>
  You may optionally specify a *display name* for the VTAP, otherwise a default is provided.
  * It does not have to be unique, and you can change it.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param CreateCaptureFilterRequest
       * @return CreateCaptureFilterResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/CreateCaptureFilter.ts.html |here} to see how to use CreateCaptureFilter API.
       */
    createCaptureFilter(createCaptureFilterRequest: requests.CreateCaptureFilterRequest): Promise<responses.CreateCaptureFilterResponse>;
    /**
       * Creates a new virtual customer-premises equipment (CPE) object in the specified compartment. For
  * more information, see [Site-to-Site VPN Overview](https://docs.cloud.oracle.com/iaas/Content/Network/Tasks/overviewIPsec.htm).
  * <p>
  For the purposes of access control, you must provide the [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment where you want
  * the CPE to reside. Notice that the CPE doesn't have to be in the same compartment as the IPSec
  * connection or other Networking Service components. If you're not sure which compartment to
  * use, put the CPE in the same compartment as the DRG. For more information about
  * compartments and access control, see [Overview of the IAM Service](https://docs.cloud.oracle.com/iaas/Content/Identity/Concepts/overview.htm).
  * For information about OCIDs, see [Resource Identifiers](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
  * <p>
  You must provide the public IP address of your on-premises router. See
  * [CPE Configuration](https://docs.cloud.oracle.com/iaas/Content/Network/Tasks/configuringCPE.htm).
  * <p>
  You may optionally specify a *display name* for the CPE, otherwise a default is provided. It does not have to
  * be unique, and you can change it. Avoid entering confidential information.
  *
       * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
       * @param CreateCpeRequest
       * @return CreateCpeResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/CreateCpe.ts.html |here} to see how to use CreateCpe API.
       */
    createCpe(createCpeRequest: requests.CreateCpeRequest): Promise<responses.CreateCpeResponse>;
    /**
       * Creates a new cross-connect. Oracle recommends you create each cross-connect in a
  * {@link CrossConnectGroup} so you can use link aggregation
  * with the connection.
  * <p>
  After creating the `CrossConnect` object, you need to go the FastConnect location
  * and request to have the physical cable installed. For more information, see
  * [FastConnect Overview](https://docs.cloud.oracle.com/iaas/Content/Network/Concepts/fastconnect.htm).
  * <p>
  For the purposes of access control, you must provide the [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the
  * compartment where you want the cross-connect to reside. If you're
  * not sure which compartment to use, put the cross-connect in the
  * same compartment with your VCN. For more information about
  * compartments and access control, see
  * [Overview of the IAM Service](https://docs.cloud.oracle.com/iaas/Content/Identity/Concepts/overview.htm).
  * For information about OCIDs, see
  * [Resource Identifiers](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
  * <p>
  You may optionally specify a *display name* for the cross-connect.
  * It does not have to be unique, and you can change it. Avoid entering confidential information.
  *
       * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
       * @param CreateCrossConnectRequest
       * @return CreateCrossConnectResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/CreateCrossConnect.ts.html |here} to see how to use CreateCrossConnect API.
       */
    createCrossConnect(createCrossConnectRequest: requests.CreateCrossConnectRequest): Promise<responses.CreateCrossConnectResponse>;
    /**
       * Creates a new cross-connect group to use with Oracle Cloud Infrastructure
  * FastConnect. For more information, see
  * [FastConnect Overview](https://docs.cloud.oracle.com/iaas/Content/Network/Concepts/fastconnect.htm).
  * <p>
  For the purposes of access control, you must provide the [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the
  * compartment where you want the cross-connect group to reside. If you're
  * not sure which compartment to use, put the cross-connect group in the
  * same compartment with your VCN. For more information about
  * compartments and access control, see
  * [Overview of the IAM Service](https://docs.cloud.oracle.com/iaas/Content/Identity/Concepts/overview.htm).
  * For information about OCIDs, see
  * [Resource Identifiers](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
  * <p>
  You may optionally specify a *display name* for the cross-connect group.
  * It does not have to be unique, and you can change it. Avoid entering confidential information.
  *
       * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
       * @param CreateCrossConnectGroupRequest
       * @return CreateCrossConnectGroupResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/CreateCrossConnectGroup.ts.html |here} to see how to use CreateCrossConnectGroup API.
       */
    createCrossConnectGroup(createCrossConnectGroupRequest: requests.CreateCrossConnectGroupRequest): Promise<responses.CreateCrossConnectGroupResponse>;
    /**
       * Creates a new set of DHCP options for the specified VCN. For more information, see
  * {@link DhcpOptions}.
  * <p>
  For the purposes of access control, you must provide the [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment where you want the set of
  * DHCP options to reside. Notice that the set of options doesn't have to be in the same compartment as the VCN,
  * subnets, or other Networking Service components. If you're not sure which compartment to use, put the set
  * of DHCP options in the same compartment as the VCN. For more information about compartments and access control, see
  * [Overview of the IAM Service](https://docs.cloud.oracle.com/iaas/Content/Identity/Concepts/overview.htm). For information about OCIDs, see
  * [Resource Identifiers](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
  * <p>
  You may optionally specify a *display name* for the set of DHCP options, otherwise a default is provided.
  * It does not have to be unique, and you can change it. Avoid entering confidential information.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param CreateDhcpOptionsRequest
       * @return CreateDhcpOptionsResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/CreateDhcpOptions.ts.html |here} to see how to use CreateDhcpOptions API.
       */
    createDhcpOptions(createDhcpOptionsRequest: requests.CreateDhcpOptionsRequest): Promise<responses.CreateDhcpOptionsResponse>;
    /**
       * Creates a new dynamic routing gateway (DRG) in the specified compartment. For more information,
  * see [Dynamic Routing Gateways (DRGs)](https://docs.cloud.oracle.com/iaas/Content/Network/Tasks/managingDRGs.htm).
  * <p>
  For the purposes of access control, you must provide the [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment where you want
  * the DRG to reside. Notice that the DRG doesn't have to be in the same compartment as the VCN,
  * the DRG attachment, or other Networking Service components. If you're not sure which compartment
  * to use, put the DRG in the same compartment as the VCN. For more information about compartments
  * and access control, see [Overview of the IAM Service](https://docs.cloud.oracle.com/iaas/Content/Identity/Concepts/overview.htm).
  * For information about OCIDs, see [Resource Identifiers](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
  * <p>
  You may optionally specify a *display name* for the DRG, otherwise a default is provided.
  * It does not have to be unique, and you can change it. Avoid entering confidential information.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param CreateDrgRequest
       * @return CreateDrgResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/CreateDrg.ts.html |here} to see how to use CreateDrg API.
       */
    createDrg(createDrgRequest: requests.CreateDrgRequest): Promise<responses.CreateDrgResponse>;
    /**
       * Attaches the specified DRG to the specified network resource. A VCN can be attached to only one DRG
  * at a time, but a DRG can be attached to more than one VCN. The response includes a `DrgAttachment`
  * object with its own [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm). For more information about DRGs, see
  * [Dynamic Routing Gateways (DRGs)](https://docs.cloud.oracle.com/iaas/Content/Network/Tasks/managingDRGs.htm).
  * <p>
  You may optionally specify a *display name* for the attachment, otherwise a default is provided.
  * It does not have to be unique, and you can change it. Avoid entering confidential information.
  * <p>
  For the purposes of access control, the DRG attachment is automatically placed into the currently selected compartment.
  * For more information about compartments and access control, see
  * [Overview of the IAM Service](https://docs.cloud.oracle.com/iaas/Content/Identity/Concepts/overview.htm).
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param CreateDrgAttachmentRequest
       * @return CreateDrgAttachmentResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/CreateDrgAttachment.ts.html |here} to see how to use CreateDrgAttachment API.
       */
    createDrgAttachment(createDrgAttachmentRequest: requests.CreateDrgAttachmentRequest): Promise<responses.CreateDrgAttachmentResponse>;
    /**
     * Creates a new route distribution for the specified DRG.
     * Assign the route distribution as an import distribution to a DRG route table using the `UpdateDrgRouteTable` or `CreateDrgRouteTable` operations.
     * Assign the route distribution as an export distribution to a DRG attachment
     * using the `UpdateDrgAttachment` or `CreateDrgAttachment` operations.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateDrgRouteDistributionRequest
     * @return CreateDrgRouteDistributionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/CreateDrgRouteDistribution.ts.html |here} to see how to use CreateDrgRouteDistribution API.
     */
    createDrgRouteDistribution(createDrgRouteDistributionRequest: requests.CreateDrgRouteDistributionRequest): Promise<responses.CreateDrgRouteDistributionResponse>;
    /**
     * Creates a new DRG route table for the specified DRG. Assign the DRG route table to a DRG attachment
     * using the `UpdateDrgAttachment` or `CreateDrgAttachment` operations.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateDrgRouteTableRequest
     * @return CreateDrgRouteTableResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/CreateDrgRouteTable.ts.html |here} to see how to use CreateDrgRouteTable API.
     */
    createDrgRouteTable(createDrgRouteTableRequest: requests.CreateDrgRouteTableRequest): Promise<responses.CreateDrgRouteTableResponse>;
    /**
       * Creates a new IPSec connection between the specified DRG and CPE. For more information, see
  * [Site-to-Site VPN Overview](https://docs.cloud.oracle.com/iaas/Content/Network/Tasks/overviewIPsec.htm).
  * <p>
  If you configure at least one tunnel to use static routing, then in the request you must provide
  * at least one valid static route (you're allowed a maximum of 10). For example: 10.0.0.0/16.
  * If you configure both tunnels to use BGP dynamic routing, you can provide an empty list for
  * the static routes. For more information, see the important note in
  * {@link IPSecConnection}.
  * <p>
  For the purposes of access control, you must provide the [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment where you want the
  * IPSec connection to reside. Notice that the IPSec connection doesn't have to be in the same compartment
  * as the DRG, CPE, or other Networking Service components. If you're not sure which compartment to
  * use, put the IPSec connection in the same compartment as the DRG. For more information about
  * compartments and access control, see
  * [Overview of the IAM Service](https://docs.cloud.oracle.com/iaas/Content/Identity/Concepts/overview.htm).
  * <p>
  You may optionally specify a *display name* for the IPSec connection, otherwise a default is provided.
  * It does not have to be unique, and you can change it. Avoid entering confidential information.
  * <p>
  After creating the IPSec connection, you need to configure your on-premises router
  * with tunnel-specific information. For tunnel status and the required configuration information, see:
  * <p>
    * {@link IPSecConnectionTunnel}
  *   * {@link IPSecConnectionTunnelSharedSecret}
  * <p>
  For each tunnel, you need the IP address of Oracle's VPN headend and the shared secret
  * (that is, the pre-shared key). For more information, see
  * [CPE Configuration](https://docs.cloud.oracle.com/iaas/Content/Network/Tasks/configuringCPE.htm).
  *
       * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
       * @param CreateIPSecConnectionRequest
       * @return CreateIPSecConnectionResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/CreateIPSecConnection.ts.html |here} to see how to use CreateIPSecConnection API.
       */
    createIPSecConnection(createIPSecConnectionRequest: requests.CreateIPSecConnectionRequest): Promise<responses.CreateIPSecConnectionResponse>;
    /**
       * Creates a new internet gateway for the specified VCN. For more information, see
  * [Access to the Internet](https://docs.cloud.oracle.com/iaas/Content/Network/Tasks/managingIGs.htm).
  * <p>
  For the purposes of access control, you must provide the [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment where you want the Internet
  * Gateway to reside. Notice that the internet gateway doesn't have to be in the same compartment as the VCN or
  * other Networking Service components. If you're not sure which compartment to use, put the Internet
  * Gateway in the same compartment with the VCN. For more information about compartments and access control, see
  * [Overview of the IAM Service](https://docs.cloud.oracle.com/iaas/Content/Identity/Concepts/overview.htm).
  * <p>
  You may optionally specify a *display name* for the internet gateway, otherwise a default is provided. It
  * does not have to be unique, and you can change it. Avoid entering confidential information.
  * <p>
  For traffic to flow between a subnet and an internet gateway, you must create a route rule accordingly in
  * the subnet's route table (for example, 0.0.0.0/0 > internet gateway). See
  * {@link #updateRouteTable(UpdateRouteTableRequest) updateRouteTable}.
  * <p>
  You must specify whether the internet gateway is enabled when you create it. If it's disabled, that means no
  * traffic will flow to/from the internet even if there's a route rule that enables that traffic. You can later
  * use {@link #updateInternetGateway(UpdateInternetGatewayRequest) updateInternetGateway} to easily disable/enable
  * the gateway without changing the route rule.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param CreateInternetGatewayRequest
       * @return CreateInternetGatewayResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/CreateInternetGateway.ts.html |here} to see how to use CreateInternetGateway API.
       */
    createInternetGateway(createInternetGatewayRequest: requests.CreateInternetGatewayRequest): Promise<responses.CreateInternetGatewayResponse>;
    /**
     * Creates an IPv6 for the specified VNIC.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateIpv6Request
     * @return CreateIpv6Response
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/CreateIpv6.ts.html |here} to see how to use CreateIpv6 API.
     */
    createIpv6(createIpv6Request: requests.CreateIpv6Request): Promise<responses.CreateIpv6Response>;
    /**
     * Creates a new local peering gateway (LPG) for the specified VCN.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateLocalPeeringGatewayRequest
     * @return CreateLocalPeeringGatewayResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/CreateLocalPeeringGateway.ts.html |here} to see how to use CreateLocalPeeringGateway API.
     */
    createLocalPeeringGateway(createLocalPeeringGatewayRequest: requests.CreateLocalPeeringGatewayRequest): Promise<responses.CreateLocalPeeringGatewayResponse>;
    /**
     * Creates a new NAT gateway for the specified VCN. You must also set up a route rule with the
     * NAT gateway as the rule's target. See {@link RouteTable}.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateNatGatewayRequest
     * @return CreateNatGatewayResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/CreateNatGateway.ts.html |here} to see how to use CreateNatGateway API.
     */
    createNatGateway(createNatGatewayRequest: requests.CreateNatGatewayRequest): Promise<responses.CreateNatGatewayResponse>;
    /**
     * Creates a new network security group for the specified VCN.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateNetworkSecurityGroupRequest
     * @return CreateNetworkSecurityGroupResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/CreateNetworkSecurityGroup.ts.html |here} to see how to use CreateNetworkSecurityGroup API.
     */
    createNetworkSecurityGroup(createNetworkSecurityGroupRequest: requests.CreateNetworkSecurityGroupRequest): Promise<responses.CreateNetworkSecurityGroupResponse>;
    /**
     * Creates a secondary private IP for the specified VNIC.
     * For more information about secondary private IPs, see
     * [IP Addresses](https://docs.cloud.oracle.com/iaas/Content/Network/Tasks/managingIPaddresses.htm).
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreatePrivateIpRequest
     * @return CreatePrivateIpResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/CreatePrivateIp.ts.html |here} to see how to use CreatePrivateIp API.
     */
    createPrivateIp(createPrivateIpRequest: requests.CreatePrivateIpRequest): Promise<responses.CreatePrivateIpResponse>;
    /**
       * Creates a public IP. Use the `lifetime` property to specify whether it's an ephemeral or
  * reserved public IP. For information about limits on how many you can create, see
  * [Public IP Addresses](https://docs.cloud.oracle.com/iaas/Content/Network/Tasks/managingpublicIPs.htm).
  * <p>
  * **For an ephemeral public IP assigned to a private IP:** You must also specify a `privateIpId`
  * with the [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the primary private IP you want to assign the public IP to. The public IP is
  * created in the same availability domain as the private IP. An ephemeral public IP must always be
  * assigned to a private IP, and only to the *primary* private IP on a VNIC, not a secondary
  * private IP. Exception: If you create a {@link NatGateway}, Oracle
  * automatically assigns the NAT gateway a regional ephemeral public IP that you cannot remove.
  * <p>
  * **For a reserved public IP:** You may also optionally assign the public IP to a private
  * IP by specifying `privateIpId`. Or you can later assign the public IP with
  * {@link #updatePublicIp(UpdatePublicIpRequest) updatePublicIp}.
  * <p>
  **Note:** When assigning a public IP to a private IP, the private IP must not already have
  * a public IP with `lifecycleState` = ASSIGNING or ASSIGNED. If it does, an error is returned.
  * <p>
  Also, for reserved public IPs, the optional assignment part of this operation is
  * asynchronous. Poll the public IP's `lifecycleState` to determine if the assignment
  * succeeded.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param CreatePublicIpRequest
       * @return CreatePublicIpResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/CreatePublicIp.ts.html |here} to see how to use CreatePublicIp API.
       */
    createPublicIp(createPublicIpRequest: requests.CreatePublicIpRequest): Promise<responses.CreatePublicIpResponse>;
    /**
     * Creates a public IP pool.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreatePublicIpPoolRequest
     * @return CreatePublicIpPoolResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/CreatePublicIpPool.ts.html |here} to see how to use CreatePublicIpPool API.
     */
    createPublicIpPool(createPublicIpPoolRequest: requests.CreatePublicIpPoolRequest): Promise<responses.CreatePublicIpPoolResponse>;
    /**
     * Creates a new remote peering connection (RPC) for the specified DRG.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param CreateRemotePeeringConnectionRequest
     * @return CreateRemotePeeringConnectionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/CreateRemotePeeringConnection.ts.html |here} to see how to use CreateRemotePeeringConnection API.
     */
    createRemotePeeringConnection(createRemotePeeringConnectionRequest: requests.CreateRemotePeeringConnectionRequest): Promise<responses.CreateRemotePeeringConnectionResponse>;
    /**
       * Creates a new route table for the specified VCN. In the request you must also include at least one route
  * rule for the new route table. For information on the number of rules you can have in a route table, see
  * [Service Limits](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/servicelimits.htm). For general information about route
  * tables in your VCN and the types of targets you can use in route rules,
  * see [Route Tables](https://docs.cloud.oracle.com/iaas/Content/Network/Tasks/managingroutetables.htm).
  * <p>
  For the purposes of access control, you must provide the [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment where you want the route
  * table to reside. Notice that the route table doesn't have to be in the same compartment as the VCN, subnets,
  * or other Networking Service components. If you're not sure which compartment to use, put the route
  * table in the same compartment as the VCN. For more information about compartments and access control, see
  * [Overview of the IAM Service](https://docs.cloud.oracle.com/iaas/Content/Identity/Concepts/overview.htm). For information about OCIDs, see
  * [Resource Identifiers](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
  * <p>
  You may optionally specify a *display name* for the route table, otherwise a default is provided.
  * It does not have to be unique, and you can change it. Avoid entering confidential information.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param CreateRouteTableRequest
       * @return CreateRouteTableResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/CreateRouteTable.ts.html |here} to see how to use CreateRouteTable API.
       */
    createRouteTable(createRouteTableRequest: requests.CreateRouteTableRequest): Promise<responses.CreateRouteTableResponse>;
    /**
       * Creates a new security list for the specified VCN. For more information
  * about security lists, see [Security Lists](https://docs.cloud.oracle.com/iaas/Content/Network/Concepts/securitylists.htm).
  * For information on the number of rules you can have in a security list, see
  * [Service Limits](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/servicelimits.htm).
  * <p>
  For the purposes of access control, you must provide the [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment where you want the security
  * list to reside. Notice that the security list doesn't have to be in the same compartment as the VCN, subnets,
  * or other Networking Service components. If you're not sure which compartment to use, put the security
  * list in the same compartment as the VCN. For more information about compartments and access control, see
  * [Overview of the IAM Service](https://docs.cloud.oracle.com/iaas/Content/Identity/Concepts/overview.htm). For information about OCIDs, see
  * [Resource Identifiers](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
  * <p>
  You may optionally specify a *display name* for the security list, otherwise a default is provided.
  * It does not have to be unique, and you can change it. Avoid entering confidential information.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param CreateSecurityListRequest
       * @return CreateSecurityListResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/CreateSecurityList.ts.html |here} to see how to use CreateSecurityList API.
       */
    createSecurityList(createSecurityListRequest: requests.CreateSecurityListRequest): Promise<responses.CreateSecurityListResponse>;
    /**
       * Creates a new service gateway in the specified compartment.
  * <p>
  For the purposes of access control, you must provide the [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment where you want
  * the service gateway to reside. For more information about compartments and access control, see
  * [Overview of the IAM Service](https://docs.cloud.oracle.com/iaas/Content/Identity/Concepts/overview.htm).
  * For information about OCIDs, see [Resource Identifiers](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
  * <p>
  You may optionally specify a *display name* for the service gateway, otherwise a default is provided.
  * It does not have to be unique, and you can change it. Avoid entering confidential information.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param CreateServiceGatewayRequest
       * @return CreateServiceGatewayResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/CreateServiceGateway.ts.html |here} to see how to use CreateServiceGateway API.
       */
    createServiceGateway(createServiceGatewayRequest: requests.CreateServiceGatewayRequest): Promise<responses.CreateServiceGatewayResponse>;
    /**
       * Creates a new subnet in the specified VCN. You can't change the size of the subnet after creation,
  * so it's important to think about the size of subnets you need before creating them.
  * For more information, see [VCNs and Subnets](https://docs.cloud.oracle.com/iaas/Content/Network/Tasks/managingVCNs.htm).
  * For information on the number of subnets you can have in a VCN, see
  * [Service Limits](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/servicelimits.htm).
  * <p>
  For the purposes of access control, you must provide the [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment where you want the subnet
  * to reside. Notice that the subnet doesn't have to be in the same compartment as the VCN, route tables, or
  * other Networking Service components. If you're not sure which compartment to use, put the subnet in
  * the same compartment as the VCN. For more information about compartments and access control, see
  * [Overview of the IAM Service](https://docs.cloud.oracle.com/iaas/Content/Identity/Concepts/overview.htm). For information about OCIDs,
  * see [Resource Identifiers](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
  * <p>
  You may optionally associate a route table with the subnet. If you don't, the subnet will use the
  * VCN's default route table. For more information about route tables, see
  * [Route Tables](https://docs.cloud.oracle.com/iaas/Content/Network/Tasks/managingroutetables.htm).
  * <p>
  You may optionally associate a security list with the subnet. If you don't, the subnet will use the
  * VCN's default security list. For more information about security lists, see
  * [Security Lists](https://docs.cloud.oracle.com/iaas/Content/Network/Concepts/securitylists.htm).
  * <p>
  You may optionally associate a set of DHCP options with the subnet. If you don't, the subnet will use the
  * VCN's default set. For more information about DHCP options, see
  * [DHCP Options](https://docs.cloud.oracle.com/iaas/Content/Network/Tasks/managingDHCP.htm).
  * <p>
  You may optionally specify a *display name* for the subnet, otherwise a default is provided.
  * It does not have to be unique, and you can change it. Avoid entering confidential information.
  * <p>
  You can also add a DNS label for the subnet, which is required if you want the Internet and
  * VCN Resolver to resolve hostnames for instances in the subnet. For more information, see
  * [DNS in Your Virtual Cloud Network](https://docs.cloud.oracle.com/iaas/Content/Network/Concepts/dns.htm).
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param CreateSubnetRequest
       * @return CreateSubnetResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/CreateSubnet.ts.html |here} to see how to use CreateSubnet API.
       */
    createSubnet(createSubnetRequest: requests.CreateSubnetRequest): Promise<responses.CreateSubnetResponse>;
    /**
       * Creates a new virtual cloud network (VCN). For more information, see
  * [VCNs and Subnets](https://docs.cloud.oracle.com/iaas/Content/Network/Tasks/managingVCNs.htm).
  * <p>
  For the VCN, you specify a list of one or more IPv4 CIDR blocks that meet the following criteria:
  * <p>
  - The CIDR blocks must be valid.
  * - They must not overlap with each other or with the on-premises network CIDR block.
  * - The number of CIDR blocks does not exceed the limit of CIDR blocks allowed per VCN.
  * <p>
  For a CIDR block, Oracle recommends that you use one of the private IP address ranges specified in [RFC 1918](https://tools.ietf.org/html/rfc1918) (10.0.0.0/8, 172.16/12, and 192.168/16). Example:
  * 172.16.0.0/16. The CIDR blocks can range from /16 to /30.
  * <p>
  For the purposes of access control, you must provide the [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment where you want the VCN to
  * reside. Consult an Oracle Cloud Infrastructure administrator in your organization if you're not sure which
  * compartment to use. Notice that the VCN doesn't have to be in the same compartment as the subnets or other
  * Networking Service components. For more information about compartments and access control, see
  * [Overview of the IAM Service](https://docs.cloud.oracle.com/iaas/Content/Identity/Concepts/overview.htm). For information about OCIDs, see
  * [Resource Identifiers](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
  * <p>
  You may optionally specify a *display name* for the VCN, otherwise a default is provided. It does not have to
  * be unique, and you can change it. Avoid entering confidential information.
  * <p>
  You can also add a DNS label for the VCN, which is required if you want the instances to use the
  * Interent and VCN Resolver option for DNS in the VCN. For more information, see
  * [DNS in Your Virtual Cloud Network](https://docs.cloud.oracle.com/iaas/Content/Network/Concepts/dns.htm).
  * <p>
  The VCN automatically comes with a default route table, default security list, and default set of DHCP options.
  * The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) for each is returned in the response. You can't delete these default objects, but you can change their
  * contents (that is, change the route rules, security list rules, and so on).
  * <p>
  The VCN and subnets you create are not accessible until you attach an internet gateway or set up a Site-to-Site VPN
  * or FastConnect. For more information, see
  * [Overview of the Networking Service](https://docs.cloud.oracle.com/iaas/Content/Network/Concepts/overview.htm).
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param CreateVcnRequest
       * @return CreateVcnResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/CreateVcn.ts.html |here} to see how to use CreateVcn API.
       */
    createVcn(createVcnRequest: requests.CreateVcnRequest): Promise<responses.CreateVcnResponse>;
    /**
       * Creates a new virtual circuit to use with Oracle Cloud
  * Infrastructure FastConnect. For more information, see
  * [FastConnect Overview](https://docs.cloud.oracle.com/iaas/Content/Network/Concepts/fastconnect.htm).
  * <p>
  For the purposes of access control, you must provide the [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the
  * compartment where you want the virtual circuit to reside. If you're
  * not sure which compartment to use, put the virtual circuit in the
  * same compartment with the DRG it's using. For more information about
  * compartments and access control, see
  * [Overview of the IAM Service](https://docs.cloud.oracle.com/iaas/Content/Identity/Concepts/overview.htm).
  * For information about OCIDs, see
  * [Resource Identifiers](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
  * <p>
  You may optionally specify a *display name* for the virtual circuit.
  * It does not have to be unique, and you can change it. Avoid entering confidential information.
  * <p>
  **Important:** When creating a virtual circuit, you specify a DRG for
  * the traffic to flow through. Make sure you attach the DRG to your
  * VCN and confirm the VCN's routing sends traffic to the DRG. Otherwise
  * traffic will not flow. For more information, see
  * [Route Tables](https://docs.cloud.oracle.com/iaas/Content/Network/Tasks/managingroutetables.htm).
  *
       * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
       * @param CreateVirtualCircuitRequest
       * @return CreateVirtualCircuitResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/CreateVirtualCircuit.ts.html |here} to see how to use CreateVirtualCircuit API.
       */
    createVirtualCircuit(createVirtualCircuitRequest: requests.CreateVirtualCircuitRequest): Promise<responses.CreateVirtualCircuitResponse>;
    /**
     * Creates a VLAN in the specified VCN and the specified compartment.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateVlanRequest
     * @return CreateVlanResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/CreateVlan.ts.html |here} to see how to use CreateVlan API.
     */
    createVlan(createVlanRequest: requests.CreateVlanRequest): Promise<responses.CreateVlanResponse>;
    /**
       * Creates a virtual test access point (VTAP) in the specified compartment.
  * <p>
  For the purposes of access control, you must provide the [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment that contains the VTAP.
  * For more information about compartments and access control, see
  * [Overview of the IAM Service](https://docs.cloud.oracle.com/iaas/Content/Identity/Concepts/overview.htm).
  * For information about OCIDs, see [Resource Identifiers](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
  * <p>
  You may optionally specify a *display name* for the VTAP, otherwise a default is provided.
  * It does not have to be unique, and you can change it.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param CreateVtapRequest
       * @return CreateVtapResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/CreateVtap.ts.html |here} to see how to use CreateVtap API.
       */
    createVtap(createVtapRequest: requests.CreateVtapRequest): Promise<responses.CreateVtapResponse>;
    /**
     * Deletes the specified `ByoipRange` resource.
     * The resource must be in one of the following states: CREATING, PROVISIONED, ACTIVE, or FAILED.
     * It must not have any subranges currently allocated to a PublicIpPool object or the deletion will fail.
     * You must specify the [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
     * If the `ByoipRange` resource is currently in the PROVISIONED or ACTIVE state, it will be de-provisioned and then deleted.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteByoipRangeRequest
     * @return DeleteByoipRangeResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/DeleteByoipRange.ts.html |here} to see how to use DeleteByoipRange API.
     */
    deleteByoipRange(deleteByoipRangeRequest: requests.DeleteByoipRangeRequest): Promise<responses.DeleteByoipRangeResponse>;
    /**
     * Deletes the specified VTAP capture filter. This is an asynchronous operation. The VTAP capture filter's `lifecycleState` will
     * change to TERMINATING temporarily until the VTAP capture filter is completely removed.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteCaptureFilterRequest
     * @return DeleteCaptureFilterResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/DeleteCaptureFilter.ts.html |here} to see how to use DeleteCaptureFilter API.
     */
    deleteCaptureFilter(deleteCaptureFilterRequest: requests.DeleteCaptureFilterRequest): Promise<responses.DeleteCaptureFilterResponse>;
    /**
     * Deletes the specified CPE object. The CPE must not be connected to a DRG. This is an asynchronous
     * operation. The CPE's `lifecycleState` will change to TERMINATING temporarily until the CPE is completely
     * removed.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteCpeRequest
     * @return DeleteCpeResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/DeleteCpe.ts.html |here} to see how to use DeleteCpe API.
     */
    deleteCpe(deleteCpeRequest: requests.DeleteCpeRequest): Promise<responses.DeleteCpeResponse>;
    /**
     * Deletes the specified cross-connect. It must not be mapped to a
     * {@link VirtualCircuit}.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteCrossConnectRequest
     * @return DeleteCrossConnectResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/DeleteCrossConnect.ts.html |here} to see how to use DeleteCrossConnect API.
     */
    deleteCrossConnect(deleteCrossConnectRequest: requests.DeleteCrossConnectRequest): Promise<responses.DeleteCrossConnectResponse>;
    /**
     * Deletes the specified cross-connect group. It must not contain any
     * cross-connects, and it cannot be mapped to a
     * {@link VirtualCircuit}.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteCrossConnectGroupRequest
     * @return DeleteCrossConnectGroupResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/DeleteCrossConnectGroup.ts.html |here} to see how to use DeleteCrossConnectGroup API.
     */
    deleteCrossConnectGroup(deleteCrossConnectGroupRequest: requests.DeleteCrossConnectGroupRequest): Promise<responses.DeleteCrossConnectGroupResponse>;
    /**
       * Deletes the specified set of DHCP options, but only if it's not associated with a subnet. You can't delete a
  * VCN's default set of DHCP options.
  * <p>
  This is an asynchronous operation. The state of the set of options will switch to TERMINATING temporarily
  * until the set is completely removed.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param DeleteDhcpOptionsRequest
       * @return DeleteDhcpOptionsResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/DeleteDhcpOptions.ts.html |here} to see how to use DeleteDhcpOptions API.
       */
    deleteDhcpOptions(deleteDhcpOptionsRequest: requests.DeleteDhcpOptionsRequest): Promise<responses.DeleteDhcpOptionsResponse>;
    /**
     * Deletes the specified DRG. The DRG must not be attached to a VCN or be connected to your on-premise
     * network. Also, there must not be a route table that lists the DRG as a target. This is an asynchronous
     * operation. The DRG's `lifecycleState` will change to TERMINATING temporarily until the DRG is completely
     * removed.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteDrgRequest
     * @return DeleteDrgResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/DeleteDrg.ts.html |here} to see how to use DeleteDrg API.
     */
    deleteDrg(deleteDrgRequest: requests.DeleteDrgRequest): Promise<responses.DeleteDrgResponse>;
    /**
     * Detaches a DRG from a network resource by deleting the corresponding `DrgAttachment` resource. This is an asynchronous
     * operation. The attachment's `lifecycleState` will temporarily change to DETACHING until the attachment
     * is completely removed.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteDrgAttachmentRequest
     * @return DeleteDrgAttachmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/DeleteDrgAttachment.ts.html |here} to see how to use DeleteDrgAttachment API.
     */
    deleteDrgAttachment(deleteDrgAttachmentRequest: requests.DeleteDrgAttachmentRequest): Promise<responses.DeleteDrgAttachmentResponse>;
    /**
       * Deletes the specified route distribution. You can't delete a route distribution currently in use by a DRG attachment or DRG route table.
  * <p>
  Remove the DRG route distribution from a DRG attachment or DRG route table by using the \"RemoveExportDrgRouteDistribution\" or \"RemoveImportDrgRouteDistribution' operations.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param DeleteDrgRouteDistributionRequest
       * @return DeleteDrgRouteDistributionResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/DeleteDrgRouteDistribution.ts.html |here} to see how to use DeleteDrgRouteDistribution API.
       */
    deleteDrgRouteDistribution(deleteDrgRouteDistributionRequest: requests.DeleteDrgRouteDistributionRequest): Promise<responses.DeleteDrgRouteDistributionResponse>;
    /**
     * Deletes the specified DRG route table. There must not be any DRG attachments assigned.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteDrgRouteTableRequest
     * @return DeleteDrgRouteTableResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/DeleteDrgRouteTable.ts.html |here} to see how to use DeleteDrgRouteTable API.
     */
    deleteDrgRouteTable(deleteDrgRouteTableRequest: requests.DeleteDrgRouteTableRequest): Promise<responses.DeleteDrgRouteTableResponse>;
    /**
       * Deletes the specified IPSec connection. If your goal is to disable the Site-to-Site VPN between your VCN and
  * on-premises network, it's easiest to simply detach the DRG but keep all the Site-to-Site VPN components intact.
  * If you were to delete all the components and then later need to create an Site-to-Site VPN again, you would
  * need to configure your on-premises router again with the new information returned from
  * {@link #createIPSecConnection(CreateIPSecConnectionRequest) createIPSecConnection}.
  * <p>
  This is an asynchronous operation. The connection's `lifecycleState` will change to TERMINATING temporarily
  * until the connection is completely removed.
  *
       * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
       * @param DeleteIPSecConnectionRequest
       * @return DeleteIPSecConnectionResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/DeleteIPSecConnection.ts.html |here} to see how to use DeleteIPSecConnection API.
       */
    deleteIPSecConnection(deleteIPSecConnectionRequest: requests.DeleteIPSecConnectionRequest): Promise<responses.DeleteIPSecConnectionResponse>;
    /**
       * Deletes the specified internet gateway. The internet gateway does not have to be disabled, but
  * there must not be a route table that lists it as a target.
  * <p>
  This is an asynchronous operation. The gateway's `lifecycleState` will change to TERMINATING temporarily
  * until the gateway is completely removed.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param DeleteInternetGatewayRequest
       * @return DeleteInternetGatewayResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/DeleteInternetGateway.ts.html |here} to see how to use DeleteInternetGateway API.
       */
    deleteInternetGateway(deleteInternetGatewayRequest: requests.DeleteInternetGatewayRequest): Promise<responses.DeleteInternetGatewayResponse>;
    /**
     * Unassigns and deletes the specified IPv6. You must specify the object's [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
     * The IPv6 address is returned to the subnet's pool of available addresses.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteIpv6Request
     * @return DeleteIpv6Response
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/DeleteIpv6.ts.html |here} to see how to use DeleteIpv6 API.
     */
    deleteIpv6(deleteIpv6Request: requests.DeleteIpv6Request): Promise<responses.DeleteIpv6Response>;
    /**
       * Deletes the specified local peering gateway (LPG).
  * <p>
  This is an asynchronous operation; the local peering gateway's `lifecycleState` changes to TERMINATING temporarily
  * until the local peering gateway is completely removed.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param DeleteLocalPeeringGatewayRequest
       * @return DeleteLocalPeeringGatewayResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/DeleteLocalPeeringGateway.ts.html |here} to see how to use DeleteLocalPeeringGateway API.
       */
    deleteLocalPeeringGateway(deleteLocalPeeringGatewayRequest: requests.DeleteLocalPeeringGatewayRequest): Promise<responses.DeleteLocalPeeringGatewayResponse>;
    /**
       * Deletes the specified NAT gateway. The NAT gateway does not have to be disabled, but there
  * must not be a route rule that lists the NAT gateway as a target.
  * <p>
  This is an asynchronous operation. The NAT gateway's `lifecycleState` will change to
  * TERMINATING temporarily until the NAT gateway is completely removed.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param DeleteNatGatewayRequest
       * @return DeleteNatGatewayResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/DeleteNatGateway.ts.html |here} to see how to use DeleteNatGateway API.
       */
    deleteNatGateway(deleteNatGatewayRequest: requests.DeleteNatGatewayRequest): Promise<responses.DeleteNatGatewayResponse>;
    /**
       * Deletes the specified network security group. The group must not contain any VNICs.
  * <p>
  To get a list of the VNICs in a network security group, use
  * {@link #listNetworkSecurityGroupVnics(ListNetworkSecurityGroupVnicsRequest) listNetworkSecurityGroupVnics}.
  * Each returned {@link NetworkSecurityGroupVnic} object
  * contains both the [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the VNIC and the [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the VNIC's parent resource (for example,
  * the Compute instance that the VNIC is attached to).
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param DeleteNetworkSecurityGroupRequest
       * @return DeleteNetworkSecurityGroupResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/DeleteNetworkSecurityGroup.ts.html |here} to see how to use DeleteNetworkSecurityGroup API.
       */
    deleteNetworkSecurityGroup(deleteNetworkSecurityGroupRequest: requests.DeleteNetworkSecurityGroupRequest): Promise<responses.DeleteNetworkSecurityGroupResponse>;
    /**
       * Unassigns and deletes the specified private IP. You must
  * specify the object's [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm). The private IP address is returned to
  * the subnet's pool of available addresses.
  * <p>
  This operation cannot be used with primary private IPs, which are
  * automatically unassigned and deleted when the VNIC is terminated.
  * <p>
  **Important:** If a secondary private IP is the
  * [target of a route rule](https://docs.cloud.oracle.com/iaas/Content/Network/Tasks/managingroutetables.htm#privateip),
  * unassigning it from the VNIC causes that route rule to blackhole and the traffic
  * will be dropped.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param DeletePrivateIpRequest
       * @return DeletePrivateIpResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/DeletePrivateIp.ts.html |here} to see how to use DeletePrivateIp API.
       */
    deletePrivateIp(deletePrivateIpRequest: requests.DeletePrivateIpRequest): Promise<responses.DeletePrivateIpResponse>;
    /**
       * Unassigns and deletes the specified public IP (either ephemeral or reserved).
  * You must specify the object's [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm). The public IP address is returned to the
  * Oracle Cloud Infrastructure public IP pool.
  * <p>
  **Note:** You cannot update, unassign, or delete the public IP that Oracle automatically
  * assigned to an entity for you (such as a load balancer or NAT gateway). The public IP is
  * automatically deleted if the assigned entity is terminated.
  * <p>
  For an assigned reserved public IP, the initial unassignment portion of this operation
  * is asynchronous. Poll the public IP's `lifecycleState` to determine
  * if the operation succeeded.
  * <p>
  If you want to simply unassign a reserved public IP and return it to your pool
  * of reserved public IPs, instead use
  * {@link #updatePublicIp(UpdatePublicIpRequest) updatePublicIp}.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param DeletePublicIpRequest
       * @return DeletePublicIpResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/DeletePublicIp.ts.html |here} to see how to use DeletePublicIp API.
       */
    deletePublicIp(deletePublicIpRequest: requests.DeletePublicIpRequest): Promise<responses.DeletePublicIpResponse>;
    /**
     * Deletes the specified public IP pool.
     * To delete a public IP pool it must not have any active IP address allocations.
     * You must specify the object's [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) when deleting an IP pool.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeletePublicIpPoolRequest
     * @return DeletePublicIpPoolResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/DeletePublicIpPool.ts.html |here} to see how to use DeletePublicIpPool API.
     */
    deletePublicIpPool(deletePublicIpPoolRequest: requests.DeletePublicIpPoolRequest): Promise<responses.DeletePublicIpPoolResponse>;
    /**
       * Deletes the remote peering connection (RPC).
  * <p>
  This is an asynchronous operation; the RPC's `lifecycleState` changes to TERMINATING temporarily
  * until the RPC is completely removed.
  *
       * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
       * @param DeleteRemotePeeringConnectionRequest
       * @return DeleteRemotePeeringConnectionResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/DeleteRemotePeeringConnection.ts.html |here} to see how to use DeleteRemotePeeringConnection API.
       */
    deleteRemotePeeringConnection(deleteRemotePeeringConnectionRequest: requests.DeleteRemotePeeringConnectionRequest): Promise<responses.DeleteRemotePeeringConnectionResponse>;
    /**
       * Deletes the specified route table, but only if it's not associated with a subnet. You can't delete a
  * VCN's default route table.
  * <p>
  This is an asynchronous operation. The route table's `lifecycleState` will change to TERMINATING temporarily
  * until the route table is completely removed.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param DeleteRouteTableRequest
       * @return DeleteRouteTableResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/DeleteRouteTable.ts.html |here} to see how to use DeleteRouteTable API.
       */
    deleteRouteTable(deleteRouteTableRequest: requests.DeleteRouteTableRequest): Promise<responses.DeleteRouteTableResponse>;
    /**
       * Deletes the specified security list, but only if it's not associated with a subnet. You can't delete
  * a VCN's default security list.
  * <p>
  This is an asynchronous operation. The security list's `lifecycleState` will change to TERMINATING temporarily
  * until the security list is completely removed.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param DeleteSecurityListRequest
       * @return DeleteSecurityListResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/DeleteSecurityList.ts.html |here} to see how to use DeleteSecurityList API.
       */
    deleteSecurityList(deleteSecurityListRequest: requests.DeleteSecurityListRequest): Promise<responses.DeleteSecurityListResponse>;
    /**
     * Deletes the specified service gateway. There must not be a route table that lists the service
     * gateway as a target.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteServiceGatewayRequest
     * @return DeleteServiceGatewayResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/DeleteServiceGateway.ts.html |here} to see how to use DeleteServiceGateway API.
     */
    deleteServiceGateway(deleteServiceGatewayRequest: requests.DeleteServiceGatewayRequest): Promise<responses.DeleteServiceGatewayResponse>;
    /**
     * Deletes the specified subnet, but only if there are no instances in the subnet. This is an asynchronous
     * operation. The subnet's `lifecycleState` will change to TERMINATING temporarily. If there are any
     * instances in the subnet, the state will instead change back to AVAILABLE.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteSubnetRequest
     * @return DeleteSubnetResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/DeleteSubnet.ts.html |here} to see how to use DeleteSubnet API.
     */
    deleteSubnet(deleteSubnetRequest: requests.DeleteSubnetRequest): Promise<responses.DeleteSubnetResponse>;
    /**
       * Deletes the specified VCN. The VCN must be completely empty and have no attached gateways. This is an asynchronous
  * operation.
  * <p>
  A deleted VCN's `lifecycleState` changes to TERMINATING and then TERMINATED temporarily until the VCN is completely
  * removed. A completely removed VCN does not appear in the results of a `ListVcns` operation and can't be used in a
  * `GetVcn` operation.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param DeleteVcnRequest
       * @return DeleteVcnResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/DeleteVcn.ts.html |here} to see how to use DeleteVcn API.
       */
    deleteVcn(deleteVcnRequest: requests.DeleteVcnRequest): Promise<responses.DeleteVcnResponse>;
    /**
     * Deletes the specified virtual circuit.
     * <p>
     **Important:** If you're using FastConnect via a provider,
     * make sure to also terminate the connection with
     * the provider, or else the provider may continue to bill you.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param DeleteVirtualCircuitRequest
     * @return DeleteVirtualCircuitResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/DeleteVirtualCircuit.ts.html |here} to see how to use DeleteVirtualCircuit API.
     */
    deleteVirtualCircuit(deleteVirtualCircuitRequest: requests.DeleteVirtualCircuitRequest): Promise<responses.DeleteVirtualCircuitResponse>;
    /**
     * Deletes the specified VLAN, but only if there are no VNICs in the VLAN.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteVlanRequest
     * @return DeleteVlanResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/DeleteVlan.ts.html |here} to see how to use DeleteVlan API.
     */
    deleteVlan(deleteVlanRequest: requests.DeleteVlanRequest): Promise<responses.DeleteVlanResponse>;
    /**
     * Deletes the specified VTAP. This is an asynchronous operation. The VTAP's `lifecycleState` will change to
     * TERMINATING temporarily until the VTAP is completely removed.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteVtapRequest
     * @return DeleteVtapResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/DeleteVtap.ts.html |here} to see how to use DeleteVtap API.
     */
    deleteVtap(deleteVtapRequest: requests.DeleteVtapRequest): Promise<responses.DeleteVtapResponse>;
    /**
     * Removes the specified {@link Service} from the list of enabled
     * `Service` objects for the specified gateway. You do not need to remove any route
     * rules that specify this `Service` object's `cidrBlock` as the destination CIDR. However, consider
     * removing the rules if your intent is to permanently disable use of the `Service` through this
     * service gateway.
     * <p>
     **Note:** The `DetachServiceId` operation is an easy way to remove an individual `Service` from
     * the service gateway. Compare it with
     * {@link #updateServiceGateway(UpdateServiceGatewayRequest) updateServiceGateway}, which replaces
     * the entire existing list of enabled `Service` objects with the list that you provide in the
     * `Update` call. `UpdateServiceGateway` also lets you block all traffic through the service
     * gateway without having to remove each of the individual `Service` objects.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DetachServiceIdRequest
     * @return DetachServiceIdResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/DetachServiceId.ts.html |here} to see how to use DetachServiceId API.
     */
    detachServiceId(detachServiceIdRequest: requests.DetachServiceIdRequest): Promise<responses.DetachServiceIdResponse>;
    /**
     * Returns a complete list of DRG attachments that belong to a particular DRG.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetAllDrgAttachmentsRequest
     * @return GetAllDrgAttachmentsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetAllDrgAttachments.ts.html |here} to see how to use GetAllDrgAttachments API.
     */
    getAllDrgAttachments(getAllDrgAttachmentsRequest: requests.GetAllDrgAttachmentsRequest): Promise<responses.GetAllDrgAttachmentsResponse>;
    /**
     * NOTE: This function is deprecated in favor of getAllDrgAttachmentsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.DrgAttachmentInfo objects
     * contained in responses from the getAllDrgAttachments operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    getAllAllDrgAttachments(request: requests.GetAllDrgAttachmentsRequest): AsyncIterableIterator<model.DrgAttachmentInfo>;
    /**
     * NOTE: This function is deprecated in favor of getAllDrgAttachmentsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the getAllDrgAttachments operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    getAllAllDrgAttachmentsResponses(request: requests.GetAllDrgAttachmentsRequest): AsyncIterableIterator<responses.GetAllDrgAttachmentsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.DrgAttachmentInfo objects
     * contained in responses from the getAllDrgAttachments operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    getAllDrgAttachmentsRecordIterator(request: requests.GetAllDrgAttachmentsRequest): AsyncIterableIterator<model.DrgAttachmentInfo>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the getAllDrgAttachments operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    getAllDrgAttachmentsResponseIterator(request: requests.GetAllDrgAttachmentsRequest): AsyncIterableIterator<responses.GetAllDrgAttachmentsResponse>;
    /**
     * The parameters allowed for IKE IPSec tunnels.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetAllowedIkeIPSecParametersRequest
     * @return GetAllowedIkeIPSecParametersResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetAllowedIkeIPSecParameters.ts.html |here} to see how to use GetAllowedIkeIPSecParameters API.
     */
    getAllowedIkeIPSecParameters(getAllowedIkeIPSecParametersRequest: requests.GetAllowedIkeIPSecParametersRequest): Promise<responses.GetAllowedIkeIPSecParametersResponse>;
    /**
     * Gets the `ByoipRange` resource. You must specify the [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetByoipRangeRequest
     * @return GetByoipRangeResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetByoipRange.ts.html |here} to see how to use GetByoipRange API.
     */
    getByoipRange(getByoipRangeRequest: requests.GetByoipRangeRequest): Promise<responses.GetByoipRangeResponse>;
    /**
     * Gets information about the specified VTAP capture filter.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetCaptureFilterRequest
     * @return GetCaptureFilterResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetCaptureFilter.ts.html |here} to see how to use GetCaptureFilter API.
     */
    getCaptureFilter(getCaptureFilterRequest: requests.GetCaptureFilterRequest): Promise<responses.GetCaptureFilterResponse>;
    /**
     * Gets the specified CPE's information.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetCpeRequest
     * @return GetCpeResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetCpe.ts.html |here} to see how to use GetCpe API.
     */
    getCpe(getCpeRequest: requests.GetCpeRequest): Promise<responses.GetCpeResponse>;
    /**
       * Renders a set of CPE configuration content that can help a network engineer configure the actual
  * CPE device (for example, a hardware router) represented by the specified {@link Cpe}
  * object.
  * <p>
  The rendered content is specific to the type of CPE device (for example, Cisco ASA). Therefore the
  * {@link Cpe} must have the CPE's device type specified by the `cpeDeviceShapeId`
  * attribute. The content optionally includes answers that the customer provides (see
  * {@link #updateTunnelCpeDeviceConfig(UpdateTunnelCpeDeviceConfigRequest) updateTunnelCpeDeviceConfig}),
  * merged with a template of other information specific to the CPE device type.
  * <p>
  The operation returns configuration information for *all* of the
  * {@link IPSecConnection} objects that use the specified CPE.
  * Here are similar operations:
  * <p>
    * {@link #getIpsecCpeDeviceConfigContent(GetIpsecCpeDeviceConfigContentRequest) getIpsecCpeDeviceConfigContent}
  *   returns CPE configuration content for all IPSec tunnels in a single IPSec connection.
  *   * {@link #getTunnelCpeDeviceConfigContent(GetTunnelCpeDeviceConfigContentRequest) getTunnelCpeDeviceConfigContent}
  *   returns CPE configuration content for a specific IPSec tunnel in an IPSec connection.
  *
       * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
       * @param GetCpeDeviceConfigContentRequest
       * @return GetCpeDeviceConfigContentResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetCpeDeviceConfigContent.ts.html |here} to see how to use GetCpeDeviceConfigContent API.
       */
    getCpeDeviceConfigContent(getCpeDeviceConfigContentRequest: requests.GetCpeDeviceConfigContentRequest): Promise<responses.GetCpeDeviceConfigContentResponse>;
    /**
     * Gets the detailed information about the specified CPE device type. This might include a set of questions
     * that are specific to the particular CPE device type. The customer must supply answers to those questions
     * (see {@link #updateTunnelCpeDeviceConfig(UpdateTunnelCpeDeviceConfigRequest) updateTunnelCpeDeviceConfig}).
     * The service merges the answers with a template of other information for the CPE device type. The following
     * operations return the merged content:
     * <p>
     * {@link #getCpeDeviceConfigContent(GetCpeDeviceConfigContentRequest) getCpeDeviceConfigContent}
     *   * {@link #getIpsecCpeDeviceConfigContent(GetIpsecCpeDeviceConfigContentRequest) getIpsecCpeDeviceConfigContent}
     *   * {@link #getTunnelCpeDeviceConfigContent(GetTunnelCpeDeviceConfigContentRequest) getTunnelCpeDeviceConfigContent}
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetCpeDeviceShapeRequest
     * @return GetCpeDeviceShapeResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetCpeDeviceShape.ts.html |here} to see how to use GetCpeDeviceShape API.
     */
    getCpeDeviceShape(getCpeDeviceShapeRequest: requests.GetCpeDeviceShapeRequest): Promise<responses.GetCpeDeviceShapeResponse>;
    /**
     * Gets the specified cross-connect's information.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetCrossConnectRequest
     * @return GetCrossConnectResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetCrossConnect.ts.html |here} to see how to use GetCrossConnect API.
     */
    getCrossConnect(getCrossConnectRequest: requests.GetCrossConnectRequest): Promise<responses.GetCrossConnectResponse>;
    /**
     * Gets the specified cross-connect group's information.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetCrossConnectGroupRequest
     * @return GetCrossConnectGroupResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetCrossConnectGroup.ts.html |here} to see how to use GetCrossConnectGroup API.
     */
    getCrossConnectGroup(getCrossConnectGroupRequest: requests.GetCrossConnectGroupRequest): Promise<responses.GetCrossConnectGroupResponse>;
    /**
     * Gets the Letter of Authority for the specified cross-connect.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetCrossConnectLetterOfAuthorityRequest
     * @return GetCrossConnectLetterOfAuthorityResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetCrossConnectLetterOfAuthority.ts.html |here} to see how to use GetCrossConnectLetterOfAuthority API.
     */
    getCrossConnectLetterOfAuthority(getCrossConnectLetterOfAuthorityRequest: requests.GetCrossConnectLetterOfAuthorityRequest): Promise<responses.GetCrossConnectLetterOfAuthorityResponse>;
    /**
     * Gets the status of the specified cross-connect.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetCrossConnectStatusRequest
     * @return GetCrossConnectStatusResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetCrossConnectStatus.ts.html |here} to see how to use GetCrossConnectStatus API.
     */
    getCrossConnectStatus(getCrossConnectStatusRequest: requests.GetCrossConnectStatusRequest): Promise<responses.GetCrossConnectStatusResponse>;
    /**
     * Gets the specified set of DHCP options.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetDhcpOptionsRequest
     * @return GetDhcpOptionsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetDhcpOptions.ts.html |here} to see how to use GetDhcpOptions API.
     */
    getDhcpOptions(getDhcpOptionsRequest: requests.GetDhcpOptionsRequest): Promise<responses.GetDhcpOptionsResponse>;
    /**
     * Gets the specified DRG's information.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetDrgRequest
     * @return GetDrgResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetDrg.ts.html |here} to see how to use GetDrg API.
     */
    getDrg(getDrgRequest: requests.GetDrgRequest): Promise<responses.GetDrgResponse>;
    /**
     * Gets the `DrgAttachment` resource.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetDrgAttachmentRequest
     * @return GetDrgAttachmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetDrgAttachment.ts.html |here} to see how to use GetDrgAttachment API.
     */
    getDrgAttachment(getDrgAttachmentRequest: requests.GetDrgAttachmentRequest): Promise<responses.GetDrgAttachmentResponse>;
    /**
     * Gets the redundancy status for the specified DRG. For more information, see
     * [Redundancy Remedies](https://docs.cloud.oracle.com/iaas/Content/Network/Troubleshoot/drgredundancy.htm).
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetDrgRedundancyStatusRequest
     * @return GetDrgRedundancyStatusResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetDrgRedundancyStatus.ts.html |here} to see how to use GetDrgRedundancyStatus API.
     */
    getDrgRedundancyStatus(getDrgRedundancyStatusRequest: requests.GetDrgRedundancyStatusRequest): Promise<responses.GetDrgRedundancyStatusResponse>;
    /**
     * Gets the specified route distribution's information.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetDrgRouteDistributionRequest
     * @return GetDrgRouteDistributionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetDrgRouteDistribution.ts.html |here} to see how to use GetDrgRouteDistribution API.
     */
    getDrgRouteDistribution(getDrgRouteDistributionRequest: requests.GetDrgRouteDistributionRequest): Promise<responses.GetDrgRouteDistributionResponse>;
    /**
     * Gets the specified DRG route table's information.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetDrgRouteTableRequest
     * @return GetDrgRouteTableResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetDrgRouteTable.ts.html |here} to see how to use GetDrgRouteTable API.
     */
    getDrgRouteTable(getDrgRouteTableRequest: requests.GetDrgRouteTableRequest): Promise<responses.GetDrgRouteTableResponse>;
    /**
     * Gets the specified provider service.
     * For more information, see [FastConnect Overview](https://docs.cloud.oracle.com/iaas/Content/Network/Concepts/fastconnect.htm).
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetFastConnectProviderServiceRequest
     * @return GetFastConnectProviderServiceResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetFastConnectProviderService.ts.html |here} to see how to use GetFastConnectProviderService API.
     */
    getFastConnectProviderService(getFastConnectProviderServiceRequest: requests.GetFastConnectProviderServiceRequest): Promise<responses.GetFastConnectProviderServiceResponse>;
    /**
     * Gets the specified provider service key's information. Use this operation to validate a
     * provider service key. An invalid key returns a 404 error.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetFastConnectProviderServiceKeyRequest
     * @return GetFastConnectProviderServiceKeyResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetFastConnectProviderServiceKey.ts.html |here} to see how to use GetFastConnectProviderServiceKey API.
     */
    getFastConnectProviderServiceKey(getFastConnectProviderServiceKeyRequest: requests.GetFastConnectProviderServiceKeyRequest): Promise<responses.GetFastConnectProviderServiceKeyResponse>;
    /**
     * Gets the specified IPSec connection's basic information, including the static routes for the
     * on-premises router. If you want the status of the connection (whether it's up or down), use
     * {@link #getIPSecConnectionTunnel(GetIPSecConnectionTunnelRequest) getIPSecConnectionTunnel}.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetIPSecConnectionRequest
     * @return GetIPSecConnectionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetIPSecConnection.ts.html |here} to see how to use GetIPSecConnection API.
     */
    getIPSecConnection(getIPSecConnectionRequest: requests.GetIPSecConnectionRequest): Promise<responses.GetIPSecConnectionResponse>;
    /**
     * Deprecated. To get tunnel information, instead use:
     * <p>
     * {@link #getIPSecConnectionTunnel(GetIPSecConnectionTunnelRequest) getIPSecConnectionTunnel}
     * * {@link #getIPSecConnectionTunnelSharedSecret(GetIPSecConnectionTunnelSharedSecretRequest) getIPSecConnectionTunnelSharedSecret}
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetIPSecConnectionDeviceConfigRequest
     * @return GetIPSecConnectionDeviceConfigResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetIPSecConnectionDeviceConfig.ts.html |here} to see how to use GetIPSecConnectionDeviceConfig API.
     */
    getIPSecConnectionDeviceConfig(getIPSecConnectionDeviceConfigRequest: requests.GetIPSecConnectionDeviceConfigRequest): Promise<responses.GetIPSecConnectionDeviceConfigResponse>;
    /**
     * Deprecated. To get the tunnel status, instead use
     * {@link #getIPSecConnectionTunnel(GetIPSecConnectionTunnelRequest) getIPSecConnectionTunnel}.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetIPSecConnectionDeviceStatusRequest
     * @return GetIPSecConnectionDeviceStatusResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetIPSecConnectionDeviceStatus.ts.html |here} to see how to use GetIPSecConnectionDeviceStatus API.
     */
    getIPSecConnectionDeviceStatus(getIPSecConnectionDeviceStatusRequest: requests.GetIPSecConnectionDeviceStatusRequest): Promise<responses.GetIPSecConnectionDeviceStatusResponse>;
    /**
     * Gets the specified tunnel's information. The resulting object does not include the tunnel's
     * shared secret (pre-shared key). To retrieve that, use
     * {@link #getIPSecConnectionTunnelSharedSecret(GetIPSecConnectionTunnelSharedSecretRequest) getIPSecConnectionTunnelSharedSecret}.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetIPSecConnectionTunnelRequest
     * @return GetIPSecConnectionTunnelResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetIPSecConnectionTunnel.ts.html |here} to see how to use GetIPSecConnectionTunnel API.
     */
    getIPSecConnectionTunnel(getIPSecConnectionTunnelRequest: requests.GetIPSecConnectionTunnelRequest): Promise<responses.GetIPSecConnectionTunnelResponse>;
    /**
     * Gets the identified error for the specified IPSec tunnel ID.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetIPSecConnectionTunnelErrorRequest
     * @return GetIPSecConnectionTunnelErrorResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetIPSecConnectionTunnelError.ts.html |here} to see how to use GetIPSecConnectionTunnelError API.
     */
    getIPSecConnectionTunnelError(getIPSecConnectionTunnelErrorRequest: requests.GetIPSecConnectionTunnelErrorRequest): Promise<responses.GetIPSecConnectionTunnelErrorResponse>;
    /**
     * Gets the specified tunnel's shared secret (pre-shared key). To get other information
     * about the tunnel, use {@link #getIPSecConnectionTunnel(GetIPSecConnectionTunnelRequest) getIPSecConnectionTunnel}.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetIPSecConnectionTunnelSharedSecretRequest
     * @return GetIPSecConnectionTunnelSharedSecretResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetIPSecConnectionTunnelSharedSecret.ts.html |here} to see how to use GetIPSecConnectionTunnelSharedSecret API.
     */
    getIPSecConnectionTunnelSharedSecret(getIPSecConnectionTunnelSharedSecretRequest: requests.GetIPSecConnectionTunnelSharedSecretRequest): Promise<responses.GetIPSecConnectionTunnelSharedSecretResponse>;
    /**
     * Gets the specified internet gateway's information.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetInternetGatewayRequest
     * @return GetInternetGatewayResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetInternetGateway.ts.html |here} to see how to use GetInternetGateway API.
     */
    getInternetGateway(getInternetGatewayRequest: requests.GetInternetGatewayRequest): Promise<responses.GetInternetGatewayResponse>;
    /**
       * Renders a set of CPE configuration content for the specified IPSec connection (for all the
  * tunnels in the connection). The content helps a network engineer configure the actual CPE
  * device (for example, a hardware router) that the specified IPSec connection terminates on.
  * <p>
  The rendered content is specific to the type of CPE device (for example, Cisco ASA). Therefore the
  * {@link Cpe} used by the specified {@link IPSecConnection}
  * must have the CPE's device type specified by the `cpeDeviceShapeId` attribute. The content
  * optionally includes answers that the customer provides (see
  * {@link #updateTunnelCpeDeviceConfig(UpdateTunnelCpeDeviceConfigRequest) updateTunnelCpeDeviceConfig}),
  * merged with a template of other information specific to the CPE device type.
  * <p>
  The operation returns configuration information for all tunnels in the single specified
  * {@link IPSecConnection} object. Here are other similar
  * operations:
  * <p>
    * {@link #getTunnelCpeDeviceConfigContent(GetTunnelCpeDeviceConfigContentRequest) getTunnelCpeDeviceConfigContent}
  *   returns CPE configuration content for a specific tunnel within an IPSec connection.
  *   * {@link #getCpeDeviceConfigContent(GetCpeDeviceConfigContentRequest) getCpeDeviceConfigContent}
  *   returns CPE configuration content for *all* IPSec connections that use a specific CPE.
  *
       * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
       * @param GetIpsecCpeDeviceConfigContentRequest
       * @return GetIpsecCpeDeviceConfigContentResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetIpsecCpeDeviceConfigContent.ts.html |here} to see how to use GetIpsecCpeDeviceConfigContent API.
       */
    getIpsecCpeDeviceConfigContent(getIpsecCpeDeviceConfigContentRequest: requests.GetIpsecCpeDeviceConfigContentRequest): Promise<responses.GetIpsecCpeDeviceConfigContentResponse>;
    /**
     * Gets the specified IPv6. You must specify the object's [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
     * Alternatively, you can get the object by using
     * {@link #listIpv6s(ListIpv6sRequest) listIpv6s}
     * with the IPv6 address (for example, 2001:0db8:0123:1111:98fe:dcba:9876:4321) and subnet [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetIpv6Request
     * @return GetIpv6Response
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetIpv6.ts.html |here} to see how to use GetIpv6 API.
     */
    getIpv6(getIpv6Request: requests.GetIpv6Request): Promise<responses.GetIpv6Response>;
    /**
     * Gets the specified local peering gateway's information.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetLocalPeeringGatewayRequest
     * @return GetLocalPeeringGatewayResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetLocalPeeringGateway.ts.html |here} to see how to use GetLocalPeeringGateway API.
     */
    getLocalPeeringGateway(getLocalPeeringGatewayRequest: requests.GetLocalPeeringGatewayRequest): Promise<responses.GetLocalPeeringGatewayResponse>;
    /**
     * Gets the specified NAT gateway's information.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetNatGatewayRequest
     * @return GetNatGatewayResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetNatGateway.ts.html |here} to see how to use GetNatGateway API.
     */
    getNatGateway(getNatGatewayRequest: requests.GetNatGatewayRequest): Promise<responses.GetNatGatewayResponse>;
    /**
       * Gets the specified network security group's information.
  * <p>
  To list the VNICs in an NSG, see
  * {@link #listNetworkSecurityGroupVnics(ListNetworkSecurityGroupVnicsRequest) listNetworkSecurityGroupVnics}.
  * <p>
  To list the security rules in an NSG, see
  * {@link #listNetworkSecurityGroupSecurityRules(ListNetworkSecurityGroupSecurityRulesRequest) listNetworkSecurityGroupSecurityRules}.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param GetNetworkSecurityGroupRequest
       * @return GetNetworkSecurityGroupResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetNetworkSecurityGroup.ts.html |here} to see how to use GetNetworkSecurityGroup API.
       */
    getNetworkSecurityGroup(getNetworkSecurityGroupRequest: requests.GetNetworkSecurityGroupRequest): Promise<responses.GetNetworkSecurityGroupResponse>;
    /**
     * Gets a virtual networking topology for the current region.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetNetworkingTopologyRequest
     * @return GetNetworkingTopologyResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetNetworkingTopology.ts.html |here} to see how to use GetNetworkingTopology API.
     */
    getNetworkingTopology(getNetworkingTopologyRequest: requests.GetNetworkingTopologyRequest): Promise<responses.GetNetworkingTopologyResponse>;
    /**
     * Gets the specified private IP. You must specify the object's [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
     * Alternatively, you can get the object by using
     * {@link #listPrivateIps(ListPrivateIpsRequest) listPrivateIps}
     * with the private IP address (for example, 10.0.3.3) and subnet [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetPrivateIpRequest
     * @return GetPrivateIpResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetPrivateIp.ts.html |here} to see how to use GetPrivateIp API.
     */
    getPrivateIp(getPrivateIpRequest: requests.GetPrivateIpRequest): Promise<responses.GetPrivateIpResponse>;
    /**
       * Gets the specified public IP. You must specify the object's [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
  * <p>
  Alternatively, you can get the object by using {@link #getPublicIpByIpAddress(GetPublicIpByIpAddressRequest) getPublicIpByIpAddress}
  * with the public IP address (for example, 203.0.113.2).
  * <p>
  Or you can use {@link #getPublicIpByPrivateIpId(GetPublicIpByPrivateIpIdRequest) getPublicIpByPrivateIpId}
  * with the [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the private IP that the public IP is assigned to.
  * <p>
  **Note:** If you're fetching a reserved public IP that is in the process of being
  * moved to a different private IP, the service returns the public IP object with
  * `lifecycleState` = ASSIGNING and `assignedEntityId` = [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the target private IP.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param GetPublicIpRequest
       * @return GetPublicIpResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetPublicIp.ts.html |here} to see how to use GetPublicIp API.
       */
    getPublicIp(getPublicIpRequest: requests.GetPublicIpRequest): Promise<responses.GetPublicIpResponse>;
    /**
     * Gets the public IP based on the public IP address (for example, 203.0.113.2).
     * <p>
     **Note:** If you're fetching a reserved public IP that is in the process of being
     * moved to a different private IP, the service returns the public IP object with
     * `lifecycleState` = ASSIGNING and `assignedEntityId` = [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the target private IP.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetPublicIpByIpAddressRequest
     * @return GetPublicIpByIpAddressResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetPublicIpByIpAddress.ts.html |here} to see how to use GetPublicIpByIpAddress API.
     */
    getPublicIpByIpAddress(getPublicIpByIpAddressRequest: requests.GetPublicIpByIpAddressRequest): Promise<responses.GetPublicIpByIpAddressResponse>;
    /**
     * Gets the public IP assigned to the specified private IP. You must specify the OCID
     * of the private IP. If no public IP is assigned, a 404 is returned.
     * <p>
     **Note:** If you're fetching a reserved public IP that is in the process of being
     * moved to a different private IP, and you provide the [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the original private
     * IP, this operation returns a 404. If you instead provide the [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the target
     * private IP, or if you instead call
     * {@link #getPublicIp(GetPublicIpRequest) getPublicIp} or
     * {@link #getPublicIpByIpAddress(GetPublicIpByIpAddressRequest) getPublicIpByIpAddress}, the
     * service returns the public IP object with `lifecycleState` = ASSIGNING and
     * `assignedEntityId` = [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the target private IP.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetPublicIpByPrivateIpIdRequest
     * @return GetPublicIpByPrivateIpIdResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetPublicIpByPrivateIpId.ts.html |here} to see how to use GetPublicIpByPrivateIpId API.
     */
    getPublicIpByPrivateIpId(getPublicIpByPrivateIpIdRequest: requests.GetPublicIpByPrivateIpIdRequest): Promise<responses.GetPublicIpByPrivateIpIdResponse>;
    /**
     * Gets the specified `PublicIpPool` object. You must specify the object's [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetPublicIpPoolRequest
     * @return GetPublicIpPoolResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetPublicIpPool.ts.html |here} to see how to use GetPublicIpPool API.
     */
    getPublicIpPool(getPublicIpPoolRequest: requests.GetPublicIpPoolRequest): Promise<responses.GetPublicIpPoolResponse>;
    /**
     * Get the specified remote peering connection's information.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetRemotePeeringConnectionRequest
     * @return GetRemotePeeringConnectionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetRemotePeeringConnection.ts.html |here} to see how to use GetRemotePeeringConnection API.
     */
    getRemotePeeringConnection(getRemotePeeringConnectionRequest: requests.GetRemotePeeringConnectionRequest): Promise<responses.GetRemotePeeringConnectionResponse>;
    /**
     * Gets the `IpInventory` resource.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetResourceIpInventoryRequest
     * @return GetResourceIpInventoryResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetResourceIpInventory.ts.html |here} to see how to use GetResourceIpInventory API.
     */
    getResourceIpInventory(getResourceIpInventoryRequest: requests.GetResourceIpInventoryRequest): Promise<responses.GetResourceIpInventoryResponse>;
    /**
     * Gets the specified route table's information.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetRouteTableRequest
     * @return GetRouteTableResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetRouteTable.ts.html |here} to see how to use GetRouteTable API.
     */
    getRouteTable(getRouteTableRequest: requests.GetRouteTableRequest): Promise<responses.GetRouteTableResponse>;
    /**
     * Gets the specified security list's information.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetSecurityListRequest
     * @return GetSecurityListResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetSecurityList.ts.html |here} to see how to use GetSecurityList API.
     */
    getSecurityList(getSecurityListRequest: requests.GetSecurityListRequest): Promise<responses.GetSecurityListResponse>;
    /**
     * Gets the specified {@link Service} object.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetServiceRequest
     * @return GetServiceResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetService.ts.html |here} to see how to use GetService API.
     */
    getService(getServiceRequest: requests.GetServiceRequest): Promise<responses.GetServiceResponse>;
    /**
     * Gets the specified service gateway's information.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetServiceGatewayRequest
     * @return GetServiceGatewayResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetServiceGateway.ts.html |here} to see how to use GetServiceGateway API.
     */
    getServiceGateway(getServiceGatewayRequest: requests.GetServiceGatewayRequest): Promise<responses.GetServiceGatewayResponse>;
    /**
     * Gets the specified subnet's information.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetSubnetRequest
     * @return GetSubnetResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetSubnet.ts.html |here} to see how to use GetSubnet API.
     */
    getSubnet(getSubnetRequest: requests.GetSubnetRequest): Promise<responses.GetSubnetResponse>;
    /**
     * Gets the CIDR utilization data of the specified subnet. Specify the [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetSubnetCidrUtilizationRequest
     * @return GetSubnetCidrUtilizationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetSubnetCidrUtilization.ts.html |here} to see how to use GetSubnetCidrUtilization API.
     */
    getSubnetCidrUtilization(getSubnetCidrUtilizationRequest: requests.GetSubnetCidrUtilizationRequest): Promise<responses.GetSubnetCidrUtilizationResponse>;
    /**
     * Gets the IP Inventory data of the specified subnet. Specify the [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetSubnetIpInventoryRequest
     * @return GetSubnetIpInventoryResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetSubnetIpInventory.ts.html |here} to see how to use GetSubnetIpInventory API.
     */
    getSubnetIpInventory(getSubnetIpInventoryRequest: requests.GetSubnetIpInventoryRequest): Promise<responses.GetSubnetIpInventoryResponse>;
    /**
     * Gets a topology for a given subnet.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetSubnetTopologyRequest
     * @return GetSubnetTopologyResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetSubnetTopology.ts.html |here} to see how to use GetSubnetTopology API.
     */
    getSubnetTopology(getSubnetTopologyRequest: requests.GetSubnetTopologyRequest): Promise<responses.GetSubnetTopologyResponse>;
    /**
     * Gets the set of CPE configuration answers for the tunnel, which the customer provided in
     * {@link #updateTunnelCpeDeviceConfig(UpdateTunnelCpeDeviceConfigRequest) updateTunnelCpeDeviceConfig}.
     * To get the full set of content for the tunnel (any answers merged with the template of other
     * information specific to the CPE device type), use
     * {@link #getTunnelCpeDeviceConfigContent(GetTunnelCpeDeviceConfigContentRequest) getTunnelCpeDeviceConfigContent}.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetTunnelCpeDeviceConfigRequest
     * @return GetTunnelCpeDeviceConfigResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetTunnelCpeDeviceConfig.ts.html |here} to see how to use GetTunnelCpeDeviceConfig API.
     */
    getTunnelCpeDeviceConfig(getTunnelCpeDeviceConfigRequest: requests.GetTunnelCpeDeviceConfigRequest): Promise<responses.GetTunnelCpeDeviceConfigResponse>;
    /**
       * Renders a set of CPE configuration content for the specified IPSec tunnel. The content helps a
  * network engineer configure the actual CPE device (for example, a hardware router) that the specified
  * IPSec tunnel terminates on.
  * <p>
  The rendered content is specific to the type of CPE device (for example, Cisco ASA). Therefore the
  * {@link Cpe} used by the specified {@link IPSecConnection}
  * must have the CPE's device type specified by the `cpeDeviceShapeId` attribute. The content
  * optionally includes answers that the customer provides (see
  * {@link #updateTunnelCpeDeviceConfig(UpdateTunnelCpeDeviceConfigRequest) updateTunnelCpeDeviceConfig}),
  * merged with a template of other information specific to the CPE device type.
  * <p>
  The operation returns configuration information for only the specified IPSec tunnel.
  * Here are other similar operations:
  * <p>
    * {@link #getIpsecCpeDeviceConfigContent(GetIpsecCpeDeviceConfigContentRequest) getIpsecCpeDeviceConfigContent}
  *   returns CPE configuration content for all tunnels in a single IPSec connection.
  *   * {@link #getCpeDeviceConfigContent(GetCpeDeviceConfigContentRequest) getCpeDeviceConfigContent}
  *   returns CPE configuration content for *all* IPSec connections that use a specific CPE.
  *
       * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
       * @param GetTunnelCpeDeviceConfigContentRequest
       * @return GetTunnelCpeDeviceConfigContentResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetTunnelCpeDeviceConfigContent.ts.html |here} to see how to use GetTunnelCpeDeviceConfigContent API.
       */
    getTunnelCpeDeviceConfigContent(getTunnelCpeDeviceConfigContentRequest: requests.GetTunnelCpeDeviceConfigContentRequest): Promise<responses.GetTunnelCpeDeviceConfigContentResponse>;
    /**
     * Returns the DRG upgrade status. The status can be not updated, in progress, or updated. Also indicates how much of the upgrade is completed.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetUpgradeStatusRequest
     * @return GetUpgradeStatusResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetUpgradeStatus.ts.html |here} to see how to use GetUpgradeStatus API.
     */
    getUpgradeStatus(getUpgradeStatusRequest: requests.GetUpgradeStatusRequest): Promise<responses.GetUpgradeStatusResponse>;
    /**
     * Gets the specified VCN's information.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetVcnRequest
     * @return GetVcnResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetVcn.ts.html |here} to see how to use GetVcn API.
     */
    getVcn(getVcnRequest: requests.GetVcnRequest): Promise<responses.GetVcnResponse>;
    /**
     * Get the associated DNS resolver information with a vcn
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetVcnDnsResolverAssociationRequest
     * @return GetVcnDnsResolverAssociationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetVcnDnsResolverAssociation.ts.html |here} to see how to use GetVcnDnsResolverAssociation API.
     */
    getVcnDnsResolverAssociation(getVcnDnsResolverAssociationRequest: requests.GetVcnDnsResolverAssociationRequest): Promise<responses.GetVcnDnsResolverAssociationResponse>;
    /**
     * Gets the CIDR overlap information of the specified VCN in selected compartments. Specify the [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetVcnOverlapRequest
     * @return GetVcnOverlapResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetVcnOverlap.ts.html |here} to see how to use GetVcnOverlap API.
     */
    getVcnOverlap(getVcnOverlapRequest: requests.GetVcnOverlapRequest): Promise<responses.GetVcnOverlapResponse>;
    /**
     * Gets a virtual network topology for a given VCN.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetVcnTopologyRequest
     * @return GetVcnTopologyResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetVcnTopology.ts.html |here} to see how to use GetVcnTopology API.
     */
    getVcnTopology(getVcnTopologyRequest: requests.GetVcnTopologyRequest): Promise<responses.GetVcnTopologyResponse>;
    /**
     * Gets the specified virtual circuit's information.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param GetVirtualCircuitRequest
     * @return GetVirtualCircuitResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetVirtualCircuit.ts.html |here} to see how to use GetVirtualCircuit API.
     */
    getVirtualCircuit(getVirtualCircuitRequest: requests.GetVirtualCircuitRequest): Promise<responses.GetVirtualCircuitResponse>;
    /**
     * Gets the specified VLAN's information.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetVlanRequest
     * @return GetVlanResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetVlan.ts.html |here} to see how to use GetVlan API.
     */
    getVlan(getVlanRequest: requests.GetVlanRequest): Promise<responses.GetVlanResponse>;
    /**
     * Gets the information for the specified virtual network interface card (VNIC).
     * You can get the VNIC [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) from the
     * {@link #listVnicAttachments(ListVnicAttachmentsRequest) listVnicAttachments}
     * operation.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetVnicRequest
     * @return GetVnicResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetVnic.ts.html |here} to see how to use GetVnic API.
     */
    getVnic(getVnicRequest: requests.GetVnicRequest): Promise<responses.GetVnicResponse>;
    /**
     * Gets the specified `Vtap` resource.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetVtapRequest
     * @return GetVtapResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/GetVtap.ts.html |here} to see how to use GetVtap API.
     */
    getVtap(getVtapRequest: requests.GetVtapRequest): Promise<responses.GetVtapResponse>;
    /**
     * Lists the regions that support remote VCN peering (which is peering across regions).
     * For more information, see [VCN Peering](https://docs.cloud.oracle.com/iaas/Content/Network/Tasks/VCNpeering.htm).
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListAllowedPeerRegionsForRemotePeeringRequest
     * @return ListAllowedPeerRegionsForRemotePeeringResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ListAllowedPeerRegionsForRemotePeering.ts.html |here} to see how to use ListAllowedPeerRegionsForRemotePeering API.
     */
    listAllowedPeerRegionsForRemotePeering(listAllowedPeerRegionsForRemotePeeringRequest: requests.ListAllowedPeerRegionsForRemotePeeringRequest): Promise<responses.ListAllowedPeerRegionsForRemotePeeringResponse>;
    /**
     * Lists the subranges of a BYOIP CIDR block currently allocated to an IP pool.
     * Each `ByoipAllocatedRange` object also lists the IP pool where it is allocated.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListByoipAllocatedRangesRequest
     * @return ListByoipAllocatedRangesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ListByoipAllocatedRanges.ts.html |here} to see how to use ListByoipAllocatedRanges API.
     */
    listByoipAllocatedRanges(listByoipAllocatedRangesRequest: requests.ListByoipAllocatedRangesRequest): Promise<responses.ListByoipAllocatedRangesResponse>;
    /**
     * Lists the `ByoipRange` resources in the specified compartment.
     * You can filter the list using query parameters.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListByoipRangesRequest
     * @return ListByoipRangesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ListByoipRanges.ts.html |here} to see how to use ListByoipRanges API.
     */
    listByoipRanges(listByoipRangesRequest: requests.ListByoipRangesRequest): Promise<responses.ListByoipRangesResponse>;
    /**
     * Lists the capture filters in the specified compartment.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListCaptureFiltersRequest
     * @return ListCaptureFiltersResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ListCaptureFilters.ts.html |here} to see how to use ListCaptureFilters API.
     */
    listCaptureFilters(listCaptureFiltersRequest: requests.ListCaptureFiltersRequest): Promise<responses.ListCaptureFiltersResponse>;
    /**
     * NOTE: This function is deprecated in favor of listCaptureFiltersRecordIterator function.
     * Creates a new async iterator which will iterate over the models.CaptureFilter objects
     * contained in responses from the listCaptureFilters operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllCaptureFilters(request: requests.ListCaptureFiltersRequest): AsyncIterableIterator<model.CaptureFilter>;
    /**
     * NOTE: This function is deprecated in favor of listCaptureFiltersResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listCaptureFilters operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllCaptureFiltersResponses(request: requests.ListCaptureFiltersRequest): AsyncIterableIterator<responses.ListCaptureFiltersResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.CaptureFilter objects
     * contained in responses from the listCaptureFilters operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listCaptureFiltersRecordIterator(request: requests.ListCaptureFiltersRequest): AsyncIterableIterator<model.CaptureFilter>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listCaptureFilters operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listCaptureFiltersResponseIterator(request: requests.ListCaptureFiltersRequest): AsyncIterableIterator<responses.ListCaptureFiltersResponse>;
    /**
       * Lists the CPE device types that the Networking service provides CPE configuration
  * content for (example: Cisco ASA). The content helps a network engineer configure
  * the actual CPE device represented by a {@link Cpe} object.
  * <p>
  If you want to generate CPE configuration content for one of the returned CPE device types,
  * ensure that the {@link Cpe} object's `cpeDeviceShapeId` attribute is set
  * to the CPE device type's [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) (returned by this operation).
  * <p>
  For information about generating CPE configuration content, see these operations:
  * <p>
    * {@link #getCpeDeviceConfigContent(GetCpeDeviceConfigContentRequest) getCpeDeviceConfigContent}
  *   * {@link #getIpsecCpeDeviceConfigContent(GetIpsecCpeDeviceConfigContentRequest) getIpsecCpeDeviceConfigContent}
  *   * {@link #getTunnelCpeDeviceConfigContent(GetTunnelCpeDeviceConfigContentRequest) getTunnelCpeDeviceConfigContent}
  *
       * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
       * @param ListCpeDeviceShapesRequest
       * @return ListCpeDeviceShapesResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ListCpeDeviceShapes.ts.html |here} to see how to use ListCpeDeviceShapes API.
       */
    listCpeDeviceShapes(listCpeDeviceShapesRequest: requests.ListCpeDeviceShapesRequest): Promise<responses.ListCpeDeviceShapesResponse>;
    /**
     * NOTE: This function is deprecated in favor of listCpeDeviceShapesRecordIterator function.
     * Creates a new async iterator which will iterate over the models.CpeDeviceShapeSummary objects
     * contained in responses from the listCpeDeviceShapes operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllCpeDeviceShapes(request: requests.ListCpeDeviceShapesRequest): AsyncIterableIterator<model.CpeDeviceShapeSummary>;
    /**
     * NOTE: This function is deprecated in favor of listCpeDeviceShapesResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listCpeDeviceShapes operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllCpeDeviceShapesResponses(request: requests.ListCpeDeviceShapesRequest): AsyncIterableIterator<responses.ListCpeDeviceShapesResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.CpeDeviceShapeSummary objects
     * contained in responses from the listCpeDeviceShapes operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listCpeDeviceShapesRecordIterator(request: requests.ListCpeDeviceShapesRequest): AsyncIterableIterator<model.CpeDeviceShapeSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listCpeDeviceShapes operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listCpeDeviceShapesResponseIterator(request: requests.ListCpeDeviceShapesRequest): AsyncIterableIterator<responses.ListCpeDeviceShapesResponse>;
    /**
     * Lists the customer-premises equipment objects (CPEs) in the specified compartment.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListCpesRequest
     * @return ListCpesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ListCpes.ts.html |here} to see how to use ListCpes API.
     */
    listCpes(listCpesRequest: requests.ListCpesRequest): Promise<responses.ListCpesResponse>;
    /**
     * NOTE: This function is deprecated in favor of listCpesRecordIterator function.
     * Creates a new async iterator which will iterate over the models.Cpe objects
     * contained in responses from the listCpes operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllCpes(request: requests.ListCpesRequest): AsyncIterableIterator<model.Cpe>;
    /**
     * NOTE: This function is deprecated in favor of listCpesResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listCpes operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllCpesResponses(request: requests.ListCpesRequest): AsyncIterableIterator<responses.ListCpesResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.Cpe objects
     * contained in responses from the listCpes operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listCpesRecordIterator(request: requests.ListCpesRequest): AsyncIterableIterator<model.Cpe>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listCpes operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listCpesResponseIterator(request: requests.ListCpesRequest): AsyncIterableIterator<responses.ListCpesResponse>;
    /**
     * Lists the cross-connect groups in the specified compartment.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListCrossConnectGroupsRequest
     * @return ListCrossConnectGroupsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ListCrossConnectGroups.ts.html |here} to see how to use ListCrossConnectGroups API.
     */
    listCrossConnectGroups(listCrossConnectGroupsRequest: requests.ListCrossConnectGroupsRequest): Promise<responses.ListCrossConnectGroupsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listCrossConnectGroupsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.CrossConnectGroup objects
     * contained in responses from the listCrossConnectGroups operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllCrossConnectGroups(request: requests.ListCrossConnectGroupsRequest): AsyncIterableIterator<model.CrossConnectGroup>;
    /**
     * NOTE: This function is deprecated in favor of listCrossConnectGroupsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listCrossConnectGroups operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllCrossConnectGroupsResponses(request: requests.ListCrossConnectGroupsRequest): AsyncIterableIterator<responses.ListCrossConnectGroupsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.CrossConnectGroup objects
     * contained in responses from the listCrossConnectGroups operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listCrossConnectGroupsRecordIterator(request: requests.ListCrossConnectGroupsRequest): AsyncIterableIterator<model.CrossConnectGroup>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listCrossConnectGroups operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listCrossConnectGroupsResponseIterator(request: requests.ListCrossConnectGroupsRequest): AsyncIterableIterator<responses.ListCrossConnectGroupsResponse>;
    /**
     * Lists the available FastConnect locations for cross-connect installation. You need
     * this information so you can specify your desired location when you create a cross-connect.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListCrossConnectLocationsRequest
     * @return ListCrossConnectLocationsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ListCrossConnectLocations.ts.html |here} to see how to use ListCrossConnectLocations API.
     */
    listCrossConnectLocations(listCrossConnectLocationsRequest: requests.ListCrossConnectLocationsRequest): Promise<responses.ListCrossConnectLocationsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listCrossConnectLocationsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.CrossConnectLocation objects
     * contained in responses from the listCrossConnectLocations operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllCrossConnectLocations(request: requests.ListCrossConnectLocationsRequest): AsyncIterableIterator<model.CrossConnectLocation>;
    /**
     * NOTE: This function is deprecated in favor of listCrossConnectLocationsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listCrossConnectLocations operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllCrossConnectLocationsResponses(request: requests.ListCrossConnectLocationsRequest): AsyncIterableIterator<responses.ListCrossConnectLocationsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.CrossConnectLocation objects
     * contained in responses from the listCrossConnectLocations operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listCrossConnectLocationsRecordIterator(request: requests.ListCrossConnectLocationsRequest): AsyncIterableIterator<model.CrossConnectLocation>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listCrossConnectLocations operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listCrossConnectLocationsResponseIterator(request: requests.ListCrossConnectLocationsRequest): AsyncIterableIterator<responses.ListCrossConnectLocationsResponse>;
    /**
     * Lists the Cross Connect mapping Details for the specified
     * virtual circuit.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListCrossConnectMappingsRequest
     * @return ListCrossConnectMappingsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ListCrossConnectMappings.ts.html |here} to see how to use ListCrossConnectMappings API.
     */
    listCrossConnectMappings(listCrossConnectMappingsRequest: requests.ListCrossConnectMappingsRequest): Promise<responses.ListCrossConnectMappingsResponse>;
    /**
     * Lists the cross-connects in the specified compartment. You can filter the list
     * by specifying the [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of a cross-connect group.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListCrossConnectsRequest
     * @return ListCrossConnectsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ListCrossConnects.ts.html |here} to see how to use ListCrossConnects API.
     */
    listCrossConnects(listCrossConnectsRequest: requests.ListCrossConnectsRequest): Promise<responses.ListCrossConnectsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listCrossConnectsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.CrossConnect objects
     * contained in responses from the listCrossConnects operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllCrossConnects(request: requests.ListCrossConnectsRequest): AsyncIterableIterator<model.CrossConnect>;
    /**
     * NOTE: This function is deprecated in favor of listCrossConnectsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listCrossConnects operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllCrossConnectsResponses(request: requests.ListCrossConnectsRequest): AsyncIterableIterator<responses.ListCrossConnectsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.CrossConnect objects
     * contained in responses from the listCrossConnects operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listCrossConnectsRecordIterator(request: requests.ListCrossConnectsRequest): AsyncIterableIterator<model.CrossConnect>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listCrossConnects operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listCrossConnectsResponseIterator(request: requests.ListCrossConnectsRequest): AsyncIterableIterator<responses.ListCrossConnectsResponse>;
    /**
     * Lists the available port speeds for cross-connects. You need this information
     * so you can specify your desired port speed (that is, shape) when you create a
     * cross-connect.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListCrossconnectPortSpeedShapesRequest
     * @return ListCrossconnectPortSpeedShapesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ListCrossconnectPortSpeedShapes.ts.html |here} to see how to use ListCrossconnectPortSpeedShapes API.
     */
    listCrossconnectPortSpeedShapes(listCrossconnectPortSpeedShapesRequest: requests.ListCrossconnectPortSpeedShapesRequest): Promise<responses.ListCrossconnectPortSpeedShapesResponse>;
    /**
     * NOTE: This function is deprecated in favor of listCrossconnectPortSpeedShapesRecordIterator function.
     * Creates a new async iterator which will iterate over the models.CrossConnectPortSpeedShape objects
     * contained in responses from the listCrossconnectPortSpeedShapes operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllCrossconnectPortSpeedShapes(request: requests.ListCrossconnectPortSpeedShapesRequest): AsyncIterableIterator<model.CrossConnectPortSpeedShape>;
    /**
     * NOTE: This function is deprecated in favor of listCrossconnectPortSpeedShapesResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listCrossconnectPortSpeedShapes operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllCrossconnectPortSpeedShapesResponses(request: requests.ListCrossconnectPortSpeedShapesRequest): AsyncIterableIterator<responses.ListCrossconnectPortSpeedShapesResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.CrossConnectPortSpeedShape objects
     * contained in responses from the listCrossconnectPortSpeedShapes operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listCrossconnectPortSpeedShapesRecordIterator(request: requests.ListCrossconnectPortSpeedShapesRequest): AsyncIterableIterator<model.CrossConnectPortSpeedShape>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listCrossconnectPortSpeedShapes operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listCrossconnectPortSpeedShapesResponseIterator(request: requests.ListCrossconnectPortSpeedShapesRequest): AsyncIterableIterator<responses.ListCrossconnectPortSpeedShapesResponse>;
    /**
     * Lists the sets of DHCP options in the specified VCN and specified compartment.
     * If the VCN ID is not provided, then the list includes the sets of DHCP options from all VCNs in the specified compartment.
     * The response includes the default set of options that automatically comes with each VCN,
     * plus any other sets you've created.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListDhcpOptionsRequest
     * @return ListDhcpOptionsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ListDhcpOptions.ts.html |here} to see how to use ListDhcpOptions API.
     */
    listDhcpOptions(listDhcpOptionsRequest: requests.ListDhcpOptionsRequest): Promise<responses.ListDhcpOptionsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listDhcpOptionsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.DhcpOptions objects
     * contained in responses from the listDhcpOptions operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllDhcpOptions(request: requests.ListDhcpOptionsRequest): AsyncIterableIterator<model.DhcpOptions>;
    /**
     * NOTE: This function is deprecated in favor of listDhcpOptionsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listDhcpOptions operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllDhcpOptionsResponses(request: requests.ListDhcpOptionsRequest): AsyncIterableIterator<responses.ListDhcpOptionsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.DhcpOptions objects
     * contained in responses from the listDhcpOptions operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listDhcpOptionsRecordIterator(request: requests.ListDhcpOptionsRequest): AsyncIterableIterator<model.DhcpOptions>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listDhcpOptions operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listDhcpOptionsResponseIterator(request: requests.ListDhcpOptionsRequest): AsyncIterableIterator<responses.ListDhcpOptionsResponse>;
    /**
       * Lists the `DrgAttachment` resource for the specified compartment. You can filter the
  * results by DRG, attached network, attachment type, DRG route table or
  * VCN route table.
  * <p>
  The LIST API lists DRG attachments by attachment type. It will default to list VCN attachments,
  * but you may request to list ALL attachments of ALL types.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param ListDrgAttachmentsRequest
       * @return ListDrgAttachmentsResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ListDrgAttachments.ts.html |here} to see how to use ListDrgAttachments API.
       */
    listDrgAttachments(listDrgAttachmentsRequest: requests.ListDrgAttachmentsRequest): Promise<responses.ListDrgAttachmentsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listDrgAttachmentsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.DrgAttachment objects
     * contained in responses from the listDrgAttachments operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllDrgAttachments(request: requests.ListDrgAttachmentsRequest): AsyncIterableIterator<model.DrgAttachment>;
    /**
     * NOTE: This function is deprecated in favor of listDrgAttachmentsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listDrgAttachments operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllDrgAttachmentsResponses(request: requests.ListDrgAttachmentsRequest): AsyncIterableIterator<responses.ListDrgAttachmentsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.DrgAttachment objects
     * contained in responses from the listDrgAttachments operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listDrgAttachmentsRecordIterator(request: requests.ListDrgAttachmentsRequest): AsyncIterableIterator<model.DrgAttachment>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listDrgAttachments operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listDrgAttachmentsResponseIterator(request: requests.ListDrgAttachmentsRequest): AsyncIterableIterator<responses.ListDrgAttachmentsResponse>;
    /**
     * Lists the statements for the specified route distribution.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListDrgRouteDistributionStatementsRequest
     * @return ListDrgRouteDistributionStatementsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ListDrgRouteDistributionStatements.ts.html |here} to see how to use ListDrgRouteDistributionStatements API.
     */
    listDrgRouteDistributionStatements(listDrgRouteDistributionStatementsRequest: requests.ListDrgRouteDistributionStatementsRequest): Promise<responses.ListDrgRouteDistributionStatementsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listDrgRouteDistributionStatementsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.DrgRouteDistributionStatement objects
     * contained in responses from the listDrgRouteDistributionStatements operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllDrgRouteDistributionStatements(request: requests.ListDrgRouteDistributionStatementsRequest): AsyncIterableIterator<model.DrgRouteDistributionStatement>;
    /**
     * NOTE: This function is deprecated in favor of listDrgRouteDistributionStatementsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listDrgRouteDistributionStatements operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllDrgRouteDistributionStatementsResponses(request: requests.ListDrgRouteDistributionStatementsRequest): AsyncIterableIterator<responses.ListDrgRouteDistributionStatementsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.DrgRouteDistributionStatement objects
     * contained in responses from the listDrgRouteDistributionStatements operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listDrgRouteDistributionStatementsRecordIterator(request: requests.ListDrgRouteDistributionStatementsRequest): AsyncIterableIterator<model.DrgRouteDistributionStatement>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listDrgRouteDistributionStatements operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listDrgRouteDistributionStatementsResponseIterator(request: requests.ListDrgRouteDistributionStatementsRequest): AsyncIterableIterator<responses.ListDrgRouteDistributionStatementsResponse>;
    /**
       * Lists the route distributions in the specified DRG.
  * <p>
  To retrieve the statements in a distribution, use the
  * ListDrgRouteDistributionStatements operation.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param ListDrgRouteDistributionsRequest
       * @return ListDrgRouteDistributionsResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ListDrgRouteDistributions.ts.html |here} to see how to use ListDrgRouteDistributions API.
       */
    listDrgRouteDistributions(listDrgRouteDistributionsRequest: requests.ListDrgRouteDistributionsRequest): Promise<responses.ListDrgRouteDistributionsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listDrgRouteDistributionsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.DrgRouteDistribution objects
     * contained in responses from the listDrgRouteDistributions operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllDrgRouteDistributions(request: requests.ListDrgRouteDistributionsRequest): AsyncIterableIterator<model.DrgRouteDistribution>;
    /**
     * NOTE: This function is deprecated in favor of listDrgRouteDistributionsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listDrgRouteDistributions operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllDrgRouteDistributionsResponses(request: requests.ListDrgRouteDistributionsRequest): AsyncIterableIterator<responses.ListDrgRouteDistributionsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.DrgRouteDistribution objects
     * contained in responses from the listDrgRouteDistributions operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listDrgRouteDistributionsRecordIterator(request: requests.ListDrgRouteDistributionsRequest): AsyncIterableIterator<model.DrgRouteDistribution>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listDrgRouteDistributions operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listDrgRouteDistributionsResponseIterator(request: requests.ListDrgRouteDistributionsRequest): AsyncIterableIterator<responses.ListDrgRouteDistributionsResponse>;
    /**
     * Lists the route rules in the specified DRG route table.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListDrgRouteRulesRequest
     * @return ListDrgRouteRulesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ListDrgRouteRules.ts.html |here} to see how to use ListDrgRouteRules API.
     */
    listDrgRouteRules(listDrgRouteRulesRequest: requests.ListDrgRouteRulesRequest): Promise<responses.ListDrgRouteRulesResponse>;
    /**
     * NOTE: This function is deprecated in favor of listDrgRouteRulesRecordIterator function.
     * Creates a new async iterator which will iterate over the models.DrgRouteRule objects
     * contained in responses from the listDrgRouteRules operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllDrgRouteRules(request: requests.ListDrgRouteRulesRequest): AsyncIterableIterator<model.DrgRouteRule>;
    /**
     * NOTE: This function is deprecated in favor of listDrgRouteRulesResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listDrgRouteRules operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllDrgRouteRulesResponses(request: requests.ListDrgRouteRulesRequest): AsyncIterableIterator<responses.ListDrgRouteRulesResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.DrgRouteRule objects
     * contained in responses from the listDrgRouteRules operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listDrgRouteRulesRecordIterator(request: requests.ListDrgRouteRulesRequest): AsyncIterableIterator<model.DrgRouteRule>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listDrgRouteRules operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listDrgRouteRulesResponseIterator(request: requests.ListDrgRouteRulesRequest): AsyncIterableIterator<responses.ListDrgRouteRulesResponse>;
    /**
       * Lists the DRG route tables for the specified DRG.
  * <p>
  Use the `ListDrgRouteRules` operation to retrieve the route rules in a table.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param ListDrgRouteTablesRequest
       * @return ListDrgRouteTablesResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ListDrgRouteTables.ts.html |here} to see how to use ListDrgRouteTables API.
       */
    listDrgRouteTables(listDrgRouteTablesRequest: requests.ListDrgRouteTablesRequest): Promise<responses.ListDrgRouteTablesResponse>;
    /**
     * NOTE: This function is deprecated in favor of listDrgRouteTablesRecordIterator function.
     * Creates a new async iterator which will iterate over the models.DrgRouteTable objects
     * contained in responses from the listDrgRouteTables operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllDrgRouteTables(request: requests.ListDrgRouteTablesRequest): AsyncIterableIterator<model.DrgRouteTable>;
    /**
     * NOTE: This function is deprecated in favor of listDrgRouteTablesResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listDrgRouteTables operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllDrgRouteTablesResponses(request: requests.ListDrgRouteTablesRequest): AsyncIterableIterator<responses.ListDrgRouteTablesResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.DrgRouteTable objects
     * contained in responses from the listDrgRouteTables operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listDrgRouteTablesRecordIterator(request: requests.ListDrgRouteTablesRequest): AsyncIterableIterator<model.DrgRouteTable>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listDrgRouteTables operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listDrgRouteTablesResponseIterator(request: requests.ListDrgRouteTablesRequest): AsyncIterableIterator<responses.ListDrgRouteTablesResponse>;
    /**
     * Lists the DRGs in the specified compartment.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListDrgsRequest
     * @return ListDrgsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ListDrgs.ts.html |here} to see how to use ListDrgs API.
     */
    listDrgs(listDrgsRequest: requests.ListDrgsRequest): Promise<responses.ListDrgsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listDrgsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.Drg objects
     * contained in responses from the listDrgs operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllDrgs(request: requests.ListDrgsRequest): AsyncIterableIterator<model.Drg>;
    /**
     * NOTE: This function is deprecated in favor of listDrgsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listDrgs operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllDrgsResponses(request: requests.ListDrgsRequest): AsyncIterableIterator<responses.ListDrgsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.Drg objects
     * contained in responses from the listDrgs operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listDrgsRecordIterator(request: requests.ListDrgsRequest): AsyncIterableIterator<model.Drg>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listDrgs operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listDrgsResponseIterator(request: requests.ListDrgsRequest): AsyncIterableIterator<responses.ListDrgsResponse>;
    /**
       * Lists the service offerings from supported providers. You need this
  * information so you can specify your desired provider and service
  * offering when you create a virtual circuit.
  * <p>
  For the compartment ID, provide the [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of your tenancy (the root compartment).
  * <p>
  For more information, see [FastConnect Overview](https://docs.cloud.oracle.com/iaas/Content/Network/Concepts/fastconnect.htm).
  *
       * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
       * @param ListFastConnectProviderServicesRequest
       * @return ListFastConnectProviderServicesResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ListFastConnectProviderServices.ts.html |here} to see how to use ListFastConnectProviderServices API.
       */
    listFastConnectProviderServices(listFastConnectProviderServicesRequest: requests.ListFastConnectProviderServicesRequest): Promise<responses.ListFastConnectProviderServicesResponse>;
    /**
     * NOTE: This function is deprecated in favor of listFastConnectProviderServicesRecordIterator function.
     * Creates a new async iterator which will iterate over the models.FastConnectProviderService objects
     * contained in responses from the listFastConnectProviderServices operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllFastConnectProviderServices(request: requests.ListFastConnectProviderServicesRequest): AsyncIterableIterator<model.FastConnectProviderService>;
    /**
     * NOTE: This function is deprecated in favor of listFastConnectProviderServicesResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listFastConnectProviderServices operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllFastConnectProviderServicesResponses(request: requests.ListFastConnectProviderServicesRequest): AsyncIterableIterator<responses.ListFastConnectProviderServicesResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.FastConnectProviderService objects
     * contained in responses from the listFastConnectProviderServices operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listFastConnectProviderServicesRecordIterator(request: requests.ListFastConnectProviderServicesRequest): AsyncIterableIterator<model.FastConnectProviderService>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listFastConnectProviderServices operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listFastConnectProviderServicesResponseIterator(request: requests.ListFastConnectProviderServicesRequest): AsyncIterableIterator<responses.ListFastConnectProviderServicesResponse>;
    /**
       * Gets the list of available virtual circuit bandwidth levels for a provider.
  * You need this information so you can specify your desired bandwidth level (shape) when you create a virtual circuit.
  * <p>
  For more information about virtual circuits, see [FastConnect Overview](https://docs.cloud.oracle.com/iaas/Content/Network/Concepts/fastconnect.htm).
  *
       * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
       * @param ListFastConnectProviderVirtualCircuitBandwidthShapesRequest
       * @return ListFastConnectProviderVirtualCircuitBandwidthShapesResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ListFastConnectProviderVirtualCircuitBandwidthShapes.ts.html |here} to see how to use ListFastConnectProviderVirtualCircuitBandwidthShapes API.
       */
    listFastConnectProviderVirtualCircuitBandwidthShapes(listFastConnectProviderVirtualCircuitBandwidthShapesRequest: requests.ListFastConnectProviderVirtualCircuitBandwidthShapesRequest): Promise<responses.ListFastConnectProviderVirtualCircuitBandwidthShapesResponse>;
    /**
     * NOTE: This function is deprecated in favor of listFastConnectProviderVirtualCircuitBandwidthShapesRecordIterator function.
     * Creates a new async iterator which will iterate over the models.VirtualCircuitBandwidthShape objects
     * contained in responses from the listFastConnectProviderVirtualCircuitBandwidthShapes operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllFastConnectProviderVirtualCircuitBandwidthShapes(request: requests.ListFastConnectProviderVirtualCircuitBandwidthShapesRequest): AsyncIterableIterator<model.VirtualCircuitBandwidthShape>;
    /**
     * NOTE: This function is deprecated in favor of listFastConnectProviderVirtualCircuitBandwidthShapesResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listFastConnectProviderVirtualCircuitBandwidthShapes operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllFastConnectProviderVirtualCircuitBandwidthShapesResponses(request: requests.ListFastConnectProviderVirtualCircuitBandwidthShapesRequest): AsyncIterableIterator<responses.ListFastConnectProviderVirtualCircuitBandwidthShapesResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.VirtualCircuitBandwidthShape objects
     * contained in responses from the listFastConnectProviderVirtualCircuitBandwidthShapes operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listFastConnectProviderVirtualCircuitBandwidthShapesRecordIterator(request: requests.ListFastConnectProviderVirtualCircuitBandwidthShapesRequest): AsyncIterableIterator<model.VirtualCircuitBandwidthShape>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listFastConnectProviderVirtualCircuitBandwidthShapes operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listFastConnectProviderVirtualCircuitBandwidthShapesResponseIterator(request: requests.ListFastConnectProviderVirtualCircuitBandwidthShapesRequest): AsyncIterableIterator<responses.ListFastConnectProviderVirtualCircuitBandwidthShapesResponse>;
    /**
     * The routes advertised to the on-premises network and the routes received from the on-premises network.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListIPSecConnectionTunnelRoutesRequest
     * @return ListIPSecConnectionTunnelRoutesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ListIPSecConnectionTunnelRoutes.ts.html |here} to see how to use ListIPSecConnectionTunnelRoutes API.
     */
    listIPSecConnectionTunnelRoutes(listIPSecConnectionTunnelRoutesRequest: requests.ListIPSecConnectionTunnelRoutesRequest): Promise<responses.ListIPSecConnectionTunnelRoutesResponse>;
    /**
     * NOTE: This function is deprecated in favor of listIPSecConnectionTunnelRoutesRecordIterator function.
     * Creates a new async iterator which will iterate over the models.TunnelRouteSummary objects
     * contained in responses from the listIPSecConnectionTunnelRoutes operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllIPSecConnectionTunnelRoutes(request: requests.ListIPSecConnectionTunnelRoutesRequest): AsyncIterableIterator<model.TunnelRouteSummary>;
    /**
     * NOTE: This function is deprecated in favor of listIPSecConnectionTunnelRoutesResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listIPSecConnectionTunnelRoutes operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllIPSecConnectionTunnelRoutesResponses(request: requests.ListIPSecConnectionTunnelRoutesRequest): AsyncIterableIterator<responses.ListIPSecConnectionTunnelRoutesResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.TunnelRouteSummary objects
     * contained in responses from the listIPSecConnectionTunnelRoutes operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listIPSecConnectionTunnelRoutesRecordIterator(request: requests.ListIPSecConnectionTunnelRoutesRequest): AsyncIterableIterator<model.TunnelRouteSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listIPSecConnectionTunnelRoutes operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listIPSecConnectionTunnelRoutesResponseIterator(request: requests.ListIPSecConnectionTunnelRoutesRequest): AsyncIterableIterator<responses.ListIPSecConnectionTunnelRoutesResponse>;
    /**
     * Lists the tunnel security associations information for the specified IPSec tunnel ID.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListIPSecConnectionTunnelSecurityAssociationsRequest
     * @return ListIPSecConnectionTunnelSecurityAssociationsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ListIPSecConnectionTunnelSecurityAssociations.ts.html |here} to see how to use ListIPSecConnectionTunnelSecurityAssociations API.
     */
    listIPSecConnectionTunnelSecurityAssociations(listIPSecConnectionTunnelSecurityAssociationsRequest: requests.ListIPSecConnectionTunnelSecurityAssociationsRequest): Promise<responses.ListIPSecConnectionTunnelSecurityAssociationsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listIPSecConnectionTunnelSecurityAssociationsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.TunnelSecurityAssociationSummary objects
     * contained in responses from the listIPSecConnectionTunnelSecurityAssociations operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllIPSecConnectionTunnelSecurityAssociations(request: requests.ListIPSecConnectionTunnelSecurityAssociationsRequest): AsyncIterableIterator<model.TunnelSecurityAssociationSummary>;
    /**
     * NOTE: This function is deprecated in favor of listIPSecConnectionTunnelSecurityAssociationsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listIPSecConnectionTunnelSecurityAssociations operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllIPSecConnectionTunnelSecurityAssociationsResponses(request: requests.ListIPSecConnectionTunnelSecurityAssociationsRequest): AsyncIterableIterator<responses.ListIPSecConnectionTunnelSecurityAssociationsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.TunnelSecurityAssociationSummary objects
     * contained in responses from the listIPSecConnectionTunnelSecurityAssociations operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listIPSecConnectionTunnelSecurityAssociationsRecordIterator(request: requests.ListIPSecConnectionTunnelSecurityAssociationsRequest): AsyncIterableIterator<model.TunnelSecurityAssociationSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listIPSecConnectionTunnelSecurityAssociations operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listIPSecConnectionTunnelSecurityAssociationsResponseIterator(request: requests.ListIPSecConnectionTunnelSecurityAssociationsRequest): AsyncIterableIterator<responses.ListIPSecConnectionTunnelSecurityAssociationsResponse>;
    /**
     * Lists the tunnel information for the specified IPSec connection.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListIPSecConnectionTunnelsRequest
     * @return ListIPSecConnectionTunnelsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ListIPSecConnectionTunnels.ts.html |here} to see how to use ListIPSecConnectionTunnels API.
     */
    listIPSecConnectionTunnels(listIPSecConnectionTunnelsRequest: requests.ListIPSecConnectionTunnelsRequest): Promise<responses.ListIPSecConnectionTunnelsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listIPSecConnectionTunnelsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.IPSecConnectionTunnel objects
     * contained in responses from the listIPSecConnectionTunnels operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllIPSecConnectionTunnels(request: requests.ListIPSecConnectionTunnelsRequest): AsyncIterableIterator<model.IPSecConnectionTunnel>;
    /**
     * NOTE: This function is deprecated in favor of listIPSecConnectionTunnelsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listIPSecConnectionTunnels operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllIPSecConnectionTunnelsResponses(request: requests.ListIPSecConnectionTunnelsRequest): AsyncIterableIterator<responses.ListIPSecConnectionTunnelsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.IPSecConnectionTunnel objects
     * contained in responses from the listIPSecConnectionTunnels operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listIPSecConnectionTunnelsRecordIterator(request: requests.ListIPSecConnectionTunnelsRequest): AsyncIterableIterator<model.IPSecConnectionTunnel>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listIPSecConnectionTunnels operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listIPSecConnectionTunnelsResponseIterator(request: requests.ListIPSecConnectionTunnelsRequest): AsyncIterableIterator<responses.ListIPSecConnectionTunnelsResponse>;
    /**
     * Lists the IPSec connections for the specified compartment. You can filter the
     * results by DRG or CPE.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListIPSecConnectionsRequest
     * @return ListIPSecConnectionsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ListIPSecConnections.ts.html |here} to see how to use ListIPSecConnections API.
     */
    listIPSecConnections(listIPSecConnectionsRequest: requests.ListIPSecConnectionsRequest): Promise<responses.ListIPSecConnectionsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listIPSecConnectionsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.IPSecConnection objects
     * contained in responses from the listIPSecConnections operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllIPSecConnections(request: requests.ListIPSecConnectionsRequest): AsyncIterableIterator<model.IPSecConnection>;
    /**
     * NOTE: This function is deprecated in favor of listIPSecConnectionsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listIPSecConnections operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllIPSecConnectionsResponses(request: requests.ListIPSecConnectionsRequest): AsyncIterableIterator<responses.ListIPSecConnectionsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.IPSecConnection objects
     * contained in responses from the listIPSecConnections operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listIPSecConnectionsRecordIterator(request: requests.ListIPSecConnectionsRequest): AsyncIterableIterator<model.IPSecConnection>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listIPSecConnections operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listIPSecConnectionsResponseIterator(request: requests.ListIPSecConnectionsRequest): AsyncIterableIterator<responses.ListIPSecConnectionsResponse>;
    /**
     * Lists the internet gateways in the specified VCN and the specified compartment.
     * If the VCN ID is not provided, then the list includes the internet gateways from all VCNs in the specified compartment.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListInternetGatewaysRequest
     * @return ListInternetGatewaysResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ListInternetGateways.ts.html |here} to see how to use ListInternetGateways API.
     */
    listInternetGateways(listInternetGatewaysRequest: requests.ListInternetGatewaysRequest): Promise<responses.ListInternetGatewaysResponse>;
    /**
     * NOTE: This function is deprecated in favor of listInternetGatewaysRecordIterator function.
     * Creates a new async iterator which will iterate over the models.InternetGateway objects
     * contained in responses from the listInternetGateways operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllInternetGateways(request: requests.ListInternetGatewaysRequest): AsyncIterableIterator<model.InternetGateway>;
    /**
     * NOTE: This function is deprecated in favor of listInternetGatewaysResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listInternetGateways operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllInternetGatewaysResponses(request: requests.ListInternetGatewaysRequest): AsyncIterableIterator<responses.ListInternetGatewaysResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.InternetGateway objects
     * contained in responses from the listInternetGateways operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listInternetGatewaysRecordIterator(request: requests.ListInternetGatewaysRequest): AsyncIterableIterator<model.InternetGateway>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listInternetGateways operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listInternetGatewaysResponseIterator(request: requests.ListInternetGatewaysRequest): AsyncIterableIterator<responses.ListInternetGatewaysResponse>;
    /**
     * Lists the IP Inventory information in the selected compartments.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListIpInventoryRequest
     * @return ListIpInventoryResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ListIpInventory.ts.html |here} to see how to use ListIpInventory API.
     */
    listIpInventory(listIpInventoryRequest: requests.ListIpInventoryRequest): Promise<responses.ListIpInventoryResponse>;
    /**
     * Lists the {@link Ipv6} objects based
     * on one of these filters:
     * <p>
     * Subnet [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
     *   * VNIC [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
     *   * Both IPv6 address and subnet OCID: This lets you get an `Ipv6` object based on its private
     *   IPv6 address (for example, 2001:0db8:0123:1111:abcd:ef01:2345:6789) and not its [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm). For comparison,
     *   {@link #getIpv6(GetIpv6Request) getIpv6} requires the [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListIpv6sRequest
     * @return ListIpv6sResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ListIpv6s.ts.html |here} to see how to use ListIpv6s API.
     */
    listIpv6s(listIpv6sRequest: requests.ListIpv6sRequest): Promise<responses.ListIpv6sResponse>;
    /**
     * NOTE: This function is deprecated in favor of listIpv6sRecordIterator function.
     * Creates a new async iterator which will iterate over the models.Ipv6 objects
     * contained in responses from the listIpv6s operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllIpv6s(request: requests.ListIpv6sRequest): AsyncIterableIterator<model.Ipv6>;
    /**
     * NOTE: This function is deprecated in favor of listIpv6sResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listIpv6s operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllIpv6sResponses(request: requests.ListIpv6sRequest): AsyncIterableIterator<responses.ListIpv6sResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.Ipv6 objects
     * contained in responses from the listIpv6s operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listIpv6sRecordIterator(request: requests.ListIpv6sRequest): AsyncIterableIterator<model.Ipv6>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listIpv6s operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listIpv6sResponseIterator(request: requests.ListIpv6sRequest): AsyncIterableIterator<responses.ListIpv6sResponse>;
    /**
     * Lists the local peering gateways (LPGs) for the specified VCN and specified compartment.
     * If the VCN ID is not provided, then the list includes the LPGs from all VCNs in the specified compartment.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListLocalPeeringGatewaysRequest
     * @return ListLocalPeeringGatewaysResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ListLocalPeeringGateways.ts.html |here} to see how to use ListLocalPeeringGateways API.
     */
    listLocalPeeringGateways(listLocalPeeringGatewaysRequest: requests.ListLocalPeeringGatewaysRequest): Promise<responses.ListLocalPeeringGatewaysResponse>;
    /**
     * NOTE: This function is deprecated in favor of listLocalPeeringGatewaysRecordIterator function.
     * Creates a new async iterator which will iterate over the models.LocalPeeringGateway objects
     * contained in responses from the listLocalPeeringGateways operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllLocalPeeringGateways(request: requests.ListLocalPeeringGatewaysRequest): AsyncIterableIterator<model.LocalPeeringGateway>;
    /**
     * NOTE: This function is deprecated in favor of listLocalPeeringGatewaysResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listLocalPeeringGateways operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllLocalPeeringGatewaysResponses(request: requests.ListLocalPeeringGatewaysRequest): AsyncIterableIterator<responses.ListLocalPeeringGatewaysResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.LocalPeeringGateway objects
     * contained in responses from the listLocalPeeringGateways operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listLocalPeeringGatewaysRecordIterator(request: requests.ListLocalPeeringGatewaysRequest): AsyncIterableIterator<model.LocalPeeringGateway>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listLocalPeeringGateways operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listLocalPeeringGatewaysResponseIterator(request: requests.ListLocalPeeringGatewaysRequest): AsyncIterableIterator<responses.ListLocalPeeringGatewaysResponse>;
    /**
     * Lists the NAT gateways in the specified compartment. You may optionally specify a VCN OCID
     * to filter the results by VCN.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListNatGatewaysRequest
     * @return ListNatGatewaysResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ListNatGateways.ts.html |here} to see how to use ListNatGateways API.
     */
    listNatGateways(listNatGatewaysRequest: requests.ListNatGatewaysRequest): Promise<responses.ListNatGatewaysResponse>;
    /**
     * NOTE: This function is deprecated in favor of listNatGatewaysRecordIterator function.
     * Creates a new async iterator which will iterate over the models.NatGateway objects
     * contained in responses from the listNatGateways operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllNatGateways(request: requests.ListNatGatewaysRequest): AsyncIterableIterator<model.NatGateway>;
    /**
     * NOTE: This function is deprecated in favor of listNatGatewaysResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listNatGateways operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllNatGatewaysResponses(request: requests.ListNatGatewaysRequest): AsyncIterableIterator<responses.ListNatGatewaysResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.NatGateway objects
     * contained in responses from the listNatGateways operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listNatGatewaysRecordIterator(request: requests.ListNatGatewaysRequest): AsyncIterableIterator<model.NatGateway>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listNatGateways operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listNatGatewaysResponseIterator(request: requests.ListNatGatewaysRequest): AsyncIterableIterator<responses.ListNatGatewaysResponse>;
    /**
     * Lists the security rules in the specified network security group.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListNetworkSecurityGroupSecurityRulesRequest
     * @return ListNetworkSecurityGroupSecurityRulesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ListNetworkSecurityGroupSecurityRules.ts.html |here} to see how to use ListNetworkSecurityGroupSecurityRules API.
     */
    listNetworkSecurityGroupSecurityRules(listNetworkSecurityGroupSecurityRulesRequest: requests.ListNetworkSecurityGroupSecurityRulesRequest): Promise<responses.ListNetworkSecurityGroupSecurityRulesResponse>;
    /**
     * NOTE: This function is deprecated in favor of listNetworkSecurityGroupSecurityRulesRecordIterator function.
     * Creates a new async iterator which will iterate over the models.SecurityRule objects
     * contained in responses from the listNetworkSecurityGroupSecurityRules operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllNetworkSecurityGroupSecurityRules(request: requests.ListNetworkSecurityGroupSecurityRulesRequest): AsyncIterableIterator<model.SecurityRule>;
    /**
     * NOTE: This function is deprecated in favor of listNetworkSecurityGroupSecurityRulesResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listNetworkSecurityGroupSecurityRules operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllNetworkSecurityGroupSecurityRulesResponses(request: requests.ListNetworkSecurityGroupSecurityRulesRequest): AsyncIterableIterator<responses.ListNetworkSecurityGroupSecurityRulesResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.SecurityRule objects
     * contained in responses from the listNetworkSecurityGroupSecurityRules operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listNetworkSecurityGroupSecurityRulesRecordIterator(request: requests.ListNetworkSecurityGroupSecurityRulesRequest): AsyncIterableIterator<model.SecurityRule>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listNetworkSecurityGroupSecurityRules operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listNetworkSecurityGroupSecurityRulesResponseIterator(request: requests.ListNetworkSecurityGroupSecurityRulesRequest): AsyncIterableIterator<responses.ListNetworkSecurityGroupSecurityRulesResponse>;
    /**
     * Lists the VNICs in the specified network security group.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListNetworkSecurityGroupVnicsRequest
     * @return ListNetworkSecurityGroupVnicsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ListNetworkSecurityGroupVnics.ts.html |here} to see how to use ListNetworkSecurityGroupVnics API.
     */
    listNetworkSecurityGroupVnics(listNetworkSecurityGroupVnicsRequest: requests.ListNetworkSecurityGroupVnicsRequest): Promise<responses.ListNetworkSecurityGroupVnicsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listNetworkSecurityGroupVnicsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.NetworkSecurityGroupVnic objects
     * contained in responses from the listNetworkSecurityGroupVnics operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllNetworkSecurityGroupVnics(request: requests.ListNetworkSecurityGroupVnicsRequest): AsyncIterableIterator<model.NetworkSecurityGroupVnic>;
    /**
     * NOTE: This function is deprecated in favor of listNetworkSecurityGroupVnicsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listNetworkSecurityGroupVnics operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllNetworkSecurityGroupVnicsResponses(request: requests.ListNetworkSecurityGroupVnicsRequest): AsyncIterableIterator<responses.ListNetworkSecurityGroupVnicsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.NetworkSecurityGroupVnic objects
     * contained in responses from the listNetworkSecurityGroupVnics operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listNetworkSecurityGroupVnicsRecordIterator(request: requests.ListNetworkSecurityGroupVnicsRequest): AsyncIterableIterator<model.NetworkSecurityGroupVnic>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listNetworkSecurityGroupVnics operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listNetworkSecurityGroupVnicsResponseIterator(request: requests.ListNetworkSecurityGroupVnicsRequest): AsyncIterableIterator<responses.ListNetworkSecurityGroupVnicsResponse>;
    /**
     * Lists either the network security groups in the specified compartment, or those associated with the specified VLAN.
     * You must specify either a `vlanId` or a `compartmentId`, but not both. If you specify a `vlanId`, all other parameters are ignored.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListNetworkSecurityGroupsRequest
     * @return ListNetworkSecurityGroupsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ListNetworkSecurityGroups.ts.html |here} to see how to use ListNetworkSecurityGroups API.
     */
    listNetworkSecurityGroups(listNetworkSecurityGroupsRequest: requests.ListNetworkSecurityGroupsRequest): Promise<responses.ListNetworkSecurityGroupsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listNetworkSecurityGroupsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.NetworkSecurityGroup objects
     * contained in responses from the listNetworkSecurityGroups operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllNetworkSecurityGroups(request: requests.ListNetworkSecurityGroupsRequest): AsyncIterableIterator<model.NetworkSecurityGroup>;
    /**
     * NOTE: This function is deprecated in favor of listNetworkSecurityGroupsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listNetworkSecurityGroups operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllNetworkSecurityGroupsResponses(request: requests.ListNetworkSecurityGroupsRequest): AsyncIterableIterator<responses.ListNetworkSecurityGroupsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.NetworkSecurityGroup objects
     * contained in responses from the listNetworkSecurityGroups operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listNetworkSecurityGroupsRecordIterator(request: requests.ListNetworkSecurityGroupsRequest): AsyncIterableIterator<model.NetworkSecurityGroup>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listNetworkSecurityGroups operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listNetworkSecurityGroupsResponseIterator(request: requests.ListNetworkSecurityGroupsRequest): AsyncIterableIterator<responses.ListNetworkSecurityGroupsResponse>;
    /**
       * Lists the {@link PrivateIp} objects based
  * on one of these filters:
  * <p>
    - Subnet [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
  *   - VNIC [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
  *   - Both private IP address and subnet OCID: This lets
  *   you get a `privateIP` object based on its private IP
  *   address (for example, 10.0.3.3) and not its [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm). For comparison,
  *   {@link #getPrivateIp(GetPrivateIpRequest) getPrivateIp}
  *   requires the [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
  * <p>
  If you're listing all the private IPs associated with a given subnet
  * or VNIC, the response includes both primary and secondary private IPs.
  * <p>
  If you are an Oracle Cloud VMware Solution customer and have VLANs
  * in your VCN, you can filter the list by VLAN [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm). See {@link Vlan}.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param ListPrivateIpsRequest
       * @return ListPrivateIpsResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ListPrivateIps.ts.html |here} to see how to use ListPrivateIps API.
       */
    listPrivateIps(listPrivateIpsRequest: requests.ListPrivateIpsRequest): Promise<responses.ListPrivateIpsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listPrivateIpsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.PrivateIp objects
     * contained in responses from the listPrivateIps operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllPrivateIps(request: requests.ListPrivateIpsRequest): AsyncIterableIterator<model.PrivateIp>;
    /**
     * NOTE: This function is deprecated in favor of listPrivateIpsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listPrivateIps operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllPrivateIpsResponses(request: requests.ListPrivateIpsRequest): AsyncIterableIterator<responses.ListPrivateIpsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.PrivateIp objects
     * contained in responses from the listPrivateIps operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listPrivateIpsRecordIterator(request: requests.ListPrivateIpsRequest): AsyncIterableIterator<model.PrivateIp>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listPrivateIps operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listPrivateIpsResponseIterator(request: requests.ListPrivateIpsRequest): AsyncIterableIterator<responses.ListPrivateIpsResponse>;
    /**
     * Lists the public IP pools in the specified compartment.
     * You can filter the list using query parameters.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListPublicIpPoolsRequest
     * @return ListPublicIpPoolsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ListPublicIpPools.ts.html |here} to see how to use ListPublicIpPools API.
     */
    listPublicIpPools(listPublicIpPoolsRequest: requests.ListPublicIpPoolsRequest): Promise<responses.ListPublicIpPoolsResponse>;
    /**
       * Lists the {@link PublicIp} objects
  * in the specified compartment. You can filter the list by using query parameters.
  * <p>
  To list your reserved public IPs:
  *   * Set `scope` = `REGION`  (required)
  *   * Leave the `availabilityDomain` parameter empty
  *   * Set `lifetime` = `RESERVED`
  * <p>
  To list the ephemeral public IPs assigned to a regional entity such as a NAT gateway:
  *   * Set `scope` = `REGION`  (required)
  *   * Leave the `availabilityDomain` parameter empty
  *   * Set `lifetime` = `EPHEMERAL`
  * <p>
  To list the ephemeral public IPs assigned to private IPs:
  *   * Set `scope` = `AVAILABILITY_DOMAIN` (required)
  *   * Set the `availabilityDomain` parameter to the desired availability domain (required)
  *   * Set `lifetime` = `EPHEMERAL`
  * <p>
  **Note:** An ephemeral public IP assigned to a private IP
  * is always in the same availability domain and compartment as the private IP.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param ListPublicIpsRequest
       * @return ListPublicIpsResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ListPublicIps.ts.html |here} to see how to use ListPublicIps API.
       */
    listPublicIps(listPublicIpsRequest: requests.ListPublicIpsRequest): Promise<responses.ListPublicIpsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listPublicIpsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.PublicIp objects
     * contained in responses from the listPublicIps operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllPublicIps(request: requests.ListPublicIpsRequest): AsyncIterableIterator<model.PublicIp>;
    /**
     * NOTE: This function is deprecated in favor of listPublicIpsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listPublicIps operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllPublicIpsResponses(request: requests.ListPublicIpsRequest): AsyncIterableIterator<responses.ListPublicIpsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.PublicIp objects
     * contained in responses from the listPublicIps operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listPublicIpsRecordIterator(request: requests.ListPublicIpsRequest): AsyncIterableIterator<model.PublicIp>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listPublicIps operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listPublicIpsResponseIterator(request: requests.ListPublicIpsRequest): AsyncIterableIterator<responses.ListPublicIpsResponse>;
    /**
     * Lists the remote peering connections (RPCs) for the specified DRG and compartment
     * (the RPC's compartment).
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListRemotePeeringConnectionsRequest
     * @return ListRemotePeeringConnectionsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ListRemotePeeringConnections.ts.html |here} to see how to use ListRemotePeeringConnections API.
     */
    listRemotePeeringConnections(listRemotePeeringConnectionsRequest: requests.ListRemotePeeringConnectionsRequest): Promise<responses.ListRemotePeeringConnectionsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listRemotePeeringConnectionsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.RemotePeeringConnection objects
     * contained in responses from the listRemotePeeringConnections operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllRemotePeeringConnections(request: requests.ListRemotePeeringConnectionsRequest): AsyncIterableIterator<model.RemotePeeringConnection>;
    /**
     * NOTE: This function is deprecated in favor of listRemotePeeringConnectionsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listRemotePeeringConnections operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllRemotePeeringConnectionsResponses(request: requests.ListRemotePeeringConnectionsRequest): AsyncIterableIterator<responses.ListRemotePeeringConnectionsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.RemotePeeringConnection objects
     * contained in responses from the listRemotePeeringConnections operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listRemotePeeringConnectionsRecordIterator(request: requests.ListRemotePeeringConnectionsRequest): AsyncIterableIterator<model.RemotePeeringConnection>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listRemotePeeringConnections operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listRemotePeeringConnectionsResponseIterator(request: requests.ListRemotePeeringConnectionsRequest): AsyncIterableIterator<responses.ListRemotePeeringConnectionsResponse>;
    /**
     * Lists the route tables in the specified VCN and specified compartment.
     * If the VCN ID is not provided, then the list includes the route tables from all VCNs in the specified compartment.
     * The response includes the default route table that automatically comes with
     * each VCN in the specified compartment, plus any route tables you've created.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListRouteTablesRequest
     * @return ListRouteTablesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ListRouteTables.ts.html |here} to see how to use ListRouteTables API.
     */
    listRouteTables(listRouteTablesRequest: requests.ListRouteTablesRequest): Promise<responses.ListRouteTablesResponse>;
    /**
     * NOTE: This function is deprecated in favor of listRouteTablesRecordIterator function.
     * Creates a new async iterator which will iterate over the models.RouteTable objects
     * contained in responses from the listRouteTables operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllRouteTables(request: requests.ListRouteTablesRequest): AsyncIterableIterator<model.RouteTable>;
    /**
     * NOTE: This function is deprecated in favor of listRouteTablesResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listRouteTables operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllRouteTablesResponses(request: requests.ListRouteTablesRequest): AsyncIterableIterator<responses.ListRouteTablesResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.RouteTable objects
     * contained in responses from the listRouteTables operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listRouteTablesRecordIterator(request: requests.ListRouteTablesRequest): AsyncIterableIterator<model.RouteTable>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listRouteTables operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listRouteTablesResponseIterator(request: requests.ListRouteTablesRequest): AsyncIterableIterator<responses.ListRouteTablesResponse>;
    /**
     * Lists the security lists in the specified VCN and compartment.
     * If the VCN ID is not provided, then the list includes the security lists from all VCNs in the specified compartment.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListSecurityListsRequest
     * @return ListSecurityListsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ListSecurityLists.ts.html |here} to see how to use ListSecurityLists API.
     */
    listSecurityLists(listSecurityListsRequest: requests.ListSecurityListsRequest): Promise<responses.ListSecurityListsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listSecurityListsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.SecurityList objects
     * contained in responses from the listSecurityLists operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllSecurityLists(request: requests.ListSecurityListsRequest): AsyncIterableIterator<model.SecurityList>;
    /**
     * NOTE: This function is deprecated in favor of listSecurityListsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listSecurityLists operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllSecurityListsResponses(request: requests.ListSecurityListsRequest): AsyncIterableIterator<responses.ListSecurityListsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.SecurityList objects
     * contained in responses from the listSecurityLists operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listSecurityListsRecordIterator(request: requests.ListSecurityListsRequest): AsyncIterableIterator<model.SecurityList>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listSecurityLists operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listSecurityListsResponseIterator(request: requests.ListSecurityListsRequest): AsyncIterableIterator<responses.ListSecurityListsResponse>;
    /**
     * Lists the service gateways in the specified compartment. You may optionally specify a VCN OCID
     * to filter the results by VCN.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListServiceGatewaysRequest
     * @return ListServiceGatewaysResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ListServiceGateways.ts.html |here} to see how to use ListServiceGateways API.
     */
    listServiceGateways(listServiceGatewaysRequest: requests.ListServiceGatewaysRequest): Promise<responses.ListServiceGatewaysResponse>;
    /**
     * NOTE: This function is deprecated in favor of listServiceGatewaysRecordIterator function.
     * Creates a new async iterator which will iterate over the models.ServiceGateway objects
     * contained in responses from the listServiceGateways operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllServiceGateways(request: requests.ListServiceGatewaysRequest): AsyncIterableIterator<model.ServiceGateway>;
    /**
     * NOTE: This function is deprecated in favor of listServiceGatewaysResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listServiceGateways operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllServiceGatewaysResponses(request: requests.ListServiceGatewaysRequest): AsyncIterableIterator<responses.ListServiceGatewaysResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.ServiceGateway objects
     * contained in responses from the listServiceGateways operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listServiceGatewaysRecordIterator(request: requests.ListServiceGatewaysRequest): AsyncIterableIterator<model.ServiceGateway>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listServiceGateways operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listServiceGatewaysResponseIterator(request: requests.ListServiceGatewaysRequest): AsyncIterableIterator<responses.ListServiceGatewaysResponse>;
    /**
     * Lists the available {@link Service} objects that you can enable for a
     * service gateway in this region.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListServicesRequest
     * @return ListServicesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ListServices.ts.html |here} to see how to use ListServices API.
     */
    listServices(listServicesRequest: requests.ListServicesRequest): Promise<responses.ListServicesResponse>;
    /**
     * NOTE: This function is deprecated in favor of listServicesRecordIterator function.
     * Creates a new async iterator which will iterate over the models.Service objects
     * contained in responses from the listServices operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllServices(request: requests.ListServicesRequest): AsyncIterableIterator<model.Service>;
    /**
     * NOTE: This function is deprecated in favor of listServicesResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listServices operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllServicesResponses(request: requests.ListServicesRequest): AsyncIterableIterator<responses.ListServicesResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.Service objects
     * contained in responses from the listServices operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listServicesRecordIterator(request: requests.ListServicesRequest): AsyncIterableIterator<model.Service>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listServices operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listServicesResponseIterator(request: requests.ListServicesRequest): AsyncIterableIterator<responses.ListServicesResponse>;
    /**
     * Lists the subnets in the specified VCN and the specified compartment.
     * If the VCN ID is not provided, then the list includes the subnets from all VCNs in the specified compartment.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListSubnetsRequest
     * @return ListSubnetsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ListSubnets.ts.html |here} to see how to use ListSubnets API.
     */
    listSubnets(listSubnetsRequest: requests.ListSubnetsRequest): Promise<responses.ListSubnetsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listSubnetsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.Subnet objects
     * contained in responses from the listSubnets operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllSubnets(request: requests.ListSubnetsRequest): AsyncIterableIterator<model.Subnet>;
    /**
     * NOTE: This function is deprecated in favor of listSubnetsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listSubnets operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllSubnetsResponses(request: requests.ListSubnetsRequest): AsyncIterableIterator<responses.ListSubnetsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.Subnet objects
     * contained in responses from the listSubnets operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listSubnetsRecordIterator(request: requests.ListSubnetsRequest): AsyncIterableIterator<model.Subnet>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listSubnets operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listSubnetsResponseIterator(request: requests.ListSubnetsRequest): AsyncIterableIterator<responses.ListSubnetsResponse>;
    /**
     * Lists the virtual cloud networks (VCNs) in the specified compartment.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListVcnsRequest
     * @return ListVcnsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ListVcns.ts.html |here} to see how to use ListVcns API.
     */
    listVcns(listVcnsRequest: requests.ListVcnsRequest): Promise<responses.ListVcnsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listVcnsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.Vcn objects
     * contained in responses from the listVcns operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllVcns(request: requests.ListVcnsRequest): AsyncIterableIterator<model.Vcn>;
    /**
     * NOTE: This function is deprecated in favor of listVcnsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listVcns operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllVcnsResponses(request: requests.ListVcnsRequest): AsyncIterableIterator<responses.ListVcnsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.Vcn objects
     * contained in responses from the listVcns operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listVcnsRecordIterator(request: requests.ListVcnsRequest): AsyncIterableIterator<model.Vcn>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listVcns operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listVcnsResponseIterator(request: requests.ListVcnsRequest): AsyncIterableIterator<responses.ListVcnsResponse>;
    /**
     * Gets the specified virtual circuit's associatedTunnelsInfo.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListVirtualCircuitAssociatedTunnelsRequest
     * @return ListVirtualCircuitAssociatedTunnelsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ListVirtualCircuitAssociatedTunnels.ts.html |here} to see how to use ListVirtualCircuitAssociatedTunnels API.
     */
    listVirtualCircuitAssociatedTunnels(listVirtualCircuitAssociatedTunnelsRequest: requests.ListVirtualCircuitAssociatedTunnelsRequest): Promise<responses.ListVirtualCircuitAssociatedTunnelsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listVirtualCircuitAssociatedTunnelsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.VirtualCircuitAssociatedTunnelDetails objects
     * contained in responses from the listVirtualCircuitAssociatedTunnels operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllVirtualCircuitAssociatedTunnels(request: requests.ListVirtualCircuitAssociatedTunnelsRequest): AsyncIterableIterator<model.VirtualCircuitAssociatedTunnelDetails>;
    /**
     * NOTE: This function is deprecated in favor of listVirtualCircuitAssociatedTunnelsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listVirtualCircuitAssociatedTunnels operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllVirtualCircuitAssociatedTunnelsResponses(request: requests.ListVirtualCircuitAssociatedTunnelsRequest): AsyncIterableIterator<responses.ListVirtualCircuitAssociatedTunnelsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.VirtualCircuitAssociatedTunnelDetails objects
     * contained in responses from the listVirtualCircuitAssociatedTunnels operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listVirtualCircuitAssociatedTunnelsRecordIterator(request: requests.ListVirtualCircuitAssociatedTunnelsRequest): AsyncIterableIterator<model.VirtualCircuitAssociatedTunnelDetails>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listVirtualCircuitAssociatedTunnels operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listVirtualCircuitAssociatedTunnelsResponseIterator(request: requests.ListVirtualCircuitAssociatedTunnelsRequest): AsyncIterableIterator<responses.ListVirtualCircuitAssociatedTunnelsResponse>;
    /**
     * The deprecated operation lists available bandwidth levels for virtual circuits. For the compartment ID, provide the [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of your tenancy (the root compartment).
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListVirtualCircuitBandwidthShapesRequest
     * @return ListVirtualCircuitBandwidthShapesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ListVirtualCircuitBandwidthShapes.ts.html |here} to see how to use ListVirtualCircuitBandwidthShapes API.
     */
    listVirtualCircuitBandwidthShapes(listVirtualCircuitBandwidthShapesRequest: requests.ListVirtualCircuitBandwidthShapesRequest): Promise<responses.ListVirtualCircuitBandwidthShapesResponse>;
    /**
     * NOTE: This function is deprecated in favor of listVirtualCircuitBandwidthShapesRecordIterator function.
     * Creates a new async iterator which will iterate over the models.VirtualCircuitBandwidthShape objects
     * contained in responses from the listVirtualCircuitBandwidthShapes operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllVirtualCircuitBandwidthShapes(request: requests.ListVirtualCircuitBandwidthShapesRequest): AsyncIterableIterator<model.VirtualCircuitBandwidthShape>;
    /**
     * NOTE: This function is deprecated in favor of listVirtualCircuitBandwidthShapesResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listVirtualCircuitBandwidthShapes operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllVirtualCircuitBandwidthShapesResponses(request: requests.ListVirtualCircuitBandwidthShapesRequest): AsyncIterableIterator<responses.ListVirtualCircuitBandwidthShapesResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.VirtualCircuitBandwidthShape objects
     * contained in responses from the listVirtualCircuitBandwidthShapes operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listVirtualCircuitBandwidthShapesRecordIterator(request: requests.ListVirtualCircuitBandwidthShapesRequest): AsyncIterableIterator<model.VirtualCircuitBandwidthShape>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listVirtualCircuitBandwidthShapes operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listVirtualCircuitBandwidthShapesResponseIterator(request: requests.ListVirtualCircuitBandwidthShapesRequest): AsyncIterableIterator<responses.ListVirtualCircuitBandwidthShapesResponse>;
    /**
     * Lists the public IP prefixes and their details for the specified
     * public virtual circuit.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListVirtualCircuitPublicPrefixesRequest
     * @return ListVirtualCircuitPublicPrefixesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ListVirtualCircuitPublicPrefixes.ts.html |here} to see how to use ListVirtualCircuitPublicPrefixes API.
     */
    listVirtualCircuitPublicPrefixes(listVirtualCircuitPublicPrefixesRequest: requests.ListVirtualCircuitPublicPrefixesRequest): Promise<responses.ListVirtualCircuitPublicPrefixesResponse>;
    /**
     * Lists the virtual circuits in the specified compartment.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param ListVirtualCircuitsRequest
     * @return ListVirtualCircuitsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ListVirtualCircuits.ts.html |here} to see how to use ListVirtualCircuits API.
     */
    listVirtualCircuits(listVirtualCircuitsRequest: requests.ListVirtualCircuitsRequest): Promise<responses.ListVirtualCircuitsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listVirtualCircuitsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.VirtualCircuit objects
     * contained in responses from the listVirtualCircuits operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllVirtualCircuits(request: requests.ListVirtualCircuitsRequest): AsyncIterableIterator<model.VirtualCircuit>;
    /**
     * NOTE: This function is deprecated in favor of listVirtualCircuitsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listVirtualCircuits operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllVirtualCircuitsResponses(request: requests.ListVirtualCircuitsRequest): AsyncIterableIterator<responses.ListVirtualCircuitsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.VirtualCircuit objects
     * contained in responses from the listVirtualCircuits operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listVirtualCircuitsRecordIterator(request: requests.ListVirtualCircuitsRequest): AsyncIterableIterator<model.VirtualCircuit>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listVirtualCircuits operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listVirtualCircuitsResponseIterator(request: requests.ListVirtualCircuitsRequest): AsyncIterableIterator<responses.ListVirtualCircuitsResponse>;
    /**
     * Lists the VLANs in the specified VCN and the specified compartment.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListVlansRequest
     * @return ListVlansResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ListVlans.ts.html |here} to see how to use ListVlans API.
     */
    listVlans(listVlansRequest: requests.ListVlansRequest): Promise<responses.ListVlansResponse>;
    /**
     * NOTE: This function is deprecated in favor of listVlansRecordIterator function.
     * Creates a new async iterator which will iterate over the models.Vlan objects
     * contained in responses from the listVlans operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllVlans(request: requests.ListVlansRequest): AsyncIterableIterator<model.Vlan>;
    /**
     * NOTE: This function is deprecated in favor of listVlansResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listVlans operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllVlansResponses(request: requests.ListVlansRequest): AsyncIterableIterator<responses.ListVlansResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.Vlan objects
     * contained in responses from the listVlans operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listVlansRecordIterator(request: requests.ListVlansRequest): AsyncIterableIterator<model.Vlan>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listVlans operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listVlansResponseIterator(request: requests.ListVlansRequest): AsyncIterableIterator<responses.ListVlansResponse>;
    /**
     * Lists the virtual test access points (VTAPs) in the specified compartment.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListVtapsRequest
     * @return ListVtapsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ListVtaps.ts.html |here} to see how to use ListVtaps API.
     */
    listVtaps(listVtapsRequest: requests.ListVtapsRequest): Promise<responses.ListVtapsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listVtapsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.Vtap objects
     * contained in responses from the listVtaps operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllVtaps(request: requests.ListVtapsRequest): AsyncIterableIterator<model.Vtap>;
    /**
     * NOTE: This function is deprecated in favor of listVtapsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listVtaps operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllVtapsResponses(request: requests.ListVtapsRequest): AsyncIterableIterator<responses.ListVtapsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.Vtap objects
     * contained in responses from the listVtaps operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listVtapsRecordIterator(request: requests.ListVtapsRequest): AsyncIterableIterator<model.Vtap>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listVtaps operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listVtapsResponseIterator(request: requests.ListVtapsRequest): AsyncIterableIterator<responses.ListVtapsResponse>;
    /**
       * Updates the specified CIDR block of a VCN. The new CIDR IP range must meet the following criteria:
  * <p>
  - Must be valid.
  * - Must not overlap with another CIDR block in the VCN, a CIDR block of a peered VCN, or the on-premises network CIDR block.
  * - Must not exceed the limit of CIDR blocks allowed per VCN.
  * - Must include IP addresses from the original CIDR block that are used in the VCN's existing route rules.
  * - No IP address in an existing subnet should be outside of the new CIDR block range.
  * <p>
  **Note:** Modifying a CIDR block places your VCN in an updating state until the changes are complete. You cannot create or update the VCN's subnets, VLANs, LPGs, or route tables during this operation. The time to completion can vary depending on the size of your network. Updating a small network could take about a minute, and updating a large network could take up to an hour. You can use the `GetWorkRequest` operation to check the status of the update.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param ModifyVcnCidrRequest
       * @return ModifyVcnCidrResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ModifyVcnCidr.ts.html |here} to see how to use ModifyVcnCidr API.
       */
    modifyVcnCidr(modifyVcnCidrRequest: requests.ModifyVcnCidrRequest): Promise<responses.ModifyVcnCidrResponse>;
    /**
     * Removes one or more route distribution statements from the specified route distribution's map.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param RemoveDrgRouteDistributionStatementsRequest
     * @return RemoveDrgRouteDistributionStatementsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/RemoveDrgRouteDistributionStatements.ts.html |here} to see how to use RemoveDrgRouteDistributionStatements API.
     */
    removeDrgRouteDistributionStatements(removeDrgRouteDistributionStatementsRequest: requests.RemoveDrgRouteDistributionStatementsRequest): Promise<responses.RemoveDrgRouteDistributionStatementsResponse>;
    /**
     * Removes one or more route rules from the specified DRG route table.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param RemoveDrgRouteRulesRequest
     * @return RemoveDrgRouteRulesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/RemoveDrgRouteRules.ts.html |here} to see how to use RemoveDrgRouteRules API.
     */
    removeDrgRouteRules(removeDrgRouteRulesRequest: requests.RemoveDrgRouteRulesRequest): Promise<responses.RemoveDrgRouteRulesResponse>;
    /**
     * Removes the export route distribution from the DRG attachment so no routes are advertised to it.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param RemoveExportDrgRouteDistributionRequest
     * @return RemoveExportDrgRouteDistributionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/RemoveExportDrgRouteDistribution.ts.html |here} to see how to use RemoveExportDrgRouteDistribution API.
     */
    removeExportDrgRouteDistribution(removeExportDrgRouteDistributionRequest: requests.RemoveExportDrgRouteDistributionRequest): Promise<responses.RemoveExportDrgRouteDistributionResponse>;
    /**
     * Removes the import route distribution from the DRG route table so no routes are imported
     * into it.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param RemoveImportDrgRouteDistributionRequest
     * @return RemoveImportDrgRouteDistributionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/RemoveImportDrgRouteDistribution.ts.html |here} to see how to use RemoveImportDrgRouteDistribution API.
     */
    removeImportDrgRouteDistribution(removeImportDrgRouteDistributionRequest: requests.RemoveImportDrgRouteDistributionRequest): Promise<responses.RemoveImportDrgRouteDistributionResponse>;
    /**
     * Remove an IPv6 prefix from a subnet. At least one IPv6 CIDR should remain.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param RemoveIpv6SubnetCidrRequest
     * @return RemoveIpv6SubnetCidrResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/RemoveIpv6SubnetCidr.ts.html |here} to see how to use RemoveIpv6SubnetCidr API.
     */
    removeIpv6SubnetCidr(removeIpv6SubnetCidrRequest: requests.RemoveIpv6SubnetCidrRequest): Promise<responses.RemoveIpv6SubnetCidrResponse>;
    /**
     * Removing an existing IPv6 prefix from a VCN.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param RemoveIpv6VcnCidrRequest
     * @return RemoveIpv6VcnCidrResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/RemoveIpv6VcnCidr.ts.html |here} to see how to use RemoveIpv6VcnCidr API.
     */
    removeIpv6VcnCidr(removeIpv6VcnCidrRequest: requests.RemoveIpv6VcnCidrRequest): Promise<responses.RemoveIpv6VcnCidrResponse>;
    /**
     * Removes one or more security rules from the specified network security group.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param RemoveNetworkSecurityGroupSecurityRulesRequest
     * @return RemoveNetworkSecurityGroupSecurityRulesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/RemoveNetworkSecurityGroupSecurityRules.ts.html |here} to see how to use RemoveNetworkSecurityGroupSecurityRules API.
     */
    removeNetworkSecurityGroupSecurityRules(removeNetworkSecurityGroupSecurityRulesRequest: requests.RemoveNetworkSecurityGroupSecurityRulesRequest): Promise<responses.RemoveNetworkSecurityGroupSecurityRulesResponse>;
    /**
     * Removes a CIDR block from the referenced public IP pool.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param RemovePublicIpPoolCapacityRequest
     * @return RemovePublicIpPoolCapacityResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/RemovePublicIpPoolCapacity.ts.html |here} to see how to use RemovePublicIpPoolCapacity API.
     */
    removePublicIpPoolCapacity(removePublicIpPoolCapacityRequest: requests.RemovePublicIpPoolCapacityRequest): Promise<responses.RemovePublicIpPoolCapacityResponse>;
    /**
     * Removes a specified CIDR block from a VCN.
     * <p>
     **Notes:**
     * - You cannot remove a CIDR block if an IP address in its range is in use.
     * - Removing a CIDR block places your VCN in an updating state until the changes are complete. You cannot create or update the VCN's subnets, VLANs, LPGs, or route tables during this operation. The time to completion can take a few minutes. You can use the `GetWorkRequest` operation to check the status of the update.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param RemoveVcnCidrRequest
     * @return RemoveVcnCidrResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/RemoveVcnCidr.ts.html |here} to see how to use RemoveVcnCidr API.
     */
    removeVcnCidr(removeVcnCidrRequest: requests.RemoveVcnCidrRequest): Promise<responses.RemoveVcnCidrResponse>;
    /**
     * Updates the tags or display name associated to the specified BYOIP CIDR block.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateByoipRangeRequest
     * @return UpdateByoipRangeResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/UpdateByoipRange.ts.html |here} to see how to use UpdateByoipRange API.
     */
    updateByoipRange(updateByoipRangeRequest: requests.UpdateByoipRangeRequest): Promise<responses.UpdateByoipRangeResponse>;
    /**
     * Updates the specified VTAP capture filter's display name or tags.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateCaptureFilterRequest
     * @return UpdateCaptureFilterResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/UpdateCaptureFilter.ts.html |here} to see how to use UpdateCaptureFilter API.
     */
    updateCaptureFilter(updateCaptureFilterRequest: requests.UpdateCaptureFilterRequest): Promise<responses.UpdateCaptureFilterResponse>;
    /**
     * Updates the specified CPE's display name or tags.
     * Avoid entering confidential information.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateCpeRequest
     * @return UpdateCpeResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/UpdateCpe.ts.html |here} to see how to use UpdateCpe API.
     */
    updateCpe(updateCpeRequest: requests.UpdateCpeRequest): Promise<responses.UpdateCpeResponse>;
    /**
     * Updates the specified cross-connect.
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateCrossConnectRequest
     * @return UpdateCrossConnectResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/UpdateCrossConnect.ts.html |here} to see how to use UpdateCrossConnect API.
     */
    updateCrossConnect(updateCrossConnectRequest: requests.UpdateCrossConnectRequest): Promise<responses.UpdateCrossConnectResponse>;
    /**
     * Updates the specified cross-connect group's display name.
     * Avoid entering confidential information.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateCrossConnectGroupRequest
     * @return UpdateCrossConnectGroupResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/UpdateCrossConnectGroup.ts.html |here} to see how to use UpdateCrossConnectGroup API.
     */
    updateCrossConnectGroup(updateCrossConnectGroupRequest: requests.UpdateCrossConnectGroupRequest): Promise<responses.UpdateCrossConnectGroupResponse>;
    /**
       * Updates the specified set of DHCP options. You can update the display name or the options
  * themselves. Avoid entering confidential information.
  * <p>
  Note that the `options` object you provide replaces the entire existing set of options.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param UpdateDhcpOptionsRequest
       * @return UpdateDhcpOptionsResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/UpdateDhcpOptions.ts.html |here} to see how to use UpdateDhcpOptions API.
       */
    updateDhcpOptions(updateDhcpOptionsRequest: requests.UpdateDhcpOptionsRequest): Promise<responses.UpdateDhcpOptionsResponse>;
    /**
     * Updates the specified DRG's display name or tags. Avoid entering confidential information.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateDrgRequest
     * @return UpdateDrgResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/UpdateDrg.ts.html |here} to see how to use UpdateDrg API.
     */
    updateDrg(updateDrgRequest: requests.UpdateDrgRequest): Promise<responses.UpdateDrgResponse>;
    /**
     * Updates the display name and routing information for the specified `DrgAttachment`.
     * Avoid entering confidential information.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateDrgAttachmentRequest
     * @return UpdateDrgAttachmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/UpdateDrgAttachment.ts.html |here} to see how to use UpdateDrgAttachment API.
     */
    updateDrgAttachment(updateDrgAttachmentRequest: requests.UpdateDrgAttachmentRequest): Promise<responses.UpdateDrgAttachmentResponse>;
    /**
     * Updates the specified route distribution
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateDrgRouteDistributionRequest
     * @return UpdateDrgRouteDistributionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/UpdateDrgRouteDistribution.ts.html |here} to see how to use UpdateDrgRouteDistribution API.
     */
    updateDrgRouteDistribution(updateDrgRouteDistributionRequest: requests.UpdateDrgRouteDistributionRequest): Promise<responses.UpdateDrgRouteDistributionResponse>;
    /**
     * Updates one or more route distribution statements in the specified route distribution.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateDrgRouteDistributionStatementsRequest
     * @return UpdateDrgRouteDistributionStatementsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/UpdateDrgRouteDistributionStatements.ts.html |here} to see how to use UpdateDrgRouteDistributionStatements API.
     */
    updateDrgRouteDistributionStatements(updateDrgRouteDistributionStatementsRequest: requests.UpdateDrgRouteDistributionStatementsRequest): Promise<responses.UpdateDrgRouteDistributionStatementsResponse>;
    /**
     * Updates one or more route rules in the specified DRG route table.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateDrgRouteRulesRequest
     * @return UpdateDrgRouteRulesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/UpdateDrgRouteRules.ts.html |here} to see how to use UpdateDrgRouteRules API.
     */
    updateDrgRouteRules(updateDrgRouteRulesRequest: requests.UpdateDrgRouteRulesRequest): Promise<responses.UpdateDrgRouteRulesResponse>;
    /**
     * Updates the specified DRG route table.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateDrgRouteTableRequest
     * @return UpdateDrgRouteTableResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/UpdateDrgRouteTable.ts.html |here} to see how to use UpdateDrgRouteTable API.
     */
    updateDrgRouteTable(updateDrgRouteTableRequest: requests.UpdateDrgRouteTableRequest): Promise<responses.UpdateDrgRouteTableResponse>;
    /**
       * Updates the specified IPSec connection.
  * <p>
  To update an individual IPSec tunnel's attributes, use
  * {@link #updateIPSecConnectionTunnel(UpdateIPSecConnectionTunnelRequest) updateIPSecConnectionTunnel}.
  *
       * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
       * @param UpdateIPSecConnectionRequest
       * @return UpdateIPSecConnectionResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/UpdateIPSecConnection.ts.html |here} to see how to use UpdateIPSecConnection API.
       */
    updateIPSecConnection(updateIPSecConnectionRequest: requests.UpdateIPSecConnectionRequest): Promise<responses.UpdateIPSecConnectionResponse>;
    /**
     * Updates the specified tunnel. This operation lets you change tunnel attributes such as the
     * routing type (BGP dynamic routing or static routing). Here are some important notes:
     * <p>
     * If you change the tunnel's routing type or BGP session configuration, the tunnel will go
     *     down while it's reprovisioned.
     * <p>
     * If you want to switch the tunnel's `routing` from `STATIC` to `BGP`, make sure the tunnel's
     *     BGP session configuration attributes have been set ({@link #bgpSessionInfo(BgpSessionInfoRequest) bgpSessionInfo}).
     * <p>
     * If you want to switch the tunnel's `routing` from `BGP` to `STATIC`, make sure the
     *     {@link IPSecConnection} already has at least one valid CIDR
     *     static route.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateIPSecConnectionTunnelRequest
     * @return UpdateIPSecConnectionTunnelResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/UpdateIPSecConnectionTunnel.ts.html |here} to see how to use UpdateIPSecConnectionTunnel API.
     */
    updateIPSecConnectionTunnel(updateIPSecConnectionTunnelRequest: requests.UpdateIPSecConnectionTunnelRequest): Promise<responses.UpdateIPSecConnectionTunnelResponse>;
    /**
     * Updates the shared secret (pre-shared key) for the specified tunnel.
     * <p>
     **Important:** If you change the shared secret, the tunnel will go down while it's reprovisioned.
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateIPSecConnectionTunnelSharedSecretRequest
     * @return UpdateIPSecConnectionTunnelSharedSecretResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/UpdateIPSecConnectionTunnelSharedSecret.ts.html |here} to see how to use UpdateIPSecConnectionTunnelSharedSecret API.
     */
    updateIPSecConnectionTunnelSharedSecret(updateIPSecConnectionTunnelSharedSecretRequest: requests.UpdateIPSecConnectionTunnelSharedSecretRequest): Promise<responses.UpdateIPSecConnectionTunnelSharedSecretResponse>;
    /**
       * Updates the specified internet gateway. You can disable/enable it, or change its display name
  * or tags. Avoid entering confidential information.
  * <p>
  If the gateway is disabled, that means no traffic will flow to/from the internet even if there's
  * a route rule that enables that traffic.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param UpdateInternetGatewayRequest
       * @return UpdateInternetGatewayResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/UpdateInternetGateway.ts.html |here} to see how to use UpdateInternetGateway API.
       */
    updateInternetGateway(updateInternetGatewayRequest: requests.UpdateInternetGatewayRequest): Promise<responses.UpdateInternetGatewayResponse>;
    /**
     * Updates the specified IPv6. You must specify the object's [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
     * Use this operation if you want to:
     * <p>
     * Move an IPv6 to a different VNIC in the same subnet.
     *   * Enable/disable internet access for an IPv6.
     *   * Change the display name for an IPv6.
     *   * Update resource tags for an IPv6.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateIpv6Request
     * @return UpdateIpv6Response
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/UpdateIpv6.ts.html |here} to see how to use UpdateIpv6 API.
     */
    updateIpv6(updateIpv6Request: requests.UpdateIpv6Request): Promise<responses.UpdateIpv6Response>;
    /**
     * Updates the specified local peering gateway (LPG).
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateLocalPeeringGatewayRequest
     * @return UpdateLocalPeeringGatewayResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/UpdateLocalPeeringGateway.ts.html |here} to see how to use UpdateLocalPeeringGateway API.
     */
    updateLocalPeeringGateway(updateLocalPeeringGatewayRequest: requests.UpdateLocalPeeringGatewayRequest): Promise<responses.UpdateLocalPeeringGatewayResponse>;
    /**
     * Updates the specified NAT gateway.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateNatGatewayRequest
     * @return UpdateNatGatewayResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/UpdateNatGateway.ts.html |here} to see how to use UpdateNatGateway API.
     */
    updateNatGateway(updateNatGatewayRequest: requests.UpdateNatGatewayRequest): Promise<responses.UpdateNatGatewayResponse>;
    /**
       * Updates the specified network security group.
  * <p>
  To add or remove an existing VNIC from the group, use
  * {@link #updateVnic(UpdateVnicRequest) updateVnic}.
  * <p>
  To add a VNIC to the group *when you create the VNIC*, specify the NSG's [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) during creation.
  * For example, see the `nsgIds` attribute in {@link #createVnicDetails(CreateVnicDetailsRequest) createVnicDetails}.
  * <p>
  To add or remove security rules from the group, use
  * {@link #addNetworkSecurityGroupSecurityRules(AddNetworkSecurityGroupSecurityRulesRequest) addNetworkSecurityGroupSecurityRules}
  * or
  * {@link #removeNetworkSecurityGroupSecurityRules(RemoveNetworkSecurityGroupSecurityRulesRequest) removeNetworkSecurityGroupSecurityRules}.
  * <p>
  To edit the contents of existing security rules in the group, use
  * {@link #updateNetworkSecurityGroupSecurityRules(UpdateNetworkSecurityGroupSecurityRulesRequest) updateNetworkSecurityGroupSecurityRules}.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param UpdateNetworkSecurityGroupRequest
       * @return UpdateNetworkSecurityGroupResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/UpdateNetworkSecurityGroup.ts.html |here} to see how to use UpdateNetworkSecurityGroup API.
       */
    updateNetworkSecurityGroup(updateNetworkSecurityGroupRequest: requests.UpdateNetworkSecurityGroupRequest): Promise<responses.UpdateNetworkSecurityGroupResponse>;
    /**
     * Updates one or more security rules in the specified network security group.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateNetworkSecurityGroupSecurityRulesRequest
     * @return UpdateNetworkSecurityGroupSecurityRulesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/UpdateNetworkSecurityGroupSecurityRules.ts.html |here} to see how to use UpdateNetworkSecurityGroupSecurityRules API.
     */
    updateNetworkSecurityGroupSecurityRules(updateNetworkSecurityGroupSecurityRulesRequest: requests.UpdateNetworkSecurityGroupSecurityRulesRequest): Promise<responses.UpdateNetworkSecurityGroupSecurityRulesResponse>;
    /**
       * Updates the specified private IP. You must specify the object's [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
  * Use this operation if you want to:
  * <p>
    - Move a secondary private IP to a different VNIC in the same subnet.
  *   - Change the display name for a secondary private IP.
  *   - Change the hostname for a secondary private IP.
  * <p>
  This operation cannot be used with primary private IPs.
  * To update the hostname for the primary IP on a VNIC, use
  * {@link #updateVnic(UpdateVnicRequest) updateVnic}.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param UpdatePrivateIpRequest
       * @return UpdatePrivateIpResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/UpdatePrivateIp.ts.html |here} to see how to use UpdatePrivateIp API.
       */
    updatePrivateIp(updatePrivateIpRequest: requests.UpdatePrivateIpRequest): Promise<responses.UpdatePrivateIpResponse>;
    /**
       * Updates the specified public IP. You must specify the object's [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm). Use this operation if you want to:
  * <p>
  * Assign a reserved public IP in your pool to a private IP.
  * * Move a reserved public IP to a different private IP.
  * * Unassign a reserved public IP from a private IP (which returns it to your pool
  * of reserved public IPs).
  * * Change the display name or tags for a public IP.
  * <p>
  Assigning, moving, and unassigning a reserved public IP are asynchronous
  * operations. Poll the public IP's `lifecycleState` to determine if the operation
  * succeeded.
  * <p>
  **Note:** When moving a reserved public IP, the target private IP
  * must not already have a public IP with `lifecycleState` = ASSIGNING or ASSIGNED. If it
  * does, an error is returned. Also, the initial unassignment from the original
  * private IP always succeeds, but the assignment to the target private IP is asynchronous and
  * could fail silently (for example, if the target private IP is deleted or has a different public IP
  * assigned to it in the interim). If that occurs, the public IP remains unassigned and its
  * `lifecycleState` switches to AVAILABLE (it is not reassigned to its original private IP).
  * You must poll the public IP's `lifecycleState` to determine if the move succeeded.
  * <p>
  Regarding ephemeral public IPs:
  * <p>
  * If you want to assign an ephemeral public IP to a primary private IP, use
  * {@link #createPublicIp(CreatePublicIpRequest) createPublicIp}.
  * * You can't move an ephemeral public IP to a different private IP.
  * * If you want to unassign an ephemeral public IP from its private IP, use
  * {@link #deletePublicIp(DeletePublicIpRequest) deletePublicIp}, which
  * unassigns and deletes the ephemeral public IP.
  * <p>
  **Note:** If a public IP is assigned to a secondary private
  * IP (see {@link PrivateIp}), and you move that secondary
  * private IP to another VNIC, the public IP moves with it.
  * <p>
  **Note:** There's a limit to the number of {@link PublicIp}
  * a VNIC or instance can have. If you try to move a reserved public IP
  * to a VNIC or instance that has already reached its public IP limit, an error is
  * returned. For information about the public IP limits, see
  * [Public IP Addresses](https://docs.cloud.oracle.com/iaas/Content/Network/Tasks/managingpublicIPs.htm).
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param UpdatePublicIpRequest
       * @return UpdatePublicIpResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/UpdatePublicIp.ts.html |here} to see how to use UpdatePublicIp API.
       */
    updatePublicIp(updatePublicIpRequest: requests.UpdatePublicIpRequest): Promise<responses.UpdatePublicIpResponse>;
    /**
     * Updates the specified public IP pool.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdatePublicIpPoolRequest
     * @return UpdatePublicIpPoolResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/UpdatePublicIpPool.ts.html |here} to see how to use UpdatePublicIpPool API.
     */
    updatePublicIpPool(updatePublicIpPoolRequest: requests.UpdatePublicIpPoolRequest): Promise<responses.UpdatePublicIpPoolResponse>;
    /**
     * Updates the specified remote peering connection (RPC).
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateRemotePeeringConnectionRequest
     * @return UpdateRemotePeeringConnectionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/UpdateRemotePeeringConnection.ts.html |here} to see how to use UpdateRemotePeeringConnection API.
     */
    updateRemotePeeringConnection(updateRemotePeeringConnectionRequest: requests.UpdateRemotePeeringConnectionRequest): Promise<responses.UpdateRemotePeeringConnectionResponse>;
    /**
       * Updates the specified route table's display name or route rules.
  * Avoid entering confidential information.
  * <p>
  Note that the `routeRules` object you provide replaces the entire existing set of rules.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param UpdateRouteTableRequest
       * @return UpdateRouteTableResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/UpdateRouteTable.ts.html |here} to see how to use UpdateRouteTable API.
       */
    updateRouteTable(updateRouteTableRequest: requests.UpdateRouteTableRequest): Promise<responses.UpdateRouteTableResponse>;
    /**
       * Updates the specified security list's display name or rules.
  * Avoid entering confidential information.
  * <p>
  Note that the `egressSecurityRules` or `ingressSecurityRules` objects you provide replace the entire
  * existing objects.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param UpdateSecurityListRequest
       * @return UpdateSecurityListResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/UpdateSecurityList.ts.html |here} to see how to use UpdateSecurityList API.
       */
    updateSecurityList(updateSecurityListRequest: requests.UpdateSecurityListRequest): Promise<responses.UpdateSecurityListResponse>;
    /**
     * Updates the specified service gateway. The information you provide overwrites the existing
     * attributes of the gateway.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateServiceGatewayRequest
     * @return UpdateServiceGatewayResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/UpdateServiceGateway.ts.html |here} to see how to use UpdateServiceGateway API.
     */
    updateServiceGateway(updateServiceGatewayRequest: requests.UpdateServiceGatewayRequest): Promise<responses.UpdateServiceGatewayResponse>;
    /**
     * Updates the specified subnet.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateSubnetRequest
     * @return UpdateSubnetResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/UpdateSubnet.ts.html |here} to see how to use UpdateSubnet API.
     */
    updateSubnet(updateSubnetRequest: requests.UpdateSubnetRequest): Promise<responses.UpdateSubnetResponse>;
    /**
     * Creates or updates the set of CPE configuration answers for the specified tunnel.
     * The answers correlate to the questions that are specific to the CPE device type (see the
     * `parameters` attribute of {@link CpeDeviceShapeDetail}).
     *
     * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
     * @param UpdateTunnelCpeDeviceConfigRequest
     * @return UpdateTunnelCpeDeviceConfigResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/UpdateTunnelCpeDeviceConfig.ts.html |here} to see how to use UpdateTunnelCpeDeviceConfig API.
     */
    updateTunnelCpeDeviceConfig(updateTunnelCpeDeviceConfigRequest: requests.UpdateTunnelCpeDeviceConfigRequest): Promise<responses.UpdateTunnelCpeDeviceConfigResponse>;
    /**
     * Updates the specified VCN.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateVcnRequest
     * @return UpdateVcnResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/UpdateVcn.ts.html |here} to see how to use UpdateVcn API.
     */
    updateVcn(updateVcnRequest: requests.UpdateVcnRequest): Promise<responses.UpdateVcnResponse>;
    /**
       * Updates the specified virtual circuit. This can be called by
  * either the customer who owns the virtual circuit, or the
  * provider (when provisioning or de-provisioning the virtual
  * circuit from their end). The documentation for
  * {@link #updateVirtualCircuitDetails(UpdateVirtualCircuitDetailsRequest) updateVirtualCircuitDetails}
  * indicates who can update each property of the virtual circuit.
  * <p>
  **Important:** If the virtual circuit is working and in the
  * PROVISIONED state, updating any of the network-related properties
  * (such as the DRG being used, the BGP ASN, and so on) will cause the virtual
  * circuit's state to switch to PROVISIONING and the related BGP
  * session to go down. After Oracle re-provisions the virtual circuit,
  * its state will return to PROVISIONED. Make sure you confirm that
  * the associated BGP session is back up. For more information
  * about the various states and how to test connectivity, see
  * [FastConnect Overview](https://docs.cloud.oracle.com/iaas/Content/Network/Concepts/fastconnect.htm).
  * <p>
  To change the list of public IP prefixes for a public virtual circuit,
  * use {@link #bulkAddVirtualCircuitPublicPrefixes(BulkAddVirtualCircuitPublicPrefixesRequest) bulkAddVirtualCircuitPublicPrefixes}
  * and
  * {@link #bulkDeleteVirtualCircuitPublicPrefixes(BulkDeleteVirtualCircuitPublicPrefixesRequest) bulkDeleteVirtualCircuitPublicPrefixes}.
  * Updating the list of prefixes does NOT cause the BGP session to go down. However,
  * Oracle must verify the customer's ownership of each added prefix before
  * traffic for that prefix will flow across the virtual circuit.
  *
       * This operation uses {@link common.OciSdkDefaultRetryConfiguration} by default if no retry configuration is defined by the user.
       * @param UpdateVirtualCircuitRequest
       * @return UpdateVirtualCircuitResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/UpdateVirtualCircuit.ts.html |here} to see how to use UpdateVirtualCircuit API.
       */
    updateVirtualCircuit(updateVirtualCircuitRequest: requests.UpdateVirtualCircuitRequest): Promise<responses.UpdateVirtualCircuitResponse>;
    /**
     * Updates the specified VLAN. Note that this operation might require changes to all
     * the VNICs in the VLAN, which can take a while. The VLAN will be in the UPDATING state until the changes are complete.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateVlanRequest
     * @return UpdateVlanResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/UpdateVlan.ts.html |here} to see how to use UpdateVlan API.
     */
    updateVlan(updateVlanRequest: requests.UpdateVlanRequest): Promise<responses.UpdateVlanResponse>;
    /**
     * Updates the specified VNIC.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateVnicRequest
     * @return UpdateVnicResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/UpdateVnic.ts.html |here} to see how to use UpdateVnic API.
     */
    updateVnic(updateVnicRequest: requests.UpdateVnicRequest): Promise<responses.UpdateVnicResponse>;
    /**
     * Updates the specified VTAP's display name or tags.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateVtapRequest
     * @return UpdateVtapResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/UpdateVtap.ts.html |here} to see how to use UpdateVtap API.
     */
    updateVtap(updateVtapRequest: requests.UpdateVtapRequest): Promise<responses.UpdateVtapResponse>;
    /**
     * Upgrades the DRG. After upgrade, you can control routing inside your DRG
     * via DRG attachments, route distributions, and DRG route tables.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpgradeDrgRequest
     * @return UpgradeDrgResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/UpgradeDrg.ts.html |here} to see how to use UpgradeDrg API.
     */
    upgradeDrg(upgradeDrgRequest: requests.UpgradeDrgRequest): Promise<responses.UpgradeDrgResponse>;
    /**
     * Submits the BYOIP CIDR block you are importing for validation. Do not submit to Oracle for validation if you have not already
     * modified the information for the BYOIP CIDR block with your Regional Internet Registry. See [To import a CIDR block](https://docs.cloud.oracle.com/iaas/Content/Network/Concepts/BYOIP.htm#import_cidr) for details.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ValidateByoipRangeRequest
     * @return ValidateByoipRangeResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/ValidateByoipRange.ts.html |here} to see how to use ValidateByoipRange API.
     */
    validateByoipRange(validateByoipRangeRequest: requests.ValidateByoipRangeRequest): Promise<responses.ValidateByoipRangeResponse>;
    /**
     * Withdraws BGP route advertisement for the BYOIP CIDR block.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param WithdrawByoipRangeRequest
     * @return WithdrawByoipRangeResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/core/WithdrawByoipRange.ts.html |here} to see how to use WithdrawByoipRange API.
     */
    withdrawByoipRange(withdrawByoipRangeRequest: requests.WithdrawByoipRangeRequest): Promise<responses.WithdrawByoipRangeResponse>;
}
export {};
