/**
 * Database Service API
 * The API for the Database Service. Use this API to manage resources such as databases and DB Systems. For more information, see [Overview of the Database Service](/iaas/Content/Database/Concepts/databaseoverview.htm).

 * OpenAPI spec version: 20160918
 * Contact: sic_dbaas_cp_us_grp@oracle.com
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import common = require("oci-common");
import * as requests from "./request";
import * as model from "./model";
import * as responses from "./response";
import { WorkRequestClient } from "oci-workrequests";
import { DatabaseWaiter } from "./database-waiter";
declare const Breaker: any;
export declare enum DatabaseApiKeys {
}
/**
 * This service client uses {@link common.CircuitBreaker.DefaultConfiguration} for all the operations by default if no circuit breaker configuration is defined by the user.
 */
export declare class DatabaseClient {
    protected static serviceEndpointTemplate: string;
    protected static endpointServiceName: string;
    protected "_realmSpecificEndpointTemplateEnabled": boolean | undefined;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_waiters": DatabaseWaiter;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: typeof Breaker | null;
    protected _httpOptions: any;
    protected _bodyDuplexMode: any;
    targetService: string;
    protected _regionId: string;
    protected "_region": common.Region;
    protected _lastSetRegionOrRegionId: string;
    protected _httpClient: common.HttpClient;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    get endpoint(): string;
    /**
     * Sets the endpoint to call (ex, https://www.example.com).
     * @param endpoint The endpoint of the service.
     */
    set endpoint(endpoint: string);
    get logger(): import("oci-common/lib/log").Logger;
    /**
     * Determines whether realm specific endpoint should be used or not.
     * Set realmSpecificEndpointTemplateEnabled to "true" if the user wants to enable use of realm specific endpoint template, otherwise set it to "false"
     * @param realmSpecificEndpointTemplateEnabled flag to enable the use of realm specific endpoint template
     */
    set useRealmSpecificEndpointTemplate(realmSpecificEndpointTemplateEnabled: boolean);
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    set region(region: common.Region);
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    set regionId(regionId: string);
    /**
     * Creates a new DatabaseWaiter for resources for this service.
     *
     * @param workRequestClient The work request service client used to query for work request status
     * @param config The waiter configuration for termination and delay strategy
     * @return The service waiters.
     */
    createWaiters(workRequestClient: WorkRequestClient, config?: common.WaiterConfiguration): DatabaseWaiter;
    /**
     * Gets the waiters available for resources for this service.
     *
     * @return The service waiters.
     */
    getWaiters(): DatabaseWaiter;
    /**
     * Shutdown the circuit breaker used by the client when it is no longer needed
     */
    shutdownCircuitBreaker(): void;
    /**
     * Close the client once it is no longer needed
     */
    close(): void;
    /**
     * Activates the specified Exadata infrastructure resource. Applies to Exadata Cloud@Customer instances only.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ActivateExadataInfrastructureRequest
     * @return ActivateExadataInfrastructureResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ActivateExadataInfrastructure.ts.html |here} to see how to use ActivateExadataInfrastructure API.
     */
    activateExadataInfrastructure(activateExadataInfrastructureRequest: requests.ActivateExadataInfrastructureRequest): Promise<responses.ActivateExadataInfrastructureResponse>;
    /**
     * Makes the storage capacity from additional storage servers available for Cloud VM Cluster consumption. Applies to Exadata Cloud Service instances and Autonomous Database on dedicated Exadata infrastructure only.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param AddStorageCapacityCloudExadataInfrastructureRequest
     * @return AddStorageCapacityCloudExadataInfrastructureResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/AddStorageCapacityCloudExadataInfrastructure.ts.html |here} to see how to use AddStorageCapacityCloudExadataInfrastructure API.
     */
    addStorageCapacityCloudExadataInfrastructure(addStorageCapacityCloudExadataInfrastructureRequest: requests.AddStorageCapacityCloudExadataInfrastructureRequest): Promise<responses.AddStorageCapacityCloudExadataInfrastructureResponse>;
    /**
     * Makes the storage capacity from additional storage servers available for VM Cluster consumption. Applies to Exadata Cloud@Customer instances only.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param AddStorageCapacityExadataInfrastructureRequest
     * @return AddStorageCapacityExadataInfrastructureResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/AddStorageCapacityExadataInfrastructure.ts.html |here} to see how to use AddStorageCapacityExadataInfrastructure API.
     */
    addStorageCapacityExadataInfrastructure(addStorageCapacityExadataInfrastructureRequest: requests.AddStorageCapacityExadataInfrastructureRequest): Promise<responses.AddStorageCapacityExadataInfrastructureResponse>;
    /**
     * Add Virtual Machines to the Cloud VM cluster. Applies to Exadata Cloud instances only.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param AddVirtualMachineToCloudVmClusterRequest
     * @return AddVirtualMachineToCloudVmClusterResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/AddVirtualMachineToCloudVmCluster.ts.html |here} to see how to use AddVirtualMachineToCloudVmCluster API.
     */
    addVirtualMachineToCloudVmCluster(addVirtualMachineToCloudVmClusterRequest: requests.AddVirtualMachineToCloudVmClusterRequest): Promise<responses.AddVirtualMachineToCloudVmClusterResponse>;
    /**
     * Add Virtual Machines to the VM cluster. Applies to Exadata Cloud@Customer instances only.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param AddVirtualMachineToVmClusterRequest
     * @return AddVirtualMachineToVmClusterResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/AddVirtualMachineToVmCluster.ts.html |here} to see how to use AddVirtualMachineToVmCluster API.
     */
    addVirtualMachineToVmCluster(addVirtualMachineToVmClusterRequest: requests.AddVirtualMachineToVmClusterRequest): Promise<responses.AddVirtualMachineToVmClusterResponse>;
    /**
     * Initiates a data refresh for an Autonomous Database refreshable clone. Data is refreshed from the source database to the point of a specified timestamp.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param AutonomousDatabaseManualRefreshRequest
     * @return AutonomousDatabaseManualRefreshResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/AutonomousDatabaseManualRefresh.ts.html |here} to see how to use AutonomousDatabaseManualRefresh API.
     */
    autonomousDatabaseManualRefresh(autonomousDatabaseManualRefreshRequest: requests.AutonomousDatabaseManualRefreshRequest): Promise<responses.AutonomousDatabaseManualRefreshResponse>;
    /**
     * Cancel automatic/standalone full/incremental create backup workrequests specified by the backup Id.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CancelBackupRequest
     * @return CancelBackupResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/CancelBackup.ts.html |here} to see how to use CancelBackup API.
     */
    cancelBackup(cancelBackupRequest: requests.CancelBackupRequest): Promise<responses.CancelBackupResponse>;
    /**
     * Move the Autonomous Container Database and its dependent resources to the specified compartment.
     * For more information about moving Autonomous Container Databases, see
     * [Moving Database Resources to a Different Compartment](https://docs.cloud.oracle.com/Content/Database/Concepts/databaseoverview.htm#moveRes).
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangeAutonomousContainerDatabaseCompartmentRequest
     * @return ChangeAutonomousContainerDatabaseCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ChangeAutonomousContainerDatabaseCompartment.ts.html |here} to see how to use ChangeAutonomousContainerDatabaseCompartment API.
     */
    changeAutonomousContainerDatabaseCompartment(changeAutonomousContainerDatabaseCompartmentRequest: requests.ChangeAutonomousContainerDatabaseCompartmentRequest): Promise<responses.ChangeAutonomousContainerDatabaseCompartmentResponse>;
    /**
     * Move the Autonomous Database and its dependent resources to the specified compartment.
     * For more information about moving Autonomous Databases, see
     * [Moving Database Resources to a Different Compartment](https://docs.cloud.oracle.com/Content/Database/Concepts/databaseoverview.htm#moveRes).
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangeAutonomousDatabaseCompartmentRequest
     * @return ChangeAutonomousDatabaseCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ChangeAutonomousDatabaseCompartment.ts.html |here} to see how to use ChangeAutonomousDatabaseCompartment API.
     */
    changeAutonomousDatabaseCompartment(changeAutonomousDatabaseCompartmentRequest: requests.ChangeAutonomousDatabaseCompartmentRequest): Promise<responses.ChangeAutonomousDatabaseCompartmentResponse>;
    /**
     * Move the Autonomous Database Software Image and its dependent resources to the specified compartment.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangeAutonomousDatabaseSoftwareImageCompartmentRequest
     * @return ChangeAutonomousDatabaseSoftwareImageCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ChangeAutonomousDatabaseSoftwareImageCompartment.ts.html |here} to see how to use ChangeAutonomousDatabaseSoftwareImageCompartment API.
     */
    changeAutonomousDatabaseSoftwareImageCompartment(changeAutonomousDatabaseSoftwareImageCompartmentRequest: requests.ChangeAutonomousDatabaseSoftwareImageCompartmentRequest): Promise<responses.ChangeAutonomousDatabaseSoftwareImageCompartmentResponse>;
    /**
     * **Deprecated.** Use the {@link #changeCloudExadataInfrastructureCompartment(ChangeCloudExadataInfrastructureCompartmentRequest) changeCloudExadataInfrastructureCompartment} operation to move an Exadata infrastructure resource to a different compartment and  {@link #changeCloudAutonomousVmClusterCompartment(ChangeCloudAutonomousVmClusterCompartmentRequest) changeCloudAutonomousVmClusterCompartment} operation to move an Autonomous Exadata VM cluster to a different compartment.
     * For more information, see
     * [Moving Database Resources to a Different Compartment](https://docs.cloud.oracle.com/Content/Database/Concepts/databaseoverview.htm#moveRes).
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangeAutonomousExadataInfrastructureCompartmentRequest
     * @return ChangeAutonomousExadataInfrastructureCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ChangeAutonomousExadataInfrastructureCompartment.ts.html |here} to see how to use ChangeAutonomousExadataInfrastructureCompartment API.
     */
    changeAutonomousExadataInfrastructureCompartment(changeAutonomousExadataInfrastructureCompartmentRequest: requests.ChangeAutonomousExadataInfrastructureCompartmentRequest): Promise<responses.ChangeAutonomousExadataInfrastructureCompartmentResponse>;
    /**
     * Moves an Autonomous VM cluster and its dependent resources to another compartment. Applies to Exadata Cloud@Customer  only. For systems in the Oracle cloud, see {@link #changeAutonomousVmClusterCompartment(ChangeAutonomousVmClusterCompartmentRequest) changeAutonomousVmClusterCompartment}.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangeAutonomousVmClusterCompartmentRequest
     * @return ChangeAutonomousVmClusterCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ChangeAutonomousVmClusterCompartment.ts.html |here} to see how to use ChangeAutonomousVmClusterCompartment API.
     */
    changeAutonomousVmClusterCompartment(changeAutonomousVmClusterCompartmentRequest: requests.ChangeAutonomousVmClusterCompartmentRequest): Promise<responses.ChangeAutonomousVmClusterCompartmentResponse>;
    /**
     * Move the backup destination and its dependent resources to the specified compartment.
     * For more information, see
     * [Moving Database Resources to a Different Compartment](https://docs.cloud.oracle.com/Content/Database/Concepts/databaseoverview.htm#moveRes).
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangeBackupDestinationCompartmentRequest
     * @return ChangeBackupDestinationCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ChangeBackupDestinationCompartment.ts.html |here} to see how to use ChangeBackupDestinationCompartment API.
     */
    changeBackupDestinationCompartment(changeBackupDestinationCompartmentRequest: requests.ChangeBackupDestinationCompartmentRequest): Promise<responses.ChangeBackupDestinationCompartmentResponse>;
    /**
     * Moves an Autonomous Exadata VM cluster in the Oracle cloud and its dependent resources to another compartment. For Exadata Cloud@Customer systems, see {@link #changeAutonomousVmClusterCompartment(ChangeAutonomousVmClusterCompartmentRequest) changeAutonomousVmClusterCompartment}.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangeCloudAutonomousVmClusterCompartmentRequest
     * @return ChangeCloudAutonomousVmClusterCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ChangeCloudAutonomousVmClusterCompartment.ts.html |here} to see how to use ChangeCloudAutonomousVmClusterCompartment API.
     */
    changeCloudAutonomousVmClusterCompartment(changeCloudAutonomousVmClusterCompartmentRequest: requests.ChangeCloudAutonomousVmClusterCompartmentRequest): Promise<responses.ChangeCloudAutonomousVmClusterCompartmentResponse>;
    /**
     * Moves a cloud Exadata infrastructure resource and its dependent resources to another compartment. Applies to Exadata Cloud Service instances and Autonomous Database on dedicated Exadata infrastructure only.For more information about moving resources to a different compartment, see [Moving Database Resources to a Different Compartment](https://docs.cloud.oracle.com/Content/Database/Concepts/databaseoverview.htm#moveRes).
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangeCloudExadataInfrastructureCompartmentRequest
     * @return ChangeCloudExadataInfrastructureCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ChangeCloudExadataInfrastructureCompartment.ts.html |here} to see how to use ChangeCloudExadataInfrastructureCompartment API.
     */
    changeCloudExadataInfrastructureCompartment(changeCloudExadataInfrastructureCompartmentRequest: requests.ChangeCloudExadataInfrastructureCompartmentRequest): Promise<responses.ChangeCloudExadataInfrastructureCompartmentResponse>;
    /**
     * Moves a cloud VM cluster and its dependent resources to another compartment. Applies to Exadata Cloud Service instances and Autonomous Database on dedicated Exadata infrastructure only.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangeCloudVmClusterCompartmentRequest
     * @return ChangeCloudVmClusterCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ChangeCloudVmClusterCompartment.ts.html |here} to see how to use ChangeCloudVmClusterCompartment API.
     */
    changeCloudVmClusterCompartment(changeCloudVmClusterCompartmentRequest: requests.ChangeCloudVmClusterCompartmentRequest): Promise<responses.ChangeCloudVmClusterCompartmentResponse>;
    /**
     * Move the Database Software Image and its dependent resources to the specified compartment.
     * For more information about moving Databse Software Images, see
     * [Moving Database Resources to a Different Compartment](https://docs.cloud.oracle.com/Content/Database/Concepts/databaseoverview.htm#moveRes).
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangeDatabaseSoftwareImageCompartmentRequest
     * @return ChangeDatabaseSoftwareImageCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ChangeDatabaseSoftwareImageCompartment.ts.html |here} to see how to use ChangeDatabaseSoftwareImageCompartment API.
     */
    changeDatabaseSoftwareImageCompartment(changeDatabaseSoftwareImageCompartmentRequest: requests.ChangeDatabaseSoftwareImageCompartmentRequest): Promise<responses.ChangeDatabaseSoftwareImageCompartmentResponse>;
    /**
     * Switch the Autonomous Container Database role between Standby and Snapshot Standby.
     * For more information about changing Autonomous Container Databases Dataguard Role, see
     * [Convert Physical Standby to Snapshot Standby](https://docs.oracle.com/en/cloud/paas/autonomous-database/dedicated/adbcl/index.html#ADBCL-GUID-D3B503F1-0032-4B0D-9F00-ACAE8151AB80) and [Convert Snapshot Standby to Physical Standby](https://docs.oracle.com/en/cloud/paas/autonomous-database/dedicated/adbcl/index.html#ADBCL-GUID-E8D7E0EE-8244-467D-B33A-1BC6F969A0A4).
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangeDataguardRoleRequest
     * @return ChangeDataguardRoleResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ChangeDataguardRole.ts.html |here} to see how to use ChangeDataguardRole API.
     */
    changeDataguardRole(changeDataguardRoleRequest: requests.ChangeDataguardRoleRequest): Promise<responses.ChangeDataguardRoleResponse>;
    /**
     * Moves the DB system and its dependent resources to the specified compartment.
     * For more information about moving DB systems, see
     * [Moving Database Resources to a Different Compartment](https://docs.cloud.oracle.com/Content/Database/Concepts/databaseoverview.htm#moveRes).
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangeDbSystemCompartmentRequest
     * @return ChangeDbSystemCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ChangeDbSystemCompartment.ts.html |here} to see how to use ChangeDbSystemCompartment API.
     */
    changeDbSystemCompartment(changeDbSystemCompartmentRequest: requests.ChangeDbSystemCompartmentRequest): Promise<responses.ChangeDbSystemCompartmentResponse>;
    /**
     * This operation updates the cross-region disaster recovery (DR) details of the standby Autonomous Database Serverless database, and must be run on the standby side.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangeDisasterRecoveryConfigurationRequest
     * @return ChangeDisasterRecoveryConfigurationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ChangeDisasterRecoveryConfiguration.ts.html |here} to see how to use ChangeDisasterRecoveryConfiguration API.
     */
    changeDisasterRecoveryConfiguration(changeDisasterRecoveryConfigurationRequest: requests.ChangeDisasterRecoveryConfigurationRequest): Promise<responses.ChangeDisasterRecoveryConfigurationResponse>;
    /**
     * Moves an Exadata infrastructure resource and its dependent resources to another compartment. Applies to Exadata Cloud@Customer instances only.
     * To move an Exadata Cloud Service infrastructure resource to another compartment, use the  {@link #changeCloudExadataInfrastructureCompartment(ChangeCloudExadataInfrastructureCompartmentRequest) changeCloudExadataInfrastructureCompartment} operation.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangeExadataInfrastructureCompartmentRequest
     * @return ChangeExadataInfrastructureCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ChangeExadataInfrastructureCompartment.ts.html |here} to see how to use ChangeExadataInfrastructureCompartment API.
     */
    changeExadataInfrastructureCompartment(changeExadataInfrastructureCompartmentRequest: requests.ChangeExadataInfrastructureCompartmentRequest): Promise<responses.ChangeExadataInfrastructureCompartmentResponse>;
    /**
     * Moves a Exadata VM cluster on Exascale Infrastructure and its dependent resources to another compartment. Applies to Exadata Database Service on Exascale Infrastructure only.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangeExadbVmClusterCompartmentRequest
     * @return ChangeExadbVmClusterCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ChangeExadbVmClusterCompartment.ts.html |here} to see how to use ChangeExadbVmClusterCompartment API.
     */
    changeExadbVmClusterCompartment(changeExadbVmClusterCompartmentRequest: requests.ChangeExadbVmClusterCompartmentRequest): Promise<responses.ChangeExadbVmClusterCompartmentResponse>;
    /**
     * Moves a Exadata Database Storage Vault to another compartment.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangeExascaleDbStorageVaultCompartmentRequest
     * @return ChangeExascaleDbStorageVaultCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ChangeExascaleDbStorageVaultCompartment.ts.html |here} to see how to use ChangeExascaleDbStorageVaultCompartment API.
     */
    changeExascaleDbStorageVaultCompartment(changeExascaleDbStorageVaultCompartmentRequest: requests.ChangeExascaleDbStorageVaultCompartmentRequest): Promise<responses.ChangeExascaleDbStorageVaultCompartmentResponse>;
    /**
     * Move the {@link #createExternalContainerDatabaseDetails(CreateExternalContainerDatabaseDetailsRequest) createExternalContainerDatabaseDetails}
     * and its dependent resources to the specified compartment.
     * For more information about moving external container databases, see
     * [Moving Database Resources to a Different Compartment](https://docs.cloud.oracle.com/Content/Database/Concepts/databaseoverview.htm#moveRes).
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangeExternalContainerDatabaseCompartmentRequest
     * @return ChangeExternalContainerDatabaseCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ChangeExternalContainerDatabaseCompartment.ts.html |here} to see how to use ChangeExternalContainerDatabaseCompartment API.
     */
    changeExternalContainerDatabaseCompartment(changeExternalContainerDatabaseCompartmentRequest: requests.ChangeExternalContainerDatabaseCompartmentRequest): Promise<responses.ChangeExternalContainerDatabaseCompartmentResponse>;
    /**
     * Move the external non-container database and its dependent resources to the specified compartment.
     * For more information about moving external non-container databases, see
     * [Moving Database Resources to a Different Compartment](https://docs.cloud.oracle.com/Content/Database/Concepts/databaseoverview.htm#moveRes).
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangeExternalNonContainerDatabaseCompartmentRequest
     * @return ChangeExternalNonContainerDatabaseCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ChangeExternalNonContainerDatabaseCompartment.ts.html |here} to see how to use ChangeExternalNonContainerDatabaseCompartment API.
     */
    changeExternalNonContainerDatabaseCompartment(changeExternalNonContainerDatabaseCompartmentRequest: requests.ChangeExternalNonContainerDatabaseCompartmentRequest): Promise<responses.ChangeExternalNonContainerDatabaseCompartmentResponse>;
    /**
     * Move the {@link #createExternalPluggableDatabaseDetails(CreateExternalPluggableDatabaseDetailsRequest) createExternalPluggableDatabaseDetails} and
     * its dependent resources to the specified compartment.
     * For more information about moving external pluggable databases, see
     * [Moving Database Resources to a Different Compartment](https://docs.cloud.oracle.com/Content/Database/Concepts/databaseoverview.htm#moveRes).
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangeExternalPluggableDatabaseCompartmentRequest
     * @return ChangeExternalPluggableDatabaseCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ChangeExternalPluggableDatabaseCompartment.ts.html |here} to see how to use ChangeExternalPluggableDatabaseCompartment API.
     */
    changeExternalPluggableDatabaseCompartment(changeExternalPluggableDatabaseCompartmentRequest: requests.ChangeExternalPluggableDatabaseCompartmentRequest): Promise<responses.ChangeExternalPluggableDatabaseCompartmentResponse>;
    /**
     * Move the key store resource to the specified compartment.
     * For more information about moving key stores, see
     * [Moving Database Resources to a Different Compartment](https://docs.cloud.oracle.com/Content/Database/Concepts/databaseoverview.htm#moveRes).
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangeKeyStoreCompartmentRequest
     * @return ChangeKeyStoreCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ChangeKeyStoreCompartment.ts.html |here} to see how to use ChangeKeyStoreCompartment API.
     */
    changeKeyStoreCompartment(changeKeyStoreCompartmentRequest: requests.ChangeKeyStoreCompartmentRequest): Promise<responses.ChangeKeyStoreCompartmentResponse>;
    /**
     * Changes encryption key management type
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangeKeyStoreTypeRequest
     * @return ChangeKeyStoreTypeResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ChangeKeyStoreType.ts.html |here} to see how to use ChangeKeyStoreType API.
     */
    changeKeyStoreType(changeKeyStoreTypeRequest: requests.ChangeKeyStoreTypeRequest): Promise<responses.ChangeKeyStoreTypeResponse>;
    /**
     * Move the one-off patch to the specified compartment.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangeOneoffPatchCompartmentRequest
     * @return ChangeOneoffPatchCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ChangeOneoffPatchCompartment.ts.html |here} to see how to use ChangeOneoffPatchCompartment API.
     */
    changeOneoffPatchCompartment(changeOneoffPatchCompartmentRequest: requests.ChangeOneoffPatchCompartmentRequest): Promise<responses.ChangeOneoffPatchCompartmentResponse>;
    /**
     * Moves a VM cluster and its dependent resources to another compartment. Applies to Exadata Cloud@Customer instances only.
     * To move a cloud VM cluster in an Exadata Cloud Service instance to another compartment, use the {@link #changeCloudVmClusterCompartment(ChangeCloudVmClusterCompartmentRequest) changeCloudVmClusterCompartment} operation.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangeVmClusterCompartmentRequest
     * @return ChangeVmClusterCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ChangeVmClusterCompartment.ts.html |here} to see how to use ChangeVmClusterCompartment API.
     */
    changeVmClusterCompartment(changeVmClusterCompartmentRequest: requests.ChangeVmClusterCompartmentRequest): Promise<responses.ChangeVmClusterCompartmentResponse>;
    /**
     * Check the status of the external database connection specified in this connector.
     * This operation will refresh the connectionStatus and timeConnectionStatusLastUpdated fields.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CheckExternalDatabaseConnectorConnectionStatusRequest
     * @return CheckExternalDatabaseConnectorConnectionStatusResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/CheckExternalDatabaseConnectorConnectionStatus.ts.html |here} to see how to use CheckExternalDatabaseConnectorConnectionStatus API.
     */
    checkExternalDatabaseConnectorConnectionStatus(checkExternalDatabaseConnectorConnectionStatusRequest: requests.CheckExternalDatabaseConnectorConnectionStatusRequest): Promise<responses.CheckExternalDatabaseConnectorConnectionStatusResponse>;
    /**
     * Changes the status of the standalone backup resource to `ACTIVE` after the backup is created from the on-premises database and placed in Oracle Cloud Infrastructure Object Storage.
     * <p>
     **Note:** This API is used by an Oracle Cloud Infrastructure Python script that is packaged with the Oracle Cloud Infrastructure CLI. Oracle recommends that you use the script instead using the API directly. See [Migrating an On-Premises Database to Oracle Cloud Infrastructure by Creating a Backup in the Cloud](https://docs.cloud.oracle.com/Content/Database/Tasks/mig-onprembackup.htm) for more information.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CompleteExternalBackupJobRequest
     * @return CompleteExternalBackupJobResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/CompleteExternalBackupJob.ts.html |here} to see how to use CompleteExternalBackupJob API.
     */
    completeExternalBackupJob(completeExternalBackupJobRequest: requests.CompleteExternalBackupJobRequest): Promise<responses.CompleteExternalBackupJobResponse>;
    /**
     * Configures the Autonomous Database Vault service [key](https://docs.cloud.oracle.com/Content/KeyManagement/Concepts/keyoverview.htm#concepts).
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ConfigureAutonomousDatabaseVaultKeyRequest
     * @return ConfigureAutonomousDatabaseVaultKeyResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ConfigureAutonomousDatabaseVaultKey.ts.html |here} to see how to use ConfigureAutonomousDatabaseVaultKey API.
     */
    configureAutonomousDatabaseVaultKey(configureAutonomousDatabaseVaultKeyRequest: requests.ConfigureAutonomousDatabaseVaultKeyRequest): Promise<responses.ConfigureAutonomousDatabaseVaultKeyResponse>;
    /**
     * This operation updates SaaS administrative user configuration of the Autonomous Database.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ConfigureSaasAdminUserRequest
     * @return ConfigureSaasAdminUserResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ConfigureSaasAdminUser.ts.html |here} to see how to use ConfigureSaasAdminUser API.
     */
    configureSaasAdminUser(configureSaasAdminUserRequest: requests.ConfigureSaasAdminUserRequest): Promise<responses.ConfigureSaasAdminUserResponse>;
    /**
     * This is for user to confirm to DBaaS that the Oracle Key Valut (OKV) connection IPs, username and password are all correct. This operation will put
     * the Key Store back into Active state. If details are incorrect, your OKV account may get locked after some unsuccessful attempts to connect.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ConfirmKeyStoreDetailsAreCorrectRequest
     * @return ConfirmKeyStoreDetailsAreCorrectResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ConfirmKeyStoreDetailsAreCorrect.ts.html |here} to see how to use ConfirmKeyStoreDetailsAreCorrect API.
     */
    confirmKeyStoreDetailsAreCorrect(confirmKeyStoreDetailsAreCorrectRequest: requests.ConfirmKeyStoreDetailsAreCorrectRequest): Promise<responses.ConfirmKeyStoreDetailsAreCorrectResponse>;
    /**
     * Converts a non-container database to a pluggable database.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ConvertToPdbRequest
     * @return ConvertToPdbResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ConvertToPdb.ts.html |here} to see how to use ConvertToPdb API.
     */
    convertToPdb(convertToPdbRequest: requests.ConvertToPdbRequest): Promise<responses.ConvertToPdbResponse>;
    /**
     * Converts a Refreshable clone to Regular pluggable database (PDB).
     * Pluggable Database will be in `READ_WRITE` openmode after conversion.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ConvertToRegularPluggableDatabaseRequest
     * @return ConvertToRegularPluggableDatabaseResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ConvertToRegularPluggableDatabase.ts.html |here} to see how to use ConvertToRegularPluggableDatabase API.
     */
    convertToRegularPluggableDatabase(convertToRegularPluggableDatabaseRequest: requests.ConvertToRegularPluggableDatabaseRequest): Promise<responses.ConvertToRegularPluggableDatabaseResponse>;
    /**
     * Creates a new application virtual IP (VIP) address in the specified cloud VM cluster based on the request parameters you provide.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateApplicationVipRequest
     * @return CreateApplicationVipResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/CreateApplicationVip.ts.html |here} to see how to use CreateApplicationVip API.
     */
    createApplicationVip(createApplicationVipRequest: requests.CreateApplicationVipRequest): Promise<responses.CreateApplicationVipResponse>;
    /**
     * Creates an Autonomous Container Database in the specified Autonomous Exadata Infrastructure.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateAutonomousContainerDatabaseRequest
     * @return CreateAutonomousContainerDatabaseResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/CreateAutonomousContainerDatabase.ts.html |here} to see how to use CreateAutonomousContainerDatabase API.
     */
    createAutonomousContainerDatabase(createAutonomousContainerDatabaseRequest: requests.CreateAutonomousContainerDatabaseRequest): Promise<responses.CreateAutonomousContainerDatabaseResponse>;
    /**
       * Create a new Autonomous Data Guard association. An Autonomous Data Guard association represents the replication relationship between the
  * specified Autonomous Container database and a peer Autonomous Container database. For more information, see [Using Oracle Data Guard](https://docs.cloud.oracle.com/Content/Database/Tasks/usingdataguard.htm).
  * <p>
  All Oracle Cloud Infrastructure resources, including Data Guard associations, get an Oracle-assigned, unique ID
  * called an Oracle Cloud Identifier (OCID). When you create a resource, you can find its OCID in the response.
  * You can also retrieve a resource's OCID by using a List API operation on that resource type, or by viewing the
  * resource in the Console. For more information, see
  * [Resource Identifiers](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm).
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param CreateAutonomousContainerDatabaseDataguardAssociationRequest
       * @return CreateAutonomousContainerDatabaseDataguardAssociationResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/CreateAutonomousContainerDatabaseDataguardAssociation.ts.html |here} to see how to use CreateAutonomousContainerDatabaseDataguardAssociation API.
       */
    createAutonomousContainerDatabaseDataguardAssociation(createAutonomousContainerDatabaseDataguardAssociationRequest: requests.CreateAutonomousContainerDatabaseDataguardAssociationRequest): Promise<responses.CreateAutonomousContainerDatabaseDataguardAssociationResponse>;
    /**
     * Creates a new Autonomous Database.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateAutonomousDatabaseRequest
     * @return CreateAutonomousDatabaseResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/CreateAutonomousDatabase.ts.html |here} to see how to use CreateAutonomousDatabase API.
     */
    createAutonomousDatabase(createAutonomousDatabaseRequest: requests.CreateAutonomousDatabaseRequest): Promise<responses.CreateAutonomousDatabaseResponse>;
    /**
     * Creates a new Autonomous Database backup for the specified database based on the provided request parameters.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateAutonomousDatabaseBackupRequest
     * @return CreateAutonomousDatabaseBackupResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/CreateAutonomousDatabaseBackup.ts.html |here} to see how to use CreateAutonomousDatabaseBackup API.
     */
    createAutonomousDatabaseBackup(createAutonomousDatabaseBackupRequest: requests.CreateAutonomousDatabaseBackupRequest): Promise<responses.CreateAutonomousDatabaseBackupResponse>;
    /**
     * create Autonomous Database Software Image in the specified compartment.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateAutonomousDatabaseSoftwareImageRequest
     * @return CreateAutonomousDatabaseSoftwareImageResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/CreateAutonomousDatabaseSoftwareImage.ts.html |here} to see how to use CreateAutonomousDatabaseSoftwareImage API.
     */
    createAutonomousDatabaseSoftwareImage(createAutonomousDatabaseSoftwareImageRequest: requests.CreateAutonomousDatabaseSoftwareImageRequest): Promise<responses.CreateAutonomousDatabaseSoftwareImageResponse>;
    /**
     * Creates an Autonomous VM cluster for Exadata Cloud@Customer. To create an Autonomous VM Cluster in the Oracle cloud, see {@link #createCloudAutonomousVmCluster(CreateCloudAutonomousVmClusterRequest) createCloudAutonomousVmCluster}.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateAutonomousVmClusterRequest
     * @return CreateAutonomousVmClusterResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/CreateAutonomousVmCluster.ts.html |here} to see how to use CreateAutonomousVmCluster API.
     */
    createAutonomousVmCluster(createAutonomousVmClusterRequest: requests.CreateAutonomousVmClusterRequest): Promise<responses.CreateAutonomousVmClusterResponse>;
    /**
     * Creates a new backup in the specified database based on the request parameters you provide. If you previously used RMAN or dbcli to configure backups and then you switch to using the Console or the API for backups, a new backup configuration is created and associated with your database. This means that you can no longer rely on your previously configured unmanaged backups to work.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateBackupRequest
     * @return CreateBackupResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/CreateBackup.ts.html |here} to see how to use CreateBackup API.
     */
    createBackup(createBackupRequest: requests.CreateBackupRequest): Promise<responses.CreateBackupResponse>;
    /**
     * Creates a backup destination in an Exadata Cloud@Customer system.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateBackupDestinationRequest
     * @return CreateBackupDestinationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/CreateBackupDestination.ts.html |here} to see how to use CreateBackupDestination API.
     */
    createBackupDestination(createBackupDestinationRequest: requests.CreateBackupDestinationRequest): Promise<responses.CreateBackupDestinationResponse>;
    /**
     * Creates an Autonomous Exadata VM cluster in the Oracle cloud. For Exadata Cloud@Customer systems, see {@link #createAutonomousVmCluster(CreateAutonomousVmClusterRequest) createAutonomousVmCluster}.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateCloudAutonomousVmClusterRequest
     * @return CreateCloudAutonomousVmClusterResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/CreateCloudAutonomousVmCluster.ts.html |here} to see how to use CreateCloudAutonomousVmCluster API.
     */
    createCloudAutonomousVmCluster(createCloudAutonomousVmClusterRequest: requests.CreateCloudAutonomousVmClusterRequest): Promise<responses.CreateCloudAutonomousVmClusterResponse>;
    /**
     * Creates a cloud Exadata infrastructure resource. This resource is used to create either an [Exadata Cloud Service](https://docs.cloud.oracle.com/Content/Database/Concepts/exaoverview.htm) instance or an Autonomous Database on dedicated Exadata infrastructure.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateCloudExadataInfrastructureRequest
     * @return CreateCloudExadataInfrastructureResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/CreateCloudExadataInfrastructure.ts.html |here} to see how to use CreateCloudExadataInfrastructure API.
     */
    createCloudExadataInfrastructure(createCloudExadataInfrastructureRequest: requests.CreateCloudExadataInfrastructureRequest): Promise<responses.CreateCloudExadataInfrastructureResponse>;
    /**
     * Creates a cloud VM cluster.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateCloudVmClusterRequest
     * @return CreateCloudVmClusterResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/CreateCloudVmCluster.ts.html |here} to see how to use CreateCloudVmCluster API.
     */
    createCloudVmCluster(createCloudVmClusterRequest: requests.CreateCloudVmClusterRequest): Promise<responses.CreateCloudVmClusterResponse>;
    /**
     * Creates a new console connection to the specified database node.
     * After the console connection has been created and is available,
     * you connect to the console using SSH.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateConsoleConnectionRequest
     * @return CreateConsoleConnectionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/CreateConsoleConnection.ts.html |here} to see how to use CreateConsoleConnection API.
     */
    createConsoleConnection(createConsoleConnectionRequest: requests.CreateConsoleConnectionRequest): Promise<responses.CreateConsoleConnectionResponse>;
    /**
     * Captures the most recent serial console data (up to a megabyte) for the specified database node.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateConsoleHistoryRequest
     * @return CreateConsoleHistoryResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/CreateConsoleHistory.ts.html |here} to see how to use CreateConsoleHistory API.
     */
    createConsoleHistory(createConsoleHistoryRequest: requests.CreateConsoleHistoryRequest): Promise<responses.CreateConsoleHistoryResponse>;
    /**
       * Creates a new Data Guard association.  A Data Guard association represents the replication relationship between the
  * specified database and a peer database. For more information, see [Using Oracle Data Guard](https://docs.cloud.oracle.com/Content/Database/Tasks/usingdataguard.htm).
  * <p>
  All Oracle Cloud Infrastructure resources, including Data Guard associations, get an Oracle-assigned, unique ID
  * called an Oracle Cloud Identifier (OCID). When you create a resource, you can find its OCID in the response.
  * You can also retrieve a resource's OCID by using a List API operation on that resource type, or by viewing the
  * resource in the Console. For more information, see
  * [Resource Identifiers](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm).
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param CreateDataGuardAssociationRequest
       * @return CreateDataGuardAssociationResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/CreateDataGuardAssociation.ts.html |here} to see how to use CreateDataGuardAssociation API.
       */
    createDataGuardAssociation(createDataGuardAssociationRequest: requests.CreateDataGuardAssociationRequest): Promise<responses.CreateDataGuardAssociationResponse>;
    /**
     * Creates a new database in the specified Database Home. If the database version is provided, it must match the version of the Database Home. Applies to Exadata and Exadata Cloud@Customer systems.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateDatabaseRequest
     * @return CreateDatabaseResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/CreateDatabase.ts.html |here} to see how to use CreateDatabase API.
     */
    createDatabase(createDatabaseRequest: requests.CreateDatabaseRequest): Promise<responses.CreateDatabaseResponse>;
    /**
     * create database software image in the specified compartment.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateDatabaseSoftwareImageRequest
     * @return CreateDatabaseSoftwareImageResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/CreateDatabaseSoftwareImage.ts.html |here} to see how to use CreateDatabaseSoftwareImage API.
     */
    createDatabaseSoftwareImage(createDatabaseSoftwareImageRequest: requests.CreateDatabaseSoftwareImageRequest): Promise<responses.CreateDatabaseSoftwareImageResponse>;
    /**
     * Creates a new Database Home in the specified database system based on the request parameters you provide. Applies to bare metal DB systems, Exadata systems, and Exadata Cloud@Customer systems.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateDbHomeRequest
     * @return CreateDbHomeResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/CreateDbHome.ts.html |here} to see how to use CreateDbHome API.
     */
    createDbHome(createDbHomeRequest: requests.CreateDbHomeRequest): Promise<responses.CreateDbHomeResponse>;
    /**
     * Creates an Exadata infrastructure resource. Applies to Exadata Cloud@Customer instances only.
     * To create an Exadata Cloud Service infrastructure resource, use the  {@link #createCloudExadataInfrastructure(CreateCloudExadataInfrastructureRequest) createCloudExadataInfrastructure} operation.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateExadataInfrastructureRequest
     * @return CreateExadataInfrastructureResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/CreateExadataInfrastructure.ts.html |here} to see how to use CreateExadataInfrastructure API.
     */
    createExadataInfrastructure(createExadataInfrastructureRequest: requests.CreateExadataInfrastructureRequest): Promise<responses.CreateExadataInfrastructureResponse>;
    /**
     * Creates an Exadata VM cluster on Exascale Infrastructure
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateExadbVmClusterRequest
     * @return CreateExadbVmClusterResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/CreateExadbVmCluster.ts.html |here} to see how to use CreateExadbVmCluster API.
     */
    createExadbVmCluster(createExadbVmClusterRequest: requests.CreateExadbVmClusterRequest): Promise<responses.CreateExadbVmClusterResponse>;
    /**
     * Creates an Exadata Database Storage Vault
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateExascaleDbStorageVaultRequest
     * @return CreateExascaleDbStorageVaultResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/CreateExascaleDbStorageVault.ts.html |here} to see how to use CreateExascaleDbStorageVault API.
     */
    createExascaleDbStorageVault(createExascaleDbStorageVaultRequest: requests.CreateExascaleDbStorageVaultRequest): Promise<responses.CreateExascaleDbStorageVaultResponse>;
    /**
     * Creates a new backup resource and returns the information the caller needs to back up an on-premises Oracle Database to Oracle Cloud Infrastructure.
     * <p>
     **Note:** This API is used by an Oracle Cloud Infrastructure Python script that is packaged with the Oracle Cloud Infrastructure CLI. Oracle recommends that you use the script instead using the API directly. See [Migrating an On-Premises Database to Oracle Cloud Infrastructure by Creating a Backup in the Cloud](https://docs.cloud.oracle.com/Content/Database/Tasks/mig-onprembackup.htm) for more information.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateExternalBackupJobRequest
     * @return CreateExternalBackupJobResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/CreateExternalBackupJob.ts.html |here} to see how to use CreateExternalBackupJob API.
     */
    createExternalBackupJob(createExternalBackupJobRequest: requests.CreateExternalBackupJobRequest): Promise<responses.CreateExternalBackupJobResponse>;
    /**
     * Creates a new external container database resource.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateExternalContainerDatabaseRequest
     * @return CreateExternalContainerDatabaseResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/CreateExternalContainerDatabase.ts.html |here} to see how to use CreateExternalContainerDatabase API.
     */
    createExternalContainerDatabase(createExternalContainerDatabaseRequest: requests.CreateExternalContainerDatabaseRequest): Promise<responses.CreateExternalContainerDatabaseResponse>;
    /**
     * Creates a new external database connector.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateExternalDatabaseConnectorRequest
     * @return CreateExternalDatabaseConnectorResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/CreateExternalDatabaseConnector.ts.html |here} to see how to use CreateExternalDatabaseConnector API.
     */
    createExternalDatabaseConnector(createExternalDatabaseConnectorRequest: requests.CreateExternalDatabaseConnectorRequest): Promise<responses.CreateExternalDatabaseConnectorResponse>;
    /**
     * Creates a new ExternalNonContainerDatabase resource
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateExternalNonContainerDatabaseRequest
     * @return CreateExternalNonContainerDatabaseResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/CreateExternalNonContainerDatabase.ts.html |here} to see how to use CreateExternalNonContainerDatabase API.
     */
    createExternalNonContainerDatabase(createExternalNonContainerDatabaseRequest: requests.CreateExternalNonContainerDatabaseRequest): Promise<responses.CreateExternalNonContainerDatabaseResponse>;
    /**
     * Registers a new {@link #createExternalPluggableDatabaseDetails(CreateExternalPluggableDatabaseDetailsRequest) createExternalPluggableDatabaseDetails}
     * resource.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateExternalPluggableDatabaseRequest
     * @return CreateExternalPluggableDatabaseResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/CreateExternalPluggableDatabase.ts.html |here} to see how to use CreateExternalPluggableDatabase API.
     */
    createExternalPluggableDatabase(createExternalPluggableDatabaseRequest: requests.CreateExternalPluggableDatabaseRequest): Promise<responses.CreateExternalPluggableDatabaseResponse>;
    /**
     * Creates a Key Store.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateKeyStoreRequest
     * @return CreateKeyStoreResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/CreateKeyStore.ts.html |here} to see how to use CreateKeyStore API.
     */
    createKeyStore(createKeyStoreRequest: requests.CreateKeyStoreRequest): Promise<responses.CreateKeyStoreResponse>;
    /**
     * Creates a maintenance run with one of the following:
     * 1. The latest available release update patch (RUP) for the Autonomous Container Database.
     * 2. The latest available RUP and DST time-zone (TZ) file updates for the Autonomous Container Database.
     * 3. The DST TZ file updates for the Autonomous Container Database.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateMaintenanceRunRequest
     * @return CreateMaintenanceRunResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/CreateMaintenanceRun.ts.html |here} to see how to use CreateMaintenanceRun API.
     */
    createMaintenanceRun(createMaintenanceRunRequest: requests.CreateMaintenanceRunRequest): Promise<responses.CreateMaintenanceRunResponse>;
    /**
     * Creates one-off patch for specified database version to download.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateOneoffPatchRequest
     * @return CreateOneoffPatchResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/CreateOneoffPatch.ts.html |here} to see how to use CreateOneoffPatch API.
     */
    createOneoffPatch(createOneoffPatchRequest: requests.CreateOneoffPatchRequest): Promise<responses.CreateOneoffPatchResponse>;
    /**
     * Creates and starts a pluggable database in the specified container database.
     * Pluggable Database can be created using different operations (e.g. LocalClone, RemoteClone, Relocate ) with this API.
     * Use the {@link #startPluggableDatabase(StartPluggableDatabaseRequest) startPluggableDatabase} and {@link #stopPluggableDatabase(StopPluggableDatabaseRequest) stopPluggableDatabase} APIs to start and stop the pluggable database.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreatePluggableDatabaseRequest
     * @return CreatePluggableDatabaseResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/CreatePluggableDatabase.ts.html |here} to see how to use CreatePluggableDatabase API.
     */
    createPluggableDatabase(createPluggableDatabaseRequest: requests.CreatePluggableDatabaseRequest): Promise<responses.CreatePluggableDatabaseResponse>;
    /**
     * Creates an Exadata Cloud@Customer VM cluster.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateVmClusterRequest
     * @return CreateVmClusterResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/CreateVmCluster.ts.html |here} to see how to use CreateVmCluster API.
     */
    createVmCluster(createVmClusterRequest: requests.CreateVmClusterRequest): Promise<responses.CreateVmClusterResponse>;
    /**
     * Creates the VM cluster network. Applies to Exadata Cloud@Customer instances only.
     * To create a cloud VM cluster in an Exadata Cloud Service instance, use the {@link #createCloudVmCluster(CreateCloudVmClusterRequest) createCloudVmCluster} operation.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateVmClusterNetworkRequest
     * @return CreateVmClusterNetworkResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/CreateVmClusterNetwork.ts.html |here} to see how to use CreateVmClusterNetwork API.
     */
    createVmClusterNetwork(createVmClusterNetworkRequest: requests.CreateVmClusterNetworkRequest): Promise<responses.CreateVmClusterNetworkResponse>;
    /**
     * Performs one of the following power actions on the specified DB node:
     * - start - power on
     * - stop - power off
     * - softreset - ACPI shutdown and power on
     * - reset - power off and power on
     * <p>
     **Note:** Stopping a node affects billing differently, depending on the type of DB system:
     * *Bare metal and Exadata systems* - The _stop_ state has no effect on the resources you consume.
     * Billing continues for DB nodes that you stop, and related resources continue
     * to apply against any relevant quotas. You must terminate the DB system
     * ({@link #terminateDbSystem(TerminateDbSystemRequest) terminateDbSystem})
     * to remove its resources from billing and quotas.
     * *Virtual machine DB systems* - Stopping a node stops billing for all OCPUs associated with that node, and billing resumes when you restart the node.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DbNodeActionRequest
     * @return DbNodeActionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/DbNodeAction.ts.html |here} to see how to use DbNodeAction API.
     */
    dbNodeAction(dbNodeActionRequest: requests.DbNodeActionRequest): Promise<responses.DbNodeActionResponse>;
    /**
     * Deletes and deregisters the specified application virtual IP (VIP) address.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteApplicationVipRequest
     * @return DeleteApplicationVipResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/DeleteApplicationVip.ts.html |here} to see how to use DeleteApplicationVip API.
     */
    deleteApplicationVip(deleteApplicationVipRequest: requests.DeleteApplicationVipRequest): Promise<responses.DeleteApplicationVipResponse>;
    /**
     * Deletes the specified Autonomous Database.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteAutonomousDatabaseRequest
     * @return DeleteAutonomousDatabaseResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/DeleteAutonomousDatabase.ts.html |here} to see how to use DeleteAutonomousDatabase API.
     */
    deleteAutonomousDatabase(deleteAutonomousDatabaseRequest: requests.DeleteAutonomousDatabaseRequest): Promise<responses.DeleteAutonomousDatabaseResponse>;
    /**
     * Deletes a long-term backup. You cannot delete other backups using this API.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteAutonomousDatabaseBackupRequest
     * @return DeleteAutonomousDatabaseBackupResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/DeleteAutonomousDatabaseBackup.ts.html |here} to see how to use DeleteAutonomousDatabaseBackup API.
     */
    deleteAutonomousDatabaseBackup(deleteAutonomousDatabaseBackupRequest: requests.DeleteAutonomousDatabaseBackupRequest): Promise<responses.DeleteAutonomousDatabaseBackupResponse>;
    /**
     * Delete an Autonomous Database Software Image
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteAutonomousDatabaseSoftwareImageRequest
     * @return DeleteAutonomousDatabaseSoftwareImageResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/DeleteAutonomousDatabaseSoftwareImage.ts.html |here} to see how to use DeleteAutonomousDatabaseSoftwareImage API.
     */
    deleteAutonomousDatabaseSoftwareImage(deleteAutonomousDatabaseSoftwareImageRequest: requests.DeleteAutonomousDatabaseSoftwareImageRequest): Promise<responses.DeleteAutonomousDatabaseSoftwareImageResponse>;
    /**
     * Deletes the specified Autonomous VM cluster in an Exadata Cloud@Customer system. To delete an Autonomous VM Cluster in the Oracle cloud, see {@link #deleteCloudAutonomousVmCluster(DeleteCloudAutonomousVmClusterRequest) deleteCloudAutonomousVmCluster}.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteAutonomousVmClusterRequest
     * @return DeleteAutonomousVmClusterResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/DeleteAutonomousVmCluster.ts.html |here} to see how to use DeleteAutonomousVmCluster API.
     */
    deleteAutonomousVmCluster(deleteAutonomousVmClusterRequest: requests.DeleteAutonomousVmClusterRequest): Promise<responses.DeleteAutonomousVmClusterResponse>;
    /**
     * Deletes a full backup. You cannot delete automatic backups using this API.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteBackupRequest
     * @return DeleteBackupResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/DeleteBackup.ts.html |here} to see how to use DeleteBackup API.
     */
    deleteBackup(deleteBackupRequest: requests.DeleteBackupRequest): Promise<responses.DeleteBackupResponse>;
    /**
     * Deletes a backup destination in an Exadata Cloud@Customer system.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteBackupDestinationRequest
     * @return DeleteBackupDestinationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/DeleteBackupDestination.ts.html |here} to see how to use DeleteBackupDestination API.
     */
    deleteBackupDestination(deleteBackupDestinationRequest: requests.DeleteBackupDestinationRequest): Promise<responses.DeleteBackupDestinationResponse>;
    /**
     * Deletes the specified Autonomous Exadata VM cluster in the Oracle cloud. For Exadata Cloud@Customer systems, see {@link #deleteAutonomousVmCluster(DeleteAutonomousVmClusterRequest) deleteAutonomousVmCluster}.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteCloudAutonomousVmClusterRequest
     * @return DeleteCloudAutonomousVmClusterResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/DeleteCloudAutonomousVmCluster.ts.html |here} to see how to use DeleteCloudAutonomousVmCluster API.
     */
    deleteCloudAutonomousVmCluster(deleteCloudAutonomousVmClusterRequest: requests.DeleteCloudAutonomousVmClusterRequest): Promise<responses.DeleteCloudAutonomousVmClusterResponse>;
    /**
     * Deletes the cloud Exadata infrastructure resource. Applies to Exadata Cloud Service instances and Autonomous Database on dedicated Exadata infrastructure only.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteCloudExadataInfrastructureRequest
     * @return DeleteCloudExadataInfrastructureResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/DeleteCloudExadataInfrastructure.ts.html |here} to see how to use DeleteCloudExadataInfrastructure API.
     */
    deleteCloudExadataInfrastructure(deleteCloudExadataInfrastructureRequest: requests.DeleteCloudExadataInfrastructureRequest): Promise<responses.DeleteCloudExadataInfrastructureResponse>;
    /**
     * Deletes the specified cloud VM cluster. Applies to Exadata Cloud Service instances and Autonomous Database on dedicated Exadata infrastructure only.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteCloudVmClusterRequest
     * @return DeleteCloudVmClusterResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/DeleteCloudVmCluster.ts.html |here} to see how to use DeleteCloudVmCluster API.
     */
    deleteCloudVmCluster(deleteCloudVmClusterRequest: requests.DeleteCloudVmClusterRequest): Promise<responses.DeleteCloudVmClusterResponse>;
    /**
     * Deletes the specified database node console connection.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteConsoleConnectionRequest
     * @return DeleteConsoleConnectionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/DeleteConsoleConnection.ts.html |here} to see how to use DeleteConsoleConnection API.
     */
    deleteConsoleConnection(deleteConsoleConnectionRequest: requests.DeleteConsoleConnectionRequest): Promise<responses.DeleteConsoleConnectionResponse>;
    /**
     * Deletes the specified database node console history.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteConsoleHistoryRequest
     * @return DeleteConsoleHistoryResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/DeleteConsoleHistory.ts.html |here} to see how to use DeleteConsoleHistory API.
     */
    deleteConsoleHistory(deleteConsoleHistoryRequest: requests.DeleteConsoleHistoryRequest): Promise<responses.DeleteConsoleHistoryResponse>;
    /**
       * Deletes the specified database. Applies only to Exadata systems.
  * <p>
  The data in this database is local to the Exadata system and will be lost when the database is deleted. Oracle recommends that you back up any data in the Exadata system prior to deleting it. You can use the `performFinalBackup` parameter to have the Exadata system database backed up before it is deleted.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param DeleteDatabaseRequest
       * @return DeleteDatabaseResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/DeleteDatabase.ts.html |here} to see how to use DeleteDatabase API.
       */
    deleteDatabase(deleteDatabaseRequest: requests.DeleteDatabaseRequest): Promise<responses.DeleteDatabaseResponse>;
    /**
     * Delete a database software image
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteDatabaseSoftwareImageRequest
     * @return DeleteDatabaseSoftwareImageResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/DeleteDatabaseSoftwareImage.ts.html |here} to see how to use DeleteDatabaseSoftwareImage API.
     */
    deleteDatabaseSoftwareImage(deleteDatabaseSoftwareImageRequest: requests.DeleteDatabaseSoftwareImageRequest): Promise<responses.DeleteDatabaseSoftwareImageResponse>;
    /**
       * Deletes a Database Home. Applies to bare metal DB systems, Exadata Cloud Service, and Exadata Cloud@Customer systems.
  * <p>
  Oracle recommends that you use the `performFinalBackup` parameter to back up any data on a bare metal DB system before you delete a Database Home. On an Exadata Cloud@Customer system or an Exadata Cloud Service system, you can delete a Database Home only when there are no databases in it and therefore you cannot use the `performFinalBackup` parameter to back up data.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param DeleteDbHomeRequest
       * @return DeleteDbHomeResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/DeleteDbHome.ts.html |here} to see how to use DeleteDbHome API.
       */
    deleteDbHome(deleteDbHomeRequest: requests.DeleteDbHomeRequest): Promise<responses.DeleteDbHomeResponse>;
    /**
     * Deletes the Exadata Cloud@Customer infrastructure.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteExadataInfrastructureRequest
     * @return DeleteExadataInfrastructureResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/DeleteExadataInfrastructure.ts.html |here} to see how to use DeleteExadataInfrastructure API.
     */
    deleteExadataInfrastructure(deleteExadataInfrastructureRequest: requests.DeleteExadataInfrastructureRequest): Promise<responses.DeleteExadataInfrastructureResponse>;
    /**
     * Deletes the specified Exadata VM cluster on Exascale Infrastructure. Applies to Exadata Database Service on Exascale Infrastructure only.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteExadbVmClusterRequest
     * @return DeleteExadbVmClusterResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/DeleteExadbVmCluster.ts.html |here} to see how to use DeleteExadbVmCluster API.
     */
    deleteExadbVmCluster(deleteExadbVmClusterRequest: requests.DeleteExadbVmClusterRequest): Promise<responses.DeleteExadbVmClusterResponse>;
    /**
     * Deletes the specified Exadata Database Storage Vault.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteExascaleDbStorageVaultRequest
     * @return DeleteExascaleDbStorageVaultResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/DeleteExascaleDbStorageVault.ts.html |here} to see how to use DeleteExascaleDbStorageVault API.
     */
    deleteExascaleDbStorageVault(deleteExascaleDbStorageVaultRequest: requests.DeleteExascaleDbStorageVaultRequest): Promise<responses.DeleteExascaleDbStorageVaultResponse>;
    /**
     * Deletes the {@link #createExternalContainerDatabaseDetails(CreateExternalContainerDatabaseDetailsRequest) createExternalContainerDatabaseDetails}
     * resource. Any external pluggable databases registered under this container database must be deleted in
     * your Oracle Cloud Infrastructure tenancy prior to this operation.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteExternalContainerDatabaseRequest
     * @return DeleteExternalContainerDatabaseResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/DeleteExternalContainerDatabase.ts.html |here} to see how to use DeleteExternalContainerDatabase API.
     */
    deleteExternalContainerDatabase(deleteExternalContainerDatabaseRequest: requests.DeleteExternalContainerDatabaseRequest): Promise<responses.DeleteExternalContainerDatabaseResponse>;
    /**
     * Deletes an external database connector.
     * Any services enabled using the external database connector must be
     * deleted prior to this operation.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteExternalDatabaseConnectorRequest
     * @return DeleteExternalDatabaseConnectorResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/DeleteExternalDatabaseConnector.ts.html |here} to see how to use DeleteExternalDatabaseConnector API.
     */
    deleteExternalDatabaseConnector(deleteExternalDatabaseConnectorRequest: requests.DeleteExternalDatabaseConnectorRequest): Promise<responses.DeleteExternalDatabaseConnectorResponse>;
    /**
     * Deletes the Oracle Cloud Infrastructure resource representing an external non-container database.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteExternalNonContainerDatabaseRequest
     * @return DeleteExternalNonContainerDatabaseResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/DeleteExternalNonContainerDatabase.ts.html |here} to see how to use DeleteExternalNonContainerDatabase API.
     */
    deleteExternalNonContainerDatabase(deleteExternalNonContainerDatabaseRequest: requests.DeleteExternalNonContainerDatabaseRequest): Promise<responses.DeleteExternalNonContainerDatabaseResponse>;
    /**
     * Deletes the {@link #createExternalPluggableDatabaseDetails(CreateExternalPluggableDatabaseDetailsRequest) createExternalPluggableDatabaseDetails}.
     * resource.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteExternalPluggableDatabaseRequest
     * @return DeleteExternalPluggableDatabaseResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/DeleteExternalPluggableDatabase.ts.html |here} to see how to use DeleteExternalPluggableDatabase API.
     */
    deleteExternalPluggableDatabase(deleteExternalPluggableDatabaseRequest: requests.DeleteExternalPluggableDatabaseRequest): Promise<responses.DeleteExternalPluggableDatabaseResponse>;
    /**
     * Deletes a key store.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteKeyStoreRequest
     * @return DeleteKeyStoreResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/DeleteKeyStore.ts.html |here} to see how to use DeleteKeyStore API.
     */
    deleteKeyStore(deleteKeyStoreRequest: requests.DeleteKeyStoreRequest): Promise<responses.DeleteKeyStoreResponse>;
    /**
     * Deletes a one-off patch.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteOneoffPatchRequest
     * @return DeleteOneoffPatchResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/DeleteOneoffPatch.ts.html |here} to see how to use DeleteOneoffPatch API.
     */
    deleteOneoffPatch(deleteOneoffPatchRequest: requests.DeleteOneoffPatchRequest): Promise<responses.DeleteOneoffPatchResponse>;
    /**
     * Deletes the specified pluggable database.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeletePluggableDatabaseRequest
     * @return DeletePluggableDatabaseResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/DeletePluggableDatabase.ts.html |here} to see how to use DeletePluggableDatabase API.
     */
    deletePluggableDatabase(deletePluggableDatabaseRequest: requests.DeletePluggableDatabaseRequest): Promise<responses.DeletePluggableDatabaseResponse>;
    /**
     * Deletes the specified VM cluster. Applies to Exadata Cloud@Customer instances only.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteVmClusterRequest
     * @return DeleteVmClusterResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/DeleteVmCluster.ts.html |here} to see how to use DeleteVmCluster API.
     */
    deleteVmCluster(deleteVmClusterRequest: requests.DeleteVmClusterRequest): Promise<responses.DeleteVmClusterResponse>;
    /**
     * Deletes the specified VM cluster network. Applies to Exadata Cloud@Customer instances only.
     * To delete a cloud VM cluster in an Exadata Cloud Service instance, use the {@link #deleteCloudVmCluster(DeleteCloudVmClusterRequest) deleteCloudVmCluster} operation.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteVmClusterNetworkRequest
     * @return DeleteVmClusterNetworkResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/DeleteVmClusterNetwork.ts.html |here} to see how to use DeleteVmClusterNetwork API.
     */
    deleteVmClusterNetwork(deleteVmClusterNetworkRequest: requests.DeleteVmClusterNetworkRequest): Promise<responses.DeleteVmClusterNetworkResponse>;
    /**
     * Asynchronously deregisters this Autonomous Database with Data Safe.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeregisterAutonomousDatabaseDataSafeRequest
     * @return DeregisterAutonomousDatabaseDataSafeResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/DeregisterAutonomousDatabaseDataSafe.ts.html |here} to see how to use DeregisterAutonomousDatabaseDataSafe API.
     */
    deregisterAutonomousDatabaseDataSafe(deregisterAutonomousDatabaseDataSafeRequest: requests.DeregisterAutonomousDatabaseDataSafeRequest): Promise<responses.DeregisterAutonomousDatabaseDataSafeResponse>;
    /**
     * Disables Database Management for the Autonomous Database resource.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DisableAutonomousDatabaseManagementRequest
     * @return DisableAutonomousDatabaseManagementResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/DisableAutonomousDatabaseManagement.ts.html |here} to see how to use DisableAutonomousDatabaseManagement API.
     */
    disableAutonomousDatabaseManagement(disableAutonomousDatabaseManagementRequest: requests.DisableAutonomousDatabaseManagementRequest): Promise<responses.DisableAutonomousDatabaseManagementResponse>;
    /**
     * Disables Operations Insights for the Autonomous Database resource.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DisableAutonomousDatabaseOperationsInsightsRequest
     * @return DisableAutonomousDatabaseOperationsInsightsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/DisableAutonomousDatabaseOperationsInsights.ts.html |here} to see how to use DisableAutonomousDatabaseOperationsInsights API.
     */
    disableAutonomousDatabaseOperationsInsights(disableAutonomousDatabaseOperationsInsightsRequest: requests.DisableAutonomousDatabaseOperationsInsightsRequest): Promise<responses.DisableAutonomousDatabaseOperationsInsightsResponse>;
    /**
     * Disables the Database Management service for the database.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DisableDatabaseManagementRequest
     * @return DisableDatabaseManagementResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/DisableDatabaseManagement.ts.html |here} to see how to use DisableDatabaseManagement API.
     */
    disableDatabaseManagement(disableDatabaseManagementRequest: requests.DisableDatabaseManagementRequest): Promise<responses.DisableDatabaseManagementResponse>;
    /**
     * Disable Database Management service for the external container database.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DisableExternalContainerDatabaseDatabaseManagementRequest
     * @return DisableExternalContainerDatabaseDatabaseManagementResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/DisableExternalContainerDatabaseDatabaseManagement.ts.html |here} to see how to use DisableExternalContainerDatabaseDatabaseManagement API.
     */
    disableExternalContainerDatabaseDatabaseManagement(disableExternalContainerDatabaseDatabaseManagementRequest: requests.DisableExternalContainerDatabaseDatabaseManagementRequest): Promise<responses.DisableExternalContainerDatabaseDatabaseManagementResponse>;
    /**
     * Disable Stack Monitoring for the external container database.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DisableExternalContainerDatabaseStackMonitoringRequest
     * @return DisableExternalContainerDatabaseStackMonitoringResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/DisableExternalContainerDatabaseStackMonitoring.ts.html |here} to see how to use DisableExternalContainerDatabaseStackMonitoring API.
     */
    disableExternalContainerDatabaseStackMonitoring(disableExternalContainerDatabaseStackMonitoringRequest: requests.DisableExternalContainerDatabaseStackMonitoringRequest): Promise<responses.DisableExternalContainerDatabaseStackMonitoringResponse>;
    /**
     * Disable Database Management Service for the external non-container database.
     * For more information about the Database Management Service, see
     * [Database Management Service](https://docs.cloud.oracle.com/Content/ExternalDatabase/Concepts/databasemanagementservice.htm).
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DisableExternalNonContainerDatabaseDatabaseManagementRequest
     * @return DisableExternalNonContainerDatabaseDatabaseManagementResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/DisableExternalNonContainerDatabaseDatabaseManagement.ts.html |here} to see how to use DisableExternalNonContainerDatabaseDatabaseManagement API.
     */
    disableExternalNonContainerDatabaseDatabaseManagement(disableExternalNonContainerDatabaseDatabaseManagementRequest: requests.DisableExternalNonContainerDatabaseDatabaseManagementRequest): Promise<responses.DisableExternalNonContainerDatabaseDatabaseManagementResponse>;
    /**
     * Disable Operations Insights for the external non-container database.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DisableExternalNonContainerDatabaseOperationsInsightsRequest
     * @return DisableExternalNonContainerDatabaseOperationsInsightsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/DisableExternalNonContainerDatabaseOperationsInsights.ts.html |here} to see how to use DisableExternalNonContainerDatabaseOperationsInsights API.
     */
    disableExternalNonContainerDatabaseOperationsInsights(disableExternalNonContainerDatabaseOperationsInsightsRequest: requests.DisableExternalNonContainerDatabaseOperationsInsightsRequest): Promise<responses.DisableExternalNonContainerDatabaseOperationsInsightsResponse>;
    /**
     * Disable Stack Monitoring for the external non-container database.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DisableExternalNonContainerDatabaseStackMonitoringRequest
     * @return DisableExternalNonContainerDatabaseStackMonitoringResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/DisableExternalNonContainerDatabaseStackMonitoring.ts.html |here} to see how to use DisableExternalNonContainerDatabaseStackMonitoring API.
     */
    disableExternalNonContainerDatabaseStackMonitoring(disableExternalNonContainerDatabaseStackMonitoringRequest: requests.DisableExternalNonContainerDatabaseStackMonitoringRequest): Promise<responses.DisableExternalNonContainerDatabaseStackMonitoringResponse>;
    /**
     * Disable Database Management Service for the external pluggable database.
     * For more information about the Database Management Service, see
     * [Database Management Service](https://docs.cloud.oracle.com/Content/ExternalDatabase/Concepts/databasemanagementservice.htm).
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DisableExternalPluggableDatabaseDatabaseManagementRequest
     * @return DisableExternalPluggableDatabaseDatabaseManagementResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/DisableExternalPluggableDatabaseDatabaseManagement.ts.html |here} to see how to use DisableExternalPluggableDatabaseDatabaseManagement API.
     */
    disableExternalPluggableDatabaseDatabaseManagement(disableExternalPluggableDatabaseDatabaseManagementRequest: requests.DisableExternalPluggableDatabaseDatabaseManagementRequest): Promise<responses.DisableExternalPluggableDatabaseDatabaseManagementResponse>;
    /**
     * Disable Operations Insights for the external pluggable database.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DisableExternalPluggableDatabaseOperationsInsightsRequest
     * @return DisableExternalPluggableDatabaseOperationsInsightsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/DisableExternalPluggableDatabaseOperationsInsights.ts.html |here} to see how to use DisableExternalPluggableDatabaseOperationsInsights API.
     */
    disableExternalPluggableDatabaseOperationsInsights(disableExternalPluggableDatabaseOperationsInsightsRequest: requests.DisableExternalPluggableDatabaseOperationsInsightsRequest): Promise<responses.DisableExternalPluggableDatabaseOperationsInsightsResponse>;
    /**
     * Disable Stack Monitoring for the external pluggable database.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DisableExternalPluggableDatabaseStackMonitoringRequest
     * @return DisableExternalPluggableDatabaseStackMonitoringResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/DisableExternalPluggableDatabaseStackMonitoring.ts.html |here} to see how to use DisableExternalPluggableDatabaseStackMonitoring API.
     */
    disableExternalPluggableDatabaseStackMonitoring(disableExternalPluggableDatabaseStackMonitoringRequest: requests.DisableExternalPluggableDatabaseStackMonitoringRequest): Promise<responses.DisableExternalPluggableDatabaseStackMonitoringResponse>;
    /**
     * Disables the Database Management service for the pluggable database.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DisablePluggableDatabaseManagementRequest
     * @return DisablePluggableDatabaseManagementResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/DisablePluggableDatabaseManagement.ts.html |here} to see how to use DisablePluggableDatabaseManagement API.
     */
    disablePluggableDatabaseManagement(disablePluggableDatabaseManagementRequest: requests.DisablePluggableDatabaseManagementRequest): Promise<responses.DisablePluggableDatabaseManagementResponse>;
    /**
     * Downloads the configuration file for the specified Exadata Cloud@Customer infrastructure.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DownloadExadataInfrastructureConfigFileRequest
     * @return DownloadExadataInfrastructureConfigFileResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/DownloadExadataInfrastructureConfigFile.ts.html |here} to see how to use DownloadExadataInfrastructureConfigFile API.
     */
    downloadExadataInfrastructureConfigFile(downloadExadataInfrastructureConfigFileRequest: requests.DownloadExadataInfrastructureConfigFileRequest): Promise<responses.DownloadExadataInfrastructureConfigFileResponse>;
    /**
     * Download one-off patch.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DownloadOneoffPatchRequest
     * @return DownloadOneoffPatchResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/DownloadOneoffPatch.ts.html |here} to see how to use DownloadOneoffPatch API.
     */
    downloadOneoffPatch(downloadOneoffPatchRequest: requests.DownloadOneoffPatchRequest): Promise<responses.DownloadOneoffPatchResponse>;
    /**
     * Downloads the network validation report file for the specified VM cluster network. Applies to Exadata Cloud@Customer instances only.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DownloadValidationReportRequest
     * @return DownloadValidationReportResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/DownloadValidationReport.ts.html |here} to see how to use DownloadValidationReport API.
     */
    downloadValidationReport(downloadValidationReportRequest: requests.DownloadValidationReportRequest): Promise<responses.DownloadValidationReportResponse>;
    /**
     * Downloads the configuration file for the specified VM cluster network. Applies to Exadata Cloud@Customer instances only.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DownloadVmClusterNetworkConfigFileRequest
     * @return DownloadVmClusterNetworkConfigFileResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/DownloadVmClusterNetworkConfigFile.ts.html |here} to see how to use DownloadVmClusterNetworkConfigFile API.
     */
    downloadVmClusterNetworkConfigFile(downloadVmClusterNetworkConfigFileRequest: requests.DownloadVmClusterNetworkConfigFileRequest): Promise<responses.DownloadVmClusterNetworkConfigFileResponse>;
    /**
     * Enables Database Management for Autonomous Database.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param EnableAutonomousDatabaseManagementRequest
     * @return EnableAutonomousDatabaseManagementResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/EnableAutonomousDatabaseManagement.ts.html |here} to see how to use EnableAutonomousDatabaseManagement API.
     */
    enableAutonomousDatabaseManagement(enableAutonomousDatabaseManagementRequest: requests.EnableAutonomousDatabaseManagementRequest): Promise<responses.EnableAutonomousDatabaseManagementResponse>;
    /**
     * Enables the specified Autonomous Database with Operations Insights.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param EnableAutonomousDatabaseOperationsInsightsRequest
     * @return EnableAutonomousDatabaseOperationsInsightsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/EnableAutonomousDatabaseOperationsInsights.ts.html |here} to see how to use EnableAutonomousDatabaseOperationsInsights API.
     */
    enableAutonomousDatabaseOperationsInsights(enableAutonomousDatabaseOperationsInsightsRequest: requests.EnableAutonomousDatabaseOperationsInsightsRequest): Promise<responses.EnableAutonomousDatabaseOperationsInsightsResponse>;
    /**
     * Enables the Database Management service for an Oracle Database located in Oracle Cloud Infrastructure. This service allows the database to access tools including Metrics and Performance hub. Database Management is enabled at the container database (CDB) level.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param EnableDatabaseManagementRequest
     * @return EnableDatabaseManagementResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/EnableDatabaseManagement.ts.html |here} to see how to use EnableDatabaseManagement API.
     */
    enableDatabaseManagement(enableDatabaseManagementRequest: requests.EnableDatabaseManagementRequest): Promise<responses.EnableDatabaseManagementResponse>;
    /**
     * Enables Database Management Service for the external container database.
     * For more information about the Database Management Service, see
     * [Database Management Service](https://docs.cloud.oracle.com/Content/ExternalDatabase/Concepts/databasemanagementservice.htm).
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param EnableExternalContainerDatabaseDatabaseManagementRequest
     * @return EnableExternalContainerDatabaseDatabaseManagementResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/EnableExternalContainerDatabaseDatabaseManagement.ts.html |here} to see how to use EnableExternalContainerDatabaseDatabaseManagement API.
     */
    enableExternalContainerDatabaseDatabaseManagement(enableExternalContainerDatabaseDatabaseManagementRequest: requests.EnableExternalContainerDatabaseDatabaseManagementRequest): Promise<responses.EnableExternalContainerDatabaseDatabaseManagementResponse>;
    /**
     * Enable Stack Monitoring for the external container database.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param EnableExternalContainerDatabaseStackMonitoringRequest
     * @return EnableExternalContainerDatabaseStackMonitoringResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/EnableExternalContainerDatabaseStackMonitoring.ts.html |here} to see how to use EnableExternalContainerDatabaseStackMonitoring API.
     */
    enableExternalContainerDatabaseStackMonitoring(enableExternalContainerDatabaseStackMonitoringRequest: requests.EnableExternalContainerDatabaseStackMonitoringRequest): Promise<responses.EnableExternalContainerDatabaseStackMonitoringResponse>;
    /**
     * Enable Database Management Service for the external non-container database.
     * For more information about the Database Management Service, see
     * [Database Management Service](https://docs.cloud.oracle.com/Content/ExternalDatabase/Concepts/databasemanagementservice.htm).
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param EnableExternalNonContainerDatabaseDatabaseManagementRequest
     * @return EnableExternalNonContainerDatabaseDatabaseManagementResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/EnableExternalNonContainerDatabaseDatabaseManagement.ts.html |here} to see how to use EnableExternalNonContainerDatabaseDatabaseManagement API.
     */
    enableExternalNonContainerDatabaseDatabaseManagement(enableExternalNonContainerDatabaseDatabaseManagementRequest: requests.EnableExternalNonContainerDatabaseDatabaseManagementRequest): Promise<responses.EnableExternalNonContainerDatabaseDatabaseManagementResponse>;
    /**
     * Enable Operations Insights for the external non-container database.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param EnableExternalNonContainerDatabaseOperationsInsightsRequest
     * @return EnableExternalNonContainerDatabaseOperationsInsightsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/EnableExternalNonContainerDatabaseOperationsInsights.ts.html |here} to see how to use EnableExternalNonContainerDatabaseOperationsInsights API.
     */
    enableExternalNonContainerDatabaseOperationsInsights(enableExternalNonContainerDatabaseOperationsInsightsRequest: requests.EnableExternalNonContainerDatabaseOperationsInsightsRequest): Promise<responses.EnableExternalNonContainerDatabaseOperationsInsightsResponse>;
    /**
     * Enable Stack Monitoring for the external non-container database.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param EnableExternalNonContainerDatabaseStackMonitoringRequest
     * @return EnableExternalNonContainerDatabaseStackMonitoringResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/EnableExternalNonContainerDatabaseStackMonitoring.ts.html |here} to see how to use EnableExternalNonContainerDatabaseStackMonitoring API.
     */
    enableExternalNonContainerDatabaseStackMonitoring(enableExternalNonContainerDatabaseStackMonitoringRequest: requests.EnableExternalNonContainerDatabaseStackMonitoringRequest): Promise<responses.EnableExternalNonContainerDatabaseStackMonitoringResponse>;
    /**
     * Enable Database Management Service for the external pluggable database.
     * For more information about the Database Management Service, see
     * [Database Management Service](https://docs.cloud.oracle.com/Content/ExternalDatabase/Concepts/databasemanagementservice.htm).
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param EnableExternalPluggableDatabaseDatabaseManagementRequest
     * @return EnableExternalPluggableDatabaseDatabaseManagementResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/EnableExternalPluggableDatabaseDatabaseManagement.ts.html |here} to see how to use EnableExternalPluggableDatabaseDatabaseManagement API.
     */
    enableExternalPluggableDatabaseDatabaseManagement(enableExternalPluggableDatabaseDatabaseManagementRequest: requests.EnableExternalPluggableDatabaseDatabaseManagementRequest): Promise<responses.EnableExternalPluggableDatabaseDatabaseManagementResponse>;
    /**
     * Enable Operations Insights for the external pluggable database.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param EnableExternalPluggableDatabaseOperationsInsightsRequest
     * @return EnableExternalPluggableDatabaseOperationsInsightsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/EnableExternalPluggableDatabaseOperationsInsights.ts.html |here} to see how to use EnableExternalPluggableDatabaseOperationsInsights API.
     */
    enableExternalPluggableDatabaseOperationsInsights(enableExternalPluggableDatabaseOperationsInsightsRequest: requests.EnableExternalPluggableDatabaseOperationsInsightsRequest): Promise<responses.EnableExternalPluggableDatabaseOperationsInsightsResponse>;
    /**
     * Enable Stack Monitoring for the external pluggable database.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param EnableExternalPluggableDatabaseStackMonitoringRequest
     * @return EnableExternalPluggableDatabaseStackMonitoringResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/EnableExternalPluggableDatabaseStackMonitoring.ts.html |here} to see how to use EnableExternalPluggableDatabaseStackMonitoring API.
     */
    enableExternalPluggableDatabaseStackMonitoring(enableExternalPluggableDatabaseStackMonitoringRequest: requests.EnableExternalPluggableDatabaseStackMonitoringRequest): Promise<responses.EnableExternalPluggableDatabaseStackMonitoringResponse>;
    /**
     * Enables the Database Management service for an Oracle Pluggable Database located in Oracle Cloud Infrastructure. This service allows the pluggable database to access tools including Metrics and Performance hub. Database Management is enabled at the pluggable database (PDB) level.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param EnablePluggableDatabaseManagementRequest
     * @return EnablePluggableDatabaseManagementResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/EnablePluggableDatabaseManagement.ts.html |here} to see how to use EnablePluggableDatabaseManagement API.
     */
    enablePluggableDatabaseManagement(enablePluggableDatabaseManagementRequest: requests.EnablePluggableDatabaseManagementRequest): Promise<responses.EnablePluggableDatabaseManagementResponse>;
    /**
     * Initiates a failover of the specified Autonomous Database to the associated peer database. Applicable only to databases with Disaster Recovery enabled.
     * This API should be called in the remote region where the peer database resides.
     * Below parameter is optional:
     *   - `peerDbId`
     *     Use this parameter to specify the database OCID of the Disaster Recovery peer, which is located in a different (remote) region from the current peer database.
     *     If this parameter is not provided, the failover will happen in the same region.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param FailOverAutonomousDatabaseRequest
     * @return FailOverAutonomousDatabaseResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/FailOverAutonomousDatabase.ts.html |here} to see how to use FailOverAutonomousDatabase API.
     */
    failOverAutonomousDatabase(failOverAutonomousDatabaseRequest: requests.FailOverAutonomousDatabaseRequest): Promise<responses.FailOverAutonomousDatabaseResponse>;
    /**
       * Fails over the standby Autonomous Container Database identified by the autonomousContainerDatabaseId parameter to the primary Autonomous Container Database after the existing primary Autonomous Container Database fails or becomes unreachable.
  * <p>
  A failover can result in data loss, depending on the protection mode in effect at the time the primary Autonomous Container Database fails.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param FailoverAutonomousContainerDatabaseDataguardAssociationRequest
       * @return FailoverAutonomousContainerDatabaseDataguardAssociationResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/FailoverAutonomousContainerDatabaseDataguardAssociation.ts.html |here} to see how to use FailoverAutonomousContainerDatabaseDataguardAssociation API.
       */
    failoverAutonomousContainerDatabaseDataguardAssociation(failoverAutonomousContainerDatabaseDataguardAssociationRequest: requests.FailoverAutonomousContainerDatabaseDataguardAssociationRequest): Promise<responses.FailoverAutonomousContainerDatabaseDataguardAssociationResponse>;
    /**
       * Performs a failover to transition the standby database identified by the `databaseId` parameter into the
  * specified Data Guard association's primary role after the existing primary database fails or becomes unreachable.
  * <p>
  A failover might result in data loss depending on the protection mode in effect at the time of the primary
  * database failure.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param FailoverDataGuardAssociationRequest
       * @return FailoverDataGuardAssociationResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/FailoverDataGuardAssociation.ts.html |here} to see how to use FailoverDataGuardAssociation API.
       */
    failoverDataGuardAssociation(failoverDataGuardAssociationRequest: requests.FailoverDataGuardAssociationRequest): Promise<responses.FailoverDataGuardAssociationResponse>;
    /**
     * Creates and downloads a wallet for the specified Autonomous Database.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GenerateAutonomousDatabaseWalletRequest
     * @return GenerateAutonomousDatabaseWalletResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/GenerateAutonomousDatabaseWallet.ts.html |here} to see how to use GenerateAutonomousDatabaseWallet API.
     */
    generateAutonomousDatabaseWallet(generateAutonomousDatabaseWalletRequest: requests.GenerateAutonomousDatabaseWalletRequest): Promise<responses.GenerateAutonomousDatabaseWalletResponse>;
    /**
     * Generates a recommended Cloud@Customer VM cluster network configuration.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GenerateRecommendedVmClusterNetworkRequest
     * @return GenerateRecommendedVmClusterNetworkResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/GenerateRecommendedVmClusterNetwork.ts.html |here} to see how to use GenerateRecommendedVmClusterNetwork API.
     */
    generateRecommendedVmClusterNetwork(generateRecommendedVmClusterNetworkRequest: requests.GenerateRecommendedVmClusterNetworkRequest): Promise<responses.GenerateRecommendedVmClusterNetworkResponse>;
    /**
     * Gets information about a specified application virtual IP (VIP) address.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetApplicationVipRequest
     * @return GetApplicationVipResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/GetApplicationVip.ts.html |here} to see how to use GetApplicationVip API.
     */
    getApplicationVip(getApplicationVipRequest: requests.GetApplicationVipRequest): Promise<responses.GetApplicationVipResponse>;
    /**
     * Gets information about the specified Autonomous Container Database.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetAutonomousContainerDatabaseRequest
     * @return GetAutonomousContainerDatabaseResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/GetAutonomousContainerDatabase.ts.html |here} to see how to use GetAutonomousContainerDatabase API.
     */
    getAutonomousContainerDatabase(getAutonomousContainerDatabaseRequest: requests.GetAutonomousContainerDatabaseRequest): Promise<responses.GetAutonomousContainerDatabaseResponse>;
    /**
     * Gets an Autonomous Container Database enabled with Autonomous Data Guard associated with the specified Autonomous Container Database.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetAutonomousContainerDatabaseDataguardAssociationRequest
     * @return GetAutonomousContainerDatabaseDataguardAssociationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/GetAutonomousContainerDatabaseDataguardAssociation.ts.html |here} to see how to use GetAutonomousContainerDatabaseDataguardAssociation API.
     */
    getAutonomousContainerDatabaseDataguardAssociation(getAutonomousContainerDatabaseDataguardAssociationRequest: requests.GetAutonomousContainerDatabaseDataguardAssociationRequest): Promise<responses.GetAutonomousContainerDatabaseDataguardAssociationResponse>;
    /**
     * Get resource usage details for the specified Autonomous Container Database.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetAutonomousContainerDatabaseResourceUsageRequest
     * @return GetAutonomousContainerDatabaseResourceUsageResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/GetAutonomousContainerDatabaseResourceUsage.ts.html |here} to see how to use GetAutonomousContainerDatabaseResourceUsage API.
     */
    getAutonomousContainerDatabaseResourceUsage(getAutonomousContainerDatabaseResourceUsageRequest: requests.GetAutonomousContainerDatabaseResourceUsageRequest): Promise<responses.GetAutonomousContainerDatabaseResourceUsageResponse>;
    /**
     * Gets the details of the specified Autonomous Database.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetAutonomousDatabaseRequest
     * @return GetAutonomousDatabaseResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/GetAutonomousDatabase.ts.html |here} to see how to use GetAutonomousDatabase API.
     */
    getAutonomousDatabase(getAutonomousDatabaseRequest: requests.GetAutonomousDatabaseRequest): Promise<responses.GetAutonomousDatabaseResponse>;
    /**
     * Gets information about the specified Autonomous Database backup.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetAutonomousDatabaseBackupRequest
     * @return GetAutonomousDatabaseBackupResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/GetAutonomousDatabaseBackup.ts.html |here} to see how to use GetAutonomousDatabaseBackup API.
     */
    getAutonomousDatabaseBackup(getAutonomousDatabaseBackupRequest: requests.GetAutonomousDatabaseBackupRequest): Promise<responses.GetAutonomousDatabaseBackupResponse>;
    /**
     * Gets an Autonomous Data Guard-enabled database associated with the specified Autonomous Database.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetAutonomousDatabaseDataguardAssociationRequest
     * @return GetAutonomousDatabaseDataguardAssociationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/GetAutonomousDatabaseDataguardAssociation.ts.html |here} to see how to use GetAutonomousDatabaseDataguardAssociation API.
     */
    getAutonomousDatabaseDataguardAssociation(getAutonomousDatabaseDataguardAssociationRequest: requests.GetAutonomousDatabaseDataguardAssociationRequest): Promise<responses.GetAutonomousDatabaseDataguardAssociationResponse>;
    /**
     * Gets the Autonomous Database regional wallet details.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetAutonomousDatabaseRegionalWalletRequest
     * @return GetAutonomousDatabaseRegionalWalletResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/GetAutonomousDatabaseRegionalWallet.ts.html |here} to see how to use GetAutonomousDatabaseRegionalWallet API.
     */
    getAutonomousDatabaseRegionalWallet(getAutonomousDatabaseRegionalWalletRequest: requests.GetAutonomousDatabaseRegionalWalletRequest): Promise<responses.GetAutonomousDatabaseRegionalWalletResponse>;
    /**
     * Gets information about the specified Autonomous Database Software Image.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetAutonomousDatabaseSoftwareImageRequest
     * @return GetAutonomousDatabaseSoftwareImageResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/GetAutonomousDatabaseSoftwareImage.ts.html |here} to see how to use GetAutonomousDatabaseSoftwareImage API.
     */
    getAutonomousDatabaseSoftwareImage(getAutonomousDatabaseSoftwareImageRequest: requests.GetAutonomousDatabaseSoftwareImageRequest): Promise<responses.GetAutonomousDatabaseSoftwareImageResponse>;
    /**
     * Gets the wallet details for the specified Autonomous Database.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetAutonomousDatabaseWalletRequest
     * @return GetAutonomousDatabaseWalletResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/GetAutonomousDatabaseWallet.ts.html |here} to see how to use GetAutonomousDatabaseWallet API.
     */
    getAutonomousDatabaseWallet(getAutonomousDatabaseWalletRequest: requests.GetAutonomousDatabaseWalletRequest): Promise<responses.GetAutonomousDatabaseWalletResponse>;
    /**
     * **Deprecated.** Use the {@link #getCloudExadataInfrastructure(GetCloudExadataInfrastructureRequest) getCloudExadataInfrastructure} operation to get details of an Exadata Infrastructure resource and the {@link #getCloudAutonomousVmCluster(GetCloudAutonomousVmClusterRequest) getCloudAutonomousVmCluster} operation to get details of an Autonomous Exadata VM cluster.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetAutonomousExadataInfrastructureRequest
     * @return GetAutonomousExadataInfrastructureResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/GetAutonomousExadataInfrastructure.ts.html |here} to see how to use GetAutonomousExadataInfrastructure API.
     */
    getAutonomousExadataInfrastructure(getAutonomousExadataInfrastructureRequest: requests.GetAutonomousExadataInfrastructureRequest): Promise<responses.GetAutonomousExadataInfrastructureResponse>;
    /**
     * Gets information about a specific autonomous patch.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetAutonomousPatchRequest
     * @return GetAutonomousPatchResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/GetAutonomousPatch.ts.html |here} to see how to use GetAutonomousPatch API.
     */
    getAutonomousPatch(getAutonomousPatchRequest: requests.GetAutonomousPatchRequest): Promise<responses.GetAutonomousPatchResponse>;
    /**
     * Gets the details of specific Autonomous Virtual Machine.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetAutonomousVirtualMachineRequest
     * @return GetAutonomousVirtualMachineResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/GetAutonomousVirtualMachine.ts.html |here} to see how to use GetAutonomousVirtualMachine API.
     */
    getAutonomousVirtualMachine(getAutonomousVirtualMachineRequest: requests.GetAutonomousVirtualMachineRequest): Promise<responses.GetAutonomousVirtualMachineResponse>;
    /**
     * Gets information about the specified Autonomous VM cluster for an Exadata Cloud@Customer system. To get information about an Autonomous VM Cluster in the Oracle cloud, see {@link #getCloudAutonomousVmCluster(GetCloudAutonomousVmClusterRequest) getCloudAutonomousVmCluster}.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetAutonomousVmClusterRequest
     * @return GetAutonomousVmClusterResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/GetAutonomousVmCluster.ts.html |here} to see how to use GetAutonomousVmCluster API.
     */
    getAutonomousVmCluster(getAutonomousVmClusterRequest: requests.GetAutonomousVmClusterRequest): Promise<responses.GetAutonomousVmClusterResponse>;
    /**
     * Get the resource usage details for the specified Autonomous Exadata VM cluster.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetAutonomousVmClusterResourceUsageRequest
     * @return GetAutonomousVmClusterResourceUsageResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/GetAutonomousVmClusterResourceUsage.ts.html |here} to see how to use GetAutonomousVmClusterResourceUsage API.
     */
    getAutonomousVmClusterResourceUsage(getAutonomousVmClusterResourceUsageRequest: requests.GetAutonomousVmClusterResourceUsageRequest): Promise<responses.GetAutonomousVmClusterResourceUsageResponse>;
    /**
     * Gets information about the specified backup.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetBackupRequest
     * @return GetBackupResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/GetBackup.ts.html |here} to see how to use GetBackup API.
     */
    getBackup(getBackupRequest: requests.GetBackupRequest): Promise<responses.GetBackupResponse>;
    /**
     * Gets information about the specified backup destination in an Exadata Cloud@Customer system.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetBackupDestinationRequest
     * @return GetBackupDestinationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/GetBackupDestination.ts.html |here} to see how to use GetBackupDestination API.
     */
    getBackupDestination(getBackupDestinationRequest: requests.GetBackupDestinationRequest): Promise<responses.GetBackupDestinationResponse>;
    /**
     * Gets information about the specified Autonomous Exadata VM cluster in the Oracle cloud. For Exadata Cloud@Custustomer systems, see {@link #getAutonomousVmCluster(GetAutonomousVmClusterRequest) getAutonomousVmCluster}.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetCloudAutonomousVmClusterRequest
     * @return GetCloudAutonomousVmClusterResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/GetCloudAutonomousVmCluster.ts.html |here} to see how to use GetCloudAutonomousVmCluster API.
     */
    getCloudAutonomousVmCluster(getCloudAutonomousVmClusterRequest: requests.GetCloudAutonomousVmClusterRequest): Promise<responses.GetCloudAutonomousVmClusterResponse>;
    /**
     * Get the resource usage details for the specified Cloud Autonomous Exadata VM cluster.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetCloudAutonomousVmClusterResourceUsageRequest
     * @return GetCloudAutonomousVmClusterResourceUsageResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/GetCloudAutonomousVmClusterResourceUsage.ts.html |here} to see how to use GetCloudAutonomousVmClusterResourceUsage API.
     */
    getCloudAutonomousVmClusterResourceUsage(getCloudAutonomousVmClusterResourceUsageRequest: requests.GetCloudAutonomousVmClusterResourceUsageRequest): Promise<responses.GetCloudAutonomousVmClusterResourceUsageResponse>;
    /**
     * Gets information about the specified cloud Exadata infrastructure resource. Applies to Exadata Cloud Service instances and Autonomous Database on dedicated Exadata infrastructure only.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetCloudExadataInfrastructureRequest
     * @return GetCloudExadataInfrastructureResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/GetCloudExadataInfrastructure.ts.html |here} to see how to use GetCloudExadataInfrastructure API.
     */
    getCloudExadataInfrastructure(getCloudExadataInfrastructureRequest: requests.GetCloudExadataInfrastructureRequest): Promise<responses.GetCloudExadataInfrastructureResponse>;
    /**
     * Gets unallocated resources information for the specified Cloud Exadata infrastructure.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetCloudExadataInfrastructureUnallocatedResourcesRequest
     * @return GetCloudExadataInfrastructureUnallocatedResourcesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/GetCloudExadataInfrastructureUnallocatedResources.ts.html |here} to see how to use GetCloudExadataInfrastructureUnallocatedResources API.
     */
    getCloudExadataInfrastructureUnallocatedResources(getCloudExadataInfrastructureUnallocatedResourcesRequest: requests.GetCloudExadataInfrastructureUnallocatedResourcesRequest): Promise<responses.GetCloudExadataInfrastructureUnallocatedResourcesResponse>;
    /**
     * Gets information about the specified cloud VM cluster. Applies to Exadata Cloud Service instances and Autonomous Database on dedicated Exadata infrastructure only.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetCloudVmClusterRequest
     * @return GetCloudVmClusterResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/GetCloudVmCluster.ts.html |here} to see how to use GetCloudVmCluster API.
     */
    getCloudVmCluster(getCloudVmClusterRequest: requests.GetCloudVmClusterRequest): Promise<responses.GetCloudVmClusterResponse>;
    /**
     * Gets the IORM configuration for the specified cloud VM cluster in an Exadata Cloud Service instance.
     * If you have not specified an IORM configuration, the default configuration is returned.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetCloudVmClusterIormConfigRequest
     * @return GetCloudVmClusterIormConfigResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/GetCloudVmClusterIormConfig.ts.html |here} to see how to use GetCloudVmClusterIormConfig API.
     */
    getCloudVmClusterIormConfig(getCloudVmClusterIormConfigRequest: requests.GetCloudVmClusterIormConfigRequest): Promise<responses.GetCloudVmClusterIormConfigResponse>;
    /**
     * Gets information about a specified maintenance update package for a cloud VM cluster. Applies to Exadata Cloud Service instances only.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetCloudVmClusterUpdateRequest
     * @return GetCloudVmClusterUpdateResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/GetCloudVmClusterUpdate.ts.html |here} to see how to use GetCloudVmClusterUpdate API.
     */
    getCloudVmClusterUpdate(getCloudVmClusterUpdateRequest: requests.GetCloudVmClusterUpdateRequest): Promise<responses.GetCloudVmClusterUpdateResponse>;
    /**
     * Gets the maintenance update history details for the specified update history entry. Applies to Exadata Cloud Service instances only.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetCloudVmClusterUpdateHistoryEntryRequest
     * @return GetCloudVmClusterUpdateHistoryEntryResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/GetCloudVmClusterUpdateHistoryEntry.ts.html |here} to see how to use GetCloudVmClusterUpdateHistoryEntry API.
     */
    getCloudVmClusterUpdateHistoryEntry(getCloudVmClusterUpdateHistoryEntryRequest: requests.GetCloudVmClusterUpdateHistoryEntryRequest): Promise<responses.GetCloudVmClusterUpdateHistoryEntryResponse>;
    /**
     * Gets the specified database node console connection's information.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetConsoleConnectionRequest
     * @return GetConsoleConnectionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/GetConsoleConnection.ts.html |here} to see how to use GetConsoleConnection API.
     */
    getConsoleConnection(getConsoleConnectionRequest: requests.GetConsoleConnectionRequest): Promise<responses.GetConsoleConnectionResponse>;
    /**
     * Gets information about the specified database node console history.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetConsoleHistoryRequest
     * @return GetConsoleHistoryResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/GetConsoleHistory.ts.html |here} to see how to use GetConsoleHistory API.
     */
    getConsoleHistory(getConsoleHistoryRequest: requests.GetConsoleHistoryRequest): Promise<responses.GetConsoleHistoryResponse>;
    /**
     * Retrieves the specified database node console history contents upto a megabyte.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetConsoleHistoryContentRequest
     * @return GetConsoleHistoryContentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/GetConsoleHistoryContent.ts.html |here} to see how to use GetConsoleHistoryContent API.
     */
    getConsoleHistoryContent(getConsoleHistoryContentRequest: requests.GetConsoleHistoryContentRequest): Promise<responses.GetConsoleHistoryContentResponse>;
    /**
     * Gets the specified Data Guard association's configuration information.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetDataGuardAssociationRequest
     * @return GetDataGuardAssociationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/GetDataGuardAssociation.ts.html |here} to see how to use GetDataGuardAssociation API.
     */
    getDataGuardAssociation(getDataGuardAssociationRequest: requests.GetDataGuardAssociationRequest): Promise<responses.GetDataGuardAssociationResponse>;
    /**
     * Gets information about the specified database.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetDatabaseRequest
     * @return GetDatabaseResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/GetDatabase.ts.html |here} to see how to use GetDatabase API.
     */
    getDatabase(getDatabaseRequest: requests.GetDatabaseRequest): Promise<responses.GetDatabaseResponse>;
    /**
     * Gets information about the specified database software image.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetDatabaseSoftwareImageRequest
     * @return GetDatabaseSoftwareImageResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/GetDatabaseSoftwareImage.ts.html |here} to see how to use GetDatabaseSoftwareImage API.
     */
    getDatabaseSoftwareImage(getDatabaseSoftwareImageRequest: requests.GetDatabaseSoftwareImageRequest): Promise<responses.GetDatabaseSoftwareImageResponse>;
    /**
     * gets the upgrade history for a specified database.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetDatabaseUpgradeHistoryEntryRequest
     * @return GetDatabaseUpgradeHistoryEntryResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/GetDatabaseUpgradeHistoryEntry.ts.html |here} to see how to use GetDatabaseUpgradeHistoryEntry API.
     */
    getDatabaseUpgradeHistoryEntry(getDatabaseUpgradeHistoryEntryRequest: requests.GetDatabaseUpgradeHistoryEntryRequest): Promise<responses.GetDatabaseUpgradeHistoryEntryResponse>;
    /**
     * Gets information about the specified Database Home.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetDbHomeRequest
     * @return GetDbHomeResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/GetDbHome.ts.html |here} to see how to use GetDbHome API.
     */
    getDbHome(getDbHomeRequest: requests.GetDbHomeRequest): Promise<responses.GetDbHomeResponse>;
    /**
     * Gets information about a specified patch package.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetDbHomePatchRequest
     * @return GetDbHomePatchResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/GetDbHomePatch.ts.html |here} to see how to use GetDbHomePatch API.
     */
    getDbHomePatch(getDbHomePatchRequest: requests.GetDbHomePatchRequest): Promise<responses.GetDbHomePatchResponse>;
    /**
     * Gets the patch history details for the specified patchHistoryEntryId
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetDbHomePatchHistoryEntryRequest
     * @return GetDbHomePatchHistoryEntryResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/GetDbHomePatchHistoryEntry.ts.html |here} to see how to use GetDbHomePatchHistoryEntry API.
     */
    getDbHomePatchHistoryEntry(getDbHomePatchHistoryEntryRequest: requests.GetDbHomePatchHistoryEntryRequest): Promise<responses.GetDbHomePatchHistoryEntryResponse>;
    /**
     * Gets information about the specified database node.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetDbNodeRequest
     * @return GetDbNodeResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/GetDbNode.ts.html |here} to see how to use GetDbNode API.
     */
    getDbNode(getDbNodeRequest: requests.GetDbNodeRequest): Promise<responses.GetDbNodeResponse>;
    /**
     * Gets information about the Exadata Db server.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetDbServerRequest
     * @return GetDbServerResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/GetDbServer.ts.html |here} to see how to use GetDbServer API.
     */
    getDbServer(getDbServerRequest: requests.GetDbServerRequest): Promise<responses.GetDbServerResponse>;
    /**
       * Gets information about the specified DB system.
  * <p>
  **Note:** Deprecated for Exadata Cloud Service systems. Use the [new resource model APIs](https://docs.cloud.oracle.com/iaas/Content/Database/Concepts/exaflexsystem.htm#exaflexsystem_topic-resource_model) instead.
  * <p>
  For Exadata Cloud Service instances, support for this API will end on May 15th, 2021. See [Switching an Exadata DB System to the New Resource Model and APIs](https://docs.cloud.oracle.com/iaas/Content/Database/Concepts/exaflexsystem_topic-resource_model_conversion.htm) for details on converting existing Exadata DB systems to the new resource model.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param GetDbSystemRequest
       * @return GetDbSystemResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/GetDbSystem.ts.html |here} to see how to use GetDbSystem API.
       */
    getDbSystem(getDbSystemRequest: requests.GetDbSystemRequest): Promise<responses.GetDbSystemResponse>;
    /**
     * Gets information the specified patch.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetDbSystemPatchRequest
     * @return GetDbSystemPatchResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/GetDbSystemPatch.ts.html |here} to see how to use GetDbSystemPatch API.
     */
    getDbSystemPatch(getDbSystemPatchRequest: requests.GetDbSystemPatchRequest): Promise<responses.GetDbSystemPatchResponse>;
    /**
     * Gets the details of the specified patch operation on the specified DB system.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetDbSystemPatchHistoryEntryRequest
     * @return GetDbSystemPatchHistoryEntryResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/GetDbSystemPatchHistoryEntry.ts.html |here} to see how to use GetDbSystemPatchHistoryEntry API.
     */
    getDbSystemPatchHistoryEntry(getDbSystemPatchHistoryEntryRequest: requests.GetDbSystemPatchHistoryEntryRequest): Promise<responses.GetDbSystemPatchHistoryEntryResponse>;
    /**
     * Gets the details of the specified operating system upgrade operation for the specified DB system.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetDbSystemUpgradeHistoryEntryRequest
     * @return GetDbSystemUpgradeHistoryEntryResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/GetDbSystemUpgradeHistoryEntry.ts.html |here} to see how to use GetDbSystemUpgradeHistoryEntry API.
     */
    getDbSystemUpgradeHistoryEntry(getDbSystemUpgradeHistoryEntryRequest: requests.GetDbSystemUpgradeHistoryEntryRequest): Promise<responses.GetDbSystemUpgradeHistoryEntryResponse>;
    /**
     * Gets information about the specified Exadata infrastructure. Applies to Exadata Cloud@Customer instances only.
     * To get information on an Exadata Cloud Service infrastructure resource, use the  {@link #getCloudExadataInfrastructure(GetCloudExadataInfrastructureRequest) getCloudExadataInfrastructure} operation.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetExadataInfrastructureRequest
     * @return GetExadataInfrastructureResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/GetExadataInfrastructure.ts.html |here} to see how to use GetExadataInfrastructure API.
     */
    getExadataInfrastructure(getExadataInfrastructureRequest: requests.GetExadataInfrastructureRequest): Promise<responses.GetExadataInfrastructureResponse>;
    /**
     * Gets details of the available and consumed OCPUs for the specified Autonomous Exadata Infrastructure resource.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetExadataInfrastructureOcpusRequest
     * @return GetExadataInfrastructureOcpusResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/GetExadataInfrastructureOcpus.ts.html |here} to see how to use GetExadataInfrastructureOcpus API.
     */
    getExadataInfrastructureOcpus(getExadataInfrastructureOcpusRequest: requests.GetExadataInfrastructureOcpusRequest): Promise<responses.GetExadataInfrastructureOcpusResponse>;
    /**
     * Gets un allocated resources information for the specified Exadata infrastructure. Applies to Exadata Cloud@Customer instances only.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetExadataInfrastructureUnAllocatedResourcesRequest
     * @return GetExadataInfrastructureUnAllocatedResourcesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/GetExadataInfrastructureUnAllocatedResources.ts.html |here} to see how to use GetExadataInfrastructureUnAllocatedResources API.
     */
    getExadataInfrastructureUnAllocatedResources(getExadataInfrastructureUnAllocatedResourcesRequest: requests.GetExadataInfrastructureUnAllocatedResourcesRequest): Promise<responses.GetExadataInfrastructureUnAllocatedResourcesResponse>;
    /**
       * Gets the IORM configuration settings for the specified cloud Exadata DB system.
  * All Exadata service instances have default IORM settings.
  * <p>
  **Note:** Deprecated for Exadata Cloud Service systems. Use the [new resource model APIs](https://docs.cloud.oracle.com/iaas/Content/Database/Concepts/exaflexsystem.htm#exaflexsystem_topic-resource_model) instead.
  * <p>
  For Exadata Cloud Service instances, support for this API will end on May 15th, 2021. See [Switching an Exadata DB System to the New Resource Model and APIs](https://docs.cloud.oracle.com/iaas/Content/Database/Concepts/exaflexsystem_topic-resource_model_conversion.htm) for details on converting existing Exadata DB systems to the new resource model.
  * <p>
  The {@link #getCloudVmClusterIormConfig(GetCloudVmClusterIormConfigRequest) getCloudVmClusterIormConfig} API is used for this operation with Exadata systems using the
  * new resource model.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param GetExadataIormConfigRequest
       * @return GetExadataIormConfigResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/GetExadataIormConfig.ts.html |here} to see how to use GetExadataIormConfig API.
       */
    getExadataIormConfig(getExadataIormConfigRequest: requests.GetExadataIormConfigRequest): Promise<responses.GetExadataIormConfigResponse>;
    /**
     * Gets information about the specified Exadata VM cluster on Exascale Infrastructure. Applies to Exadata Database Service on Exascale Infrastructure only.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetExadbVmClusterRequest
     * @return GetExadbVmClusterResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/GetExadbVmCluster.ts.html |here} to see how to use GetExadbVmCluster API.
     */
    getExadbVmCluster(getExadbVmClusterRequest: requests.GetExadbVmClusterRequest): Promise<responses.GetExadbVmClusterResponse>;
    /**
     * Gets information about a specified maintenance update package for a Exadata VM cluster on Exascale Infrastructure.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetExadbVmClusterUpdateRequest
     * @return GetExadbVmClusterUpdateResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/GetExadbVmClusterUpdate.ts.html |here} to see how to use GetExadbVmClusterUpdate API.
     */
    getExadbVmClusterUpdate(getExadbVmClusterUpdateRequest: requests.GetExadbVmClusterUpdateRequest): Promise<responses.GetExadbVmClusterUpdateResponse>;
    /**
     * Gets the maintenance update history details for the specified update history entry.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetExadbVmClusterUpdateHistoryEntryRequest
     * @return GetExadbVmClusterUpdateHistoryEntryResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/GetExadbVmClusterUpdateHistoryEntry.ts.html |here} to see how to use GetExadbVmClusterUpdateHistoryEntry API.
     */
    getExadbVmClusterUpdateHistoryEntry(getExadbVmClusterUpdateHistoryEntryRequest: requests.GetExadbVmClusterUpdateHistoryEntryRequest): Promise<responses.GetExadbVmClusterUpdateHistoryEntryResponse>;
    /**
     * Gets information about the specified Exadata Database Storage Vaults in the specified compartment.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetExascaleDbStorageVaultRequest
     * @return GetExascaleDbStorageVaultResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/GetExascaleDbStorageVault.ts.html |here} to see how to use GetExascaleDbStorageVault API.
     */
    getExascaleDbStorageVault(getExascaleDbStorageVaultRequest: requests.GetExascaleDbStorageVaultRequest): Promise<responses.GetExascaleDbStorageVaultResponse>;
    /**
     * Gets information about the specified external backup job.
     * <p>
     **Note:** This API is used by an Oracle Cloud Infrastructure Python script that is packaged with the Oracle Cloud Infrastructure CLI. Oracle recommends that you use the script instead using the API directly. See [Migrating an On-Premises Database to Oracle Cloud Infrastructure by Creating a Backup in the Cloud](https://docs.cloud.oracle.com/Content/Database/Tasks/mig-onprembackup.htm) for more information.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetExternalBackupJobRequest
     * @return GetExternalBackupJobResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/GetExternalBackupJob.ts.html |here} to see how to use GetExternalBackupJob API.
     */
    getExternalBackupJob(getExternalBackupJobRequest: requests.GetExternalBackupJobRequest): Promise<responses.GetExternalBackupJobResponse>;
    /**
     * Gets information about the specified external container database.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetExternalContainerDatabaseRequest
     * @return GetExternalContainerDatabaseResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/GetExternalContainerDatabase.ts.html |here} to see how to use GetExternalContainerDatabase API.
     */
    getExternalContainerDatabase(getExternalContainerDatabaseRequest: requests.GetExternalContainerDatabaseRequest): Promise<responses.GetExternalContainerDatabaseResponse>;
    /**
     * Gets information about the specified external database connector.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetExternalDatabaseConnectorRequest
     * @return GetExternalDatabaseConnectorResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/GetExternalDatabaseConnector.ts.html |here} to see how to use GetExternalDatabaseConnector API.
     */
    getExternalDatabaseConnector(getExternalDatabaseConnectorRequest: requests.GetExternalDatabaseConnectorRequest): Promise<responses.GetExternalDatabaseConnectorResponse>;
    /**
     * Gets information about a specific external non-container database.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetExternalNonContainerDatabaseRequest
     * @return GetExternalNonContainerDatabaseResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/GetExternalNonContainerDatabase.ts.html |here} to see how to use GetExternalNonContainerDatabase API.
     */
    getExternalNonContainerDatabase(getExternalNonContainerDatabaseRequest: requests.GetExternalNonContainerDatabaseRequest): Promise<responses.GetExternalNonContainerDatabaseResponse>;
    /**
     * Gets information about a specific
     * {@link #createExternalPluggableDatabaseDetails(CreateExternalPluggableDatabaseDetailsRequest) createExternalPluggableDatabaseDetails} resource.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetExternalPluggableDatabaseRequest
     * @return GetExternalPluggableDatabaseResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/GetExternalPluggableDatabase.ts.html |here} to see how to use GetExternalPluggableDatabase API.
     */
    getExternalPluggableDatabase(getExternalPluggableDatabaseRequest: requests.GetExternalPluggableDatabaseRequest): Promise<responses.GetExternalPluggableDatabaseResponse>;
    /**
     * Gets details of the Exadata Infrastructure target system software versions that can be applied to the specified infrastructure resource for maintenance updates.
     * Applies to Exadata Cloud@Customer and Exadata Cloud instances only.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetInfrastructureTargetVersionsRequest
     * @return GetInfrastructureTargetVersionsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/GetInfrastructureTargetVersions.ts.html |here} to see how to use GetInfrastructureTargetVersions API.
     */
    getInfrastructureTargetVersions(getInfrastructureTargetVersionsRequest: requests.GetInfrastructureTargetVersionsRequest): Promise<responses.GetInfrastructureTargetVersionsResponse>;
    /**
     * Gets information about the specified key store.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetKeyStoreRequest
     * @return GetKeyStoreResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/GetKeyStore.ts.html |here} to see how to use GetKeyStore API.
     */
    getKeyStore(getKeyStoreRequest: requests.GetKeyStoreRequest): Promise<responses.GetKeyStoreResponse>;
    /**
     * Gets information about the specified maintenance run.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetMaintenanceRunRequest
     * @return GetMaintenanceRunResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/GetMaintenanceRun.ts.html |here} to see how to use GetMaintenanceRun API.
     */
    getMaintenanceRun(getMaintenanceRunRequest: requests.GetMaintenanceRunRequest): Promise<responses.GetMaintenanceRunResponse>;
    /**
     * Gets information about the specified maintenance run history.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetMaintenanceRunHistoryRequest
     * @return GetMaintenanceRunHistoryResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/GetMaintenanceRunHistory.ts.html |here} to see how to use GetMaintenanceRunHistory API.
     */
    getMaintenanceRunHistory(getMaintenanceRunHistoryRequest: requests.GetMaintenanceRunHistoryRequest): Promise<responses.GetMaintenanceRunHistoryResponse>;
    /**
     * Gets information about the specified one-off patch.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetOneoffPatchRequest
     * @return GetOneoffPatchResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/GetOneoffPatch.ts.html |here} to see how to use GetOneoffPatch API.
     */
    getOneoffPatch(getOneoffPatchRequest: requests.GetOneoffPatchRequest): Promise<responses.GetOneoffPatchResponse>;
    /**
     * Gets the details of operations performed to convert the specified database from non-container (non-CDB) to pluggable (PDB).
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetPdbConversionHistoryEntryRequest
     * @return GetPdbConversionHistoryEntryResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/GetPdbConversionHistoryEntry.ts.html |here} to see how to use GetPdbConversionHistoryEntry API.
     */
    getPdbConversionHistoryEntry(getPdbConversionHistoryEntryRequest: requests.GetPdbConversionHistoryEntryRequest): Promise<responses.GetPdbConversionHistoryEntryResponse>;
    /**
     * Gets information about the specified pluggable database.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetPluggableDatabaseRequest
     * @return GetPluggableDatabaseResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/GetPluggableDatabase.ts.html |here} to see how to use GetPluggableDatabase API.
     */
    getPluggableDatabase(getPluggableDatabaseRequest: requests.GetPluggableDatabaseRequest): Promise<responses.GetPluggableDatabaseResponse>;
    /**
     * Gets information about the VM cluster. Applies to Exadata Cloud@Customer instances only.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetVmClusterRequest
     * @return GetVmClusterResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/GetVmCluster.ts.html |here} to see how to use GetVmCluster API.
     */
    getVmCluster(getVmClusterRequest: requests.GetVmClusterRequest): Promise<responses.GetVmClusterResponse>;
    /**
     * Gets information about the specified VM cluster network. Applies to Exadata Cloud@Customer instances only.
     * To get information about a cloud VM cluster in an Exadata Cloud Service instance, use the {@link #getCloudVmCluster(GetCloudVmClusterRequest) getCloudVmCluster} operation.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetVmClusterNetworkRequest
     * @return GetVmClusterNetworkResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/GetVmClusterNetwork.ts.html |here} to see how to use GetVmClusterNetwork API.
     */
    getVmClusterNetwork(getVmClusterNetworkRequest: requests.GetVmClusterNetworkRequest): Promise<responses.GetVmClusterNetworkResponse>;
    /**
     * Gets information about a specified patch package.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetVmClusterPatchRequest
     * @return GetVmClusterPatchResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/GetVmClusterPatch.ts.html |here} to see how to use GetVmClusterPatch API.
     */
    getVmClusterPatch(getVmClusterPatchRequest: requests.GetVmClusterPatchRequest): Promise<responses.GetVmClusterPatchResponse>;
    /**
     * Gets the patch history details for the specified patch history entry.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetVmClusterPatchHistoryEntryRequest
     * @return GetVmClusterPatchHistoryEntryResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/GetVmClusterPatchHistoryEntry.ts.html |here} to see how to use GetVmClusterPatchHistoryEntry API.
     */
    getVmClusterPatchHistoryEntry(getVmClusterPatchHistoryEntryRequest: requests.GetVmClusterPatchHistoryEntryRequest): Promise<responses.GetVmClusterPatchHistoryEntryResponse>;
    /**
     * Gets information about a specified maintenance update package for a VM cluster. Applies to Exadata Cloud@Customer instances only.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetVmClusterUpdateRequest
     * @return GetVmClusterUpdateResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/GetVmClusterUpdate.ts.html |here} to see how to use GetVmClusterUpdate API.
     */
    getVmClusterUpdate(getVmClusterUpdateRequest: requests.GetVmClusterUpdateRequest): Promise<responses.GetVmClusterUpdateResponse>;
    /**
     * Gets the maintenance update history details for the specified update history entry. Applies to Exadata Cloud@Customer instances only.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetVmClusterUpdateHistoryEntryRequest
     * @return GetVmClusterUpdateHistoryEntryResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/GetVmClusterUpdateHistoryEntry.ts.html |here} to see how to use GetVmClusterUpdateHistoryEntry API.
     */
    getVmClusterUpdateHistoryEntry(getVmClusterUpdateHistoryEntryRequest: requests.GetVmClusterUpdateHistoryEntryRequest): Promise<responses.GetVmClusterUpdateHistoryEntryResponse>;
    /**
     * **Deprecated** To create a new Autonomous Database system on dedicated Exadata Infrastructure, use the {@link #createCloudExadataInfrastructure(CreateCloudExadataInfrastructureRequest) createCloudExadataInfrastructure} and {@link #createCloudAutonomousVmCluster(CreateCloudAutonomousVmClusterRequest) createCloudAutonomousVmCluster} operations instead. Note that to create an Autonomous VM cluster, you must have an existing Exadata Infrastructure resource to contain the VM cluster.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param LaunchAutonomousExadataInfrastructureRequest
     * @return LaunchAutonomousExadataInfrastructureResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/LaunchAutonomousExadataInfrastructure.ts.html |here} to see how to use LaunchAutonomousExadataInfrastructure API.
     */
    launchAutonomousExadataInfrastructure(launchAutonomousExadataInfrastructureRequest: requests.LaunchAutonomousExadataInfrastructureRequest): Promise<responses.LaunchAutonomousExadataInfrastructureResponse>;
    /**
       * Creates a new DB system in the specified compartment and availability domain. The Oracle
  * Database edition that you specify applies to all the databases on that DB system. The selected edition cannot be changed.
  * <p>
  An initial database is created on the DB system based on the request parameters you provide and some default
  * options. For detailed information about default options, see [Bare metal and virtual machine DB system default options.](https://docs.cloud.oracle.com/Content/Database/Tasks/creatingDBsystem.htm#Default)
  * <p>
  **Note:** Deprecated for Exadata Cloud Service systems. Use the [new resource model APIs](https://docs.cloud.oracle.com/iaas/Content/Database/Concepts/exaflexsystem.htm#exaflexsystem_topic-resource_model) instead.
  * <p>
  For Exadata Cloud Service instances, support for this API will end on May 15th, 2021. See [Switching an Exadata DB System to the New Resource Model and APIs](https://docs.cloud.oracle.com/iaas/Content/Database/Concepts/exaflexsystem_topic-resource_model_conversion.htm) for details on converting existing Exadata DB systems to the new resource model.
  * <p>
  Use the {@link #createCloudExadataInfrastructure(CreateCloudExadataInfrastructureRequest) createCloudExadataInfrastructure} and {@link #createCloudVmCluster(CreateCloudVmClusterRequest) createCloudVmCluster} APIs to provision a new Exadata Cloud Service instance.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param LaunchDbSystemRequest
       * @return LaunchDbSystemResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/LaunchDbSystem.ts.html |here} to see how to use LaunchDbSystem API.
       */
    launchDbSystem(launchDbSystemRequest: requests.LaunchDbSystemRequest): Promise<responses.LaunchDbSystemResponse>;
    /**
     * Gets a list of application virtual IP (VIP) addresses on a cloud VM cluster.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListApplicationVipsRequest
     * @return ListApplicationVipsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ListApplicationVips.ts.html |here} to see how to use ListApplicationVips API.
     */
    listApplicationVips(listApplicationVipsRequest: requests.ListApplicationVipsRequest): Promise<responses.ListApplicationVipsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listApplicationVipsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.ApplicationVipSummary objects
     * contained in responses from the listApplicationVips operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllApplicationVips(request: requests.ListApplicationVipsRequest): AsyncIterableIterator<model.ApplicationVipSummary>;
    /**
     * NOTE: This function is deprecated in favor of listApplicationVipsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listApplicationVips operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllApplicationVipsResponses(request: requests.ListApplicationVipsRequest): AsyncIterableIterator<responses.ListApplicationVipsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.ApplicationVipSummary objects
     * contained in responses from the listApplicationVips operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listApplicationVipsRecordIterator(request: requests.ListApplicationVipsRequest): AsyncIterableIterator<model.ApplicationVipSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listApplicationVips operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listApplicationVipsResponseIterator(request: requests.ListApplicationVipsRequest): AsyncIterableIterator<responses.ListApplicationVipsResponse>;
    /**
     * Gets a list of the Autonomous Container Databases with Autonomous Data Guard-enabled associated with the specified Autonomous Container Database.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListAutonomousContainerDatabaseDataguardAssociationsRequest
     * @return ListAutonomousContainerDatabaseDataguardAssociationsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ListAutonomousContainerDatabaseDataguardAssociations.ts.html |here} to see how to use ListAutonomousContainerDatabaseDataguardAssociations API.
     */
    listAutonomousContainerDatabaseDataguardAssociations(listAutonomousContainerDatabaseDataguardAssociationsRequest: requests.ListAutonomousContainerDatabaseDataguardAssociationsRequest): Promise<responses.ListAutonomousContainerDatabaseDataguardAssociationsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listAutonomousContainerDatabaseDataguardAssociationsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.AutonomousContainerDatabaseDataguardAssociation objects
     * contained in responses from the listAutonomousContainerDatabaseDataguardAssociations operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllAutonomousContainerDatabaseDataguardAssociations(request: requests.ListAutonomousContainerDatabaseDataguardAssociationsRequest): AsyncIterableIterator<model.AutonomousContainerDatabaseDataguardAssociation>;
    /**
     * NOTE: This function is deprecated in favor of listAutonomousContainerDatabaseDataguardAssociationsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listAutonomousContainerDatabaseDataguardAssociations operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllAutonomousContainerDatabaseDataguardAssociationsResponses(request: requests.ListAutonomousContainerDatabaseDataguardAssociationsRequest): AsyncIterableIterator<responses.ListAutonomousContainerDatabaseDataguardAssociationsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.AutonomousContainerDatabaseDataguardAssociation objects
     * contained in responses from the listAutonomousContainerDatabaseDataguardAssociations operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAutonomousContainerDatabaseDataguardAssociationsRecordIterator(request: requests.ListAutonomousContainerDatabaseDataguardAssociationsRequest): AsyncIterableIterator<model.AutonomousContainerDatabaseDataguardAssociation>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listAutonomousContainerDatabaseDataguardAssociations operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAutonomousContainerDatabaseDataguardAssociationsResponseIterator(request: requests.ListAutonomousContainerDatabaseDataguardAssociationsRequest): AsyncIterableIterator<responses.ListAutonomousContainerDatabaseDataguardAssociationsResponse>;
    /**
     * Gets a list of supported Autonomous Container Database versions.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListAutonomousContainerDatabaseVersionsRequest
     * @return ListAutonomousContainerDatabaseVersionsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ListAutonomousContainerDatabaseVersions.ts.html |here} to see how to use ListAutonomousContainerDatabaseVersions API.
     */
    listAutonomousContainerDatabaseVersions(listAutonomousContainerDatabaseVersionsRequest: requests.ListAutonomousContainerDatabaseVersionsRequest): Promise<responses.ListAutonomousContainerDatabaseVersionsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listAutonomousContainerDatabaseVersionsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.AutonomousContainerDatabaseVersionSummary objects
     * contained in responses from the listAutonomousContainerDatabaseVersions operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllAutonomousContainerDatabaseVersions(request: requests.ListAutonomousContainerDatabaseVersionsRequest): AsyncIterableIterator<model.AutonomousContainerDatabaseVersionSummary>;
    /**
     * NOTE: This function is deprecated in favor of listAutonomousContainerDatabaseVersionsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listAutonomousContainerDatabaseVersions operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllAutonomousContainerDatabaseVersionsResponses(request: requests.ListAutonomousContainerDatabaseVersionsRequest): AsyncIterableIterator<responses.ListAutonomousContainerDatabaseVersionsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.AutonomousContainerDatabaseVersionSummary objects
     * contained in responses from the listAutonomousContainerDatabaseVersions operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAutonomousContainerDatabaseVersionsRecordIterator(request: requests.ListAutonomousContainerDatabaseVersionsRequest): AsyncIterableIterator<model.AutonomousContainerDatabaseVersionSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listAutonomousContainerDatabaseVersions operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAutonomousContainerDatabaseVersionsResponseIterator(request: requests.ListAutonomousContainerDatabaseVersionsRequest): AsyncIterableIterator<responses.ListAutonomousContainerDatabaseVersionsResponse>;
    /**
     * Gets a list of the Autonomous Container Databases in the specified compartment.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListAutonomousContainerDatabasesRequest
     * @return ListAutonomousContainerDatabasesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ListAutonomousContainerDatabases.ts.html |here} to see how to use ListAutonomousContainerDatabases API.
     */
    listAutonomousContainerDatabases(listAutonomousContainerDatabasesRequest: requests.ListAutonomousContainerDatabasesRequest): Promise<responses.ListAutonomousContainerDatabasesResponse>;
    /**
     * NOTE: This function is deprecated in favor of listAutonomousContainerDatabasesRecordIterator function.
     * Creates a new async iterator which will iterate over the models.AutonomousContainerDatabaseSummary objects
     * contained in responses from the listAutonomousContainerDatabases operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllAutonomousContainerDatabases(request: requests.ListAutonomousContainerDatabasesRequest): AsyncIterableIterator<model.AutonomousContainerDatabaseSummary>;
    /**
     * NOTE: This function is deprecated in favor of listAutonomousContainerDatabasesResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listAutonomousContainerDatabases operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllAutonomousContainerDatabasesResponses(request: requests.ListAutonomousContainerDatabasesRequest): AsyncIterableIterator<responses.ListAutonomousContainerDatabasesResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.AutonomousContainerDatabaseSummary objects
     * contained in responses from the listAutonomousContainerDatabases operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAutonomousContainerDatabasesRecordIterator(request: requests.ListAutonomousContainerDatabasesRequest): AsyncIterableIterator<model.AutonomousContainerDatabaseSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listAutonomousContainerDatabases operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAutonomousContainerDatabasesResponseIterator(request: requests.ListAutonomousContainerDatabasesRequest): AsyncIterableIterator<responses.ListAutonomousContainerDatabasesResponse>;
    /**
     * Gets a list of Autonomous Database backups based on either the `autonomousDatabaseId` or `compartmentId` specified as a query parameter.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListAutonomousDatabaseBackupsRequest
     * @return ListAutonomousDatabaseBackupsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ListAutonomousDatabaseBackups.ts.html |here} to see how to use ListAutonomousDatabaseBackups API.
     */
    listAutonomousDatabaseBackups(listAutonomousDatabaseBackupsRequest: requests.ListAutonomousDatabaseBackupsRequest): Promise<responses.ListAutonomousDatabaseBackupsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listAutonomousDatabaseBackupsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.AutonomousDatabaseBackupSummary objects
     * contained in responses from the listAutonomousDatabaseBackups operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllAutonomousDatabaseBackups(request: requests.ListAutonomousDatabaseBackupsRequest): AsyncIterableIterator<model.AutonomousDatabaseBackupSummary>;
    /**
     * NOTE: This function is deprecated in favor of listAutonomousDatabaseBackupsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listAutonomousDatabaseBackups operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllAutonomousDatabaseBackupsResponses(request: requests.ListAutonomousDatabaseBackupsRequest): AsyncIterableIterator<responses.ListAutonomousDatabaseBackupsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.AutonomousDatabaseBackupSummary objects
     * contained in responses from the listAutonomousDatabaseBackups operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAutonomousDatabaseBackupsRecordIterator(request: requests.ListAutonomousDatabaseBackupsRequest): AsyncIterableIterator<model.AutonomousDatabaseBackupSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listAutonomousDatabaseBackups operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAutonomousDatabaseBackupsResponseIterator(request: requests.ListAutonomousDatabaseBackupsRequest): AsyncIterableIterator<responses.ListAutonomousDatabaseBackupsResponse>;
    /**
     * Gets a list of supported character sets.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListAutonomousDatabaseCharacterSetsRequest
     * @return ListAutonomousDatabaseCharacterSetsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ListAutonomousDatabaseCharacterSets.ts.html |here} to see how to use ListAutonomousDatabaseCharacterSets API.
     */
    listAutonomousDatabaseCharacterSets(listAutonomousDatabaseCharacterSetsRequest: requests.ListAutonomousDatabaseCharacterSetsRequest): Promise<responses.ListAutonomousDatabaseCharacterSetsResponse>;
    /**
     * Lists the Autonomous Database clones for the specified Autonomous Database.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListAutonomousDatabaseClonesRequest
     * @return ListAutonomousDatabaseClonesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ListAutonomousDatabaseClones.ts.html |here} to see how to use ListAutonomousDatabaseClones API.
     */
    listAutonomousDatabaseClones(listAutonomousDatabaseClonesRequest: requests.ListAutonomousDatabaseClonesRequest): Promise<responses.ListAutonomousDatabaseClonesResponse>;
    /**
     * NOTE: This function is deprecated in favor of listAutonomousDatabaseClonesRecordIterator function.
     * Creates a new async iterator which will iterate over the models.AutonomousDatabaseSummary objects
     * contained in responses from the listAutonomousDatabaseClones operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllAutonomousDatabaseClones(request: requests.ListAutonomousDatabaseClonesRequest): AsyncIterableIterator<model.AutonomousDatabaseSummary>;
    /**
     * NOTE: This function is deprecated in favor of listAutonomousDatabaseClonesResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listAutonomousDatabaseClones operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllAutonomousDatabaseClonesResponses(request: requests.ListAutonomousDatabaseClonesRequest): AsyncIterableIterator<responses.ListAutonomousDatabaseClonesResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.AutonomousDatabaseSummary objects
     * contained in responses from the listAutonomousDatabaseClones operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAutonomousDatabaseClonesRecordIterator(request: requests.ListAutonomousDatabaseClonesRequest): AsyncIterableIterator<model.AutonomousDatabaseSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listAutonomousDatabaseClones operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAutonomousDatabaseClonesResponseIterator(request: requests.ListAutonomousDatabaseClonesRequest): AsyncIterableIterator<responses.ListAutonomousDatabaseClonesResponse>;
    /**
     * Gets a list of the Autonomous Data Guard-enabled databases associated with the specified Autonomous Database.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListAutonomousDatabaseDataguardAssociationsRequest
     * @return ListAutonomousDatabaseDataguardAssociationsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ListAutonomousDatabaseDataguardAssociations.ts.html |here} to see how to use ListAutonomousDatabaseDataguardAssociations API.
     */
    listAutonomousDatabaseDataguardAssociations(listAutonomousDatabaseDataguardAssociationsRequest: requests.ListAutonomousDatabaseDataguardAssociationsRequest): Promise<responses.ListAutonomousDatabaseDataguardAssociationsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listAutonomousDatabaseDataguardAssociationsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.AutonomousDatabaseDataguardAssociation objects
     * contained in responses from the listAutonomousDatabaseDataguardAssociations operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllAutonomousDatabaseDataguardAssociations(request: requests.ListAutonomousDatabaseDataguardAssociationsRequest): AsyncIterableIterator<model.AutonomousDatabaseDataguardAssociation>;
    /**
     * NOTE: This function is deprecated in favor of listAutonomousDatabaseDataguardAssociationsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listAutonomousDatabaseDataguardAssociations operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllAutonomousDatabaseDataguardAssociationsResponses(request: requests.ListAutonomousDatabaseDataguardAssociationsRequest): AsyncIterableIterator<responses.ListAutonomousDatabaseDataguardAssociationsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.AutonomousDatabaseDataguardAssociation objects
     * contained in responses from the listAutonomousDatabaseDataguardAssociations operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAutonomousDatabaseDataguardAssociationsRecordIterator(request: requests.ListAutonomousDatabaseDataguardAssociationsRequest): AsyncIterableIterator<model.AutonomousDatabaseDataguardAssociation>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listAutonomousDatabaseDataguardAssociations operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAutonomousDatabaseDataguardAssociationsResponseIterator(request: requests.ListAutonomousDatabaseDataguardAssociationsRequest): AsyncIterableIterator<responses.ListAutonomousDatabaseDataguardAssociationsResponse>;
    /**
     * Lists the Autonomous Database peers for the specified Autonomous Database.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListAutonomousDatabasePeersRequest
     * @return ListAutonomousDatabasePeersResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ListAutonomousDatabasePeers.ts.html |here} to see how to use ListAutonomousDatabasePeers API.
     */
    listAutonomousDatabasePeers(listAutonomousDatabasePeersRequest: requests.ListAutonomousDatabasePeersRequest): Promise<responses.ListAutonomousDatabasePeersResponse>;
    /**
     * Lists the OCIDs of the Autonomous Database local and connected remote refreshable clones with the region where they exist for the specified source database.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListAutonomousDatabaseRefreshableClonesRequest
     * @return ListAutonomousDatabaseRefreshableClonesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ListAutonomousDatabaseRefreshableClones.ts.html |here} to see how to use ListAutonomousDatabaseRefreshableClones API.
     */
    listAutonomousDatabaseRefreshableClones(listAutonomousDatabaseRefreshableClonesRequest: requests.ListAutonomousDatabaseRefreshableClonesRequest): Promise<responses.ListAutonomousDatabaseRefreshableClonesResponse>;
    /**
     * Gets a list of the Autonomous Database Software Images in the specified compartment.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListAutonomousDatabaseSoftwareImagesRequest
     * @return ListAutonomousDatabaseSoftwareImagesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ListAutonomousDatabaseSoftwareImages.ts.html |here} to see how to use ListAutonomousDatabaseSoftwareImages API.
     */
    listAutonomousDatabaseSoftwareImages(listAutonomousDatabaseSoftwareImagesRequest: requests.ListAutonomousDatabaseSoftwareImagesRequest): Promise<responses.ListAutonomousDatabaseSoftwareImagesResponse>;
    /**
     * Gets a list of Autonomous Databases based on the query parameters specified.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListAutonomousDatabasesRequest
     * @return ListAutonomousDatabasesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ListAutonomousDatabases.ts.html |here} to see how to use ListAutonomousDatabases API.
     */
    listAutonomousDatabases(listAutonomousDatabasesRequest: requests.ListAutonomousDatabasesRequest): Promise<responses.ListAutonomousDatabasesResponse>;
    /**
     * NOTE: This function is deprecated in favor of listAutonomousDatabasesRecordIterator function.
     * Creates a new async iterator which will iterate over the models.AutonomousDatabaseSummary objects
     * contained in responses from the listAutonomousDatabases operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllAutonomousDatabases(request: requests.ListAutonomousDatabasesRequest): AsyncIterableIterator<model.AutonomousDatabaseSummary>;
    /**
     * NOTE: This function is deprecated in favor of listAutonomousDatabasesResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listAutonomousDatabases operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllAutonomousDatabasesResponses(request: requests.ListAutonomousDatabasesRequest): AsyncIterableIterator<responses.ListAutonomousDatabasesResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.AutonomousDatabaseSummary objects
     * contained in responses from the listAutonomousDatabases operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAutonomousDatabasesRecordIterator(request: requests.ListAutonomousDatabasesRequest): AsyncIterableIterator<model.AutonomousDatabaseSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listAutonomousDatabases operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAutonomousDatabasesResponseIterator(request: requests.ListAutonomousDatabasesRequest): AsyncIterableIterator<responses.ListAutonomousDatabasesResponse>;
    /**
     * Gets a list of supported Autonomous Database versions. Note that preview version software is only available for
     * Autonomous Database Serverless (https://docs.oracle.com/en/cloud/paas/autonomous-database/index.html) databases.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListAutonomousDbPreviewVersionsRequest
     * @return ListAutonomousDbPreviewVersionsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ListAutonomousDbPreviewVersions.ts.html |here} to see how to use ListAutonomousDbPreviewVersions API.
     */
    listAutonomousDbPreviewVersions(listAutonomousDbPreviewVersionsRequest: requests.ListAutonomousDbPreviewVersionsRequest): Promise<responses.ListAutonomousDbPreviewVersionsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listAutonomousDbPreviewVersionsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.AutonomousDbPreviewVersionSummary objects
     * contained in responses from the listAutonomousDbPreviewVersions operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllAutonomousDbPreviewVersions(request: requests.ListAutonomousDbPreviewVersionsRequest): AsyncIterableIterator<model.AutonomousDbPreviewVersionSummary>;
    /**
     * NOTE: This function is deprecated in favor of listAutonomousDbPreviewVersionsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listAutonomousDbPreviewVersions operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllAutonomousDbPreviewVersionsResponses(request: requests.ListAutonomousDbPreviewVersionsRequest): AsyncIterableIterator<responses.ListAutonomousDbPreviewVersionsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.AutonomousDbPreviewVersionSummary objects
     * contained in responses from the listAutonomousDbPreviewVersions operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAutonomousDbPreviewVersionsRecordIterator(request: requests.ListAutonomousDbPreviewVersionsRequest): AsyncIterableIterator<model.AutonomousDbPreviewVersionSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listAutonomousDbPreviewVersions operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAutonomousDbPreviewVersionsResponseIterator(request: requests.ListAutonomousDbPreviewVersionsRequest): AsyncIterableIterator<responses.ListAutonomousDbPreviewVersionsResponse>;
    /**
     * Gets a list of supported Autonomous Database versions.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListAutonomousDbVersionsRequest
     * @return ListAutonomousDbVersionsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ListAutonomousDbVersions.ts.html |here} to see how to use ListAutonomousDbVersions API.
     */
    listAutonomousDbVersions(listAutonomousDbVersionsRequest: requests.ListAutonomousDbVersionsRequest): Promise<responses.ListAutonomousDbVersionsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listAutonomousDbVersionsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.AutonomousDbVersionSummary objects
     * contained in responses from the listAutonomousDbVersions operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllAutonomousDbVersions(request: requests.ListAutonomousDbVersionsRequest): AsyncIterableIterator<model.AutonomousDbVersionSummary>;
    /**
     * NOTE: This function is deprecated in favor of listAutonomousDbVersionsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listAutonomousDbVersions operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllAutonomousDbVersionsResponses(request: requests.ListAutonomousDbVersionsRequest): AsyncIterableIterator<responses.ListAutonomousDbVersionsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.AutonomousDbVersionSummary objects
     * contained in responses from the listAutonomousDbVersions operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAutonomousDbVersionsRecordIterator(request: requests.ListAutonomousDbVersionsRequest): AsyncIterableIterator<model.AutonomousDbVersionSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listAutonomousDbVersions operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAutonomousDbVersionsResponseIterator(request: requests.ListAutonomousDbVersionsRequest): AsyncIterableIterator<responses.ListAutonomousDbVersionsResponse>;
    /**
     * **Deprecated.**
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListAutonomousExadataInfrastructureShapesRequest
     * @return ListAutonomousExadataInfrastructureShapesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ListAutonomousExadataInfrastructureShapes.ts.html |here} to see how to use ListAutonomousExadataInfrastructureShapes API.
     */
    listAutonomousExadataInfrastructureShapes(listAutonomousExadataInfrastructureShapesRequest: requests.ListAutonomousExadataInfrastructureShapesRequest): Promise<responses.ListAutonomousExadataInfrastructureShapesResponse>;
    /**
     * NOTE: This function is deprecated in favor of listAutonomousExadataInfrastructureShapesRecordIterator function.
     * Creates a new async iterator which will iterate over the models.AutonomousExadataInfrastructureShapeSummary objects
     * contained in responses from the listAutonomousExadataInfrastructureShapes operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllAutonomousExadataInfrastructureShapes(request: requests.ListAutonomousExadataInfrastructureShapesRequest): AsyncIterableIterator<model.AutonomousExadataInfrastructureShapeSummary>;
    /**
     * NOTE: This function is deprecated in favor of listAutonomousExadataInfrastructureShapesResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listAutonomousExadataInfrastructureShapes operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllAutonomousExadataInfrastructureShapesResponses(request: requests.ListAutonomousExadataInfrastructureShapesRequest): AsyncIterableIterator<responses.ListAutonomousExadataInfrastructureShapesResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.AutonomousExadataInfrastructureShapeSummary objects
     * contained in responses from the listAutonomousExadataInfrastructureShapes operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAutonomousExadataInfrastructureShapesRecordIterator(request: requests.ListAutonomousExadataInfrastructureShapesRequest): AsyncIterableIterator<model.AutonomousExadataInfrastructureShapeSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listAutonomousExadataInfrastructureShapes operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAutonomousExadataInfrastructureShapesResponseIterator(request: requests.ListAutonomousExadataInfrastructureShapesRequest): AsyncIterableIterator<responses.ListAutonomousExadataInfrastructureShapesResponse>;
    /**
     * **Deprecated.** Use the {@link #listCloudExadataInfrastructures(ListCloudExadataInfrastructuresRequest) listCloudExadataInfrastructures} operation to list Exadata Infrastructures in the Oracle cloud and the  {@link #listCloudAutonomousVmClusters(ListCloudAutonomousVmClustersRequest) listCloudAutonomousVmClusters} operation to list Autonomous Exadata VM clusters.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListAutonomousExadataInfrastructuresRequest
     * @return ListAutonomousExadataInfrastructuresResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ListAutonomousExadataInfrastructures.ts.html |here} to see how to use ListAutonomousExadataInfrastructures API.
     */
    listAutonomousExadataInfrastructures(listAutonomousExadataInfrastructuresRequest: requests.ListAutonomousExadataInfrastructuresRequest): Promise<responses.ListAutonomousExadataInfrastructuresResponse>;
    /**
     * NOTE: This function is deprecated in favor of listAutonomousExadataInfrastructuresRecordIterator function.
     * Creates a new async iterator which will iterate over the models.AutonomousExadataInfrastructureSummary objects
     * contained in responses from the listAutonomousExadataInfrastructures operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllAutonomousExadataInfrastructures(request: requests.ListAutonomousExadataInfrastructuresRequest): AsyncIterableIterator<model.AutonomousExadataInfrastructureSummary>;
    /**
     * NOTE: This function is deprecated in favor of listAutonomousExadataInfrastructuresResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listAutonomousExadataInfrastructures operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllAutonomousExadataInfrastructuresResponses(request: requests.ListAutonomousExadataInfrastructuresRequest): AsyncIterableIterator<responses.ListAutonomousExadataInfrastructuresResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.AutonomousExadataInfrastructureSummary objects
     * contained in responses from the listAutonomousExadataInfrastructures operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAutonomousExadataInfrastructuresRecordIterator(request: requests.ListAutonomousExadataInfrastructuresRequest): AsyncIterableIterator<model.AutonomousExadataInfrastructureSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listAutonomousExadataInfrastructures operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAutonomousExadataInfrastructuresResponseIterator(request: requests.ListAutonomousExadataInfrastructuresRequest): AsyncIterableIterator<responses.ListAutonomousExadataInfrastructuresResponse>;
    /**
     * Lists the Autonomous Virtual Machines in the specified Autonomous VM Cluster and Compartment.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListAutonomousVirtualMachinesRequest
     * @return ListAutonomousVirtualMachinesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ListAutonomousVirtualMachines.ts.html |here} to see how to use ListAutonomousVirtualMachines API.
     */
    listAutonomousVirtualMachines(listAutonomousVirtualMachinesRequest: requests.ListAutonomousVirtualMachinesRequest): Promise<responses.ListAutonomousVirtualMachinesResponse>;
    /**
     * NOTE: This function is deprecated in favor of listAutonomousVirtualMachinesRecordIterator function.
     * Creates a new async iterator which will iterate over the models.AutonomousVirtualMachineSummary objects
     * contained in responses from the listAutonomousVirtualMachines operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllAutonomousVirtualMachines(request: requests.ListAutonomousVirtualMachinesRequest): AsyncIterableIterator<model.AutonomousVirtualMachineSummary>;
    /**
     * NOTE: This function is deprecated in favor of listAutonomousVirtualMachinesResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listAutonomousVirtualMachines operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllAutonomousVirtualMachinesResponses(request: requests.ListAutonomousVirtualMachinesRequest): AsyncIterableIterator<responses.ListAutonomousVirtualMachinesResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.AutonomousVirtualMachineSummary objects
     * contained in responses from the listAutonomousVirtualMachines operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAutonomousVirtualMachinesRecordIterator(request: requests.ListAutonomousVirtualMachinesRequest): AsyncIterableIterator<model.AutonomousVirtualMachineSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listAutonomousVirtualMachines operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAutonomousVirtualMachinesResponseIterator(request: requests.ListAutonomousVirtualMachinesRequest): AsyncIterableIterator<responses.ListAutonomousVirtualMachinesResponse>;
    /**
     * Gets the list of resource usage details for all the Autonomous Container Database in the specified Autonomous Exadata VM cluster.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListAutonomousVmClusterAcdResourceUsageRequest
     * @return ListAutonomousVmClusterAcdResourceUsageResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ListAutonomousVmClusterAcdResourceUsage.ts.html |here} to see how to use ListAutonomousVmClusterAcdResourceUsage API.
     */
    listAutonomousVmClusterAcdResourceUsage(listAutonomousVmClusterAcdResourceUsageRequest: requests.ListAutonomousVmClusterAcdResourceUsageRequest): Promise<responses.ListAutonomousVmClusterAcdResourceUsageResponse>;
    /**
     * NOTE: This function is deprecated in favor of listAutonomousVmClusterAcdResourceUsageRecordIterator function.
     * Creates a new async iterator which will iterate over the models.AutonomousContainerDatabaseResourceUsage objects
     * contained in responses from the listAutonomousVmClusterAcdResourceUsage operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllAutonomousVmClusterAcdResourceUsage(request: requests.ListAutonomousVmClusterAcdResourceUsageRequest): AsyncIterableIterator<model.AutonomousContainerDatabaseResourceUsage>;
    /**
     * NOTE: This function is deprecated in favor of listAutonomousVmClusterAcdResourceUsageResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listAutonomousVmClusterAcdResourceUsage operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllAutonomousVmClusterAcdResourceUsageResponses(request: requests.ListAutonomousVmClusterAcdResourceUsageRequest): AsyncIterableIterator<responses.ListAutonomousVmClusterAcdResourceUsageResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.AutonomousContainerDatabaseResourceUsage objects
     * contained in responses from the listAutonomousVmClusterAcdResourceUsage operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAutonomousVmClusterAcdResourceUsageRecordIterator(request: requests.ListAutonomousVmClusterAcdResourceUsageRequest): AsyncIterableIterator<model.AutonomousContainerDatabaseResourceUsage>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listAutonomousVmClusterAcdResourceUsage operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAutonomousVmClusterAcdResourceUsageResponseIterator(request: requests.ListAutonomousVmClusterAcdResourceUsageRequest): AsyncIterableIterator<responses.ListAutonomousVmClusterAcdResourceUsageResponse>;
    /**
     * Gets a list of Exadata Cloud@Customer Autonomous VM clusters in the specified compartment. To list Autonomous VM Clusters in the Oracle Cloud, see {@link #listCloudAutonomousVmClusters(ListCloudAutonomousVmClustersRequest) listCloudAutonomousVmClusters}.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListAutonomousVmClustersRequest
     * @return ListAutonomousVmClustersResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ListAutonomousVmClusters.ts.html |here} to see how to use ListAutonomousVmClusters API.
     */
    listAutonomousVmClusters(listAutonomousVmClustersRequest: requests.ListAutonomousVmClustersRequest): Promise<responses.ListAutonomousVmClustersResponse>;
    /**
     * NOTE: This function is deprecated in favor of listAutonomousVmClustersRecordIterator function.
     * Creates a new async iterator which will iterate over the models.AutonomousVmClusterSummary objects
     * contained in responses from the listAutonomousVmClusters operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllAutonomousVmClusters(request: requests.ListAutonomousVmClustersRequest): AsyncIterableIterator<model.AutonomousVmClusterSummary>;
    /**
     * NOTE: This function is deprecated in favor of listAutonomousVmClustersResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listAutonomousVmClusters operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllAutonomousVmClustersResponses(request: requests.ListAutonomousVmClustersRequest): AsyncIterableIterator<responses.ListAutonomousVmClustersResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.AutonomousVmClusterSummary objects
     * contained in responses from the listAutonomousVmClusters operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAutonomousVmClustersRecordIterator(request: requests.ListAutonomousVmClustersRequest): AsyncIterableIterator<model.AutonomousVmClusterSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listAutonomousVmClusters operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAutonomousVmClustersResponseIterator(request: requests.ListAutonomousVmClustersRequest): AsyncIterableIterator<responses.ListAutonomousVmClustersResponse>;
    /**
     * Gets a list of backup destinations in the specified compartment.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListBackupDestinationRequest
     * @return ListBackupDestinationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ListBackupDestination.ts.html |here} to see how to use ListBackupDestination API.
     */
    listBackupDestination(listBackupDestinationRequest: requests.ListBackupDestinationRequest): Promise<responses.ListBackupDestinationResponse>;
    /**
     * NOTE: This function is deprecated in favor of listBackupDestinationRecordIterator function.
     * Creates a new async iterator which will iterate over the models.BackupDestinationSummary objects
     * contained in responses from the listBackupDestination operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllBackupDestination(request: requests.ListBackupDestinationRequest): AsyncIterableIterator<model.BackupDestinationSummary>;
    /**
     * NOTE: This function is deprecated in favor of listBackupDestinationResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listBackupDestination operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllBackupDestinationResponses(request: requests.ListBackupDestinationRequest): AsyncIterableIterator<responses.ListBackupDestinationResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.BackupDestinationSummary objects
     * contained in responses from the listBackupDestination operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listBackupDestinationRecordIterator(request: requests.ListBackupDestinationRequest): AsyncIterableIterator<model.BackupDestinationSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listBackupDestination operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listBackupDestinationResponseIterator(request: requests.ListBackupDestinationRequest): AsyncIterableIterator<responses.ListBackupDestinationResponse>;
    /**
     * Gets a list of backups based on the `databaseId` or `compartmentId` specified. Either one of these query parameters must be provided.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListBackupsRequest
     * @return ListBackupsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ListBackups.ts.html |here} to see how to use ListBackups API.
     */
    listBackups(listBackupsRequest: requests.ListBackupsRequest): Promise<responses.ListBackupsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listBackupsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.BackupSummary objects
     * contained in responses from the listBackups operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllBackups(request: requests.ListBackupsRequest): AsyncIterableIterator<model.BackupSummary>;
    /**
     * NOTE: This function is deprecated in favor of listBackupsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listBackups operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllBackupsResponses(request: requests.ListBackupsRequest): AsyncIterableIterator<responses.ListBackupsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.BackupSummary objects
     * contained in responses from the listBackups operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listBackupsRecordIterator(request: requests.ListBackupsRequest): AsyncIterableIterator<model.BackupSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listBackups operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listBackupsResponseIterator(request: requests.ListBackupsRequest): AsyncIterableIterator<responses.ListBackupsResponse>;
    /**
     * Gets the list of resource usage details for all the Cloud Autonomous Container Database
     * in the specified Cloud Autonomous Exadata VM cluster.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListCloudAutonomousVmClusterAcdResourceUsageRequest
     * @return ListCloudAutonomousVmClusterAcdResourceUsageResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ListCloudAutonomousVmClusterAcdResourceUsage.ts.html |here} to see how to use ListCloudAutonomousVmClusterAcdResourceUsage API.
     */
    listCloudAutonomousVmClusterAcdResourceUsage(listCloudAutonomousVmClusterAcdResourceUsageRequest: requests.ListCloudAutonomousVmClusterAcdResourceUsageRequest): Promise<responses.ListCloudAutonomousVmClusterAcdResourceUsageResponse>;
    /**
     * NOTE: This function is deprecated in favor of listCloudAutonomousVmClusterAcdResourceUsageRecordIterator function.
     * Creates a new async iterator which will iterate over the models.AutonomousContainerDatabaseResourceUsage objects
     * contained in responses from the listCloudAutonomousVmClusterAcdResourceUsage operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllCloudAutonomousVmClusterAcdResourceUsage(request: requests.ListCloudAutonomousVmClusterAcdResourceUsageRequest): AsyncIterableIterator<model.AutonomousContainerDatabaseResourceUsage>;
    /**
     * NOTE: This function is deprecated in favor of listCloudAutonomousVmClusterAcdResourceUsageResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listCloudAutonomousVmClusterAcdResourceUsage operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllCloudAutonomousVmClusterAcdResourceUsageResponses(request: requests.ListCloudAutonomousVmClusterAcdResourceUsageRequest): AsyncIterableIterator<responses.ListCloudAutonomousVmClusterAcdResourceUsageResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.AutonomousContainerDatabaseResourceUsage objects
     * contained in responses from the listCloudAutonomousVmClusterAcdResourceUsage operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listCloudAutonomousVmClusterAcdResourceUsageRecordIterator(request: requests.ListCloudAutonomousVmClusterAcdResourceUsageRequest): AsyncIterableIterator<model.AutonomousContainerDatabaseResourceUsage>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listCloudAutonomousVmClusterAcdResourceUsage operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listCloudAutonomousVmClusterAcdResourceUsageResponseIterator(request: requests.ListCloudAutonomousVmClusterAcdResourceUsageRequest): AsyncIterableIterator<responses.ListCloudAutonomousVmClusterAcdResourceUsageResponse>;
    /**
     * Lists Autonomous Exadata VM clusters in the Oracle cloud. For Exadata Cloud@Customer systems, see {@link #listAutonomousVmClusters(ListAutonomousVmClustersRequest) listAutonomousVmClusters}.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListCloudAutonomousVmClustersRequest
     * @return ListCloudAutonomousVmClustersResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ListCloudAutonomousVmClusters.ts.html |here} to see how to use ListCloudAutonomousVmClusters API.
     */
    listCloudAutonomousVmClusters(listCloudAutonomousVmClustersRequest: requests.ListCloudAutonomousVmClustersRequest): Promise<responses.ListCloudAutonomousVmClustersResponse>;
    /**
     * NOTE: This function is deprecated in favor of listCloudAutonomousVmClustersRecordIterator function.
     * Creates a new async iterator which will iterate over the models.CloudAutonomousVmClusterSummary objects
     * contained in responses from the listCloudAutonomousVmClusters operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllCloudAutonomousVmClusters(request: requests.ListCloudAutonomousVmClustersRequest): AsyncIterableIterator<model.CloudAutonomousVmClusterSummary>;
    /**
     * NOTE: This function is deprecated in favor of listCloudAutonomousVmClustersResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listCloudAutonomousVmClusters operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllCloudAutonomousVmClustersResponses(request: requests.ListCloudAutonomousVmClustersRequest): AsyncIterableIterator<responses.ListCloudAutonomousVmClustersResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.CloudAutonomousVmClusterSummary objects
     * contained in responses from the listCloudAutonomousVmClusters operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listCloudAutonomousVmClustersRecordIterator(request: requests.ListCloudAutonomousVmClustersRequest): AsyncIterableIterator<model.CloudAutonomousVmClusterSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listCloudAutonomousVmClusters operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listCloudAutonomousVmClustersResponseIterator(request: requests.ListCloudAutonomousVmClustersRequest): AsyncIterableIterator<responses.ListCloudAutonomousVmClustersResponse>;
    /**
     * Gets a list of the cloud Exadata infrastructure resources in the specified compartment. Applies to Exadata Cloud Service instances and Autonomous Database on dedicated Exadata infrastructure only.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListCloudExadataInfrastructuresRequest
     * @return ListCloudExadataInfrastructuresResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ListCloudExadataInfrastructures.ts.html |here} to see how to use ListCloudExadataInfrastructures API.
     */
    listCloudExadataInfrastructures(listCloudExadataInfrastructuresRequest: requests.ListCloudExadataInfrastructuresRequest): Promise<responses.ListCloudExadataInfrastructuresResponse>;
    /**
     * NOTE: This function is deprecated in favor of listCloudExadataInfrastructuresRecordIterator function.
     * Creates a new async iterator which will iterate over the models.CloudExadataInfrastructureSummary objects
     * contained in responses from the listCloudExadataInfrastructures operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllCloudExadataInfrastructures(request: requests.ListCloudExadataInfrastructuresRequest): AsyncIterableIterator<model.CloudExadataInfrastructureSummary>;
    /**
     * NOTE: This function is deprecated in favor of listCloudExadataInfrastructuresResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listCloudExadataInfrastructures operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllCloudExadataInfrastructuresResponses(request: requests.ListCloudExadataInfrastructuresRequest): AsyncIterableIterator<responses.ListCloudExadataInfrastructuresResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.CloudExadataInfrastructureSummary objects
     * contained in responses from the listCloudExadataInfrastructures operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listCloudExadataInfrastructuresRecordIterator(request: requests.ListCloudExadataInfrastructuresRequest): AsyncIterableIterator<model.CloudExadataInfrastructureSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listCloudExadataInfrastructures operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listCloudExadataInfrastructuresResponseIterator(request: requests.ListCloudExadataInfrastructuresRequest): AsyncIterableIterator<responses.ListCloudExadataInfrastructuresResponse>;
    /**
     * Gets the history of the maintenance update actions performed on the specified cloud VM cluster. Applies to Exadata Cloud Service instances only.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListCloudVmClusterUpdateHistoryEntriesRequest
     * @return ListCloudVmClusterUpdateHistoryEntriesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ListCloudVmClusterUpdateHistoryEntries.ts.html |here} to see how to use ListCloudVmClusterUpdateHistoryEntries API.
     */
    listCloudVmClusterUpdateHistoryEntries(listCloudVmClusterUpdateHistoryEntriesRequest: requests.ListCloudVmClusterUpdateHistoryEntriesRequest): Promise<responses.ListCloudVmClusterUpdateHistoryEntriesResponse>;
    /**
     * NOTE: This function is deprecated in favor of listCloudVmClusterUpdateHistoryEntriesRecordIterator function.
     * Creates a new async iterator which will iterate over the models.UpdateHistoryEntrySummary objects
     * contained in responses from the listCloudVmClusterUpdateHistoryEntries operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllCloudVmClusterUpdateHistoryEntries(request: requests.ListCloudVmClusterUpdateHistoryEntriesRequest): AsyncIterableIterator<model.UpdateHistoryEntrySummary>;
    /**
     * NOTE: This function is deprecated in favor of listCloudVmClusterUpdateHistoryEntriesResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listCloudVmClusterUpdateHistoryEntries operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllCloudVmClusterUpdateHistoryEntriesResponses(request: requests.ListCloudVmClusterUpdateHistoryEntriesRequest): AsyncIterableIterator<responses.ListCloudVmClusterUpdateHistoryEntriesResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.UpdateHistoryEntrySummary objects
     * contained in responses from the listCloudVmClusterUpdateHistoryEntries operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listCloudVmClusterUpdateHistoryEntriesRecordIterator(request: requests.ListCloudVmClusterUpdateHistoryEntriesRequest): AsyncIterableIterator<model.UpdateHistoryEntrySummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listCloudVmClusterUpdateHistoryEntries operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listCloudVmClusterUpdateHistoryEntriesResponseIterator(request: requests.ListCloudVmClusterUpdateHistoryEntriesRequest): AsyncIterableIterator<responses.ListCloudVmClusterUpdateHistoryEntriesResponse>;
    /**
     * Lists the maintenance updates that can be applied to the specified cloud VM cluster. Applies to Exadata Cloud Service instances only.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListCloudVmClusterUpdatesRequest
     * @return ListCloudVmClusterUpdatesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ListCloudVmClusterUpdates.ts.html |here} to see how to use ListCloudVmClusterUpdates API.
     */
    listCloudVmClusterUpdates(listCloudVmClusterUpdatesRequest: requests.ListCloudVmClusterUpdatesRequest): Promise<responses.ListCloudVmClusterUpdatesResponse>;
    /**
     * NOTE: This function is deprecated in favor of listCloudVmClusterUpdatesRecordIterator function.
     * Creates a new async iterator which will iterate over the models.UpdateSummary objects
     * contained in responses from the listCloudVmClusterUpdates operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllCloudVmClusterUpdates(request: requests.ListCloudVmClusterUpdatesRequest): AsyncIterableIterator<model.UpdateSummary>;
    /**
     * NOTE: This function is deprecated in favor of listCloudVmClusterUpdatesResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listCloudVmClusterUpdates operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllCloudVmClusterUpdatesResponses(request: requests.ListCloudVmClusterUpdatesRequest): AsyncIterableIterator<responses.ListCloudVmClusterUpdatesResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.UpdateSummary objects
     * contained in responses from the listCloudVmClusterUpdates operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listCloudVmClusterUpdatesRecordIterator(request: requests.ListCloudVmClusterUpdatesRequest): AsyncIterableIterator<model.UpdateSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listCloudVmClusterUpdates operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listCloudVmClusterUpdatesResponseIterator(request: requests.ListCloudVmClusterUpdatesRequest): AsyncIterableIterator<responses.ListCloudVmClusterUpdatesResponse>;
    /**
     * Gets a list of the cloud VM clusters in the specified compartment. Applies to Exadata Cloud Service instances and Autonomous Database on dedicated Exadata infrastructure only.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListCloudVmClustersRequest
     * @return ListCloudVmClustersResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ListCloudVmClusters.ts.html |here} to see how to use ListCloudVmClusters API.
     */
    listCloudVmClusters(listCloudVmClustersRequest: requests.ListCloudVmClustersRequest): Promise<responses.ListCloudVmClustersResponse>;
    /**
     * NOTE: This function is deprecated in favor of listCloudVmClustersRecordIterator function.
     * Creates a new async iterator which will iterate over the models.CloudVmClusterSummary objects
     * contained in responses from the listCloudVmClusters operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllCloudVmClusters(request: requests.ListCloudVmClustersRequest): AsyncIterableIterator<model.CloudVmClusterSummary>;
    /**
     * NOTE: This function is deprecated in favor of listCloudVmClustersResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listCloudVmClusters operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllCloudVmClustersResponses(request: requests.ListCloudVmClustersRequest): AsyncIterableIterator<responses.ListCloudVmClustersResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.CloudVmClusterSummary objects
     * contained in responses from the listCloudVmClusters operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listCloudVmClustersRecordIterator(request: requests.ListCloudVmClustersRequest): AsyncIterableIterator<model.CloudVmClusterSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listCloudVmClusters operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listCloudVmClustersResponseIterator(request: requests.ListCloudVmClustersRequest): AsyncIterableIterator<responses.ListCloudVmClustersResponse>;
    /**
     * Lists the console connections for the specified database node.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListConsoleConnectionsRequest
     * @return ListConsoleConnectionsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ListConsoleConnections.ts.html |here} to see how to use ListConsoleConnections API.
     */
    listConsoleConnections(listConsoleConnectionsRequest: requests.ListConsoleConnectionsRequest): Promise<responses.ListConsoleConnectionsResponse>;
    /**
     * Lists the console histories for the specified database node.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListConsoleHistoriesRequest
     * @return ListConsoleHistoriesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ListConsoleHistories.ts.html |here} to see how to use ListConsoleHistories API.
     */
    listConsoleHistories(listConsoleHistoriesRequest: requests.ListConsoleHistoriesRequest): Promise<responses.ListConsoleHistoriesResponse>;
    /**
     * Lists the patches applicable to the requested container database.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListContainerDatabasePatchesRequest
     * @return ListContainerDatabasePatchesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ListContainerDatabasePatches.ts.html |here} to see how to use ListContainerDatabasePatches API.
     */
    listContainerDatabasePatches(listContainerDatabasePatchesRequest: requests.ListContainerDatabasePatchesRequest): Promise<responses.ListContainerDatabasePatchesResponse>;
    /**
     * NOTE: This function is deprecated in favor of listContainerDatabasePatchesRecordIterator function.
     * Creates a new async iterator which will iterate over the models.AutonomousPatchSummary objects
     * contained in responses from the listContainerDatabasePatches operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllContainerDatabasePatches(request: requests.ListContainerDatabasePatchesRequest): AsyncIterableIterator<model.AutonomousPatchSummary>;
    /**
     * NOTE: This function is deprecated in favor of listContainerDatabasePatchesResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listContainerDatabasePatches operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllContainerDatabasePatchesResponses(request: requests.ListContainerDatabasePatchesRequest): AsyncIterableIterator<responses.ListContainerDatabasePatchesResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.AutonomousPatchSummary objects
     * contained in responses from the listContainerDatabasePatches operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listContainerDatabasePatchesRecordIterator(request: requests.ListContainerDatabasePatchesRequest): AsyncIterableIterator<model.AutonomousPatchSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listContainerDatabasePatches operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listContainerDatabasePatchesResponseIterator(request: requests.ListContainerDatabasePatchesRequest): AsyncIterableIterator<responses.ListContainerDatabasePatchesResponse>;
    /**
     * Lists all Data Guard associations for the specified database.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListDataGuardAssociationsRequest
     * @return ListDataGuardAssociationsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ListDataGuardAssociations.ts.html |here} to see how to use ListDataGuardAssociations API.
     */
    listDataGuardAssociations(listDataGuardAssociationsRequest: requests.ListDataGuardAssociationsRequest): Promise<responses.ListDataGuardAssociationsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listDataGuardAssociationsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.DataGuardAssociationSummary objects
     * contained in responses from the listDataGuardAssociations operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllDataGuardAssociations(request: requests.ListDataGuardAssociationsRequest): AsyncIterableIterator<model.DataGuardAssociationSummary>;
    /**
     * NOTE: This function is deprecated in favor of listDataGuardAssociationsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listDataGuardAssociations operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllDataGuardAssociationsResponses(request: requests.ListDataGuardAssociationsRequest): AsyncIterableIterator<responses.ListDataGuardAssociationsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.DataGuardAssociationSummary objects
     * contained in responses from the listDataGuardAssociations operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listDataGuardAssociationsRecordIterator(request: requests.ListDataGuardAssociationsRequest): AsyncIterableIterator<model.DataGuardAssociationSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listDataGuardAssociations operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listDataGuardAssociationsResponseIterator(request: requests.ListDataGuardAssociationsRequest): AsyncIterableIterator<responses.ListDataGuardAssociationsResponse>;
    /**
     * Gets a list of the database software images in the specified compartment.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListDatabaseSoftwareImagesRequest
     * @return ListDatabaseSoftwareImagesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ListDatabaseSoftwareImages.ts.html |here} to see how to use ListDatabaseSoftwareImages API.
     */
    listDatabaseSoftwareImages(listDatabaseSoftwareImagesRequest: requests.ListDatabaseSoftwareImagesRequest): Promise<responses.ListDatabaseSoftwareImagesResponse>;
    /**
     * NOTE: This function is deprecated in favor of listDatabaseSoftwareImagesRecordIterator function.
     * Creates a new async iterator which will iterate over the models.DatabaseSoftwareImageSummary objects
     * contained in responses from the listDatabaseSoftwareImages operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllDatabaseSoftwareImages(request: requests.ListDatabaseSoftwareImagesRequest): AsyncIterableIterator<model.DatabaseSoftwareImageSummary>;
    /**
     * NOTE: This function is deprecated in favor of listDatabaseSoftwareImagesResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listDatabaseSoftwareImages operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllDatabaseSoftwareImagesResponses(request: requests.ListDatabaseSoftwareImagesRequest): AsyncIterableIterator<responses.ListDatabaseSoftwareImagesResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.DatabaseSoftwareImageSummary objects
     * contained in responses from the listDatabaseSoftwareImages operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listDatabaseSoftwareImagesRecordIterator(request: requests.ListDatabaseSoftwareImagesRequest): AsyncIterableIterator<model.DatabaseSoftwareImageSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listDatabaseSoftwareImages operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listDatabaseSoftwareImagesResponseIterator(request: requests.ListDatabaseSoftwareImagesRequest): AsyncIterableIterator<responses.ListDatabaseSoftwareImagesResponse>;
    /**
     * Gets the upgrade history for a specified database in a bare metal or virtual machine DB system.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListDatabaseUpgradeHistoryEntriesRequest
     * @return ListDatabaseUpgradeHistoryEntriesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ListDatabaseUpgradeHistoryEntries.ts.html |here} to see how to use ListDatabaseUpgradeHistoryEntries API.
     */
    listDatabaseUpgradeHistoryEntries(listDatabaseUpgradeHistoryEntriesRequest: requests.ListDatabaseUpgradeHistoryEntriesRequest): Promise<responses.ListDatabaseUpgradeHistoryEntriesResponse>;
    /**
     * NOTE: This function is deprecated in favor of listDatabaseUpgradeHistoryEntriesRecordIterator function.
     * Creates a new async iterator which will iterate over the models.DatabaseUpgradeHistoryEntrySummary objects
     * contained in responses from the listDatabaseUpgradeHistoryEntries operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllDatabaseUpgradeHistoryEntries(request: requests.ListDatabaseUpgradeHistoryEntriesRequest): AsyncIterableIterator<model.DatabaseUpgradeHistoryEntrySummary>;
    /**
     * NOTE: This function is deprecated in favor of listDatabaseUpgradeHistoryEntriesResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listDatabaseUpgradeHistoryEntries operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllDatabaseUpgradeHistoryEntriesResponses(request: requests.ListDatabaseUpgradeHistoryEntriesRequest): AsyncIterableIterator<responses.ListDatabaseUpgradeHistoryEntriesResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.DatabaseUpgradeHistoryEntrySummary objects
     * contained in responses from the listDatabaseUpgradeHistoryEntries operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listDatabaseUpgradeHistoryEntriesRecordIterator(request: requests.ListDatabaseUpgradeHistoryEntriesRequest): AsyncIterableIterator<model.DatabaseUpgradeHistoryEntrySummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listDatabaseUpgradeHistoryEntries operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listDatabaseUpgradeHistoryEntriesResponseIterator(request: requests.ListDatabaseUpgradeHistoryEntriesRequest): AsyncIterableIterator<responses.ListDatabaseUpgradeHistoryEntriesResponse>;
    /**
     * Gets a list of the databases in the specified Database Home.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListDatabasesRequest
     * @return ListDatabasesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ListDatabases.ts.html |here} to see how to use ListDatabases API.
     */
    listDatabases(listDatabasesRequest: requests.ListDatabasesRequest): Promise<responses.ListDatabasesResponse>;
    /**
     * NOTE: This function is deprecated in favor of listDatabasesRecordIterator function.
     * Creates a new async iterator which will iterate over the models.DatabaseSummary objects
     * contained in responses from the listDatabases operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllDatabases(request: requests.ListDatabasesRequest): AsyncIterableIterator<model.DatabaseSummary>;
    /**
     * NOTE: This function is deprecated in favor of listDatabasesResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listDatabases operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllDatabasesResponses(request: requests.ListDatabasesRequest): AsyncIterableIterator<responses.ListDatabasesResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.DatabaseSummary objects
     * contained in responses from the listDatabases operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listDatabasesRecordIterator(request: requests.ListDatabasesRequest): AsyncIterableIterator<model.DatabaseSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listDatabases operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listDatabasesResponseIterator(request: requests.ListDatabasesRequest): AsyncIterableIterator<responses.ListDatabasesResponse>;
    /**
     * Lists the history of patch operations on the specified Database Home.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListDbHomePatchHistoryEntriesRequest
     * @return ListDbHomePatchHistoryEntriesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ListDbHomePatchHistoryEntries.ts.html |here} to see how to use ListDbHomePatchHistoryEntries API.
     */
    listDbHomePatchHistoryEntries(listDbHomePatchHistoryEntriesRequest: requests.ListDbHomePatchHistoryEntriesRequest): Promise<responses.ListDbHomePatchHistoryEntriesResponse>;
    /**
     * NOTE: This function is deprecated in favor of listDbHomePatchHistoryEntriesRecordIterator function.
     * Creates a new async iterator which will iterate over the models.PatchHistoryEntrySummary objects
     * contained in responses from the listDbHomePatchHistoryEntries operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllDbHomePatchHistoryEntries(request: requests.ListDbHomePatchHistoryEntriesRequest): AsyncIterableIterator<model.PatchHistoryEntrySummary>;
    /**
     * NOTE: This function is deprecated in favor of listDbHomePatchHistoryEntriesResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listDbHomePatchHistoryEntries operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllDbHomePatchHistoryEntriesResponses(request: requests.ListDbHomePatchHistoryEntriesRequest): AsyncIterableIterator<responses.ListDbHomePatchHistoryEntriesResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.PatchHistoryEntrySummary objects
     * contained in responses from the listDbHomePatchHistoryEntries operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listDbHomePatchHistoryEntriesRecordIterator(request: requests.ListDbHomePatchHistoryEntriesRequest): AsyncIterableIterator<model.PatchHistoryEntrySummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listDbHomePatchHistoryEntries operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listDbHomePatchHistoryEntriesResponseIterator(request: requests.ListDbHomePatchHistoryEntriesRequest): AsyncIterableIterator<responses.ListDbHomePatchHistoryEntriesResponse>;
    /**
     * Lists patches applicable to the requested Database Home.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListDbHomePatchesRequest
     * @return ListDbHomePatchesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ListDbHomePatches.ts.html |here} to see how to use ListDbHomePatches API.
     */
    listDbHomePatches(listDbHomePatchesRequest: requests.ListDbHomePatchesRequest): Promise<responses.ListDbHomePatchesResponse>;
    /**
     * NOTE: This function is deprecated in favor of listDbHomePatchesRecordIterator function.
     * Creates a new async iterator which will iterate over the models.PatchSummary objects
     * contained in responses from the listDbHomePatches operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllDbHomePatches(request: requests.ListDbHomePatchesRequest): AsyncIterableIterator<model.PatchSummary>;
    /**
     * NOTE: This function is deprecated in favor of listDbHomePatchesResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listDbHomePatches operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllDbHomePatchesResponses(request: requests.ListDbHomePatchesRequest): AsyncIterableIterator<responses.ListDbHomePatchesResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.PatchSummary objects
     * contained in responses from the listDbHomePatches operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listDbHomePatchesRecordIterator(request: requests.ListDbHomePatchesRequest): AsyncIterableIterator<model.PatchSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listDbHomePatches operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listDbHomePatchesResponseIterator(request: requests.ListDbHomePatchesRequest): AsyncIterableIterator<responses.ListDbHomePatchesResponse>;
    /**
     * Lists the Database Homes in the specified DB system and compartment. A Database Home is a directory where Oracle Database software is installed.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListDbHomesRequest
     * @return ListDbHomesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ListDbHomes.ts.html |here} to see how to use ListDbHomes API.
     */
    listDbHomes(listDbHomesRequest: requests.ListDbHomesRequest): Promise<responses.ListDbHomesResponse>;
    /**
     * NOTE: This function is deprecated in favor of listDbHomesRecordIterator function.
     * Creates a new async iterator which will iterate over the models.DbHomeSummary objects
     * contained in responses from the listDbHomes operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllDbHomes(request: requests.ListDbHomesRequest): AsyncIterableIterator<model.DbHomeSummary>;
    /**
     * NOTE: This function is deprecated in favor of listDbHomesResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listDbHomes operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllDbHomesResponses(request: requests.ListDbHomesRequest): AsyncIterableIterator<responses.ListDbHomesResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.DbHomeSummary objects
     * contained in responses from the listDbHomes operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listDbHomesRecordIterator(request: requests.ListDbHomesRequest): AsyncIterableIterator<model.DbHomeSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listDbHomes operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listDbHomesResponseIterator(request: requests.ListDbHomesRequest): AsyncIterableIterator<responses.ListDbHomesResponse>;
    /**
     * Lists the database nodes in the specified DB system and compartment. A database node is a server running database software.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListDbNodesRequest
     * @return ListDbNodesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ListDbNodes.ts.html |here} to see how to use ListDbNodes API.
     */
    listDbNodes(listDbNodesRequest: requests.ListDbNodesRequest): Promise<responses.ListDbNodesResponse>;
    /**
     * NOTE: This function is deprecated in favor of listDbNodesRecordIterator function.
     * Creates a new async iterator which will iterate over the models.DbNodeSummary objects
     * contained in responses from the listDbNodes operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllDbNodes(request: requests.ListDbNodesRequest): AsyncIterableIterator<model.DbNodeSummary>;
    /**
     * NOTE: This function is deprecated in favor of listDbNodesResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listDbNodes operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllDbNodesResponses(request: requests.ListDbNodesRequest): AsyncIterableIterator<responses.ListDbNodesResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.DbNodeSummary objects
     * contained in responses from the listDbNodes operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listDbNodesRecordIterator(request: requests.ListDbNodesRequest): AsyncIterableIterator<model.DbNodeSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listDbNodes operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listDbNodesResponseIterator(request: requests.ListDbNodesRequest): AsyncIterableIterator<responses.ListDbNodesResponse>;
    /**
     * Lists the Exadata DB servers in the ExadataInfrastructureId and specified compartment.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListDbServersRequest
     * @return ListDbServersResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ListDbServers.ts.html |here} to see how to use ListDbServers API.
     */
    listDbServers(listDbServersRequest: requests.ListDbServersRequest): Promise<responses.ListDbServersResponse>;
    /**
     * NOTE: This function is deprecated in favor of listDbServersRecordIterator function.
     * Creates a new async iterator which will iterate over the models.DbServerSummary objects
     * contained in responses from the listDbServers operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllDbServers(request: requests.ListDbServersRequest): AsyncIterableIterator<model.DbServerSummary>;
    /**
     * NOTE: This function is deprecated in favor of listDbServersResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listDbServers operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllDbServersResponses(request: requests.ListDbServersRequest): AsyncIterableIterator<responses.ListDbServersResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.DbServerSummary objects
     * contained in responses from the listDbServers operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listDbServersRecordIterator(request: requests.ListDbServersRequest): AsyncIterableIterator<model.DbServerSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listDbServers operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listDbServersResponseIterator(request: requests.ListDbServersRequest): AsyncIterableIterator<responses.ListDbServersResponse>;
    /**
     * Gets a list of expected compute performance parameters for a virtual machine DB system based on system configuration.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListDbSystemComputePerformancesRequest
     * @return ListDbSystemComputePerformancesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ListDbSystemComputePerformances.ts.html |here} to see how to use ListDbSystemComputePerformances API.
     */
    listDbSystemComputePerformances(listDbSystemComputePerformancesRequest: requests.ListDbSystemComputePerformancesRequest): Promise<responses.ListDbSystemComputePerformancesResponse>;
    /**
     * Gets the history of the patch actions performed on the specified DB system.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListDbSystemPatchHistoryEntriesRequest
     * @return ListDbSystemPatchHistoryEntriesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ListDbSystemPatchHistoryEntries.ts.html |here} to see how to use ListDbSystemPatchHistoryEntries API.
     */
    listDbSystemPatchHistoryEntries(listDbSystemPatchHistoryEntriesRequest: requests.ListDbSystemPatchHistoryEntriesRequest): Promise<responses.ListDbSystemPatchHistoryEntriesResponse>;
    /**
     * NOTE: This function is deprecated in favor of listDbSystemPatchHistoryEntriesRecordIterator function.
     * Creates a new async iterator which will iterate over the models.PatchHistoryEntrySummary objects
     * contained in responses from the listDbSystemPatchHistoryEntries operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllDbSystemPatchHistoryEntries(request: requests.ListDbSystemPatchHistoryEntriesRequest): AsyncIterableIterator<model.PatchHistoryEntrySummary>;
    /**
     * NOTE: This function is deprecated in favor of listDbSystemPatchHistoryEntriesResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listDbSystemPatchHistoryEntries operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllDbSystemPatchHistoryEntriesResponses(request: requests.ListDbSystemPatchHistoryEntriesRequest): AsyncIterableIterator<responses.ListDbSystemPatchHistoryEntriesResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.PatchHistoryEntrySummary objects
     * contained in responses from the listDbSystemPatchHistoryEntries operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listDbSystemPatchHistoryEntriesRecordIterator(request: requests.ListDbSystemPatchHistoryEntriesRequest): AsyncIterableIterator<model.PatchHistoryEntrySummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listDbSystemPatchHistoryEntries operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listDbSystemPatchHistoryEntriesResponseIterator(request: requests.ListDbSystemPatchHistoryEntriesRequest): AsyncIterableIterator<responses.ListDbSystemPatchHistoryEntriesResponse>;
    /**
     * Lists the patches applicable to the specified DB system.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListDbSystemPatchesRequest
     * @return ListDbSystemPatchesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ListDbSystemPatches.ts.html |here} to see how to use ListDbSystemPatches API.
     */
    listDbSystemPatches(listDbSystemPatchesRequest: requests.ListDbSystemPatchesRequest): Promise<responses.ListDbSystemPatchesResponse>;
    /**
     * NOTE: This function is deprecated in favor of listDbSystemPatchesRecordIterator function.
     * Creates a new async iterator which will iterate over the models.PatchSummary objects
     * contained in responses from the listDbSystemPatches operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllDbSystemPatches(request: requests.ListDbSystemPatchesRequest): AsyncIterableIterator<model.PatchSummary>;
    /**
     * NOTE: This function is deprecated in favor of listDbSystemPatchesResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listDbSystemPatches operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllDbSystemPatchesResponses(request: requests.ListDbSystemPatchesRequest): AsyncIterableIterator<responses.ListDbSystemPatchesResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.PatchSummary objects
     * contained in responses from the listDbSystemPatches operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listDbSystemPatchesRecordIterator(request: requests.ListDbSystemPatchesRequest): AsyncIterableIterator<model.PatchSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listDbSystemPatches operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listDbSystemPatchesResponseIterator(request: requests.ListDbSystemPatchesRequest): AsyncIterableIterator<responses.ListDbSystemPatchesResponse>;
    /**
     * Gets a list of the shapes that can be used to launch a new DB system. The shape determines resources to allocate to the DB system - CPU cores and memory for VM shapes; CPU cores, memory and storage for non-VM (or bare metal) shapes.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListDbSystemShapesRequest
     * @return ListDbSystemShapesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ListDbSystemShapes.ts.html |here} to see how to use ListDbSystemShapes API.
     */
    listDbSystemShapes(listDbSystemShapesRequest: requests.ListDbSystemShapesRequest): Promise<responses.ListDbSystemShapesResponse>;
    /**
     * NOTE: This function is deprecated in favor of listDbSystemShapesRecordIterator function.
     * Creates a new async iterator which will iterate over the models.DbSystemShapeSummary objects
     * contained in responses from the listDbSystemShapes operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllDbSystemShapes(request: requests.ListDbSystemShapesRequest): AsyncIterableIterator<model.DbSystemShapeSummary>;
    /**
     * NOTE: This function is deprecated in favor of listDbSystemShapesResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listDbSystemShapes operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllDbSystemShapesResponses(request: requests.ListDbSystemShapesRequest): AsyncIterableIterator<responses.ListDbSystemShapesResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.DbSystemShapeSummary objects
     * contained in responses from the listDbSystemShapes operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listDbSystemShapesRecordIterator(request: requests.ListDbSystemShapesRequest): AsyncIterableIterator<model.DbSystemShapeSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listDbSystemShapes operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listDbSystemShapesResponseIterator(request: requests.ListDbSystemShapesRequest): AsyncIterableIterator<responses.ListDbSystemShapesResponse>;
    /**
     * Gets a list of possible expected storage performance parameters of a VMDB System based on Configuration.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListDbSystemStoragePerformancesRequest
     * @return ListDbSystemStoragePerformancesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ListDbSystemStoragePerformances.ts.html |here} to see how to use ListDbSystemStoragePerformances API.
     */
    listDbSystemStoragePerformances(listDbSystemStoragePerformancesRequest: requests.ListDbSystemStoragePerformancesRequest): Promise<responses.ListDbSystemStoragePerformancesResponse>;
    /**
     * Gets the history of the upgrade actions performed on the specified DB system.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListDbSystemUpgradeHistoryEntriesRequest
     * @return ListDbSystemUpgradeHistoryEntriesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ListDbSystemUpgradeHistoryEntries.ts.html |here} to see how to use ListDbSystemUpgradeHistoryEntries API.
     */
    listDbSystemUpgradeHistoryEntries(listDbSystemUpgradeHistoryEntriesRequest: requests.ListDbSystemUpgradeHistoryEntriesRequest): Promise<responses.ListDbSystemUpgradeHistoryEntriesResponse>;
    /**
     * NOTE: This function is deprecated in favor of listDbSystemUpgradeHistoryEntriesRecordIterator function.
     * Creates a new async iterator which will iterate over the models.DbSystemUpgradeHistoryEntrySummary objects
     * contained in responses from the listDbSystemUpgradeHistoryEntries operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllDbSystemUpgradeHistoryEntries(request: requests.ListDbSystemUpgradeHistoryEntriesRequest): AsyncIterableIterator<model.DbSystemUpgradeHistoryEntrySummary>;
    /**
     * NOTE: This function is deprecated in favor of listDbSystemUpgradeHistoryEntriesResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listDbSystemUpgradeHistoryEntries operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllDbSystemUpgradeHistoryEntriesResponses(request: requests.ListDbSystemUpgradeHistoryEntriesRequest): AsyncIterableIterator<responses.ListDbSystemUpgradeHistoryEntriesResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.DbSystemUpgradeHistoryEntrySummary objects
     * contained in responses from the listDbSystemUpgradeHistoryEntries operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listDbSystemUpgradeHistoryEntriesRecordIterator(request: requests.ListDbSystemUpgradeHistoryEntriesRequest): AsyncIterableIterator<model.DbSystemUpgradeHistoryEntrySummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listDbSystemUpgradeHistoryEntries operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listDbSystemUpgradeHistoryEntriesResponseIterator(request: requests.ListDbSystemUpgradeHistoryEntriesRequest): AsyncIterableIterator<responses.ListDbSystemUpgradeHistoryEntriesResponse>;
    /**
       * Lists the DB systems in the specified compartment. You can specify a `backupId` to list only the DB systems that support creating a database using this backup in this compartment.
  * <p>
  **Note:** Deprecated for Exadata Cloud Service systems. Use the [new resource model APIs](https://docs.cloud.oracle.com/iaas/Content/Database/Concepts/exaflexsystem.htm#exaflexsystem_topic-resource_model) instead.
  * <p>
  For Exadata Cloud Service instances, support for this API will end on May 15th, 2021. See [Switching an Exadata DB System to the New Resource Model and APIs](https://docs.cloud.oracle.com/iaas/Content/Database/Concepts/exaflexsystem_topic-resource_model_conversion.htm) for details on converting existing Exadata DB systems to the new resource model.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param ListDbSystemsRequest
       * @return ListDbSystemsResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ListDbSystems.ts.html |here} to see how to use ListDbSystems API.
       */
    listDbSystems(listDbSystemsRequest: requests.ListDbSystemsRequest): Promise<responses.ListDbSystemsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listDbSystemsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.DbSystemSummary objects
     * contained in responses from the listDbSystems operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllDbSystems(request: requests.ListDbSystemsRequest): AsyncIterableIterator<model.DbSystemSummary>;
    /**
     * NOTE: This function is deprecated in favor of listDbSystemsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listDbSystems operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllDbSystemsResponses(request: requests.ListDbSystemsRequest): AsyncIterableIterator<responses.ListDbSystemsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.DbSystemSummary objects
     * contained in responses from the listDbSystems operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listDbSystemsRecordIterator(request: requests.ListDbSystemsRequest): AsyncIterableIterator<model.DbSystemSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listDbSystems operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listDbSystemsResponseIterator(request: requests.ListDbSystemsRequest): AsyncIterableIterator<responses.ListDbSystemsResponse>;
    /**
     * Gets a list of supported Oracle Database versions.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListDbVersionsRequest
     * @return ListDbVersionsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ListDbVersions.ts.html |here} to see how to use ListDbVersions API.
     */
    listDbVersions(listDbVersionsRequest: requests.ListDbVersionsRequest): Promise<responses.ListDbVersionsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listDbVersionsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.DbVersionSummary objects
     * contained in responses from the listDbVersions operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllDbVersions(request: requests.ListDbVersionsRequest): AsyncIterableIterator<model.DbVersionSummary>;
    /**
     * NOTE: This function is deprecated in favor of listDbVersionsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listDbVersions operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllDbVersionsResponses(request: requests.ListDbVersionsRequest): AsyncIterableIterator<responses.ListDbVersionsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.DbVersionSummary objects
     * contained in responses from the listDbVersions operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listDbVersionsRecordIterator(request: requests.ListDbVersionsRequest): AsyncIterableIterator<model.DbVersionSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listDbVersions operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listDbVersionsResponseIterator(request: requests.ListDbVersionsRequest): AsyncIterableIterator<responses.ListDbVersionsResponse>;
    /**
     * Lists the Exadata infrastructure resources in the specified compartment. Applies to Exadata Cloud@Customer instances only.
     * To list the Exadata Cloud Service infrastructure resources in a compartment, use the  {@link #listCloudExadataInfrastructures(ListCloudExadataInfrastructuresRequest) listCloudExadataInfrastructures} operation.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListExadataInfrastructuresRequest
     * @return ListExadataInfrastructuresResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ListExadataInfrastructures.ts.html |here} to see how to use ListExadataInfrastructures API.
     */
    listExadataInfrastructures(listExadataInfrastructuresRequest: requests.ListExadataInfrastructuresRequest): Promise<responses.ListExadataInfrastructuresResponse>;
    /**
     * NOTE: This function is deprecated in favor of listExadataInfrastructuresRecordIterator function.
     * Creates a new async iterator which will iterate over the models.ExadataInfrastructureSummary objects
     * contained in responses from the listExadataInfrastructures operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllExadataInfrastructures(request: requests.ListExadataInfrastructuresRequest): AsyncIterableIterator<model.ExadataInfrastructureSummary>;
    /**
     * NOTE: This function is deprecated in favor of listExadataInfrastructuresResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listExadataInfrastructures operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllExadataInfrastructuresResponses(request: requests.ListExadataInfrastructuresRequest): AsyncIterableIterator<responses.ListExadataInfrastructuresResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.ExadataInfrastructureSummary objects
     * contained in responses from the listExadataInfrastructures operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listExadataInfrastructuresRecordIterator(request: requests.ListExadataInfrastructuresRequest): AsyncIterableIterator<model.ExadataInfrastructureSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listExadataInfrastructures operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listExadataInfrastructuresResponseIterator(request: requests.ListExadataInfrastructuresRequest): AsyncIterableIterator<responses.ListExadataInfrastructuresResponse>;
    /**
     * Gets the history of the maintenance update actions performed on the specified Exadata VM cluster on Exascale Infrastructure.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListExadbVmClusterUpdateHistoryEntriesRequest
     * @return ListExadbVmClusterUpdateHistoryEntriesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ListExadbVmClusterUpdateHistoryEntries.ts.html |here} to see how to use ListExadbVmClusterUpdateHistoryEntries API.
     */
    listExadbVmClusterUpdateHistoryEntries(listExadbVmClusterUpdateHistoryEntriesRequest: requests.ListExadbVmClusterUpdateHistoryEntriesRequest): Promise<responses.ListExadbVmClusterUpdateHistoryEntriesResponse>;
    /**
     * NOTE: This function is deprecated in favor of listExadbVmClusterUpdateHistoryEntriesRecordIterator function.
     * Creates a new async iterator which will iterate over the models.ExadbVmClusterUpdateHistoryEntrySummary objects
     * contained in responses from the listExadbVmClusterUpdateHistoryEntries operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllExadbVmClusterUpdateHistoryEntries(request: requests.ListExadbVmClusterUpdateHistoryEntriesRequest): AsyncIterableIterator<model.ExadbVmClusterUpdateHistoryEntrySummary>;
    /**
     * NOTE: This function is deprecated in favor of listExadbVmClusterUpdateHistoryEntriesResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listExadbVmClusterUpdateHistoryEntries operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllExadbVmClusterUpdateHistoryEntriesResponses(request: requests.ListExadbVmClusterUpdateHistoryEntriesRequest): AsyncIterableIterator<responses.ListExadbVmClusterUpdateHistoryEntriesResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.ExadbVmClusterUpdateHistoryEntrySummary objects
     * contained in responses from the listExadbVmClusterUpdateHistoryEntries operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listExadbVmClusterUpdateHistoryEntriesRecordIterator(request: requests.ListExadbVmClusterUpdateHistoryEntriesRequest): AsyncIterableIterator<model.ExadbVmClusterUpdateHistoryEntrySummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listExadbVmClusterUpdateHistoryEntries operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listExadbVmClusterUpdateHistoryEntriesResponseIterator(request: requests.ListExadbVmClusterUpdateHistoryEntriesRequest): AsyncIterableIterator<responses.ListExadbVmClusterUpdateHistoryEntriesResponse>;
    /**
     * Lists the maintenance updates that can be applied to the specified Exadata VM cluster on Exascale Infrastructure.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListExadbVmClusterUpdatesRequest
     * @return ListExadbVmClusterUpdatesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ListExadbVmClusterUpdates.ts.html |here} to see how to use ListExadbVmClusterUpdates API.
     */
    listExadbVmClusterUpdates(listExadbVmClusterUpdatesRequest: requests.ListExadbVmClusterUpdatesRequest): Promise<responses.ListExadbVmClusterUpdatesResponse>;
    /**
     * NOTE: This function is deprecated in favor of listExadbVmClusterUpdatesRecordIterator function.
     * Creates a new async iterator which will iterate over the models.ExadbVmClusterUpdateSummary objects
     * contained in responses from the listExadbVmClusterUpdates operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllExadbVmClusterUpdates(request: requests.ListExadbVmClusterUpdatesRequest): AsyncIterableIterator<model.ExadbVmClusterUpdateSummary>;
    /**
     * NOTE: This function is deprecated in favor of listExadbVmClusterUpdatesResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listExadbVmClusterUpdates operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllExadbVmClusterUpdatesResponses(request: requests.ListExadbVmClusterUpdatesRequest): AsyncIterableIterator<responses.ListExadbVmClusterUpdatesResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.ExadbVmClusterUpdateSummary objects
     * contained in responses from the listExadbVmClusterUpdates operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listExadbVmClusterUpdatesRecordIterator(request: requests.ListExadbVmClusterUpdatesRequest): AsyncIterableIterator<model.ExadbVmClusterUpdateSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listExadbVmClusterUpdates operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listExadbVmClusterUpdatesResponseIterator(request: requests.ListExadbVmClusterUpdatesRequest): AsyncIterableIterator<responses.ListExadbVmClusterUpdatesResponse>;
    /**
     * Gets a list of the Exadata VM clusters on Exascale Infrastructure in the specified compartment. Applies to Exadata Database Service on Exascale Infrastructure only.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListExadbVmClustersRequest
     * @return ListExadbVmClustersResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ListExadbVmClusters.ts.html |here} to see how to use ListExadbVmClusters API.
     */
    listExadbVmClusters(listExadbVmClustersRequest: requests.ListExadbVmClustersRequest): Promise<responses.ListExadbVmClustersResponse>;
    /**
     * NOTE: This function is deprecated in favor of listExadbVmClustersRecordIterator function.
     * Creates a new async iterator which will iterate over the models.ExadbVmClusterSummary objects
     * contained in responses from the listExadbVmClusters operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllExadbVmClusters(request: requests.ListExadbVmClustersRequest): AsyncIterableIterator<model.ExadbVmClusterSummary>;
    /**
     * NOTE: This function is deprecated in favor of listExadbVmClustersResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listExadbVmClusters operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllExadbVmClustersResponses(request: requests.ListExadbVmClustersRequest): AsyncIterableIterator<responses.ListExadbVmClustersResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.ExadbVmClusterSummary objects
     * contained in responses from the listExadbVmClusters operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listExadbVmClustersRecordIterator(request: requests.ListExadbVmClustersRequest): AsyncIterableIterator<model.ExadbVmClusterSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listExadbVmClusters operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listExadbVmClustersResponseIterator(request: requests.ListExadbVmClustersRequest): AsyncIterableIterator<responses.ListExadbVmClustersResponse>;
    /**
     * Gets a list of the Exadata Database Storage Vaults in the specified compartment.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListExascaleDbStorageVaultsRequest
     * @return ListExascaleDbStorageVaultsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ListExascaleDbStorageVaults.ts.html |here} to see how to use ListExascaleDbStorageVaults API.
     */
    listExascaleDbStorageVaults(listExascaleDbStorageVaultsRequest: requests.ListExascaleDbStorageVaultsRequest): Promise<responses.ListExascaleDbStorageVaultsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listExascaleDbStorageVaultsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.ExascaleDbStorageVaultSummary objects
     * contained in responses from the listExascaleDbStorageVaults operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllExascaleDbStorageVaults(request: requests.ListExascaleDbStorageVaultsRequest): AsyncIterableIterator<model.ExascaleDbStorageVaultSummary>;
    /**
     * NOTE: This function is deprecated in favor of listExascaleDbStorageVaultsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listExascaleDbStorageVaults operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllExascaleDbStorageVaultsResponses(request: requests.ListExascaleDbStorageVaultsRequest): AsyncIterableIterator<responses.ListExascaleDbStorageVaultsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.ExascaleDbStorageVaultSummary objects
     * contained in responses from the listExascaleDbStorageVaults operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listExascaleDbStorageVaultsRecordIterator(request: requests.ListExascaleDbStorageVaultsRequest): AsyncIterableIterator<model.ExascaleDbStorageVaultSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listExascaleDbStorageVaults operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listExascaleDbStorageVaultsResponseIterator(request: requests.ListExascaleDbStorageVaultsRequest): AsyncIterableIterator<responses.ListExascaleDbStorageVaultsResponse>;
    /**
     * Gets a list of the external container databases in the specified compartment.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListExternalContainerDatabasesRequest
     * @return ListExternalContainerDatabasesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ListExternalContainerDatabases.ts.html |here} to see how to use ListExternalContainerDatabases API.
     */
    listExternalContainerDatabases(listExternalContainerDatabasesRequest: requests.ListExternalContainerDatabasesRequest): Promise<responses.ListExternalContainerDatabasesResponse>;
    /**
     * NOTE: This function is deprecated in favor of listExternalContainerDatabasesRecordIterator function.
     * Creates a new async iterator which will iterate over the models.ExternalContainerDatabaseSummary objects
     * contained in responses from the listExternalContainerDatabases operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllExternalContainerDatabases(request: requests.ListExternalContainerDatabasesRequest): AsyncIterableIterator<model.ExternalContainerDatabaseSummary>;
    /**
     * NOTE: This function is deprecated in favor of listExternalContainerDatabasesResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listExternalContainerDatabases operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllExternalContainerDatabasesResponses(request: requests.ListExternalContainerDatabasesRequest): AsyncIterableIterator<responses.ListExternalContainerDatabasesResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.ExternalContainerDatabaseSummary objects
     * contained in responses from the listExternalContainerDatabases operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listExternalContainerDatabasesRecordIterator(request: requests.ListExternalContainerDatabasesRequest): AsyncIterableIterator<model.ExternalContainerDatabaseSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listExternalContainerDatabases operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listExternalContainerDatabasesResponseIterator(request: requests.ListExternalContainerDatabasesRequest): AsyncIterableIterator<responses.ListExternalContainerDatabasesResponse>;
    /**
     * Gets a list of the external database connectors in the specified compartment.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListExternalDatabaseConnectorsRequest
     * @return ListExternalDatabaseConnectorsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ListExternalDatabaseConnectors.ts.html |here} to see how to use ListExternalDatabaseConnectors API.
     */
    listExternalDatabaseConnectors(listExternalDatabaseConnectorsRequest: requests.ListExternalDatabaseConnectorsRequest): Promise<responses.ListExternalDatabaseConnectorsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listExternalDatabaseConnectorsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.ExternalDatabaseConnectorSummary objects
     * contained in responses from the listExternalDatabaseConnectors operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllExternalDatabaseConnectors(request: requests.ListExternalDatabaseConnectorsRequest): AsyncIterableIterator<model.ExternalDatabaseConnectorSummary>;
    /**
     * NOTE: This function is deprecated in favor of listExternalDatabaseConnectorsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listExternalDatabaseConnectors operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllExternalDatabaseConnectorsResponses(request: requests.ListExternalDatabaseConnectorsRequest): AsyncIterableIterator<responses.ListExternalDatabaseConnectorsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.ExternalDatabaseConnectorSummary objects
     * contained in responses from the listExternalDatabaseConnectors operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listExternalDatabaseConnectorsRecordIterator(request: requests.ListExternalDatabaseConnectorsRequest): AsyncIterableIterator<model.ExternalDatabaseConnectorSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listExternalDatabaseConnectors operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listExternalDatabaseConnectorsResponseIterator(request: requests.ListExternalDatabaseConnectorsRequest): AsyncIterableIterator<responses.ListExternalDatabaseConnectorsResponse>;
    /**
     * Gets a list of the ExternalNonContainerDatabases in the specified compartment.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListExternalNonContainerDatabasesRequest
     * @return ListExternalNonContainerDatabasesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ListExternalNonContainerDatabases.ts.html |here} to see how to use ListExternalNonContainerDatabases API.
     */
    listExternalNonContainerDatabases(listExternalNonContainerDatabasesRequest: requests.ListExternalNonContainerDatabasesRequest): Promise<responses.ListExternalNonContainerDatabasesResponse>;
    /**
     * NOTE: This function is deprecated in favor of listExternalNonContainerDatabasesRecordIterator function.
     * Creates a new async iterator which will iterate over the models.ExternalNonContainerDatabaseSummary objects
     * contained in responses from the listExternalNonContainerDatabases operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllExternalNonContainerDatabases(request: requests.ListExternalNonContainerDatabasesRequest): AsyncIterableIterator<model.ExternalNonContainerDatabaseSummary>;
    /**
     * NOTE: This function is deprecated in favor of listExternalNonContainerDatabasesResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listExternalNonContainerDatabases operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllExternalNonContainerDatabasesResponses(request: requests.ListExternalNonContainerDatabasesRequest): AsyncIterableIterator<responses.ListExternalNonContainerDatabasesResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.ExternalNonContainerDatabaseSummary objects
     * contained in responses from the listExternalNonContainerDatabases operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listExternalNonContainerDatabasesRecordIterator(request: requests.ListExternalNonContainerDatabasesRequest): AsyncIterableIterator<model.ExternalNonContainerDatabaseSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listExternalNonContainerDatabases operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listExternalNonContainerDatabasesResponseIterator(request: requests.ListExternalNonContainerDatabasesRequest): AsyncIterableIterator<responses.ListExternalNonContainerDatabasesResponse>;
    /**
     * Gets a list of the {@link #createExternalPluggableDatabaseDetails(CreateExternalPluggableDatabaseDetailsRequest) createExternalPluggableDatabaseDetails}
     * resources in the specified compartment.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListExternalPluggableDatabasesRequest
     * @return ListExternalPluggableDatabasesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ListExternalPluggableDatabases.ts.html |here} to see how to use ListExternalPluggableDatabases API.
     */
    listExternalPluggableDatabases(listExternalPluggableDatabasesRequest: requests.ListExternalPluggableDatabasesRequest): Promise<responses.ListExternalPluggableDatabasesResponse>;
    /**
     * NOTE: This function is deprecated in favor of listExternalPluggableDatabasesRecordIterator function.
     * Creates a new async iterator which will iterate over the models.ExternalPluggableDatabaseSummary objects
     * contained in responses from the listExternalPluggableDatabases operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllExternalPluggableDatabases(request: requests.ListExternalPluggableDatabasesRequest): AsyncIterableIterator<model.ExternalPluggableDatabaseSummary>;
    /**
     * NOTE: This function is deprecated in favor of listExternalPluggableDatabasesResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listExternalPluggableDatabases operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllExternalPluggableDatabasesResponses(request: requests.ListExternalPluggableDatabasesRequest): AsyncIterableIterator<responses.ListExternalPluggableDatabasesResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.ExternalPluggableDatabaseSummary objects
     * contained in responses from the listExternalPluggableDatabases operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listExternalPluggableDatabasesRecordIterator(request: requests.ListExternalPluggableDatabasesRequest): AsyncIterableIterator<model.ExternalPluggableDatabaseSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listExternalPluggableDatabases operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listExternalPluggableDatabasesResponseIterator(request: requests.ListExternalPluggableDatabasesRequest): AsyncIterableIterator<responses.ListExternalPluggableDatabasesResponse>;
    /**
     * Gets a list of the flex components that can be used to launch a new DB system. The flex component determines resources to allocate to the DB system - Database Servers and Storage Servers.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListFlexComponentsRequest
     * @return ListFlexComponentsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ListFlexComponents.ts.html |here} to see how to use ListFlexComponents API.
     */
    listFlexComponents(listFlexComponentsRequest: requests.ListFlexComponentsRequest): Promise<responses.ListFlexComponentsResponse>;
    /**
     * Gets a list of supported Oracle Grid Infrastructure minor versions for the given major version and shape family.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListGiVersionMinorVersionsRequest
     * @return ListGiVersionMinorVersionsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ListGiVersionMinorVersions.ts.html |here} to see how to use ListGiVersionMinorVersions API.
     */
    listGiVersionMinorVersions(listGiVersionMinorVersionsRequest: requests.ListGiVersionMinorVersionsRequest): Promise<responses.ListGiVersionMinorVersionsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listGiVersionMinorVersionsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.GiMinorVersionSummary objects
     * contained in responses from the listGiVersionMinorVersions operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllGiVersionMinorVersions(request: requests.ListGiVersionMinorVersionsRequest): AsyncIterableIterator<model.GiMinorVersionSummary>;
    /**
     * NOTE: This function is deprecated in favor of listGiVersionMinorVersionsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listGiVersionMinorVersions operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllGiVersionMinorVersionsResponses(request: requests.ListGiVersionMinorVersionsRequest): AsyncIterableIterator<responses.ListGiVersionMinorVersionsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.GiMinorVersionSummary objects
     * contained in responses from the listGiVersionMinorVersions operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listGiVersionMinorVersionsRecordIterator(request: requests.ListGiVersionMinorVersionsRequest): AsyncIterableIterator<model.GiMinorVersionSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listGiVersionMinorVersions operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listGiVersionMinorVersionsResponseIterator(request: requests.ListGiVersionMinorVersionsRequest): AsyncIterableIterator<responses.ListGiVersionMinorVersionsResponse>;
    /**
     * Gets a list of supported GI versions.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListGiVersionsRequest
     * @return ListGiVersionsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ListGiVersions.ts.html |here} to see how to use ListGiVersions API.
     */
    listGiVersions(listGiVersionsRequest: requests.ListGiVersionsRequest): Promise<responses.ListGiVersionsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listGiVersionsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.GiVersionSummary objects
     * contained in responses from the listGiVersions operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllGiVersions(request: requests.ListGiVersionsRequest): AsyncIterableIterator<model.GiVersionSummary>;
    /**
     * NOTE: This function is deprecated in favor of listGiVersionsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listGiVersions operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllGiVersionsResponses(request: requests.ListGiVersionsRequest): AsyncIterableIterator<responses.ListGiVersionsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.GiVersionSummary objects
     * contained in responses from the listGiVersions operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listGiVersionsRecordIterator(request: requests.ListGiVersionsRequest): AsyncIterableIterator<model.GiVersionSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listGiVersions operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listGiVersionsResponseIterator(request: requests.ListGiVersionsRequest): AsyncIterableIterator<responses.ListGiVersionsResponse>;
    /**
     * Gets a list of key stores in the specified compartment.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListKeyStoresRequest
     * @return ListKeyStoresResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ListKeyStores.ts.html |here} to see how to use ListKeyStores API.
     */
    listKeyStores(listKeyStoresRequest: requests.ListKeyStoresRequest): Promise<responses.ListKeyStoresResponse>;
    /**
     * NOTE: This function is deprecated in favor of listKeyStoresRecordIterator function.
     * Creates a new async iterator which will iterate over the models.KeyStoreSummary objects
     * contained in responses from the listKeyStores operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllKeyStores(request: requests.ListKeyStoresRequest): AsyncIterableIterator<model.KeyStoreSummary>;
    /**
     * NOTE: This function is deprecated in favor of listKeyStoresResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listKeyStores operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllKeyStoresResponses(request: requests.ListKeyStoresRequest): AsyncIterableIterator<responses.ListKeyStoresResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.KeyStoreSummary objects
     * contained in responses from the listKeyStores operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listKeyStoresRecordIterator(request: requests.ListKeyStoresRequest): AsyncIterableIterator<model.KeyStoreSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listKeyStores operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listKeyStoresResponseIterator(request: requests.ListKeyStoresRequest): AsyncIterableIterator<responses.ListKeyStoresResponse>;
    /**
     * Gets a list of the maintenance run histories in the specified compartment.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListMaintenanceRunHistoryRequest
     * @return ListMaintenanceRunHistoryResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ListMaintenanceRunHistory.ts.html |here} to see how to use ListMaintenanceRunHistory API.
     */
    listMaintenanceRunHistory(listMaintenanceRunHistoryRequest: requests.ListMaintenanceRunHistoryRequest): Promise<responses.ListMaintenanceRunHistoryResponse>;
    /**
     * NOTE: This function is deprecated in favor of listMaintenanceRunHistoryRecordIterator function.
     * Creates a new async iterator which will iterate over the models.MaintenanceRunHistorySummary objects
     * contained in responses from the listMaintenanceRunHistory operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllMaintenanceRunHistory(request: requests.ListMaintenanceRunHistoryRequest): AsyncIterableIterator<model.MaintenanceRunHistorySummary>;
    /**
     * NOTE: This function is deprecated in favor of listMaintenanceRunHistoryResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listMaintenanceRunHistory operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllMaintenanceRunHistoryResponses(request: requests.ListMaintenanceRunHistoryRequest): AsyncIterableIterator<responses.ListMaintenanceRunHistoryResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.MaintenanceRunHistorySummary objects
     * contained in responses from the listMaintenanceRunHistory operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listMaintenanceRunHistoryRecordIterator(request: requests.ListMaintenanceRunHistoryRequest): AsyncIterableIterator<model.MaintenanceRunHistorySummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listMaintenanceRunHistory operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listMaintenanceRunHistoryResponseIterator(request: requests.ListMaintenanceRunHistoryRequest): AsyncIterableIterator<responses.ListMaintenanceRunHistoryResponse>;
    /**
     * Gets a list of the maintenance runs in the specified compartment.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListMaintenanceRunsRequest
     * @return ListMaintenanceRunsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ListMaintenanceRuns.ts.html |here} to see how to use ListMaintenanceRuns API.
     */
    listMaintenanceRuns(listMaintenanceRunsRequest: requests.ListMaintenanceRunsRequest): Promise<responses.ListMaintenanceRunsResponse>;
    /**
     * NOTE: This function is deprecated in favor of listMaintenanceRunsRecordIterator function.
     * Creates a new async iterator which will iterate over the models.MaintenanceRunSummary objects
     * contained in responses from the listMaintenanceRuns operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllMaintenanceRuns(request: requests.ListMaintenanceRunsRequest): AsyncIterableIterator<model.MaintenanceRunSummary>;
    /**
     * NOTE: This function is deprecated in favor of listMaintenanceRunsResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listMaintenanceRuns operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllMaintenanceRunsResponses(request: requests.ListMaintenanceRunsRequest): AsyncIterableIterator<responses.ListMaintenanceRunsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.MaintenanceRunSummary objects
     * contained in responses from the listMaintenanceRuns operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listMaintenanceRunsRecordIterator(request: requests.ListMaintenanceRunsRequest): AsyncIterableIterator<model.MaintenanceRunSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listMaintenanceRuns operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listMaintenanceRunsResponseIterator(request: requests.ListMaintenanceRunsRequest): AsyncIterableIterator<responses.ListMaintenanceRunsResponse>;
    /**
     * Lists one-off patches in the specified compartment.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListOneoffPatchesRequest
     * @return ListOneoffPatchesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ListOneoffPatches.ts.html |here} to see how to use ListOneoffPatches API.
     */
    listOneoffPatches(listOneoffPatchesRequest: requests.ListOneoffPatchesRequest): Promise<responses.ListOneoffPatchesResponse>;
    /**
     * NOTE: This function is deprecated in favor of listOneoffPatchesRecordIterator function.
     * Creates a new async iterator which will iterate over the models.OneoffPatchSummary objects
     * contained in responses from the listOneoffPatches operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllOneoffPatches(request: requests.ListOneoffPatchesRequest): AsyncIterableIterator<model.OneoffPatchSummary>;
    /**
     * NOTE: This function is deprecated in favor of listOneoffPatchesResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listOneoffPatches operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllOneoffPatchesResponses(request: requests.ListOneoffPatchesRequest): AsyncIterableIterator<responses.ListOneoffPatchesResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.OneoffPatchSummary objects
     * contained in responses from the listOneoffPatches operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listOneoffPatchesRecordIterator(request: requests.ListOneoffPatchesRequest): AsyncIterableIterator<model.OneoffPatchSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listOneoffPatches operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listOneoffPatchesResponseIterator(request: requests.ListOneoffPatchesRequest): AsyncIterableIterator<responses.ListOneoffPatchesResponse>;
    /**
     * Gets the pluggable database conversion history for a specified database in a bare metal or virtual machine DB system.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListPdbConversionHistoryEntriesRequest
     * @return ListPdbConversionHistoryEntriesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ListPdbConversionHistoryEntries.ts.html |here} to see how to use ListPdbConversionHistoryEntries API.
     */
    listPdbConversionHistoryEntries(listPdbConversionHistoryEntriesRequest: requests.ListPdbConversionHistoryEntriesRequest): Promise<responses.ListPdbConversionHistoryEntriesResponse>;
    /**
     * NOTE: This function is deprecated in favor of listPdbConversionHistoryEntriesRecordIterator function.
     * Creates a new async iterator which will iterate over the models.PdbConversionHistoryEntrySummary objects
     * contained in responses from the listPdbConversionHistoryEntries operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllPdbConversionHistoryEntries(request: requests.ListPdbConversionHistoryEntriesRequest): AsyncIterableIterator<model.PdbConversionHistoryEntrySummary>;
    /**
     * NOTE: This function is deprecated in favor of listPdbConversionHistoryEntriesResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listPdbConversionHistoryEntries operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllPdbConversionHistoryEntriesResponses(request: requests.ListPdbConversionHistoryEntriesRequest): AsyncIterableIterator<responses.ListPdbConversionHistoryEntriesResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.PdbConversionHistoryEntrySummary objects
     * contained in responses from the listPdbConversionHistoryEntries operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listPdbConversionHistoryEntriesRecordIterator(request: requests.ListPdbConversionHistoryEntriesRequest): AsyncIterableIterator<model.PdbConversionHistoryEntrySummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listPdbConversionHistoryEntries operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listPdbConversionHistoryEntriesResponseIterator(request: requests.ListPdbConversionHistoryEntriesRequest): AsyncIterableIterator<responses.ListPdbConversionHistoryEntriesResponse>;
    /**
     * Gets a list of the pluggable databases in a database or compartment. You must provide either a `databaseId` or `compartmentId` value.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListPluggableDatabasesRequest
     * @return ListPluggableDatabasesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ListPluggableDatabases.ts.html |here} to see how to use ListPluggableDatabases API.
     */
    listPluggableDatabases(listPluggableDatabasesRequest: requests.ListPluggableDatabasesRequest): Promise<responses.ListPluggableDatabasesResponse>;
    /**
     * NOTE: This function is deprecated in favor of listPluggableDatabasesRecordIterator function.
     * Creates a new async iterator which will iterate over the models.PluggableDatabaseSummary objects
     * contained in responses from the listPluggableDatabases operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllPluggableDatabases(request: requests.ListPluggableDatabasesRequest): AsyncIterableIterator<model.PluggableDatabaseSummary>;
    /**
     * NOTE: This function is deprecated in favor of listPluggableDatabasesResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listPluggableDatabases operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllPluggableDatabasesResponses(request: requests.ListPluggableDatabasesRequest): AsyncIterableIterator<responses.ListPluggableDatabasesResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.PluggableDatabaseSummary objects
     * contained in responses from the listPluggableDatabases operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listPluggableDatabasesRecordIterator(request: requests.ListPluggableDatabasesRequest): AsyncIterableIterator<model.PluggableDatabaseSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listPluggableDatabases operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listPluggableDatabasesResponseIterator(request: requests.ListPluggableDatabasesRequest): AsyncIterableIterator<responses.ListPluggableDatabasesResponse>;
    /**
     * Gets a list of supported Exadata system versions for a given shape and GI version.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListSystemVersionsRequest
     * @return ListSystemVersionsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ListSystemVersions.ts.html |here} to see how to use ListSystemVersions API.
     */
    listSystemVersions(listSystemVersionsRequest: requests.ListSystemVersionsRequest): Promise<responses.ListSystemVersionsResponse>;
    /**
     * Gets a list of the VM cluster networks in the specified compartment. Applies to Exadata Cloud@Customer instances only.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListVmClusterNetworksRequest
     * @return ListVmClusterNetworksResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ListVmClusterNetworks.ts.html |here} to see how to use ListVmClusterNetworks API.
     */
    listVmClusterNetworks(listVmClusterNetworksRequest: requests.ListVmClusterNetworksRequest): Promise<responses.ListVmClusterNetworksResponse>;
    /**
     * NOTE: This function is deprecated in favor of listVmClusterNetworksRecordIterator function.
     * Creates a new async iterator which will iterate over the models.VmClusterNetworkSummary objects
     * contained in responses from the listVmClusterNetworks operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllVmClusterNetworks(request: requests.ListVmClusterNetworksRequest): AsyncIterableIterator<model.VmClusterNetworkSummary>;
    /**
     * NOTE: This function is deprecated in favor of listVmClusterNetworksResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listVmClusterNetworks operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllVmClusterNetworksResponses(request: requests.ListVmClusterNetworksRequest): AsyncIterableIterator<responses.ListVmClusterNetworksResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.VmClusterNetworkSummary objects
     * contained in responses from the listVmClusterNetworks operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listVmClusterNetworksRecordIterator(request: requests.ListVmClusterNetworksRequest): AsyncIterableIterator<model.VmClusterNetworkSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listVmClusterNetworks operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listVmClusterNetworksResponseIterator(request: requests.ListVmClusterNetworksRequest): AsyncIterableIterator<responses.ListVmClusterNetworksResponse>;
    /**
     * Gets the history of the patch actions performed on the specified VM cluster in an Exadata Cloud@Customer system.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListVmClusterPatchHistoryEntriesRequest
     * @return ListVmClusterPatchHistoryEntriesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ListVmClusterPatchHistoryEntries.ts.html |here} to see how to use ListVmClusterPatchHistoryEntries API.
     */
    listVmClusterPatchHistoryEntries(listVmClusterPatchHistoryEntriesRequest: requests.ListVmClusterPatchHistoryEntriesRequest): Promise<responses.ListVmClusterPatchHistoryEntriesResponse>;
    /**
     * NOTE: This function is deprecated in favor of listVmClusterPatchHistoryEntriesRecordIterator function.
     * Creates a new async iterator which will iterate over the models.PatchHistoryEntrySummary objects
     * contained in responses from the listVmClusterPatchHistoryEntries operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllVmClusterPatchHistoryEntries(request: requests.ListVmClusterPatchHistoryEntriesRequest): AsyncIterableIterator<model.PatchHistoryEntrySummary>;
    /**
     * NOTE: This function is deprecated in favor of listVmClusterPatchHistoryEntriesResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listVmClusterPatchHistoryEntries operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllVmClusterPatchHistoryEntriesResponses(request: requests.ListVmClusterPatchHistoryEntriesRequest): AsyncIterableIterator<responses.ListVmClusterPatchHistoryEntriesResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.PatchHistoryEntrySummary objects
     * contained in responses from the listVmClusterPatchHistoryEntries operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listVmClusterPatchHistoryEntriesRecordIterator(request: requests.ListVmClusterPatchHistoryEntriesRequest): AsyncIterableIterator<model.PatchHistoryEntrySummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listVmClusterPatchHistoryEntries operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listVmClusterPatchHistoryEntriesResponseIterator(request: requests.ListVmClusterPatchHistoryEntriesRequest): AsyncIterableIterator<responses.ListVmClusterPatchHistoryEntriesResponse>;
    /**
     * Lists the patches applicable to the specified VM cluster in an Exadata Cloud@Customer system.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListVmClusterPatchesRequest
     * @return ListVmClusterPatchesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ListVmClusterPatches.ts.html |here} to see how to use ListVmClusterPatches API.
     */
    listVmClusterPatches(listVmClusterPatchesRequest: requests.ListVmClusterPatchesRequest): Promise<responses.ListVmClusterPatchesResponse>;
    /**
     * NOTE: This function is deprecated in favor of listVmClusterPatchesRecordIterator function.
     * Creates a new async iterator which will iterate over the models.PatchSummary objects
     * contained in responses from the listVmClusterPatches operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllVmClusterPatches(request: requests.ListVmClusterPatchesRequest): AsyncIterableIterator<model.PatchSummary>;
    /**
     * NOTE: This function is deprecated in favor of listVmClusterPatchesResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listVmClusterPatches operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllVmClusterPatchesResponses(request: requests.ListVmClusterPatchesRequest): AsyncIterableIterator<responses.ListVmClusterPatchesResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.PatchSummary objects
     * contained in responses from the listVmClusterPatches operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listVmClusterPatchesRecordIterator(request: requests.ListVmClusterPatchesRequest): AsyncIterableIterator<model.PatchSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listVmClusterPatches operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listVmClusterPatchesResponseIterator(request: requests.ListVmClusterPatchesRequest): AsyncIterableIterator<responses.ListVmClusterPatchesResponse>;
    /**
     * Gets the history of the maintenance update actions performed on the specified VM cluster. Applies to Exadata Cloud@Customer instances only.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListVmClusterUpdateHistoryEntriesRequest
     * @return ListVmClusterUpdateHistoryEntriesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ListVmClusterUpdateHistoryEntries.ts.html |here} to see how to use ListVmClusterUpdateHistoryEntries API.
     */
    listVmClusterUpdateHistoryEntries(listVmClusterUpdateHistoryEntriesRequest: requests.ListVmClusterUpdateHistoryEntriesRequest): Promise<responses.ListVmClusterUpdateHistoryEntriesResponse>;
    /**
     * NOTE: This function is deprecated in favor of listVmClusterUpdateHistoryEntriesRecordIterator function.
     * Creates a new async iterator which will iterate over the models.VmClusterUpdateHistoryEntrySummary objects
     * contained in responses from the listVmClusterUpdateHistoryEntries operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllVmClusterUpdateHistoryEntries(request: requests.ListVmClusterUpdateHistoryEntriesRequest): AsyncIterableIterator<model.VmClusterUpdateHistoryEntrySummary>;
    /**
     * NOTE: This function is deprecated in favor of listVmClusterUpdateHistoryEntriesResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listVmClusterUpdateHistoryEntries operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllVmClusterUpdateHistoryEntriesResponses(request: requests.ListVmClusterUpdateHistoryEntriesRequest): AsyncIterableIterator<responses.ListVmClusterUpdateHistoryEntriesResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.VmClusterUpdateHistoryEntrySummary objects
     * contained in responses from the listVmClusterUpdateHistoryEntries operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listVmClusterUpdateHistoryEntriesRecordIterator(request: requests.ListVmClusterUpdateHistoryEntriesRequest): AsyncIterableIterator<model.VmClusterUpdateHistoryEntrySummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listVmClusterUpdateHistoryEntries operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listVmClusterUpdateHistoryEntriesResponseIterator(request: requests.ListVmClusterUpdateHistoryEntriesRequest): AsyncIterableIterator<responses.ListVmClusterUpdateHistoryEntriesResponse>;
    /**
     * Lists the maintenance updates that can be applied to the specified VM cluster. Applies to Exadata Cloud@Customer instances only.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListVmClusterUpdatesRequest
     * @return ListVmClusterUpdatesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ListVmClusterUpdates.ts.html |here} to see how to use ListVmClusterUpdates API.
     */
    listVmClusterUpdates(listVmClusterUpdatesRequest: requests.ListVmClusterUpdatesRequest): Promise<responses.ListVmClusterUpdatesResponse>;
    /**
     * NOTE: This function is deprecated in favor of listVmClusterUpdatesRecordIterator function.
     * Creates a new async iterator which will iterate over the models.VmClusterUpdateSummary objects
     * contained in responses from the listVmClusterUpdates operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllVmClusterUpdates(request: requests.ListVmClusterUpdatesRequest): AsyncIterableIterator<model.VmClusterUpdateSummary>;
    /**
     * NOTE: This function is deprecated in favor of listVmClusterUpdatesResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listVmClusterUpdates operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllVmClusterUpdatesResponses(request: requests.ListVmClusterUpdatesRequest): AsyncIterableIterator<responses.ListVmClusterUpdatesResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.VmClusterUpdateSummary objects
     * contained in responses from the listVmClusterUpdates operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listVmClusterUpdatesRecordIterator(request: requests.ListVmClusterUpdatesRequest): AsyncIterableIterator<model.VmClusterUpdateSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listVmClusterUpdates operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listVmClusterUpdatesResponseIterator(request: requests.ListVmClusterUpdatesRequest): AsyncIterableIterator<responses.ListVmClusterUpdatesResponse>;
    /**
     * Lists the VM clusters in the specified compartment. Applies to Exadata Cloud@Customer instances only.
     * To list the cloud VM clusters in an Exadata Cloud Service instance, use the {@link #listCloudVmClusters(ListCloudVmClustersRequest) listCloudVmClusters} operation.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListVmClustersRequest
     * @return ListVmClustersResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ListVmClusters.ts.html |here} to see how to use ListVmClusters API.
     */
    listVmClusters(listVmClustersRequest: requests.ListVmClustersRequest): Promise<responses.ListVmClustersResponse>;
    /**
     * NOTE: This function is deprecated in favor of listVmClustersRecordIterator function.
     * Creates a new async iterator which will iterate over the models.VmClusterSummary objects
     * contained in responses from the listVmClusters operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllVmClusters(request: requests.ListVmClustersRequest): AsyncIterableIterator<model.VmClusterSummary>;
    /**
     * NOTE: This function is deprecated in favor of listVmClustersResponseIterator function.
     * Creates a new async iterator which will iterate over the responses received from the listVmClusters operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllVmClustersResponses(request: requests.ListVmClustersRequest): AsyncIterableIterator<responses.ListVmClustersResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.VmClusterSummary objects
     * contained in responses from the listVmClusters operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listVmClustersRecordIterator(request: requests.ListVmClustersRequest): AsyncIterableIterator<model.VmClusterSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listVmClusters operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listVmClustersResponseIterator(request: requests.ListVmClustersRequest): AsyncIterableIterator<responses.ListVmClustersResponse>;
    /**
     * **Deprecated.** Use {@link #createPluggableDatabase(CreatePluggableDatabaseRequest) createPluggableDatabase} for Pluggable Database LocalClone Operation.
     * Clones and starts a pluggable database (PDB) in the same database (CDB) as the source PDB. The source PDB must be in the `READ_WRITE` openMode to perform the clone operation.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param LocalClonePluggableDatabaseRequest
     * @return LocalClonePluggableDatabaseResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/LocalClonePluggableDatabase.ts.html |here} to see how to use LocalClonePluggableDatabase API.
     */
    localClonePluggableDatabase(localClonePluggableDatabaseRequest: requests.LocalClonePluggableDatabaseRequest): Promise<responses.LocalClonePluggableDatabaseResponse>;
    /**
     * Migrates the Exadata DB system to the new [Exadata resource model](https://docs.cloud.oracle.com/iaas/Content/Database/Concepts/exaflexsystem.htm#exaflexsystem_topic-resource_model).
     * All related resources will be migrated.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param MigrateExadataDbSystemResourceModelRequest
     * @return MigrateExadataDbSystemResourceModelResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/MigrateExadataDbSystemResourceModel.ts.html |here} to see how to use MigrateExadataDbSystemResourceModel API.
     */
    migrateExadataDbSystemResourceModel(migrateExadataDbSystemResourceModelRequest: requests.MigrateExadataDbSystemResourceModelRequest): Promise<responses.MigrateExadataDbSystemResourceModelResponse>;
    /**
     * Changes encryption key management from customer-managed, using the [Vault service](https://docs.cloud.oracle.com/iaas/Content/KeyManagement/Concepts/keyoverview.htm), to Oracle-managed.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param MigrateVaultKeyRequest
     * @return MigrateVaultKeyResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/MigrateVaultKey.ts.html |here} to see how to use MigrateVaultKey API.
     */
    migrateVaultKey(migrateVaultKeyRequest: requests.MigrateVaultKeyRequest): Promise<responses.MigrateVaultKeyResponse>;
    /**
     * Updates one or more attributes of the Database Management service for the database.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ModifyDatabaseManagementRequest
     * @return ModifyDatabaseManagementResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ModifyDatabaseManagement.ts.html |here} to see how to use ModifyDatabaseManagement API.
     */
    modifyDatabaseManagement(modifyDatabaseManagementRequest: requests.ModifyDatabaseManagementRequest): Promise<responses.ModifyDatabaseManagementResponse>;
    /**
     * Updates one or more attributes of the Database Management service for the pluggable database.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ModifyPluggableDatabaseManagementRequest
     * @return ModifyPluggableDatabaseManagementResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ModifyPluggableDatabaseManagement.ts.html |here} to see how to use ModifyPluggableDatabaseManagement API.
     */
    modifyPluggableDatabaseManagement(modifyPluggableDatabaseManagementRequest: requests.ModifyPluggableDatabaseManagementRequest): Promise<responses.ModifyPluggableDatabaseManagementResponse>;
    /**
     * Refreshes a pluggable database (PDB) Refreshable clone.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param RefreshPluggableDatabaseRequest
     * @return RefreshPluggableDatabaseResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/RefreshPluggableDatabase.ts.html |here} to see how to use RefreshPluggableDatabase API.
     */
    refreshPluggableDatabase(refreshPluggableDatabaseRequest: requests.RefreshPluggableDatabaseRequest): Promise<responses.RefreshPluggableDatabaseResponse>;
    /**
     * Asynchronously registers this Autonomous Database with Data Safe.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param RegisterAutonomousDatabaseDataSafeRequest
     * @return RegisterAutonomousDatabaseDataSafeResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/RegisterAutonomousDatabaseDataSafe.ts.html |here} to see how to use RegisterAutonomousDatabaseDataSafe API.
     */
    registerAutonomousDatabaseDataSafe(registerAutonomousDatabaseDataSafeRequest: requests.RegisterAutonomousDatabaseDataSafeRequest): Promise<responses.RegisterAutonomousDatabaseDataSafeResponse>;
    /**
     * Reinstates a disabled standby Autonomous Container Database, identified by the autonomousContainerDatabaseId parameter, to an active standby Autonomous Container Database.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ReinstateAutonomousContainerDatabaseDataguardAssociationRequest
     * @return ReinstateAutonomousContainerDatabaseDataguardAssociationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ReinstateAutonomousContainerDatabaseDataguardAssociation.ts.html |here} to see how to use ReinstateAutonomousContainerDatabaseDataguardAssociation API.
     */
    reinstateAutonomousContainerDatabaseDataguardAssociation(reinstateAutonomousContainerDatabaseDataguardAssociationRequest: requests.ReinstateAutonomousContainerDatabaseDataguardAssociationRequest): Promise<responses.ReinstateAutonomousContainerDatabaseDataguardAssociationResponse>;
    /**
     * Reinstates the database identified by the `databaseId` parameter into the standby role in a Data Guard association.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ReinstateDataGuardAssociationRequest
     * @return ReinstateDataGuardAssociationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ReinstateDataGuardAssociation.ts.html |here} to see how to use ReinstateDataGuardAssociation API.
     */
    reinstateDataGuardAssociation(reinstateDataGuardAssociationRequest: requests.ReinstateDataGuardAssociationRequest): Promise<responses.ReinstateDataGuardAssociationResponse>;
    /**
     * **Deprecated.** Use {@link #createPluggableDatabase(CreatePluggableDatabaseRequest) createPluggableDatabase} for Pluggable Database RemoteClone Operation.
     * Clones a pluggable database (PDB) to a different database from the source PDB. The cloned PDB will be started upon completion of the clone operation. The source PDB must be in the `READ_WRITE` openMode when performing the clone.
     * For Exadata Cloud@Customer instances, the source pluggable database (PDB) must be on the same Exadata Infrastructure as the target container database (CDB) to create a remote clone.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param RemoteClonePluggableDatabaseRequest
     * @return RemoteClonePluggableDatabaseResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/RemoteClonePluggableDatabase.ts.html |here} to see how to use RemoteClonePluggableDatabase API.
     */
    remoteClonePluggableDatabase(remoteClonePluggableDatabaseRequest: requests.RemoteClonePluggableDatabaseRequest): Promise<responses.RemoteClonePluggableDatabaseResponse>;
    /**
     * Remove Virtual Machines from the Cloud VM cluster. Applies to Exadata Cloud instances only.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param RemoveVirtualMachineFromCloudVmClusterRequest
     * @return RemoveVirtualMachineFromCloudVmClusterResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/RemoveVirtualMachineFromCloudVmCluster.ts.html |here} to see how to use RemoveVirtualMachineFromCloudVmCluster API.
     */
    removeVirtualMachineFromCloudVmCluster(removeVirtualMachineFromCloudVmClusterRequest: requests.RemoveVirtualMachineFromCloudVmClusterRequest): Promise<responses.RemoveVirtualMachineFromCloudVmClusterResponse>;
    /**
     * Remove Virtual Machines from the Exadata VM cluster on Exascale Infrastructure. Applies to Exadata Cloud instances only.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param RemoveVirtualMachineFromExadbVmClusterRequest
     * @return RemoveVirtualMachineFromExadbVmClusterResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/RemoveVirtualMachineFromExadbVmCluster.ts.html |here} to see how to use RemoveVirtualMachineFromExadbVmCluster API.
     */
    removeVirtualMachineFromExadbVmCluster(removeVirtualMachineFromExadbVmClusterRequest: requests.RemoveVirtualMachineFromExadbVmClusterRequest): Promise<responses.RemoveVirtualMachineFromExadbVmClusterResponse>;
    /**
     * Remove Virtual Machines from the VM cluster. Applies to Exadata Cloud@Customer instances only.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param RemoveVirtualMachineFromVmClusterRequest
     * @return RemoveVirtualMachineFromVmClusterResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/RemoveVirtualMachineFromVmCluster.ts.html |here} to see how to use RemoveVirtualMachineFromVmCluster API.
     */
    removeVirtualMachineFromVmCluster(removeVirtualMachineFromVmClusterRequest: requests.RemoveVirtualMachineFromVmClusterRequest): Promise<responses.RemoveVirtualMachineFromVmClusterResponse>;
    /**
     * Adds or removes Db server network nodes to extend or shrink the existing VM cluster network. Applies to Exadata
     * Cloud@Customer instances only.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ResizeVmClusterNetworkRequest
     * @return ResizeVmClusterNetworkResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ResizeVmClusterNetwork.ts.html |here} to see how to use ResizeVmClusterNetwork API.
     */
    resizeVmClusterNetwork(resizeVmClusterNetworkRequest: requests.ResizeVmClusterNetworkRequest): Promise<responses.ResizeVmClusterNetworkResponse>;
    /**
     * Lists available resource pools shapes.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ResourcePoolShapesRequest
     * @return ResourcePoolShapesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ResourcePoolShapes.ts.html |here} to see how to use ResourcePoolShapes API.
     */
    resourcePoolShapes(resourcePoolShapesRequest: requests.ResourcePoolShapesRequest): Promise<responses.ResourcePoolShapesResponse>;
    /**
     * Rolling restarts the specified Autonomous Container Database.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param RestartAutonomousContainerDatabaseRequest
     * @return RestartAutonomousContainerDatabaseResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/RestartAutonomousContainerDatabase.ts.html |here} to see how to use RestartAutonomousContainerDatabase API.
     */
    restartAutonomousContainerDatabase(restartAutonomousContainerDatabaseRequest: requests.RestartAutonomousContainerDatabaseRequest): Promise<responses.RestartAutonomousContainerDatabaseResponse>;
    /**
     * Restarts the specified Autonomous Database.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param RestartAutonomousDatabaseRequest
     * @return RestartAutonomousDatabaseResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/RestartAutonomousDatabase.ts.html |here} to see how to use RestartAutonomousDatabase API.
     */
    restartAutonomousDatabase(restartAutonomousDatabaseRequest: requests.RestartAutonomousDatabaseRequest): Promise<responses.RestartAutonomousDatabaseResponse>;
    /**
     * Restores an Autonomous Database based on the provided request parameters.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param RestoreAutonomousDatabaseRequest
     * @return RestoreAutonomousDatabaseResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/RestoreAutonomousDatabase.ts.html |here} to see how to use RestoreAutonomousDatabase API.
     */
    restoreAutonomousDatabase(restoreAutonomousDatabaseRequest: requests.RestoreAutonomousDatabaseRequest): Promise<responses.RestoreAutonomousDatabaseResponse>;
    /**
     * Restore a Database based on the request parameters you provide.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param RestoreDatabaseRequest
     * @return RestoreDatabaseResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/RestoreDatabase.ts.html |here} to see how to use RestoreDatabase API.
     */
    restoreDatabase(restoreDatabaseRequest: requests.RestoreDatabaseRequest): Promise<responses.RestoreDatabaseResponse>;
    /**
     * Creates a new version of an existing [Vault service](https://docs.cloud.oracle.com/iaas/Content/KeyManagement/Concepts/keyoverview.htm) key.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param RotateAutonomousContainerDatabaseEncryptionKeyRequest
     * @return RotateAutonomousContainerDatabaseEncryptionKeyResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/RotateAutonomousContainerDatabaseEncryptionKey.ts.html |here} to see how to use RotateAutonomousContainerDatabaseEncryptionKey API.
     */
    rotateAutonomousContainerDatabaseEncryptionKey(rotateAutonomousContainerDatabaseEncryptionKeyRequest: requests.RotateAutonomousContainerDatabaseEncryptionKeyRequest): Promise<responses.RotateAutonomousContainerDatabaseEncryptionKeyResponse>;
    /**
     * Rotate existing AutonomousDatabase [Vault service](https://docs.cloud.oracle.com/iaas/Content/KeyManagement/Concepts/keyoverview.htm) key.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param RotateAutonomousDatabaseEncryptionKeyRequest
     * @return RotateAutonomousDatabaseEncryptionKeyResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/RotateAutonomousDatabaseEncryptionKey.ts.html |here} to see how to use RotateAutonomousDatabaseEncryptionKey API.
     */
    rotateAutonomousDatabaseEncryptionKey(rotateAutonomousDatabaseEncryptionKeyRequest: requests.RotateAutonomousDatabaseEncryptionKeyRequest): Promise<responses.RotateAutonomousDatabaseEncryptionKeyResponse>;
    /**
     * Rotates the Oracle REST Data Services (ORDS) certificates for Autonomous Exadata VM cluster.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param RotateAutonomousVmClusterOrdsCertsRequest
     * @return RotateAutonomousVmClusterOrdsCertsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/RotateAutonomousVmClusterOrdsCerts.ts.html |here} to see how to use RotateAutonomousVmClusterOrdsCerts API.
     */
    rotateAutonomousVmClusterOrdsCerts(rotateAutonomousVmClusterOrdsCertsRequest: requests.RotateAutonomousVmClusterOrdsCertsRequest): Promise<responses.RotateAutonomousVmClusterOrdsCertsResponse>;
    /**
     * Rotates the SSL certificates for Autonomous Exadata VM cluster.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param RotateAutonomousVmClusterSslCertsRequest
     * @return RotateAutonomousVmClusterSslCertsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/RotateAutonomousVmClusterSslCerts.ts.html |here} to see how to use RotateAutonomousVmClusterSslCerts API.
     */
    rotateAutonomousVmClusterSslCerts(rotateAutonomousVmClusterSslCertsRequest: requests.RotateAutonomousVmClusterSslCertsRequest): Promise<responses.RotateAutonomousVmClusterSslCertsResponse>;
    /**
     * Rotates the Oracle REST Data Services (ORDS) certificates for a cloud Autonomous Exadata VM cluster.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param RotateCloudAutonomousVmClusterOrdsCertsRequest
     * @return RotateCloudAutonomousVmClusterOrdsCertsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/RotateCloudAutonomousVmClusterOrdsCerts.ts.html |here} to see how to use RotateCloudAutonomousVmClusterOrdsCerts API.
     */
    rotateCloudAutonomousVmClusterOrdsCerts(rotateCloudAutonomousVmClusterOrdsCertsRequest: requests.RotateCloudAutonomousVmClusterOrdsCertsRequest): Promise<responses.RotateCloudAutonomousVmClusterOrdsCertsResponse>;
    /**
     * Rotates the SSL certficates for a cloud Autonomous Exadata VM cluster.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param RotateCloudAutonomousVmClusterSslCertsRequest
     * @return RotateCloudAutonomousVmClusterSslCertsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/RotateCloudAutonomousVmClusterSslCerts.ts.html |here} to see how to use RotateCloudAutonomousVmClusterSslCerts API.
     */
    rotateCloudAutonomousVmClusterSslCerts(rotateCloudAutonomousVmClusterSslCertsRequest: requests.RotateCloudAutonomousVmClusterSslCertsRequest): Promise<responses.RotateCloudAutonomousVmClusterSslCertsResponse>;
    /**
     * **Deprecated.** Use the {@link #rotateCloudAutonomousVmClusterOrdsCerts(RotateCloudAutonomousVmClusterOrdsCertsRequest) rotateCloudAutonomousVmClusterOrdsCerts} to rotate Oracle REST Data Services (ORDS) certs for an Autonomous Exadata VM cluster instead.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param RotateOrdsCertsRequest
     * @return RotateOrdsCertsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/RotateOrdsCerts.ts.html |here} to see how to use RotateOrdsCerts API.
     */
    rotateOrdsCerts(rotateOrdsCertsRequest: requests.RotateOrdsCertsRequest): Promise<responses.RotateOrdsCertsResponse>;
    /**
     * Create a new version of the existing encryption key.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param RotatePluggableDatabaseEncryptionKeyRequest
     * @return RotatePluggableDatabaseEncryptionKeyResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/RotatePluggableDatabaseEncryptionKey.ts.html |here} to see how to use RotatePluggableDatabaseEncryptionKey API.
     */
    rotatePluggableDatabaseEncryptionKey(rotatePluggableDatabaseEncryptionKeyRequest: requests.RotatePluggableDatabaseEncryptionKeyRequest): Promise<responses.RotatePluggableDatabaseEncryptionKeyResponse>;
    /**
     * **Deprecated.** Use the {@link #rotateCloudAutonomousVmClusterSslCerts(RotateCloudAutonomousVmClusterSslCertsRequest) rotateCloudAutonomousVmClusterSslCerts} to rotate SSL certs for an Autonomous Exadata VM cluster instead.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param RotateSslCertsRequest
     * @return RotateSslCertsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/RotateSslCerts.ts.html |here} to see how to use RotateSslCerts API.
     */
    rotateSslCerts(rotateSslCertsRequest: requests.RotateSslCertsRequest): Promise<responses.RotateSslCertsResponse>;
    /**
     * Creates a new version of an existing [Vault service](https://docs.cloud.oracle.com/iaas/Content/KeyManagement/Concepts/keyoverview.htm) key.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param RotateVaultKeyRequest
     * @return RotateVaultKeyResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/RotateVaultKey.ts.html |here} to see how to use RotateVaultKey API.
     */
    rotateVaultKey(rotateVaultKeyRequest: requests.RotateVaultKeyRequest): Promise<responses.RotateVaultKeyResponse>;
    /**
     * This operation gets SaaS administrative user status of the Autonomous Database.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param SaasAdminUserStatusRequest
     * @return SaasAdminUserStatusResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/SaasAdminUserStatus.ts.html |here} to see how to use SaasAdminUserStatus API.
     */
    saasAdminUserStatus(saasAdminUserStatusRequest: requests.SaasAdminUserStatusRequest): Promise<responses.SaasAdminUserStatusResponse>;
    /**
     * Scans for pluggable databases in the specified external container database.
     * This operation will return un-registered pluggable databases in the {@link #getWorkRequest(GetWorkRequestRequest) getWorkRequest} operation.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ScanExternalContainerDatabasePluggableDatabasesRequest
     * @return ScanExternalContainerDatabasePluggableDatabasesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ScanExternalContainerDatabasePluggableDatabases.ts.html |here} to see how to use ScanExternalContainerDatabasePluggableDatabases API.
     */
    scanExternalContainerDatabasePluggableDatabases(scanExternalContainerDatabasePluggableDatabasesRequest: requests.ScanExternalContainerDatabasePluggableDatabasesRequest): Promise<responses.ScanExternalContainerDatabasePluggableDatabasesResponse>;
    /**
     * This operation shrinks the current allocated storage down to the current actual used data storage (actualUsedDataStorageSizeInTBs). The if the base storage value for the database (dataStorageSizeInTBs) is larger than the actualUsedDataStorageSizeInTBs value, you are billed for the base storage value.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ShrinkAutonomousDatabaseRequest
     * @return ShrinkAutonomousDatabaseResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ShrinkAutonomousDatabase.ts.html |here} to see how to use ShrinkAutonomousDatabase API.
     */
    shrinkAutonomousDatabase(shrinkAutonomousDatabaseRequest: requests.ShrinkAutonomousDatabaseRequest): Promise<responses.ShrinkAutonomousDatabaseResponse>;
    /**
     * Starts the specified Autonomous Database.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param StartAutonomousDatabaseRequest
     * @return StartAutonomousDatabaseResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/StartAutonomousDatabase.ts.html |here} to see how to use StartAutonomousDatabase API.
     */
    startAutonomousDatabase(startAutonomousDatabaseRequest: requests.StartAutonomousDatabaseRequest): Promise<responses.StartAutonomousDatabaseResponse>;
    /**
     * Starts a stopped pluggable database. The `openMode` value of the pluggable database will be `READ_WRITE` upon completion.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param StartPluggableDatabaseRequest
     * @return StartPluggableDatabaseResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/StartPluggableDatabase.ts.html |here} to see how to use StartPluggableDatabase API.
     */
    startPluggableDatabase(startPluggableDatabaseRequest: requests.StartPluggableDatabaseRequest): Promise<responses.StartPluggableDatabaseResponse>;
    /**
     * Stops the specified Autonomous Database.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param StopAutonomousDatabaseRequest
     * @return StopAutonomousDatabaseResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/StopAutonomousDatabase.ts.html |here} to see how to use StopAutonomousDatabase API.
     */
    stopAutonomousDatabase(stopAutonomousDatabaseRequest: requests.StopAutonomousDatabaseRequest): Promise<responses.StopAutonomousDatabaseResponse>;
    /**
     * Stops a pluggable database. The `openMode` value of the pluggable database will be `MOUNTED` upon completion.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param StopPluggableDatabaseRequest
     * @return StopPluggableDatabaseResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/StopPluggableDatabase.ts.html |here} to see how to use StopPluggableDatabase API.
     */
    stopPluggableDatabase(stopPluggableDatabaseRequest: requests.StopPluggableDatabaseRequest): Promise<responses.StopPluggableDatabaseResponse>;
    /**
       * Switches over the primary Autonomous Container Database of an Autonomous Data Guard peer association to standby role. The standby Autonomous Container Database associated with autonomousContainerDatabaseDataguardAssociationId assumes the primary Autonomous Container Database role.
  * <p>
  A switchover incurs no data loss.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param SwitchoverAutonomousContainerDatabaseDataguardAssociationRequest
       * @return SwitchoverAutonomousContainerDatabaseDataguardAssociationResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/SwitchoverAutonomousContainerDatabaseDataguardAssociation.ts.html |here} to see how to use SwitchoverAutonomousContainerDatabaseDataguardAssociation API.
       */
    switchoverAutonomousContainerDatabaseDataguardAssociation(switchoverAutonomousContainerDatabaseDataguardAssociationRequest: requests.SwitchoverAutonomousContainerDatabaseDataguardAssociationRequest): Promise<responses.SwitchoverAutonomousContainerDatabaseDataguardAssociationResponse>;
    /**
     * Initiates a switchover of the specified Autonomous Database to the associated peer database. Applicable only to databases with Disaster Recovery enabled.
     * This API should be called in the remote region where the peer database resides.
     * Below parameter is optional:
     *   - `peerDbId`
     *     Use this parameter to specify the database OCID of the Disaster Recovery peer, which is located in a different (remote) region from the current peer database.
     *     If this parameter is not provided, the switchover will happen in the same region.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param SwitchoverAutonomousDatabaseRequest
     * @return SwitchoverAutonomousDatabaseResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/SwitchoverAutonomousDatabase.ts.html |here} to see how to use SwitchoverAutonomousDatabase API.
     */
    switchoverAutonomousDatabase(switchoverAutonomousDatabaseRequest: requests.SwitchoverAutonomousDatabaseRequest): Promise<responses.SwitchoverAutonomousDatabaseResponse>;
    /**
       * Performs a switchover to transition the primary database of a Data Guard association into a standby role. The
  * standby database associated with the `dataGuardAssociationId` assumes the primary database role.
  * <p>
  A switchover guarantees no data loss.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param SwitchoverDataGuardAssociationRequest
       * @return SwitchoverDataGuardAssociationResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/SwitchoverDataGuardAssociation.ts.html |here} to see how to use SwitchoverDataGuardAssociation API.
       */
    switchoverDataGuardAssociation(switchoverDataGuardAssociationRequest: requests.SwitchoverDataGuardAssociationRequest): Promise<responses.SwitchoverDataGuardAssociationResponse>;
    /**
     * Terminates an Autonomous Container Database, which permanently deletes the container database and any databases within the container database. The database data is local to the Autonomous Exadata Infrastructure and will be lost when the container database is terminated. Oracle recommends that you back up any data in the Autonomous Container Database prior to terminating it.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param TerminateAutonomousContainerDatabaseRequest
     * @return TerminateAutonomousContainerDatabaseResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/TerminateAutonomousContainerDatabase.ts.html |here} to see how to use TerminateAutonomousContainerDatabase API.
     */
    terminateAutonomousContainerDatabase(terminateAutonomousContainerDatabaseRequest: requests.TerminateAutonomousContainerDatabaseRequest): Promise<responses.TerminateAutonomousContainerDatabaseResponse>;
    /**
     * **Deprecated.** To terminate an Exadata Infrastructure resource in the Oracle cloud, use the {@link #deleteCloudExadataInfrastructure(DeleteCloudExadataInfrastructureRequest) deleteCloudExadataInfrastructure} operation. To delete an Autonomous Exadata VM cluster in the Oracle cloud, use the {@link #deleteCloudAutonomousVmCluster(DeleteCloudAutonomousVmClusterRequest) deleteCloudAutonomousVmCluster} operation.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param TerminateAutonomousExadataInfrastructureRequest
     * @return TerminateAutonomousExadataInfrastructureResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/TerminateAutonomousExadataInfrastructure.ts.html |here} to see how to use TerminateAutonomousExadataInfrastructure API.
     */
    terminateAutonomousExadataInfrastructure(terminateAutonomousExadataInfrastructureRequest: requests.TerminateAutonomousExadataInfrastructureRequest): Promise<responses.TerminateAutonomousExadataInfrastructureResponse>;
    /**
       * Terminates a DB system and permanently deletes it and any databases running on it, and any storage volumes attached to it. The database data is local to the DB system and will be lost when the system is terminated. Oracle recommends that you back up any data in the DB system prior to terminating it.
  * <p>
  **Note:** Deprecated for Exadata Cloud Service systems. Use the [new resource model APIs](https://docs.cloud.oracle.com/iaas/Content/Database/Concepts/exaflexsystem.htm#exaflexsystem_topic-resource_model) instead.
  * <p>
  For Exadata Cloud Service instances, support for this API will end on May 15th, 2021. See [Switching an Exadata DB System to the New Resource Model and APIs](https://docs.cloud.oracle.com/iaas/Content/Database/Concepts/exaflexsystem_topic-resource_model_conversion.htm) for details on converting existing Exadata DB systems to the new resource model.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param TerminateDbSystemRequest
       * @return TerminateDbSystemResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/TerminateDbSystem.ts.html |here} to see how to use TerminateDbSystem API.
       */
    terminateDbSystem(terminateDbSystemRequest: requests.TerminateDbSystemRequest): Promise<responses.TerminateDbSystemResponse>;
    /**
     * Updates the properties of an Autonomous Container Database, such as display name, maintenance preference, backup retention, and tags.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateAutonomousContainerDatabaseRequest
     * @return UpdateAutonomousContainerDatabaseResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/UpdateAutonomousContainerDatabase.ts.html |here} to see how to use UpdateAutonomousContainerDatabase API.
     */
    updateAutonomousContainerDatabase(updateAutonomousContainerDatabaseRequest: requests.UpdateAutonomousContainerDatabaseRequest): Promise<responses.UpdateAutonomousContainerDatabaseResponse>;
    /**
     * Update Autonomous Data Guard association.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateAutonomousContainerDatabaseDataguardAssociationRequest
     * @return UpdateAutonomousContainerDatabaseDataguardAssociationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/UpdateAutonomousContainerDatabaseDataguardAssociation.ts.html |here} to see how to use UpdateAutonomousContainerDatabaseDataguardAssociation API.
     */
    updateAutonomousContainerDatabaseDataguardAssociation(updateAutonomousContainerDatabaseDataguardAssociationRequest: requests.UpdateAutonomousContainerDatabaseDataguardAssociationRequest): Promise<responses.UpdateAutonomousContainerDatabaseDataguardAssociationResponse>;
    /**
     * Updates one or more attributes of the specified Autonomous Database. See the UpdateAutonomousDatabaseDetails resource for a full list of attributes that can be updated.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateAutonomousDatabaseRequest
     * @return UpdateAutonomousDatabaseResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/UpdateAutonomousDatabase.ts.html |here} to see how to use UpdateAutonomousDatabase API.
     */
    updateAutonomousDatabase(updateAutonomousDatabaseRequest: requests.UpdateAutonomousDatabaseRequest): Promise<responses.UpdateAutonomousDatabaseResponse>;
    /**
     * Updates the Autonomous Database backup of the specified database based on the request parameters.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateAutonomousDatabaseBackupRequest
     * @return UpdateAutonomousDatabaseBackupResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/UpdateAutonomousDatabaseBackup.ts.html |here} to see how to use UpdateAutonomousDatabaseBackup API.
     */
    updateAutonomousDatabaseBackup(updateAutonomousDatabaseBackupRequest: requests.UpdateAutonomousDatabaseBackupRequest): Promise<responses.UpdateAutonomousDatabaseBackupResponse>;
    /**
     * Updates the Autonomous Database regional wallet.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateAutonomousDatabaseRegionalWalletRequest
     * @return UpdateAutonomousDatabaseRegionalWalletResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/UpdateAutonomousDatabaseRegionalWallet.ts.html |here} to see how to use UpdateAutonomousDatabaseRegionalWallet API.
     */
    updateAutonomousDatabaseRegionalWallet(updateAutonomousDatabaseRegionalWalletRequest: requests.UpdateAutonomousDatabaseRegionalWalletRequest): Promise<responses.UpdateAutonomousDatabaseRegionalWalletResponse>;
    /**
     * Updates the properties of an Autonomous Database Software Image, like add tags
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateAutonomousDatabaseSoftwareImageRequest
     * @return UpdateAutonomousDatabaseSoftwareImageResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/UpdateAutonomousDatabaseSoftwareImage.ts.html |here} to see how to use UpdateAutonomousDatabaseSoftwareImage API.
     */
    updateAutonomousDatabaseSoftwareImage(updateAutonomousDatabaseSoftwareImageRequest: requests.UpdateAutonomousDatabaseSoftwareImageRequest): Promise<responses.UpdateAutonomousDatabaseSoftwareImageResponse>;
    /**
     * Updates the wallet for the specified Autonomous Database.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateAutonomousDatabaseWalletRequest
     * @return UpdateAutonomousDatabaseWalletResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/UpdateAutonomousDatabaseWallet.ts.html |here} to see how to use UpdateAutonomousDatabaseWallet API.
     */
    updateAutonomousDatabaseWallet(updateAutonomousDatabaseWalletRequest: requests.UpdateAutonomousDatabaseWalletRequest): Promise<responses.UpdateAutonomousDatabaseWalletResponse>;
    /**
     * **Deprecated.** Use the {@link #updateCloudExadataInfrastructure(UpdateCloudExadataInfrastructureRequest) updateCloudExadataInfrastructure} operation to update an Exadata Infrastructure resource and  {@link #updateCloudAutonomousVmCluster(UpdateCloudAutonomousVmClusterRequest) updateCloudAutonomousVmCluster} operation to update an Autonomous Exadata VM cluster.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateAutonomousExadataInfrastructureRequest
     * @return UpdateAutonomousExadataInfrastructureResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/UpdateAutonomousExadataInfrastructure.ts.html |here} to see how to use UpdateAutonomousExadataInfrastructure API.
     */
    updateAutonomousExadataInfrastructure(updateAutonomousExadataInfrastructureRequest: requests.UpdateAutonomousExadataInfrastructureRequest): Promise<responses.UpdateAutonomousExadataInfrastructureResponse>;
    /**
     * Updates the specified Autonomous VM cluster for the Exadata Cloud@Customer system.To update an Autonomous VM Cluster in the Oracle cloud, see {@link #updateCloudAutonomousVmCluster(UpdateCloudAutonomousVmClusterRequest) updateCloudAutonomousVmCluster}.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateAutonomousVmClusterRequest
     * @return UpdateAutonomousVmClusterResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/UpdateAutonomousVmCluster.ts.html |here} to see how to use UpdateAutonomousVmCluster API.
     */
    updateAutonomousVmCluster(updateAutonomousVmClusterRequest: requests.UpdateAutonomousVmClusterRequest): Promise<responses.UpdateAutonomousVmClusterResponse>;
    /**
     * If no database is associated with the backup destination:
     * - For a RECOVERY_APPLIANCE backup destination, updates the connection string and/or the list of VPC users.
     * - For an NFS backup destination, updates the NFS location.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateBackupDestinationRequest
     * @return UpdateBackupDestinationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/UpdateBackupDestination.ts.html |here} to see how to use UpdateBackupDestination API.
     */
    updateBackupDestination(updateBackupDestinationRequest: requests.UpdateBackupDestinationRequest): Promise<responses.UpdateBackupDestinationResponse>;
    /**
     * Updates the specified Autonomous Exadata VM cluster in the Oracle cloud. For Exadata Cloud@Customer systems, see {@link #updateAutonomousVmCluster(UpdateAutonomousVmClusterRequest) updateAutonomousVmCluster}.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateCloudAutonomousVmClusterRequest
     * @return UpdateCloudAutonomousVmClusterResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/UpdateCloudAutonomousVmCluster.ts.html |here} to see how to use UpdateCloudAutonomousVmCluster API.
     */
    updateCloudAutonomousVmCluster(updateCloudAutonomousVmClusterRequest: requests.UpdateCloudAutonomousVmClusterRequest): Promise<responses.UpdateCloudAutonomousVmClusterResponse>;
    /**
     * Updates the Cloud Exadata infrastructure resource. Applies to Exadata Cloud Service instances and Autonomous Database on dedicated Exadata infrastructure only.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateCloudExadataInfrastructureRequest
     * @return UpdateCloudExadataInfrastructureResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/UpdateCloudExadataInfrastructure.ts.html |here} to see how to use UpdateCloudExadataInfrastructure API.
     */
    updateCloudExadataInfrastructure(updateCloudExadataInfrastructureRequest: requests.UpdateCloudExadataInfrastructureRequest): Promise<responses.UpdateCloudExadataInfrastructureResponse>;
    /**
     * Updates the specified cloud VM cluster. Applies to Exadata Cloud Service instances and Autonomous Database on dedicated Exadata infrastructure only.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateCloudVmClusterRequest
     * @return UpdateCloudVmClusterResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/UpdateCloudVmCluster.ts.html |here} to see how to use UpdateCloudVmCluster API.
     */
    updateCloudVmCluster(updateCloudVmClusterRequest: requests.UpdateCloudVmClusterRequest): Promise<responses.UpdateCloudVmClusterResponse>;
    /**
     * Updates the IORM settings for the specified cloud VM cluster in an Exadata Cloud Service instance.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateCloudVmClusterIormConfigRequest
     * @return UpdateCloudVmClusterIormConfigResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/UpdateCloudVmClusterIormConfig.ts.html |here} to see how to use UpdateCloudVmClusterIormConfig API.
     */
    updateCloudVmClusterIormConfig(updateCloudVmClusterIormConfigRequest: requests.UpdateCloudVmClusterIormConfigRequest): Promise<responses.UpdateCloudVmClusterIormConfigResponse>;
    /**
     * Updates the specified database node console connection.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateConsoleConnectionRequest
     * @return UpdateConsoleConnectionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/UpdateConsoleConnection.ts.html |here} to see how to use UpdateConsoleConnection API.
     */
    updateConsoleConnection(updateConsoleConnectionRequest: requests.UpdateConsoleConnectionRequest): Promise<responses.UpdateConsoleConnectionResponse>;
    /**
     * Updates the specified database node console history.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateConsoleHistoryRequest
     * @return UpdateConsoleHistoryResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/UpdateConsoleHistory.ts.html |here} to see how to use UpdateConsoleHistory API.
     */
    updateConsoleHistory(updateConsoleHistoryRequest: requests.UpdateConsoleHistoryRequest): Promise<responses.UpdateConsoleHistoryResponse>;
    /**
     * Updates the Data Guard association the specified database. This API can be used to change the `protectionMode` and `transportType` of the Data Guard association.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateDataGuardAssociationRequest
     * @return UpdateDataGuardAssociationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/UpdateDataGuardAssociation.ts.html |here} to see how to use UpdateDataGuardAssociation API.
     */
    updateDataGuardAssociation(updateDataGuardAssociationRequest: requests.UpdateDataGuardAssociationRequest): Promise<responses.UpdateDataGuardAssociationResponse>;
    /**
     * Update the specified database based on the request parameters provided.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateDatabaseRequest
     * @return UpdateDatabaseResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/UpdateDatabase.ts.html |here} to see how to use UpdateDatabase API.
     */
    updateDatabase(updateDatabaseRequest: requests.UpdateDatabaseRequest): Promise<responses.UpdateDatabaseResponse>;
    /**
     * Updates the properties of a Database Software Image, like Display Nmae
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateDatabaseSoftwareImageRequest
     * @return UpdateDatabaseSoftwareImageResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/UpdateDatabaseSoftwareImage.ts.html |here} to see how to use UpdateDatabaseSoftwareImage API.
     */
    updateDatabaseSoftwareImage(updateDatabaseSoftwareImageRequest: requests.UpdateDatabaseSoftwareImageRequest): Promise<responses.UpdateDatabaseSoftwareImageResponse>;
    /**
     * Patches the specified Database Home.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateDbHomeRequest
     * @return UpdateDbHomeResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/UpdateDbHome.ts.html |here} to see how to use UpdateDbHome API.
     */
    updateDbHome(updateDbHomeRequest: requests.UpdateDbHomeRequest): Promise<responses.UpdateDbHomeResponse>;
    /**
     * Updates the specified database node.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateDbNodeRequest
     * @return UpdateDbNodeResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/UpdateDbNode.ts.html |here} to see how to use UpdateDbNode API.
     */
    updateDbNode(updateDbNodeRequest: requests.UpdateDbNodeRequest): Promise<responses.UpdateDbNodeResponse>;
    /**
       * Updates the properties of the specified DB system.
  * <p>
  **Note:** Deprecated for Exadata Cloud Service systems. Use the [new resource model APIs](https://docs.cloud.oracle.com/iaas/Content/Database/Concepts/exaflexsystem.htm#exaflexsystem_topic-resource_model) instead.
  * <p>
  For Exadata Cloud Service instances, support for this API will end on May 15th, 2021. See [Switching an Exadata DB System to the New Resource Model and APIs](https://docs.cloud.oracle.com/iaas/Content/Database/Concepts/exaflexsystem_topic-resource_model_conversion.htm) for details on converting existing Exadata DB systems to the new resource model.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param UpdateDbSystemRequest
       * @return UpdateDbSystemResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/UpdateDbSystem.ts.html |here} to see how to use UpdateDbSystem API.
       */
    updateDbSystem(updateDbSystemRequest: requests.UpdateDbSystemRequest): Promise<responses.UpdateDbSystemResponse>;
    /**
     * Updates the Exadata infrastructure resource. Applies to Exadata Cloud@Customer instances only.
     * To update an Exadata Cloud Service infrastructure resource, use the  {@link #updateCloudExadataInfrastructure(UpdateCloudExadataInfrastructureRequest) updateCloudExadataInfrastructure} operation.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateExadataInfrastructureRequest
     * @return UpdateExadataInfrastructureResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/UpdateExadataInfrastructure.ts.html |here} to see how to use UpdateExadataInfrastructure API.
     */
    updateExadataInfrastructure(updateExadataInfrastructureRequest: requests.UpdateExadataInfrastructureRequest): Promise<responses.UpdateExadataInfrastructureResponse>;
    /**
       * Updates IORM settings for the specified Exadata DB system.
  * <p>
  **Note:** Deprecated for Exadata Cloud Service systems. Use the [new resource model APIs](https://docs.cloud.oracle.com/iaas/Content/Database/Concepts/exaflexsystem.htm#exaflexsystem_topic-resource_model) instead.
  * <p>
  For Exadata Cloud Service instances, support for this API will end on May 15th, 2021. See [Switching an Exadata DB System to the New Resource Model and APIs](https://docs.cloud.oracle.com/iaas/Content/Database/Concepts/exaflexsystem_topic-resource_model_conversion.htm) for details on converting existing Exadata DB systems to the new resource model.
  * <p>
  The {@link #updateCloudVmClusterIormConfig(UpdateCloudVmClusterIormConfigRequest) updateCloudVmClusterIormConfig} API is used for Exadata systems using the
  * new resource model.
  *
       * This operation does not retry by default if the user has not defined a retry configuration.
       * @param UpdateExadataIormConfigRequest
       * @return UpdateExadataIormConfigResponse
       * @throws OciError when an error occurs
       * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/UpdateExadataIormConfig.ts.html |here} to see how to use UpdateExadataIormConfig API.
       */
    updateExadataIormConfig(updateExadataIormConfigRequest: requests.UpdateExadataIormConfigRequest): Promise<responses.UpdateExadataIormConfigResponse>;
    /**
     * Updates the specified Exadata VM cluster on Exascale Infrastructure. Applies to Exadata Database Service on Exascale Infrastructure only.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateExadbVmClusterRequest
     * @return UpdateExadbVmClusterResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/UpdateExadbVmCluster.ts.html |here} to see how to use UpdateExadbVmCluster API.
     */
    updateExadbVmCluster(updateExadbVmClusterRequest: requests.UpdateExadbVmClusterRequest): Promise<responses.UpdateExadbVmClusterResponse>;
    /**
     * Updates the specified Exadata Database Storage Vault.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateExascaleDbStorageVaultRequest
     * @return UpdateExascaleDbStorageVaultResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/UpdateExascaleDbStorageVault.ts.html |here} to see how to use UpdateExascaleDbStorageVault API.
     */
    updateExascaleDbStorageVault(updateExascaleDbStorageVaultRequest: requests.UpdateExascaleDbStorageVaultRequest): Promise<responses.UpdateExascaleDbStorageVaultResponse>;
    /**
     * Updates the properties of
     * an {@link #createExternalContainerDatabaseDetails(CreateExternalContainerDatabaseDetailsRequest) createExternalContainerDatabaseDetails} resource,
     * such as the display name.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateExternalContainerDatabaseRequest
     * @return UpdateExternalContainerDatabaseResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/UpdateExternalContainerDatabase.ts.html |here} to see how to use UpdateExternalContainerDatabase API.
     */
    updateExternalContainerDatabase(updateExternalContainerDatabaseRequest: requests.UpdateExternalContainerDatabaseRequest): Promise<responses.UpdateExternalContainerDatabaseResponse>;
    /**
     * Updates the properties of an external database connector, such as the display name.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateExternalDatabaseConnectorRequest
     * @return UpdateExternalDatabaseConnectorResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/UpdateExternalDatabaseConnector.ts.html |here} to see how to use UpdateExternalDatabaseConnector API.
     */
    updateExternalDatabaseConnector(updateExternalDatabaseConnectorRequest: requests.UpdateExternalDatabaseConnectorRequest): Promise<responses.UpdateExternalDatabaseConnectorResponse>;
    /**
     * Updates the properties of an external non-container database, such as the display name.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateExternalNonContainerDatabaseRequest
     * @return UpdateExternalNonContainerDatabaseResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/UpdateExternalNonContainerDatabase.ts.html |here} to see how to use UpdateExternalNonContainerDatabase API.
     */
    updateExternalNonContainerDatabase(updateExternalNonContainerDatabaseRequest: requests.UpdateExternalNonContainerDatabaseRequest): Promise<responses.UpdateExternalNonContainerDatabaseResponse>;
    /**
     * Updates the properties of an
     * {@link #createExternalPluggableDatabaseDetails(CreateExternalPluggableDatabaseDetailsRequest) createExternalPluggableDatabaseDetails} resource,
     * such as the display name.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateExternalPluggableDatabaseRequest
     * @return UpdateExternalPluggableDatabaseResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/UpdateExternalPluggableDatabase.ts.html |here} to see how to use UpdateExternalPluggableDatabase API.
     */
    updateExternalPluggableDatabase(updateExternalPluggableDatabaseRequest: requests.UpdateExternalPluggableDatabaseRequest): Promise<responses.UpdateExternalPluggableDatabaseResponse>;
    /**
     * Edit the key store.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateKeyStoreRequest
     * @return UpdateKeyStoreResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/UpdateKeyStore.ts.html |here} to see how to use UpdateKeyStore API.
     */
    updateKeyStore(updateKeyStoreRequest: requests.UpdateKeyStoreRequest): Promise<responses.UpdateKeyStoreResponse>;
    /**
     * Updates the properties of a maintenance run, such as the state of a maintenance run.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateMaintenanceRunRequest
     * @return UpdateMaintenanceRunResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/UpdateMaintenanceRun.ts.html |here} to see how to use UpdateMaintenanceRun API.
     */
    updateMaintenanceRun(updateMaintenanceRunRequest: requests.UpdateMaintenanceRunRequest): Promise<responses.UpdateMaintenanceRunResponse>;
    /**
     * Updates the properties of the specified one-off patch.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateOneoffPatchRequest
     * @return UpdateOneoffPatchResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/UpdateOneoffPatch.ts.html |here} to see how to use UpdateOneoffPatch API.
     */
    updateOneoffPatch(updateOneoffPatchRequest: requests.UpdateOneoffPatchRequest): Promise<responses.UpdateOneoffPatchResponse>;
    /**
     * Updates the specified pluggable database.
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdatePluggableDatabaseRequest
     * @return UpdatePluggableDatabaseResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/UpdatePluggableDatabase.ts.html |here} to see how to use UpdatePluggableDatabase API.
     */
    updatePluggableDatabase(updatePluggableDatabaseRequest: requests.UpdatePluggableDatabaseRequest): Promise<responses.UpdatePluggableDatabaseResponse>;
    /**
     * Updates the specified VM cluster. Applies to Exadata Cloud@Customer instances only.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateVmClusterRequest
     * @return UpdateVmClusterResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/UpdateVmCluster.ts.html |here} to see how to use UpdateVmCluster API.
     */
    updateVmCluster(updateVmClusterRequest: requests.UpdateVmClusterRequest): Promise<responses.UpdateVmClusterResponse>;
    /**
     * Updates the specified VM cluster network. Applies to Exadata Cloud@Customer instances only.
     * To update a cloud VM cluster in an Exadata Cloud Service instance, use the {@link #updateCloudVmCluster(UpdateCloudVmClusterRequest) updateCloudVmCluster} operation.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateVmClusterNetworkRequest
     * @return UpdateVmClusterNetworkResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/UpdateVmClusterNetwork.ts.html |here} to see how to use UpdateVmClusterNetwork API.
     */
    updateVmClusterNetwork(updateVmClusterNetworkRequest: requests.UpdateVmClusterNetworkRequest): Promise<responses.UpdateVmClusterNetworkResponse>;
    /**
     * Upgrades the specified Oracle Database instance.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpgradeDatabaseRequest
     * @return UpgradeDatabaseResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/UpgradeDatabase.ts.html |here} to see how to use UpgradeDatabase API.
     */
    upgradeDatabase(upgradeDatabaseRequest: requests.UpgradeDatabaseRequest): Promise<responses.UpgradeDatabaseResponse>;
    /**
     * Upgrades the operating system and grid infrastructure of the DB system.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpgradeDbSystemRequest
     * @return UpgradeDbSystemResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/UpgradeDbSystem.ts.html |here} to see how to use UpgradeDbSystem API.
     */
    upgradeDbSystem(upgradeDbSystemRequest: requests.UpgradeDbSystemRequest): Promise<responses.UpgradeDbSystemResponse>;
    /**
     * Validates the specified VM cluster network. Applies to Exadata Cloud@Customer instances only.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ValidateVmClusterNetworkRequest
     * @return ValidateVmClusterNetworkResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/database/ValidateVmClusterNetwork.ts.html |here} to see how to use ValidateVmClusterNetwork API.
     */
    validateVmClusterNetwork(validateVmClusterNetworkRequest: requests.ValidateVmClusterNetworkRequest): Promise<responses.ValidateVmClusterNetworkResponse>;
}
export {};
