/**
 * Application Dependency Management API
 * Use the Application Dependency Management API to create knowledge bases and vulnerability audits.  For more information, see [ADM](/Content/application-dependency-management/home.htm).
 * OpenAPI spec version: 20220421
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * A vulnerability audit associates the application dependencies of a project with their associated Vulnerabilities.
 * Each Vulnerability is associated with a score (Common Vulnerability Scoring System V2 or V3).
 * A vulnerable application dependency can be ignored based on the configuration of the vulnerability audit.
 * maxObservedCvssV2Score, maxObservedCvssV3Score and vulnerableArtifactsCount do not take into account non-vulnerable application dependency.
 *
 */
export interface VulnerabilityAudit {
    /**
     * The Oracle Cloud identifier ([OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm)) of the vulnerability audit.
     */
    "id": string;
    /**
     * The name of the vulnerability audit.
     */
    "displayName"?: string;
    /**
     * The Oracle Cloud identifier ([OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm)) of the knowledge base.
     */
    "knowledgeBaseId": string;
    /**
     * The creation date and time of the vulnerability audit (formatted according to [RFC3339](https://datatracker.ietf.org/doc/html/rfc3339)).
     */
    "timeCreated": Date;
    /**
     * The update date and time of the vulnerability audit (formatted according to [RFC3339](https://datatracker.ietf.org/doc/html/rfc3339)).
     */
    "timeUpdated": Date;
    /**
     * The current lifecycle state of the vulnerability audit.
     */
    "lifecycleState": VulnerabilityAudit.LifecycleState;
    /**
     * Details on the lifecycle state.
     */
    "lifecycleDetails"?: VulnerabilityAudit.LifecycleDetails;
    /**
     * List of vulnerabilities found in the vulnerability audit. If a vulnerability affects multiple dependencies, the metadata returned here consists of audit-wide aggregates.
     */
    "vulnerabilities": Array<model.Vulnerability>;
    /**
     * Maximum Common Vulnerability Scoring System Version 2 score observed for non-ignored vulnerable application dependencies. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "maxObservedCvssV2Score"?: number;
    /**
     * Maximum Common Vulnerability Scoring System Version 3 score observed for non-ignored vulnerable application dependencies. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "maxObservedCvssV3Score"?: number;
    /**
     * Maximum ADM Severity observed for non-ignored vulnerable application dependencies.
     */
    "maxObservedSeverity"?: model.VulnerabilitySeverity;
    /**
     * Maximum Common Vulnerability Scoring System Version 2 score observed for vulnerable application dependencies including ignored ones. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "maxObservedCvssV2ScoreWithIgnored"?: number;
    /**
     * Maximum Common Vulnerability Scoring System Version 3 score observed for vulnerable application dependencies including ignored ones. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "maxObservedCvssV3ScoreWithIgnored"?: number;
    /**
     * Maximum ADM Severity observed for vulnerable application dependencies including ignored ones.
     */
    "maxObservedSeverityWithIgnored"?: model.VulnerabilitySeverity;
    /**
     * Count of all vulnerable application dependencies. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "vulnerableArtifactsCountWithIgnored": number;
    /**
     * Count of non-ignored vulnerable application dependencies. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "vulnerableArtifactsCount": number;
    "configuration"?: model.VulnerabilityAuditConfiguration;
    "usageData"?: model.UsageDataViaObjectStorageTupleDetails;
    /**
     * Indicates if an audit succeeded according to the configuration. The value is {@code null} if the audit is in the {@code CREATING} state.
     */
    "isSuccess"?: boolean;
    /**
     * The type of the build tool is restricted to only two values MAVEN or UNSET. Use UNSET when the list of application dependencies is not Maven-related or is a mix of Maven and other ecosystems. This option is soon to be deprecated.
     */
    "buildType": VulnerabilityAudit.BuildType;
    "source": model.UnknownSourceVulnerabilityAuditSource | model.OciResourceVulnerabilityAuditSource | model.ExternalResourceVulnerabilityAuditSource;
    /**
     * The compartment Oracle Cloud identifier ([OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm)) of the vulnerability audit.
     */
    "compartmentId": string;
    /**
     * Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
     * Example: {@code {\"bar-key\": \"value\"}}
     *
     */
    "freeformTags"?: {
        [key: string]: string;
    };
    /**
     * Defined tags for this resource. Each key is predefined and scoped to a namespace.
     * Example: {@code {\"foo-namespace\": {\"bar-key\": \"value\"}}}
     *
     */
    "definedTags"?: {
        [key: string]: {
            [key: string]: any;
        };
    };
    /**
     * Usage of system tag keys. These predefined keys are scoped to namespaces.
     * Example: {@code {\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}}
     *
     */
    "systemTags"?: {
        [key: string]: {
            [key: string]: any;
        };
    };
}
export declare namespace VulnerabilityAudit {
    enum LifecycleState {
        Active = "ACTIVE",
        Creating = "CREATING",
        Deleted = "DELETED",
        Deleting = "DELETING",
        Failed = "FAILED",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    enum LifecycleDetails {
        UsageDataNotFoundOrNotAuthorized = "USAGE_DATA_NOT_FOUND_OR_NOT_AUTHORIZED",
        UsageDataParseFailed = "USAGE_DATA_PARSE_FAILED",
        UsageDataCompressedSizeLimitExceeded = "USAGE_DATA_COMPRESSED_SIZE_LIMIT_EXCEEDED",
        UsageDataUncompressedSizeLimitExceeded = "USAGE_DATA_UNCOMPRESSED_SIZE_LIMIT_EXCEEDED",
        UsageDataUnknownError = "USAGE_DATA_UNKNOWN_ERROR",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    enum BuildType {
        Maven = "MAVEN",
        Unset = "UNSET",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    function getJsonObj(obj: VulnerabilityAudit): object;
    function getDeserializedJsonObj(obj: VulnerabilityAudit): object;
}
