/**
 * Scanning API
 * Use the Vulnerability Scanning Service (VSS) API to manage scan recipes, targets, and reports. For more information, see [the Vulnerability Scanning documentation](/iaas/scanning/home.htm).
 * OpenAPI spec version: 20210215
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import common = require("oci-common");
import * as requests from "./request";
import * as responses from "./response";
import { VulnerabilityScanningWaiter } from "./vulnerabilityscanning-waiter";
declare const Breaker: any;
export declare enum VulnerabilityScanningApiKeys {
}
/**
 * This service client uses {@link common.CircuitBreaker.DefaultConfiguration} for all the operations by default if no circuit breaker configuration is defined by the user.
 */
export declare class VulnerabilityScanningClient {
    protected static serviceEndpointTemplate: string;
    protected static endpointServiceName: string;
    protected "_realmSpecificEndpointTemplateEnabled": boolean | undefined;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_waiters": VulnerabilityScanningWaiter;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: typeof Breaker | null;
    protected _httpOptions: any;
    protected _bodyDuplexMode: any;
    targetService: string;
    protected _regionId: string;
    protected "_region": common.Region;
    protected _lastSetRegionOrRegionId: string;
    protected _httpClient: common.HttpClient;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    get endpoint(): string;
    /**
     * Sets the endpoint to call (ex, https://www.example.com).
     * @param endpoint The endpoint of the service.
     */
    set endpoint(endpoint: string);
    get logger(): import("oci-common/lib/log").Logger;
    /**
     * Determines whether realm specific endpoint should be used or not.
     * Set realmSpecificEndpointTemplateEnabled to "true" if the user wants to enable use of realm specific endpoint template, otherwise set it to "false"
     * @param realmSpecificEndpointTemplateEnabled flag to enable the use of realm specific endpoint template
     */
    set useRealmSpecificEndpointTemplate(realmSpecificEndpointTemplateEnabled: boolean);
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    set region(region: common.Region);
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    set regionId(regionId: string);
    /**
     * Creates a new VulnerabilityScanningWaiter for resources for this service.
     *
     * @param config The waiter configuration for termination and delay strategy
     * @return The service waiters.
     */
    createWaiters(config?: common.WaiterConfiguration): VulnerabilityScanningWaiter;
    /**
     * Gets the waiters available for resources for this service.
     *
     * @return The service waiters.
     */
    getWaiters(): VulnerabilityScanningWaiter;
    /**
     * Shutdown the circuit breaker used by the client when it is no longer needed
     */
    shutdownCircuitBreaker(): void;
    /**
     * Close the client once it is no longer needed
     */
    close(): void;
    /**
     * Moves a ContainerScanRecipe into a different compartment. When provided, If-Match is checked against ETag values of the resource.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangeContainerScanRecipeCompartmentRequest
     * @return ChangeContainerScanRecipeCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/vulnerabilityscanning/ChangeContainerScanRecipeCompartment.ts.html |here} to see how to use ChangeContainerScanRecipeCompartment API.
     */
    changeContainerScanRecipeCompartment(changeContainerScanRecipeCompartmentRequest: requests.ChangeContainerScanRecipeCompartmentRequest): Promise<responses.ChangeContainerScanRecipeCompartmentResponse>;
    /**
     * Moves a ContainerScanResult into a different compartment. When provided, If-Match is checked against ETag values of the resource.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangeContainerScanResultCompartmentRequest
     * @return ChangeContainerScanResultCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/vulnerabilityscanning/ChangeContainerScanResultCompartment.ts.html |here} to see how to use ChangeContainerScanResultCompartment API.
     */
    changeContainerScanResultCompartment(changeContainerScanResultCompartmentRequest: requests.ChangeContainerScanResultCompartmentRequest): Promise<responses.ChangeContainerScanResultCompartmentResponse>;
    /**
     * Moves a ContainerScanTarget into a different compartment. When provided, If-Match is checked against ETag values of the resource.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangeContainerScanTargetCompartmentRequest
     * @return ChangeContainerScanTargetCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/vulnerabilityscanning/ChangeContainerScanTargetCompartment.ts.html |here} to see how to use ChangeContainerScanTargetCompartment API.
     */
    changeContainerScanTargetCompartment(changeContainerScanTargetCompartmentRequest: requests.ChangeContainerScanTargetCompartmentRequest): Promise<responses.ChangeContainerScanTargetCompartmentResponse>;
    /**
     * Moves a HostAgentScanResult into a different compartment. When provided, If-Match is checked against ETag values of the resource.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangeHostAgentScanResultCompartmentRequest
     * @return ChangeHostAgentScanResultCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/vulnerabilityscanning/ChangeHostAgentScanResultCompartment.ts.html |here} to see how to use ChangeHostAgentScanResultCompartment API.
     */
    changeHostAgentScanResultCompartment(changeHostAgentScanResultCompartmentRequest: requests.ChangeHostAgentScanResultCompartmentRequest): Promise<responses.ChangeHostAgentScanResultCompartmentResponse>;
    /**
     * Moves a HostCisBenchmarkScanResult into a different compartment. When provided, If-Match is checked against ETag values of the resource.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangeHostCisBenchmarkScanResultCompartmentRequest
     * @return ChangeHostCisBenchmarkScanResultCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/vulnerabilityscanning/ChangeHostCisBenchmarkScanResultCompartment.ts.html |here} to see how to use ChangeHostCisBenchmarkScanResultCompartment API.
     */
    changeHostCisBenchmarkScanResultCompartment(changeHostCisBenchmarkScanResultCompartmentRequest: requests.ChangeHostCisBenchmarkScanResultCompartmentRequest): Promise<responses.ChangeHostCisBenchmarkScanResultCompartmentResponse>;
    /**
     * Moves a HostEndpointProtectionScanResult into a different compartment. When provided, If-Match is checked against ETag values of the resource.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangeHostEndpointProtectionScanResultCompartmentRequest
     * @return ChangeHostEndpointProtectionScanResultCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/vulnerabilityscanning/ChangeHostEndpointProtectionScanResultCompartment.ts.html |here} to see how to use ChangeHostEndpointProtectionScanResultCompartment API.
     */
    changeHostEndpointProtectionScanResultCompartment(changeHostEndpointProtectionScanResultCompartmentRequest: requests.ChangeHostEndpointProtectionScanResultCompartmentRequest): Promise<responses.ChangeHostEndpointProtectionScanResultCompartmentResponse>;
    /**
     * Moves a HostPortScanResult into a different compartment. When provided, If-Match is checked against ETag values of the resource.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangeHostPortScanResultCompartmentRequest
     * @return ChangeHostPortScanResultCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/vulnerabilityscanning/ChangeHostPortScanResultCompartment.ts.html |here} to see how to use ChangeHostPortScanResultCompartment API.
     */
    changeHostPortScanResultCompartment(changeHostPortScanResultCompartmentRequest: requests.ChangeHostPortScanResultCompartmentRequest): Promise<responses.ChangeHostPortScanResultCompartmentResponse>;
    /**
     * Moves a HostScanRecipe into a different compartment. When provided, If-Match is checked against ETag values of the resource.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangeHostScanRecipeCompartmentRequest
     * @return ChangeHostScanRecipeCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/vulnerabilityscanning/ChangeHostScanRecipeCompartment.ts.html |here} to see how to use ChangeHostScanRecipeCompartment API.
     */
    changeHostScanRecipeCompartment(changeHostScanRecipeCompartmentRequest: requests.ChangeHostScanRecipeCompartmentRequest): Promise<responses.ChangeHostScanRecipeCompartmentResponse>;
    /**
     * Moves a HostScanTarget into a different compartment. When provided, If-Match is checked against ETag values of the resource.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangeHostScanTargetCompartmentRequest
     * @return ChangeHostScanTargetCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/vulnerabilityscanning/ChangeHostScanTargetCompartment.ts.html |here} to see how to use ChangeHostScanTargetCompartment API.
     */
    changeHostScanTargetCompartment(changeHostScanTargetCompartmentRequest: requests.ChangeHostScanTargetCompartmentRequest): Promise<responses.ChangeHostScanTargetCompartmentResponse>;
    /**
     * Creates a new ContainerScanRecipe. A recipe determines the types of security issues that you want scanned.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateContainerScanRecipeRequest
     * @return CreateContainerScanRecipeResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/vulnerabilityscanning/CreateContainerScanRecipe.ts.html |here} to see how to use CreateContainerScanRecipe API.
     */
    createContainerScanRecipe(createContainerScanRecipeRequest: requests.CreateContainerScanRecipeRequest): Promise<responses.CreateContainerScanRecipeResponse>;
    /**
     * Creates a new ContainerScanTarget. A container scan target specifies a group of one or more Docker image repositories in Oracle Cloud Infrastructure Registry (OCIR) that you want routinely scanned for security vulnerabilities.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateContainerScanTargetRequest
     * @return CreateContainerScanTargetResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/vulnerabilityscanning/CreateContainerScanTarget.ts.html |here} to see how to use CreateContainerScanTarget API.
     */
    createContainerScanTarget(createContainerScanTargetRequest: requests.CreateContainerScanTargetRequest): Promise<responses.CreateContainerScanTargetResponse>;
    /**
     * Creates a new HostScanRecipe. A recipe determines the types of security issues that you want scanned, and how often to scan.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateHostScanRecipeRequest
     * @return CreateHostScanRecipeResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/vulnerabilityscanning/CreateHostScanRecipe.ts.html |here} to see how to use CreateHostScanRecipe API.
     */
    createHostScanRecipe(createHostScanRecipeRequest: requests.CreateHostScanRecipeRequest): Promise<responses.CreateHostScanRecipeResponse>;
    /**
     * Creates a new HostScanTarget. A host scan target is a collection of compute instances that you want routinely scanned for security vulnerabilities.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateHostScanTargetRequest
     * @return CreateHostScanTargetResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/vulnerabilityscanning/CreateHostScanTarget.ts.html |here} to see how to use CreateHostScanTarget API.
     */
    createHostScanTarget(createHostScanTargetRequest: requests.CreateHostScanTargetRequest): Promise<responses.CreateHostScanTargetResponse>;
    /**
     * Deletes the ContainerScanRecipe identified by the recipe ID.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteContainerScanRecipeRequest
     * @return DeleteContainerScanRecipeResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/vulnerabilityscanning/DeleteContainerScanRecipe.ts.html |here} to see how to use DeleteContainerScanRecipe API.
     */
    deleteContainerScanRecipe(deleteContainerScanRecipeRequest: requests.DeleteContainerScanRecipeRequest): Promise<responses.DeleteContainerScanRecipeResponse>;
    /**
     * Deletes the ContainerScanResult identified by the container scan ID.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteContainerScanResultRequest
     * @return DeleteContainerScanResultResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/vulnerabilityscanning/DeleteContainerScanResult.ts.html |here} to see how to use DeleteContainerScanResult API.
     */
    deleteContainerScanResult(deleteContainerScanResultRequest: requests.DeleteContainerScanResultRequest): Promise<responses.DeleteContainerScanResultResponse>;
    /**
     * Deletes the ContainerScanTarget identified by the target ID.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteContainerScanTargetRequest
     * @return DeleteContainerScanTargetResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/vulnerabilityscanning/DeleteContainerScanTarget.ts.html |here} to see how to use DeleteContainerScanTarget API.
     */
    deleteContainerScanTarget(deleteContainerScanTargetRequest: requests.DeleteContainerScanTargetRequest): Promise<responses.DeleteContainerScanTargetResponse>;
    /**
     * Deletes the HostAgentScanResult identified by the host agent scan ID.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteHostAgentScanResultRequest
     * @return DeleteHostAgentScanResultResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/vulnerabilityscanning/DeleteHostAgentScanResult.ts.html |here} to see how to use DeleteHostAgentScanResult API.
     */
    deleteHostAgentScanResult(deleteHostAgentScanResultRequest: requests.DeleteHostAgentScanResultRequest): Promise<responses.DeleteHostAgentScanResultResponse>;
    /**
     * Deletes the HostCisBenchmarkScanResult identified by the benchmark scan result ID.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteHostCisBenchmarkScanResultRequest
     * @return DeleteHostCisBenchmarkScanResultResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/vulnerabilityscanning/DeleteHostCisBenchmarkScanResult.ts.html |here} to see how to use DeleteHostCisBenchmarkScanResult API.
     */
    deleteHostCisBenchmarkScanResult(deleteHostCisBenchmarkScanResultRequest: requests.DeleteHostCisBenchmarkScanResultRequest): Promise<responses.DeleteHostCisBenchmarkScanResultResponse>;
    /**
     * Deletes the HostEndpointProtectionScanResult identified by the id
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteHostEndpointProtectionScanResultRequest
     * @return DeleteHostEndpointProtectionScanResultResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/vulnerabilityscanning/DeleteHostEndpointProtectionScanResult.ts.html |here} to see how to use DeleteHostEndpointProtectionScanResult API.
     */
    deleteHostEndpointProtectionScanResult(deleteHostEndpointProtectionScanResultRequest: requests.DeleteHostEndpointProtectionScanResultRequest): Promise<responses.DeleteHostEndpointProtectionScanResultResponse>;
    /**
     * Deletes the HostPortScanResult identified by the host port scan ID.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteHostPortScanResultRequest
     * @return DeleteHostPortScanResultResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/vulnerabilityscanning/DeleteHostPortScanResult.ts.html |here} to see how to use DeleteHostPortScanResult API.
     */
    deleteHostPortScanResult(deleteHostPortScanResultRequest: requests.DeleteHostPortScanResultRequest): Promise<responses.DeleteHostPortScanResultResponse>;
    /**
     * Deletes the HostScanRecipe identified by the recipe ID.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteHostScanRecipeRequest
     * @return DeleteHostScanRecipeResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/vulnerabilityscanning/DeleteHostScanRecipe.ts.html |here} to see how to use DeleteHostScanRecipe API.
     */
    deleteHostScanRecipe(deleteHostScanRecipeRequest: requests.DeleteHostScanRecipeRequest): Promise<responses.DeleteHostScanRecipeResponse>;
    /**
     * Deletes the HostScanTarget identified by the target ID.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteHostScanTargetRequest
     * @return DeleteHostScanTargetResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/vulnerabilityscanning/DeleteHostScanTarget.ts.html |here} to see how to use DeleteHostScanTarget API.
     */
    deleteHostScanTarget(deleteHostScanTargetRequest: requests.DeleteHostScanTargetRequest): Promise<responses.DeleteHostScanTargetResponse>;
    /**
     * Exports a list of HostAgentScanResultSummary objects within a compartment and during a specified time range in CSV format. You can filter the results by problem severity.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ExportHostAgentScanResultCsvRequest
     * @return ExportHostAgentScanResultCsvResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/vulnerabilityscanning/ExportHostAgentScanResultCsv.ts.html |here} to see how to use ExportHostAgentScanResultCsv API.
     */
    exportHostAgentScanResultCsv(exportHostAgentScanResultCsvRequest: requests.ExportHostAgentScanResultCsvRequest): Promise<responses.ExportHostAgentScanResultCsvResponse>;
    /**
     * Exports a list of HostVulnerabilitySummary objects in a compartment in CSV format.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ExportHostVulnerabilityCsvRequest
     * @return ExportHostVulnerabilityCsvResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/vulnerabilityscanning/ExportHostVulnerabilityCsv.ts.html |here} to see how to use ExportHostVulnerabilityCsv API.
     */
    exportHostVulnerabilityCsv(exportHostVulnerabilityCsvRequest: requests.ExportHostVulnerabilityCsvRequest): Promise<responses.ExportHostVulnerabilityCsvResponse>;
    /**
     * Retrieves a ContainerScanRecipe identified by the recipe ID. A recipe determines the types of security issues that you want scanned.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetContainerScanRecipeRequest
     * @return GetContainerScanRecipeResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/vulnerabilityscanning/GetContainerScanRecipe.ts.html |here} to see how to use GetContainerScanRecipe API.
     */
    getContainerScanRecipe(getContainerScanRecipeRequest: requests.GetContainerScanRecipeRequest): Promise<responses.GetContainerScanRecipeResponse>;
    /**
     * Retrieves a ContainerScanResult identified by the container scan ID. The result includes a list of problems found in a specific image in a Docker repository.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetContainerScanResultRequest
     * @return GetContainerScanResultResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/vulnerabilityscanning/GetContainerScanResult.ts.html |here} to see how to use GetContainerScanResult API.
     */
    getContainerScanResult(getContainerScanResultRequest: requests.GetContainerScanResultRequest): Promise<responses.GetContainerScanResultResponse>;
    /**
     * Gets a ContainerScanTarget identified by the target ID. A container scan target specifies a group of one or more Docker image repositories in Oracle Cloud Infrastructure Registry (OCIR) that you want routinely scanned for security vulnerabilities.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetContainerScanTargetRequest
     * @return GetContainerScanTargetResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/vulnerabilityscanning/GetContainerScanTarget.ts.html |here} to see how to use GetContainerScanTarget API.
     */
    getContainerScanTarget(getContainerScanTargetRequest: requests.GetContainerScanTargetRequest): Promise<responses.GetContainerScanTargetResponse>;
    /**
     * Retrieves a HostAgentScanResult identified by the host agent scan ID. The result includes a list of CVEs detected in a specific compute instance.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetHostAgentScanResultRequest
     * @return GetHostAgentScanResultResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/vulnerabilityscanning/GetHostAgentScanResult.ts.html |here} to see how to use GetHostAgentScanResult API.
     */
    getHostAgentScanResult(getHostAgentScanResultRequest: requests.GetHostAgentScanResultRequest): Promise<responses.GetHostAgentScanResultResponse>;
    /**
     * Retrieves a HostCisBenchmarkScanResult identified by the benchmark scan result ID. A CIS (Center for Internet Security) benchmark scan result includes a list of benchmarks that were tested on a specific compute instance, and whether each test passed or failed.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetHostCisBenchmarkScanResultRequest
     * @return GetHostCisBenchmarkScanResultResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/vulnerabilityscanning/GetHostCisBenchmarkScanResult.ts.html |here} to see how to use GetHostCisBenchmarkScanResult API.
     */
    getHostCisBenchmarkScanResult(getHostCisBenchmarkScanResultRequest: requests.GetHostCisBenchmarkScanResultRequest): Promise<responses.GetHostCisBenchmarkScanResultResponse>;
    /**
     * Returns HostEndpointProtectionScanResults for the given host endpoint protection scan result ID.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetHostEndpointProtectionScanResultRequest
     * @return GetHostEndpointProtectionScanResultResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/vulnerabilityscanning/GetHostEndpointProtectionScanResult.ts.html |here} to see how to use GetHostEndpointProtectionScanResult API.
     */
    getHostEndpointProtectionScanResult(getHostEndpointProtectionScanResultRequest: requests.GetHostEndpointProtectionScanResultRequest): Promise<responses.GetHostEndpointProtectionScanResultResponse>;
    /**
     * Retrieves a HostPortScanResult identified by the host port scan ID. The result includes a list of open ports that were detected in a specific compute instance.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetHostPortScanResultRequest
     * @return GetHostPortScanResultResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/vulnerabilityscanning/GetHostPortScanResult.ts.html |here} to see how to use GetHostPortScanResult API.
     */
    getHostPortScanResult(getHostPortScanResultRequest: requests.GetHostPortScanResultRequest): Promise<responses.GetHostPortScanResultResponse>;
    /**
     * Retrieves a HostScanRecipe identified by the recipe ID. A recipe determines the types of security issues that you want scanned, and how often to scan.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetHostScanRecipeRequest
     * @return GetHostScanRecipeResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/vulnerabilityscanning/GetHostScanRecipe.ts.html |here} to see how to use GetHostScanRecipe API.
     */
    getHostScanRecipe(getHostScanRecipeRequest: requests.GetHostScanRecipeRequest): Promise<responses.GetHostScanRecipeResponse>;
    /**
     * Retrieves a HostScanTarget identified by the target ID. A host scan target is a collection of compute instances that you want routinely scanned for security vulnerabilities.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetHostScanTargetRequest
     * @return GetHostScanTargetResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/vulnerabilityscanning/GetHostScanTarget.ts.html |here} to see how to use GetHostScanTarget API.
     */
    getHostScanTarget(getHostScanTargetRequest: requests.GetHostScanTargetRequest): Promise<responses.GetHostScanTargetResponse>;
    /**
     * Retrieves a HostVulnerability identified by the host vulnerability ID. A host vulnerability describes a security issue that was detected in scans of one or more compute instances. Common Vulnerabilities and Exposures (CVE) numbers identify security vulnerabilities for operating systems and other software, including Critical Patch Updates and Security Alert advisories.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetHostVulnerabilityRequest
     * @return GetHostVulnerabilityResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/vulnerabilityscanning/GetHostVulnerability.ts.html |here} to see how to use GetHostVulnerability API.
     */
    getHostVulnerability(getHostVulnerabilityRequest: requests.GetHostVulnerabilityRequest): Promise<responses.GetHostVulnerabilityResponse>;
    /**
     * Retrieves a Vulnerability identified by the vulnerability ID. A vulnerability describes a security issue that was detected in scans of one or more compute instances, container scan repositories. Common Vulnerabilities and Exposures (CVE) numbers identify security vulnerabilities for operating systems and other software, including Critical Patch Updates and Security Alert advisories.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetVulnerabilityRequest
     * @return GetVulnerabilityResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/vulnerabilityscanning/GetVulnerability.ts.html |here} to see how to use GetVulnerability API.
     */
    getVulnerability(getVulnerabilityRequest: requests.GetVulnerabilityRequest): Promise<responses.GetVulnerabilityResponse>;
    /**
     * Gets the status of the work request with the given ID.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetWorkRequestRequest
     * @return GetWorkRequestResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/vulnerabilityscanning/GetWorkRequest.ts.html |here} to see how to use GetWorkRequest API.
     */
    getWorkRequest(getWorkRequestRequest: requests.GetWorkRequestRequest): Promise<responses.GetWorkRequestResponse>;
    /**
     * Retrieves a list of ContainerScanRecipeSummary objects in a compartment. A recipe determines the types of security issues that you want scanned.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListContainerScanRecipesRequest
     * @return ListContainerScanRecipesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/vulnerabilityscanning/ListContainerScanRecipes.ts.html |here} to see how to use ListContainerScanRecipes API.
     */
    listContainerScanRecipes(listContainerScanRecipesRequest: requests.ListContainerScanRecipesRequest): Promise<responses.ListContainerScanRecipesResponse>;
    /**
     * Retrieves a list of ContainerScanResultSummary objects in a compartment. You can filter and sort the results by problem severity and time. A container scan result includes a list of problems detected in a specific image in a Docker repository.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListContainerScanResultsRequest
     * @return ListContainerScanResultsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/vulnerabilityscanning/ListContainerScanResults.ts.html |here} to see how to use ListContainerScanResults API.
     */
    listContainerScanResults(listContainerScanResultsRequest: requests.ListContainerScanResultsRequest): Promise<responses.ListContainerScanResultsResponse>;
    /**
     * Retrieves a list of ContainerScanTargetSummary objects in a compartment. A container scan target specifies a group of one or more Docker image repositories in Oracle Cloud Infrastructure Registry (OCIR) that you want routinely scanned for security vulnerabilities.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListContainerScanTargetsRequest
     * @return ListContainerScanTargetsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/vulnerabilityscanning/ListContainerScanTargets.ts.html |here} to see how to use ListContainerScanTargets API.
     */
    listContainerScanTargets(listContainerScanTargetsRequest: requests.ListContainerScanTargetsRequest): Promise<responses.ListContainerScanTargetsResponse>;
    /**
     * Retrieves a list of HostAgentScanResultSummary objects in a compartment. You can filter and sort the results by problem severity and time. An agent scan result includes a list of CVEs detected in a specific compute instance.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListHostAgentScanResultsRequest
     * @return ListHostAgentScanResultsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/vulnerabilityscanning/ListHostAgentScanResults.ts.html |here} to see how to use ListHostAgentScanResults API.
     */
    listHostAgentScanResults(listHostAgentScanResultsRequest: requests.ListHostAgentScanResultsRequest): Promise<responses.ListHostAgentScanResultsResponse>;
    /**
     * Retrieves a list of HostCisBenchmarkScanResultSummary objects in a compartment. You can filter and sort the results by problem severity and time. A CIS (Center for Internet Security) benchmark scan result includes the number of failed benchmark tests on a specific compute instance.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListHostCisBenchmarkScanResultsRequest
     * @return ListHostCisBenchmarkScanResultsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/vulnerabilityscanning/ListHostCisBenchmarkScanResults.ts.html |here} to see how to use ListHostCisBenchmarkScanResults API.
     */
    listHostCisBenchmarkScanResults(listHostCisBenchmarkScanResultsRequest: requests.ListHostCisBenchmarkScanResultsRequest): Promise<responses.ListHostCisBenchmarkScanResultsResponse>;
    /**
     * Returns a collection of HostEndpointProtectionScanResultSummary objects
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListHostEndpointProtectionScanResultsRequest
     * @return ListHostEndpointProtectionScanResultsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/vulnerabilityscanning/ListHostEndpointProtectionScanResults.ts.html |here} to see how to use ListHostEndpointProtectionScanResults API.
     */
    listHostEndpointProtectionScanResults(listHostEndpointProtectionScanResultsRequest: requests.ListHostEndpointProtectionScanResultsRequest): Promise<responses.ListHostEndpointProtectionScanResultsResponse>;
    /**
     * Retrieves a list of HostPortScanResultSummary objects in a compartment. You can filter and sort the results by problem severity and time. A port scan result includes a list of open ports that were detected in a specific compute instance.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListHostPortScanResultsRequest
     * @return ListHostPortScanResultsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/vulnerabilityscanning/ListHostPortScanResults.ts.html |here} to see how to use ListHostPortScanResults API.
     */
    listHostPortScanResults(listHostPortScanResultsRequest: requests.ListHostPortScanResultsRequest): Promise<responses.ListHostPortScanResultsResponse>;
    /**
     * Retrieves a list of HostScanRecipeSummary objects in a compartment. A recipe determines the types of security issues that you want scanned, and how often to scan.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListHostScanRecipesRequest
     * @return ListHostScanRecipesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/vulnerabilityscanning/ListHostScanRecipes.ts.html |here} to see how to use ListHostScanRecipes API.
     */
    listHostScanRecipes(listHostScanRecipesRequest: requests.ListHostScanRecipesRequest): Promise<responses.ListHostScanRecipesResponse>;
    /**
     * Retrieves list of errors during scanning on instances associated with HostScanTarget identified by the target ID. A host scan target is a collection of compute instances that you want routinely scanned for security vulnerabilities.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListHostScanTargetErrorsRequest
     * @return ListHostScanTargetErrorsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/vulnerabilityscanning/ListHostScanTargetErrors.ts.html |here} to see how to use ListHostScanTargetErrors API.
     */
    listHostScanTargetErrors(listHostScanTargetErrorsRequest: requests.ListHostScanTargetErrorsRequest): Promise<responses.ListHostScanTargetErrorsResponse>;
    /**
     * Retrieves a list of HostScanTargetSummary objects in a compartment. A host scan target is a collection of compute instances that you want routinely scanned for security vulnerabilities.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListHostScanTargetsRequest
     * @return ListHostScanTargetsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/vulnerabilityscanning/ListHostScanTargets.ts.html |here} to see how to use ListHostScanTargets API.
     */
    listHostScanTargets(listHostScanTargetsRequest: requests.ListHostScanTargetsRequest): Promise<responses.ListHostScanTargetsResponse>;
    /**
     * Retrieves a list of HostVulnerabilitySummary objects in a compartment. You can filter and sort the vulnerabilities by problem severity and time. A host vulnerability describes a security issue that was detected in scans of one or more compute instances.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListHostVulnerabilitiesRequest
     * @return ListHostVulnerabilitiesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/vulnerabilityscanning/ListHostVulnerabilities.ts.html |here} to see how to use ListHostVulnerabilities API.
     */
    listHostVulnerabilities(listHostVulnerabilitiesRequest: requests.ListHostVulnerabilitiesRequest): Promise<responses.ListHostVulnerabilitiesResponse>;
    /**
     * Retrieves a list of HostVulnerabilityImpactedHostSummary objects for a specific host vulnerability ID. An impacted host summary identifies a compute instance on which the specified vulnerability was detected.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListHostVulnerabilityImpactedHostsRequest
     * @return ListHostVulnerabilityImpactedHostsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/vulnerabilityscanning/ListHostVulnerabilityImpactedHosts.ts.html |here} to see how to use ListHostVulnerabilityImpactedHosts API.
     */
    listHostVulnerabilityImpactedHosts(listHostVulnerabilityImpactedHostsRequest: requests.ListHostVulnerabilityImpactedHostsRequest): Promise<responses.ListHostVulnerabilityImpactedHostsResponse>;
    /**
     * Retrieves a list of VulnerabilitySummary objects in a compartment. You can filter and sort the vulnerabilities by problem severity and time and type. A vulnerability describes a security issue that was detected in scans of one or more compute instances, container images.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListVulnerabilitiesRequest
     * @return ListVulnerabilitiesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/vulnerabilityscanning/ListVulnerabilities.ts.html |here} to see how to use ListVulnerabilities API.
     */
    listVulnerabilities(listVulnerabilitiesRequest: requests.ListVulnerabilitiesRequest): Promise<responses.ListVulnerabilitiesResponse>;
    /**
     * Retrieves a list of VulnerabilityImpactedContainerSummary objects for a specific vulnerability ID. An impacted container image summary identifies container images on which the specified vulnerability was detected.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListVulnerabilityImpactedContainersRequest
     * @return ListVulnerabilityImpactedContainersResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/vulnerabilityscanning/ListVulnerabilityImpactedContainers.ts.html |here} to see how to use ListVulnerabilityImpactedContainers API.
     */
    listVulnerabilityImpactedContainers(listVulnerabilityImpactedContainersRequest: requests.ListVulnerabilityImpactedContainersRequest): Promise<responses.ListVulnerabilityImpactedContainersResponse>;
    /**
     * Retrieves a list of VulnerabilityImpactedHostSummary objects for a specific host vulnerability ID. An impacted host summary identifies a compute instance on which the specified vulnerability was detected.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListVulnerabilityImpactedHostsRequest
     * @return ListVulnerabilityImpactedHostsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/vulnerabilityscanning/ListVulnerabilityImpactedHosts.ts.html |here} to see how to use ListVulnerabilityImpactedHosts API.
     */
    listVulnerabilityImpactedHosts(listVulnerabilityImpactedHostsRequest: requests.ListVulnerabilityImpactedHostsRequest): Promise<responses.ListVulnerabilityImpactedHostsResponse>;
    /**
     * Return a (paginated) list of errors for a given work request.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListWorkRequestErrorsRequest
     * @return ListWorkRequestErrorsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/vulnerabilityscanning/ListWorkRequestErrors.ts.html |here} to see how to use ListWorkRequestErrors API.
     */
    listWorkRequestErrors(listWorkRequestErrorsRequest: requests.ListWorkRequestErrorsRequest): Promise<responses.ListWorkRequestErrorsResponse>;
    /**
     * Return a (paginated) list of logs for a given work request.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListWorkRequestLogsRequest
     * @return ListWorkRequestLogsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/vulnerabilityscanning/ListWorkRequestLogs.ts.html |here} to see how to use ListWorkRequestLogs API.
     */
    listWorkRequestLogs(listWorkRequestLogsRequest: requests.ListWorkRequestLogsRequest): Promise<responses.ListWorkRequestLogsResponse>;
    /**
     * Lists the work requests in a compartment.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListWorkRequestsRequest
     * @return ListWorkRequestsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/vulnerabilityscanning/ListWorkRequests.ts.html |here} to see how to use ListWorkRequests API.
     */
    listWorkRequests(listWorkRequestsRequest: requests.ListWorkRequestsRequest): Promise<responses.ListWorkRequestsResponse>;
    /**
     * Updates the ContainerScanRecipe identified by the recipe ID. A recipe determines the types of security issues that you want scanned.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateContainerScanRecipeRequest
     * @return UpdateContainerScanRecipeResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/vulnerabilityscanning/UpdateContainerScanRecipe.ts.html |here} to see how to use UpdateContainerScanRecipe API.
     */
    updateContainerScanRecipe(updateContainerScanRecipeRequest: requests.UpdateContainerScanRecipeRequest): Promise<responses.UpdateContainerScanRecipeResponse>;
    /**
     * Updates the ContainerScanTarget identified by the target ID. A container scan target specifies a group of one or more Docker image repositories in Oracle Cloud Infrastructure Registry (OCIR) that you want routinely scanned for security vulnerabilities.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateContainerScanTargetRequest
     * @return UpdateContainerScanTargetResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/vulnerabilityscanning/UpdateContainerScanTarget.ts.html |here} to see how to use UpdateContainerScanTarget API.
     */
    updateContainerScanTarget(updateContainerScanTargetRequest: requests.UpdateContainerScanTargetRequest): Promise<responses.UpdateContainerScanTargetResponse>;
    /**
     * Updates the HostScanRecipe identified by the recipe ID. A recipe determines the types of security issues that you want scanned, and how often to scan.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateHostScanRecipeRequest
     * @return UpdateHostScanRecipeResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/vulnerabilityscanning/UpdateHostScanRecipe.ts.html |here} to see how to use UpdateHostScanRecipe API.
     */
    updateHostScanRecipe(updateHostScanRecipeRequest: requests.UpdateHostScanRecipeRequest): Promise<responses.UpdateHostScanRecipeResponse>;
    /**
     * Updates the HostScanTarget identified by the target ID. A host scan target is a collection of compute instances that you want routinely scanned for security vulnerabilities.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateHostScanTargetRequest
     * @return UpdateHostScanTargetResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.89.2/vulnerabilityscanning/UpdateHostScanTarget.ts.html |here} to see how to use UpdateHostScanTarget API.
     */
    updateHostScanTarget(updateHostScanTargetRequest: requests.UpdateHostScanTargetRequest): Promise<responses.UpdateHostScanTargetResponse>;
}
export {};
