/**
 * Scanning API
 * Use the Vulnerability Scanning Service (VSS) API to manage scan recipes, targets, and reports. For more information, see [the Vulnerability Scanning documentation](/iaas/scanning/home.htm).
 * OpenAPI spec version: 20210215
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * A scan result for a container scan
 */
export interface ContainerScanResult {
    /**
     * The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of container scan result. Immutable and generated on creation.
     */
    "id": string;
    /**
     * The URL of the docker registry the repository is located in.
     */
    "registryUrl"?: string;
    /**
     * Repository in which the container image scanned is located
     */
    "repository": string;
    /**
     * Image name
     */
    "image": string;
    /**
     * The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the container scan result's compartment. This is set to the same as the compartmentId of the container scan target
     */
    "compartmentId": string;
    /**
     * The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment to where scan was performed.
     */
    "targetCompartmentId"?: string;
    /**
     * The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of container scan target.
     */
    "containerScanTargetId"?: string;
    /**
     * Highest problem severity in this report
     */
    "highestProblemSeverity": model.ScanResultProblemSeverity;
    /**
     * Total number of problems found in this scan Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "problemCount"?: number;
    /**
     * Date and time the scan was started, as described in [RFC 3339](https://tools.ietf.org/rfc/rfc3339)
     */
    "timeStarted": Date;
    /**
     * Date and time the scan was completed, as described in [RFC 3339](https://tools.ietf.org/rfc/rfc3339)
     */
    "timeFinished": Date;
    /**
     * List of problems found in this scan
     */
    "problems": Array<model.ContainerScanResultProblem>;
}
export declare namespace ContainerScanResult {
    function getJsonObj(obj: ContainerScanResult): object;
    function getDeserializedJsonObj(obj: ContainerScanResult): object;
}
